@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -48,7 +48,6 @@ import org.eclipse.core.filebuffers.ITextFileBuffer;
 
 import org.eclipse.jface.action.Action;
 import org.eclipse.jface.action.IAction;
-import org.eclipse.jface.action.IMenuListener;
 import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.action.MenuManager;
@@ -130,60 +129,27 @@ import org.eclipse.jdt.core.dom.Statement;
 import org.eclipse.jdt.core.dom.SwitchExpression;
 import org.eclipse.jdt.core.dom.YieldStatement;
 import org.eclipse.jdt.core.manipulation.SharedASTProviderCore;
+
 import org.eclipse.jdt.ui.JavaUI;
 
+import org.eclipse.jdt.internal.ui.util.ASTHelper;
+
 
 public class ASTView extends ViewPart implements IShowInSource, IShowInTargetList {
 
-	static final int JLS_LATEST= AST.JLS13;
-
-	private static final int JLS13= AST.JLS13;
-
-	/**
-	 * @deprecated to get rid of deprecation warnings in code
-	 */
-	@Deprecated
-	private static final int JLS12= AST.JLS12;
-
-	/**
-	 * @deprecated to get rid of deprecation warnings in code
-	 */
-	@Deprecated
-	private static final int JLS11= AST.JLS11;
-
-	/**
-	 * @deprecated to get rid of deprecation warnings in code
-	 */
-	@Deprecated
-	private static final int JLS10= AST.JLS10;
-
-	/**
-	 * @deprecated to get rid of deprecation warnings in code
-	 */
-	@Deprecated
-	private static final int JLS9= AST.JLS9;
-
-	/**
-	 * @deprecated to get rid of deprecation warnings in code
-	 */
-	@Deprecated
-	private static final int JLS8= AST.JLS8;
-
-	/**
-	 * @deprecated to get rid of deprecation warnings in code
-	 */
-	@Deprecated
-	private static final int JLS4= AST.JLS4;
-	/**
-	 * @deprecated to get rid of deprecation warnings in code
-	 */
-	@Deprecated
-	private static final int JLS3= AST.JLS3;
-	/**
-	 * @deprecated to get rid of deprecation warnings in code
-	 */
-	@Deprecated
-	private static final int JLS2= AST.JLS2;
+	static final int JLS_LATEST= AST.getJLSLatest();
+	private static final int JLS16= ASTHelper.JLS16;
+	private static final int JLS15= ASTHelper.JLS15;
+	private static final int JLS14= ASTHelper.JLS14;
+	private static final int JLS13= ASTHelper.JLS13;
+	private static final int JLS12= ASTHelper.JLS12;
+	private static final int JLS11= ASTHelper.JLS11;
+	private static final int JLS10= ASTHelper.JLS10;
+	private static final int JLS9= ASTHelper.JLS9;
+	private static final int JLS8= ASTHelper.JLS8;
+	private static final int JLS4= ASTHelper.JLS4;
+	private static final int JLS3= ASTHelper.JLS3;
+	private static final int JLS2= ASTHelper.JLS2;
 
 	private class ASTViewSelectionProvider implements ISelectionProvider {
 		ListenerList<ISelectionChangedListener> fListeners= new ListenerList<>(ListenerList.IDENTITY);
@@ -540,6 +506,9 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 				case JLS11:
 				case JLS12:
 				case JLS13:
+				case JLS14:
+				case JLS15:
+				case JLS16:
 					fCurrentASTLevel= level;
 			}
 		} catch (NumberFormatException e) {
@@ -747,16 +716,16 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 	}
 
 	private void updateContentDescription(IJavaElement element, CompilationUnit root, long time) {
-		String version= "AST Level " + root.getAST().apiLevel();
+		StringBuilder version= new StringBuilder("AST Level ").append(root.getAST().apiLevel());
 		switch (getCurrentInputKind()) {
 		case ASTInputKindAction.USE_RECONCILE:
-			version+= ", from reconciler"; //$NON-NLS-1$
+			version.append(", from reconciler"); //$NON-NLS-1$
 			break;
 		case ASTInputKindAction.USE_CACHE:
-			version+= ", from ASTProvider"; //$NON-NLS-1$
+			version.append(", from ASTProvider"); //$NON-NLS-1$
 			break;
 		case ASTInputKindAction.USE_FOCAL:
-			version+= ", using focal position"; //$NON-NLS-1$
+			version.append(", using focal position"); //$NON-NLS-1$
 			break;
 		default:
 			break;
@@ -764,7 +733,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		TreeInfoCollector collector= new TreeInfoCollector(root);
 
 		String msg= "{0} ({1}).  Creation time: {2,number} ms.  Size: {3,number} nodes, {4,number} bytes (AST nodes only)."; //$NON-NLS-1$
-		Object[] args= { element.getElementName(), version, Long.valueOf(time),  Integer.valueOf(collector.getNumberOfNodes()), Integer.valueOf(collector.getSize())};
+		Object[] args= { element.getElementName(), version.toString(), Long.valueOf(time),  Integer.valueOf(collector.getNumberOfNodes()), Integer.valueOf(collector.getSize())};
 		setContentDescription(MessageFormat.format(msg, args));
 
 	}
@@ -828,34 +797,23 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 		final TrayLabelProvider trayLabelProvider= new TrayLabelProvider();
 		fTray.setLabelProvider(trayLabelProvider);
 		fTray.setAutoExpandLevel(AbstractTreeViewer.ALL_LEVELS);
-		fTrayUpdater= new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				IStructuredSelection viewerSelection= (IStructuredSelection) fViewer.getSelection();
-				if (viewerSelection.size() == 1) {
-					Object first= viewerSelection.getFirstElement();
-					if (unwrapAttribute(first) != null) {
-						trayLabelProvider.setViewerElement(first);
-						return;
-					}
+		fTrayUpdater= event -> {
+			IStructuredSelection viewerSelection= (IStructuredSelection) fViewer.getSelection();
+			if (viewerSelection.size() == 1) {
+				Object first= viewerSelection.getFirstElement();
+				if (unwrapAttribute(first) != null) {
+					trayLabelProvider.setViewerElement(first);
+					return;
 				}
-				trayLabelProvider.setViewerElement(null);
 			}
+			trayLabelProvider.setViewerElement(null);
 		};
 		fTray.addPostSelectionChangedListener(fTrayUpdater);
 		fViewer.addPostSelectionChangedListener(fTrayUpdater);
-		fTray.addDoubleClickListener(new IDoubleClickListener() {
-			@Override
-			public void doubleClick(DoubleClickEvent event) {
-				performTrayDoubleClick();
-			}
-		});
-		fTray.addSelectionChangedListener(new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				IStructuredSelection selection= (IStructuredSelection) event.getSelection();
-				fDeleteAction.setEnabled(selection.size() >= 1 && fTray.getTree().isFocusControl());
-			}
+		fTray.addDoubleClickListener(event -> performTrayDoubleClick());
+		fTray.addSelectionChangedListener(event -> {
+			IStructuredSelection selection= (IStructuredSelection) event.getSelection();
+			fDeleteAction.setEnabled(selection.size() >= 1 && fTray.getTree().isFocusControl());
 		});
 		fTray.getTree().addFocusListener(new FocusAdapter() {
 			@Override
@@ -894,12 +852,7 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 	private void hookContextMenu() {
 		MenuManager menuMgr = new MenuManager("#PopupMenu"); //$NON-NLS-1$
 		menuMgr.setRemoveAllWhenShown(true);
-		menuMgr.addMenuListener(new IMenuListener() {
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				ASTView.this.fillContextMenu(manager);
-			}
-		});
+		menuMgr.addMenuListener(this::fillContextMenu);
 		Menu menu = menuMgr.createContextMenu(fViewer.getControl());
 		fViewer.getControl().setMenu(menu);
 		getSite().registerContextMenu(menuMgr, fViewer);
@@ -908,14 +861,11 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 	private void hookTrayContextMenu() {
 		MenuManager menuMgr = new MenuManager("#TrayPopupMenu"); //$NON-NLS-1$
 		menuMgr.setRemoveAllWhenShown(true);
-		menuMgr.addMenuListener(new IMenuListener() {
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				manager.add(fCopyAction);
-				manager.add(fDeleteAction);
-				manager.add(new Separator());
-				manager.add(new Separator(IWorkbenchActionConstants.MB_ADDITIONS));
-			}
+		menuMgr.addMenuListener(manager -> {
+			manager.add(fCopyAction);
+			manager.add(fDeleteAction);
+			manager.add(new Separator());
+			manager.add(new Separator(IWorkbenchActionConstants.MB_ADDITIONS));
 		});
 		Menu menu = menuMgr.createContextMenu(fTray.getControl());
 		fTray.getControl().setMenu(menu);
@@ -1178,6 +1128,9 @@ public class ASTView extends ViewPart implements IShowInSource, IShowInTargetLis
 				new ASTLevelToggle("AST Level 1&1 (11)", JLS11), //$NON-NLS-1$
 				new ASTLevelToggle("AST Level 1&2 (12)", JLS12), //$NON-NLS-1$
 				new ASTLevelToggle("AST Level 1&3 (13)", JLS13), //$NON-NLS-1$
+				new ASTLevelToggle("AST Level 1&4 (14)", JLS14), //$NON-NLS-1$
+				new ASTLevelToggle("AST Level 1&5 (15)", JLS15), //$NON-NLS-1$
+				new ASTLevelToggle("AST Level 1&6 (16)", JLS16), //$NON-NLS-1$
 		};
 
 		fAddToTrayAction= new Action() {
