@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -39,6 +39,8 @@ import org.eclipse.core.resources.ProjectScope;
 import org.eclipse.text.edits.DeleteEdit;
 import org.eclipse.text.edits.MalformedTreeException;
 import org.eclipse.text.edits.MultiTextEdit;
+import org.eclipse.text.templates.TemplatePersistenceData;
+import org.eclipse.text.templates.TemplateStoreCore;
 
 import org.eclipse.jface.text.BadLocationException;
 import org.eclipse.jface.text.Document;
@@ -47,8 +49,6 @@ import org.eclipse.jface.text.IRegion;
 import org.eclipse.jface.text.templates.Template;
 import org.eclipse.jface.text.templates.TemplateBuffer;
 import org.eclipse.jface.text.templates.TemplateException;
-import org.eclipse.text.templates.TemplatePersistenceData;
-import org.eclipse.text.templates.TemplateStoreCore;
 import org.eclipse.jface.text.templates.TemplateVariable;
 
 import org.eclipse.jdt.core.Flags;
@@ -69,7 +69,6 @@ import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.NamingConventions;
 import org.eclipse.jdt.core.Signature;
-import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.ASTNode;
 import org.eclipse.jdt.core.dom.ASTParser;
 import org.eclipse.jdt.core.dom.AbstractTypeDeclaration;
@@ -102,13 +101,14 @@ import org.eclipse.jdt.core.manipulation.CodeGeneration;
 import org.eclipse.jdt.core.manipulation.CodeStyleConfiguration;
 import org.eclipse.jdt.core.manipulation.JavaManipulation;
 
-import org.eclipse.jdt.internal.corext.dom.ASTNodes;
-import org.eclipse.jdt.internal.corext.dom.Bindings;
 import org.eclipse.jdt.internal.core.manipulation.dom.ASTResolving;
 import org.eclipse.jdt.internal.core.manipulation.util.Strings;
-
+import org.eclipse.jdt.internal.corext.dom.ASTNodes;
+import org.eclipse.jdt.internal.corext.dom.Bindings;
 import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
 
+import org.eclipse.jdt.internal.ui.util.ASTHelper;
+
 /**
  * Implementations for {@link CodeGeneration} APIs, and other helper methods
  * to create source code stubs based on {@link IJavaElement}s.
@@ -127,6 +127,7 @@ public class StubUtility {
 		VALID_TYPE_BODY_TEMPLATES.add(CodeTemplateContextType.INTERFACEBODY_ID);
 		VALID_TYPE_BODY_TEMPLATES.add(CodeTemplateContextType.ENUMBODY_ID);
 		VALID_TYPE_BODY_TEMPLATES.add(CodeTemplateContextType.ANNOTATIONBODY_ID);
+		VALID_TYPE_BODY_TEMPLATES.add(CodeTemplateContextType.RECORDBODY_ID);
 	}
 
 	//COPIED from org.eclipse.jdt.ui.PreferenceConstants
@@ -275,7 +276,7 @@ public class StubUtility {
 	 * Don't use this method directly, use CodeGeneration.
 	 * @see CodeGeneration#getTypeComment(ICompilationUnit, String, String[], String)
 	 */
-	public static String getTypeComment(ICompilationUnit cu, String typeQualifiedName, String[] typeParameterNames, String lineDelim) throws CoreException {
+	public static String getTypeComment(ICompilationUnit cu, String typeQualifiedName, String[] typeParameterNames, String[] params, String lineDelim) throws CoreException {
 		Template template= getCodeTemplate(CodeTemplateContextType.TYPECOMMENT_ID, cu.getJavaProject());
 		if (template == null) {
 			return null;
@@ -288,9 +289,7 @@ public class StubUtility {
 		TemplateBuffer buffer;
 		try {
 			buffer= context.evaluate(template);
-		} catch (BadLocationException e) {
-			throw new CoreException(Status.CANCEL_STATUS);
-		} catch (TemplateException e) {
+		} catch (BadLocationException | TemplateException e) {
 			throw new CoreException(Status.CANCEL_STATUS);
 		}
 		String str= buffer.getString();
@@ -307,9 +306,9 @@ public class StubUtility {
 		int[] tagOffsets= position.getOffsets();
 		for (int i= tagOffsets.length - 1; i >= 0; i--) { // from last to first
 			try {
-				insertTag(document, tagOffsets[i], position.getLength(), EMPTY, EMPTY, null, typeParameterNames, false, lineDelim);
+				insertTag(document, tagOffsets[i], position.getLength(), params, EMPTY, null, typeParameterNames, false, lineDelim);
 			} catch (BadLocationException e) {
-				throw new CoreException(new Status(IStatus.ERROR, JavaManipulationPlugin.getPluginId(), IStatus.ERROR, e.getMessage(), e));
+				throw new CoreException(new Status(IStatus.ERROR, JavaManipulation.ID_PLUGIN, IStatus.ERROR, e.getMessage(), e));
 			}
 		}
 		return document.get();
@@ -446,9 +445,7 @@ public class StubUtility {
 		TemplateBuffer buffer;
 		try {
 			buffer= context.evaluate(template);
-		} catch (BadLocationException e) {
-			throw new CoreException(Status.CANCEL_STATUS);
-		} catch (TemplateException e) {
+		} catch (BadLocationException | TemplateException e) {
 			throw new CoreException(Status.CANCEL_STATUS);
 		}
 		if (buffer == null) {
@@ -475,7 +472,7 @@ public class StubUtility {
 			try {
 				insertTag(document, tagOffsets[i], position.getLength(), paramNames, exceptionNames, returnType, typeParameterNames, false, lineDelimiter);
 			} catch (BadLocationException e) {
-				throw new CoreException(new Status(IStatus.ERROR, JavaManipulationPlugin.getPluginId(), IStatus.ERROR, e.getMessage(), e));
+				throw new CoreException(new Status(IStatus.ERROR, JavaManipulation.ID_PLUGIN, IStatus.ERROR, e.getMessage(), e));
 			}
 		}
 		return document.get();
@@ -492,13 +489,12 @@ public class StubUtility {
 			if (position == null || position.getLength() > 0) {
 				continue;
 			}
-			int[] offsets= position.getOffsets();
-			for (int k= 0; k < offsets.length; k++) {
-				int line= doc.getLineOfOffset(offsets[k]);
+			for (int offset2 : position.getOffsets()) {
+				int line= doc.getLineOfOffset(offset2);
 				IRegion lineInfo= doc.getLineInformation(line);
 				int offset= lineInfo.getOffset();
 				String str= doc.get(offset, lineInfo.getLength());
-				if (Strings.containsOnlyWhitespaces(str) && nLines > line + 1 && removedLines.add(Integer.valueOf(line))) {
+				if (Strings.containsOnlyWhitespaces(str) && nLines > line + 1 && removedLines.add(line)) {
 					int nextStart= doc.getLineOffset(line + 1);
 					edit.addChild(new DeleteEdit(offset, nextStart - offset));
 				}
@@ -525,9 +521,7 @@ public class StubUtility {
 		TemplateBuffer buffer;
 		try {
 			buffer= context.evaluate(template);
-		} catch (BadLocationException e) {
-			throw new CoreException(Status.CANCEL_STATUS);
-		} catch (TemplateException e) {
+		} catch (BadLocationException | TemplateException e) {
 			throw new CoreException(Status.CANCEL_STATUS);
 		}
 		String str= buffer.getString();
@@ -547,7 +541,7 @@ public class StubUtility {
 				insertModuleTags(document, tagOffsets[i], position.getLength(), providesNames, usesNames,
 						lineDelimiter);
 			} catch (BadLocationException e) {
-				throw new CoreException(new Status(IStatus.ERROR, JavaManipulationPlugin.getPluginId(), IStatus.ERROR, e.getMessage(), e));
+				throw new CoreException(new Status(IStatus.ERROR, JavaManipulation.ID_PLUGIN, IStatus.ERROR, e.getMessage(), e));
 			}
 		}
 		return document.get();
@@ -562,17 +556,17 @@ public class StubUtility {
 		String lineStart= textBuffer.get(region.getOffset(), offset - region.getOffset());
 
 		StringBuilder buf= new StringBuilder();
-		for (int i= 0; i < providesNames.length; i++) {
+		for (String providesName : providesNames) {
 			if (buf.length() > 0) {
 				buf.append(lineDelimiter).append(lineStart);
 			}
-			buf.append("@provides ").append(providesNames[i]); //$NON-NLS-1$
+			buf.append("@provides ").append(providesName); //$NON-NLS-1$
 		}
-		for (int i= 0; i < usesNames.length; i++) {
+		for (String usesName : usesNames) {
 			if (buf.length() > 0) {
 				buf.append(lineDelimiter).append(lineStart);
 			}
-			buf.append("@uses ").append(usesNames[i]); //$NON-NLS-1$
+			buf.append("@uses ").append(usesName); //$NON-NLS-1$
 		}
 		if (buf.length() == 0 && isAllCommentWhitespace(lineStart)) {
 			int prevLine= textBuffer.getLineOfOffset(offset) - 1;
@@ -653,9 +647,7 @@ public class StubUtility {
 		TemplateBuffer buffer;
 		try {
 			buffer= context.evaluate(template);
-		} catch (BadLocationException e) {
-			throw new CoreException(Status.CANCEL_STATUS);
-		} catch (TemplateException e) {
+		} catch (BadLocationException | TemplateException e) {
 			throw new CoreException(Status.CANCEL_STATUS);
 		}
 		if (buffer == null)
@@ -678,9 +670,7 @@ public class StubUtility {
 				return null;
 			}
 			return str;
-		} catch (BadLocationException e) {
-			throw new CoreException(Status.CANCEL_STATUS);
-		} catch (TemplateException e) {
+		} catch (BadLocationException | TemplateException e) {
 			throw new CoreException(Status.CANCEL_STATUS);
 		}
 	}
@@ -724,9 +714,7 @@ public class StubUtility {
 		TemplateBuffer buffer;
 		try {
 			buffer= context.evaluate(template);
-		} catch (BadLocationException e) {
-			throw new CoreException(Status.CANCEL_STATUS);
-		} catch (TemplateException e) {
+		} catch (BadLocationException | TemplateException e) {
 			throw new CoreException(Status.CANCEL_STATUS);
 		}
 		if (buffer == null)
@@ -764,7 +752,7 @@ public class StubUtility {
 			try {
 				insertTag(textBuffer, tagOffsets[i], position.getLength(), paramNames, exceptionNames, returnType, typeParamNames, isDeprecated, lineDelimiter);
 			} catch (BadLocationException e) {
-				throw new CoreException(new Status(IStatus.ERROR, JavaManipulationPlugin.getPluginId(), IStatus.ERROR, e.getMessage(), e));
+				throw new CoreException(new Status(IStatus.ERROR, JavaManipulation.ID_PLUGIN, IStatus.ERROR, e.getMessage(), e));
 			}
 		}
 		return textBuffer.get();
@@ -778,7 +766,7 @@ public class StubUtility {
 	@Deprecated
 	private static String[] getExceptionNames(MethodDeclaration decl) {
 		String[] exceptionNames;
-		if (decl.getAST().apiLevel() >= AST.JLS8) {
+		if (decl.getAST().apiLevel() >= ASTHelper.JLS8) {
 			List<Type> exceptions= decl.thrownExceptionTypes();
 			exceptionNames= new String[exceptions.size()];
 			for (int i= 0; i < exceptionNames.length; i++) {
@@ -806,7 +794,7 @@ public class StubUtility {
 	@Deprecated
 	private static ASTNode getReturnType(MethodDeclaration decl) {
 		// used from API, can't eliminate
-		return decl.getAST().apiLevel() == AST.JLS2 ? decl.getReturnType() : decl.getReturnType2();
+		return decl.getAST().apiLevel() == ASTHelper.JLS2 ? decl.getReturnType() : decl.getReturnType2();
 	}
 
 
@@ -840,7 +828,7 @@ public class StubUtility {
 			}
 			buf.append("@param ").append(paramName); //$NON-NLS-1$
 		}
-		if (returnType != null && !returnType.equals("void")) { //$NON-NLS-1$
+		if (returnType != null && !"void".equals(returnType)) { //$NON-NLS-1$
 			if (buf.length() > 0) {
 				buf.append(lineDelimiter).append(lineStart);
 			}
@@ -874,12 +862,12 @@ public class StubUtility {
 	}
 
 	private static boolean isAllCommentWhitespace(String lineStart) {
-		for (int i= 0; i < lineStart.length(); i++) {
-			char ch= lineStart.charAt(i);
+		for (char ch : lineStart.toCharArray()) {
 			if (!Character.isWhitespace(ch) && ch != '*') {
 				return false;
 			}
 		}
+
 		return true;
 	}
 
@@ -1171,8 +1159,7 @@ public class StubUtility {
 			String string= assignedExpression instanceof StringLiteral ? ((StringLiteral)assignedExpression).getLiteralValue() : ((NumberLiteral)assignedExpression).getToken();
 			StringBuilder res= new StringBuilder();
 			boolean needsUnderscore= false;
-			for (int i= 0; i < string.length(); i++) {
-				char ch= string.charAt(i);
+			for (char ch : string.toCharArray()) {
 				if (Character.isJavaIdentifierPart(ch)) {
 					if (res.length() == 0 && !Character.isJavaIdentifierStart(ch) || needsUnderscore) {
 						res.append('_');
@@ -1510,11 +1497,11 @@ public class StubUtility {
 	// -------------------- preference access -----------------------
 
 	public static boolean useThisForFieldAccess(IJavaProject project) {
-		return Boolean.valueOf(JavaManipulation.getPreference(CODEGEN_KEYWORD_THIS, project)).booleanValue();
+		return Boolean.parseBoolean(JavaManipulation.getPreference(CODEGEN_KEYWORD_THIS, project));
 	}
 
 	public static boolean useIsForBooleanGetters(IJavaProject project) {
-		return Boolean.valueOf(JavaManipulation.getPreference(CODEGEN_IS_FOR_GETTERS, project)).booleanValue();
+		return Boolean.parseBoolean(JavaManipulation.getPreference(CODEGEN_IS_FOR_GETTERS, project));
 	}
 
 	public static String getExceptionVariableName(IJavaProject project) {
@@ -1522,7 +1509,7 @@ public class StubUtility {
 	}
 
 	public static boolean doAddComments(IJavaProject project) {
-		return Boolean.valueOf(JavaManipulation.getPreference(CODEGEN_ADD_COMMENTS, project)).booleanValue();
+		return Boolean.parseBoolean(JavaManipulation.getPreference(CODEGEN_ADD_COMMENTS, project));
 	}
 
 	/**
@@ -1580,4 +1567,7 @@ public class StubUtility {
 		return rewrite;
 	}
 
+	private StubUtility() {
+	}
+
 }
