@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -62,6 +62,7 @@ public final class CorrectionMessages extends NLS {
 	public static String QuickAssistProcessor_convert_to_method_reference;
 	public static String QuickAssistProcessor_convert_to_multiple_singletype_catch_blocks;
 	public static String QuickAssistProcessor_convert_to_single_multicatch_block;
+	public static String QuickAssistProcessor_convert_to_string_format;
 	public static String QuickAssistProcessor_convert_to_try_with_resource;
 	public static String QuickAssistProcessor_convert_to_string_buffer_description;
 	public static String QuickAssistProcessor_exceptiontothrows_description;
@@ -155,6 +156,9 @@ public final class CorrectionMessages extends NLS {
 	public static String RenameRefactoringProposal_additionalInfo;
 	public static String RenameRefactoringProposal_name;
 
+	public static String ModifierCorrectionSubProcessor_changemodifierto_final_description;
+	public static String ModifierCorrectionSubProcessor_changemodifierto_sealed_description;
+	public static String ModifierCorrectionSubProcessor_changemodifierto_nonsealed_description;
 	public static String ModifierCorrectionSubProcessor_changemodifiertoabstract_description;
 	public static String ModifierCorrectionSubProcessor_changemodifiertostatic_description;
 	public static String ModifierCorrectionSubProcessor_changemodifiertononstatic_description;
@@ -178,12 +182,14 @@ public final class CorrectionMessages extends NLS {
 	public static String ReturnTypeSubProcessor_missingreturntype_description;
 	public static String ReturnTypeSubProcessor_wrongconstructorname_description;
 	public static String ReturnTypeSubProcessor_changetovoid_description;
+	public static String ReturnTypeSubProcessor_changeReturnToYield_description;
 	public static String MissingReturnTypeCorrectionProposal_addreturnstatement_description;
 	public static String MissingReturnTypeCorrectionProposal_changereturnstatement_description;
 	public static String TypeArgumentMismatchSubProcessor_removeTypeArguments;
 
 	public static String InitializeFieldAtDeclarationCorrectionProposal_description;
 	public static String InitializeFieldInConstructorCorrectionProposal_description;
+	public static String InitializeFieldWithConstructorParameterCorrectionProposal_description;
 
 	public static String UnimplementedMethodsCorrectionProposal_description;
 	public static String UnimplementedMethodsCorrectionProposal_enum_info;
@@ -218,6 +224,9 @@ public final class CorrectionMessages extends NLS {
 	public static String UnresolvedElementsSubProcessor_createconst_description;
 	public static String UnresolvedElementsSubProcessor_createenum_description;
 	public static String UnresolvedElementsSubProcessor_createconst_other_description;
+	public static String UnresolvedElementsSubProcessor_createnew_instance_of_object;
+	public static String UnresolvedElementsSubProcessor_createnew_reference_to_instance;
+	public static String UnresolvedElementsSubProcessor_createnew_reference_to_variable;
 	public static String UnresolvedElementsSubProcessor_removestatement_description;
 	public static String UnresolvedElementsSubProcessor_changeparamsignature_description;
 	public static String UnresolvedElementsSubProcessor_changemethodtargetcast_description;
@@ -292,6 +301,7 @@ public final class CorrectionMessages extends NLS {
 	public static String AssignToVariableAssistProposal_assigntofield_description;
 	public static String AssignToVariableAssistProposal_assignparamtofield_description;
 	public static String AssignToVariableAssistProposal_assignallparamstofields_description;
+	public static String AssignToVariableAssistProposal_assignintrywithresources_description;
 	public static String QuickAssistProcessor_catchclausetothrows_description;
 	public static String QuickAssistProcessor_change_lambda_body_to_block;
 	public static String QuickAssistProcessor_change_lambda_body_to_expression;
@@ -349,6 +359,7 @@ public final class CorrectionMessages extends NLS {
 	public static String TypeChangeCompletionProposal_method_name;
 	public static String ImplementInterfaceProposal_name;
 	public static String AddUnimplementedMethodsOperation_AddMissingMethod_group;
+	public static String AddUnimplementedMethodReferenceOperation_AddMissingMethod_group;
 	public static String AdvancedQuickAssistProcessor_convertToIfReturn;
 	public static String AdvancedQuickAssistProcessor_combineSelectedStrings;
 	public static String AdvancedQuickAssistProcessor_convertToIfElse_description;
@@ -415,6 +426,8 @@ public final class CorrectionMessages extends NLS {
 	public static String QuickAssistProcessor_move_exceptions_to_separate_catch_block;
 	public static String QuickAssistProcessor_create_new_junit_test_case;
 	public static String QuickAssistProcessor_create_new_junit_test_case_desc;
+	public static String QuickAssistProcessor_create_new_impl;
+	public static String QuickAssistProcessor_create_new_impl_desc;
 	public static String SuppressWarningsSubProcessor_suppress_warnings_label;
 	public static String ReorgCorrectionsSubProcessor_accessrules_description;
 	public static String ReorgCorrectionsSubProcessor_project_seup_fix_description;
@@ -449,6 +462,9 @@ public final class CorrectionMessages extends NLS {
 	public static String LocalCorrectionsSubProcessor_replace_with_unqualified_enum_constant;
 	public static String LocalCorrectionsSubProcessor_throw_allocated_description;
 	public static String LocalCorrectionsSubProcessor_add_provider_method_description;
+	public static String LocalCorrectionsSubProcessor_declareSealedAsDirectSuperInterface_description;
+	public static String LocalCorrectionsSubProcessor_declareSealedAsDirectSuperClass_description;
+	public static String LocalCorrectionsSubProcessor_declareSubClassAsPermitsSealedClass_description;
 	public static String SuppressWarningsSubProcessor_fix_suppress_token_label;
 	public static String SuppressWarningsSubProcessor_remove_annotation_label;
 	public static String VarargsWarningsSubProcessor_add_safevarargs_label;
