@@ -21,7 +21,6 @@ package org.eclipse.jdt.internal.corext.codemanipulation;
 
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.core.runtime.Assert;
@@ -136,7 +135,7 @@ public final class GenerateHashCodeEqualsOperation implements IWorkspaceRunnable
 
 	private interface IHashCodeAccessProvider {
 
-		public Expression getThisAccess(String name);
+		Expression getThisAccess(String name);
 	}
 
 	private static final String JAVA_UTIL_ARRAYS= "java.util.Arrays"; //$NON-NLS-1$
@@ -297,7 +296,7 @@ public final class GenerateHashCodeEqualsOperation implements IWorkspaceRunnable
 	 *
 	 * @return the resulting edit
 	 */
-	public final TextEdit getResultingEdit() {
+	public TextEdit getResultingEdit() {
 		return fEdit;
 	}
 
@@ -306,7 +305,7 @@ public final class GenerateHashCodeEqualsOperation implements IWorkspaceRunnable
 	 *
 	 * @return the scheduling rule
 	 */
-	public final ISchedulingRule getSchedulingRule() {
+	public ISchedulingRule getSchedulingRule() {
 		return ResourcesPlugin.getWorkspace().getRoot();
 	}
 
@@ -314,7 +313,7 @@ public final class GenerateHashCodeEqualsOperation implements IWorkspaceRunnable
 	 * @see org.eclipse.core.resources.IWorkspaceRunnable#run(org.eclipse.core.runtime.IProgressMonitor)
 	 */
 	@Override
-	public final void run(IProgressMonitor monitor) throws CoreException {
+	public void run(IProgressMonitor monitor) throws CoreException {
 		if (monitor == null)
 			monitor= new NullProgressMonitor();
 		try {
@@ -351,9 +350,7 @@ public final class GenerateHashCodeEqualsOperation implements IWorkspaceRunnable
 				addMethod(rewriter, equalsMethod, hashCodeMethod, oldHash);
 
 				// helpers
-				for (final Iterator<ITypeBinding> iterator= fCustomHashCodeTypes.iterator(); iterator.hasNext();) {
-					final ITypeBinding binding= iterator.next();
-
+				for (ITypeBinding binding : fCustomHashCodeTypes) {
 					if (findMethodToReplace(list, METHODNAME_HASH_CODE, objectAsParam) == null) {
 						final MethodDeclaration helperDecl= createHashCodeHelper(binding);
 						addHelper(rewriter, null, helperDecl);
@@ -381,8 +378,7 @@ public final class GenerateHashCodeEqualsOperation implements IWorkspaceRunnable
 	}
 
 	private BodyDeclaration findMethodToReplace(final List<BodyDeclaration> list, String name, ITypeBinding[] paramTypes) {
-		for (final Iterator<BodyDeclaration> iterator= list.iterator(); iterator.hasNext();) {
-			final BodyDeclaration bodyDecl= iterator.next();
+		for (BodyDeclaration bodyDecl : list) {
 			if (bodyDecl instanceof MethodDeclaration) {
 				final MethodDeclaration method= (MethodDeclaration) bodyDecl;
 				final IMethodBinding binding= method.resolveBinding();
@@ -479,9 +475,7 @@ public final class GenerateHashCodeEqualsOperation implements IWorkspaceRunnable
 					j7Invoc.arguments().add(fAst.newSimpleName(field.getName()));
 				} else if (field.getType().isPrimitive()) {
 					Statement[] sts= createAddSimpleHashCode(field.getType(), this::getThisAccessForHashCode, field.getName(), false);
-					for (Statement st : sts) {
-						body.statements().add(st);
-					}
+					body.statements().addAll(Arrays.asList(sts));
 				} else {
 					body.statements().add(createAddQualifiedHashCode(field));
 				}
@@ -502,7 +496,7 @@ public final class GenerateHashCodeEqualsOperation implements IWorkspaceRunnable
 			ITypeBinding object= fAst.resolveWellKnownType(JAVA_LANG_OBJECT);
 			IMethodBinding objectMethod= null;
 			for (IMethodBinding objm : object.getDeclaredMethods()) {
-				if (objm.getName().equals(METHODNAME_HASH_CODE) && objm.getParameterTypes().length == 0) {
+				if (METHODNAME_HASH_CODE.equals(objm.getName()) && objm.getParameterTypes().length == 0) {
 					objectMethod= objm;
 				}
 			}
@@ -728,19 +722,13 @@ public final class GenerateHashCodeEqualsOperation implements IWorkspaceRunnable
 		body.statements().add(forStatement);
 
 		Block forBody= fAst.newBlock();
-		Statement[] statements= createAddSimpleHashCode(binding, new IHashCodeAccessProvider() {
-
-			@Override
-			public Expression getThisAccess(String name) {
-				ArrayAccess a= fAst.newArrayAccess();
-				a.setArray(fAst.newSimpleName(VARIABLE_NAME_HASHCODE_PARAM));
-				a.setIndex(fAst.newSimpleName(name));
-				return a;
-			}
+		Statement[] statements= createAddSimpleHashCode(binding, name -> {
+			ArrayAccess a= fAst.newArrayAccess();
+			a.setArray(fAst.newSimpleName(VARIABLE_NAME_HASHCODE_PARAM));
+			a.setIndex(fAst.newSimpleName(name));
+			return a;
 		}, VARIABLE_NAME_INDEX, true);
-		for (Statement statement : statements) {
-			forBody.statements().add(statement);
-		}
+		forBody.statements().addAll(Arrays.asList(statements));
 		forStatement.setBody(forBody);
 
 		// END RETURN
@@ -958,7 +946,7 @@ public final class GenerateHashCodeEqualsOperation implements IWorkspaceRunnable
 			ITypeBinding object= fAst.resolveWellKnownType(JAVA_LANG_OBJECT);
 			IMethodBinding objectMethod= null;
 			for (IMethodBinding objm : object.getDeclaredMethods()) {
-				if (objm.getName().equals(METHODNAME_EQUALS) && objm.getParameterTypes().length == 1 && objm.getParameterTypes()[0].getQualifiedName().equals(JAVA_LANG_OBJECT)) {
+				if (METHODNAME_EQUALS.equals(objm.getName()) && objm.getParameterTypes().length == 1 && JAVA_LANG_OBJECT.equals(objm.getParameterTypes()[0].getQualifiedName())) {
 					objectMethod= objm;
 				}
 			}
@@ -1028,7 +1016,7 @@ public final class GenerateHashCodeEqualsOperation implements IWorkspaceRunnable
 				invoc.setExpression(getQualifiedName(JAVA_UTIL_OBJECTS));
 				invoc.setName(fAst.newSimpleName(METHODNAME_EQUALS));
 			}
-			invoc.arguments().add(fAst.newSimpleName(name));
+			invoc.arguments().add(getThisAccessForEquals(name));
 			invoc.arguments().add(getOtherAccess(name));
 			return invoc;
 		}
@@ -1198,7 +1186,7 @@ public final class GenerateHashCodeEqualsOperation implements IWorkspaceRunnable
 		IMethodBinding binding= Bindings.findMethodInHierarchy(typeBinding.getSuperclass(), name, parameters);
 		if (binding != null && !Modifier.isAbstract(binding.getModifiers())) {
 			ITypeBinding declaring= binding.getDeclaringClass();
-			return declaring.getQualifiedName().equals(JAVA_LANG_OBJECT);
+			return JAVA_LANG_OBJECT.equals(declaring.getQualifiedName());
 		}
 		return true;
 	}
@@ -1283,9 +1271,9 @@ public final class GenerateHashCodeEqualsOperation implements IWorkspaceRunnable
 
 	private boolean needsThisQualification(String name, boolean isHashCode) {
 		if (isHashCode)
-			return ( (fDoubleCount > 0 && name.equals(VARIABLE_NAME_DOUBLE_TEMPORARY)) || (name.equals(VARIABLE_NAME_PRIME)) || (name
-					.equals(VARIABLE_NAME_RESULT)));
-		return ( (name.equals(VARIABLE_NAME_EQUALS_CASTED)) || (name.equals(VARIABLE_NAME_EQUALS_PARAM)));
+			return ( (fDoubleCount > 0 && VARIABLE_NAME_DOUBLE_TEMPORARY.equals(name)) || (VARIABLE_NAME_PRIME.equals(name)) || (VARIABLE_NAME_RESULT
+					.equals(name)));
+		return ( (VARIABLE_NAME_EQUALS_CASTED.equals(name)) || (VARIABLE_NAME_EQUALS_PARAM.equals(name)));
 	}
 
 	private boolean needsDeepMethod(ITypeBinding type) {
