@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -449,6 +449,16 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 		endVisit((Expression)node);
 	}
 
+	@Override
+	public boolean visit(PatternInstanceofExpression node) {
+		return visit((Expression)node);
+	}
+
+	@Override
+	public void endVisit(PatternInstanceofExpression node) {
+		endVisit((Expression)node);
+	}
+
 	@Override
 	public boolean visit(LambdaExpression node) {
 		return visit((Expression)node);
@@ -489,6 +499,16 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 		endVisit((Statement)node);
 	}
 
+	@Override
+	public boolean visit(RecordDeclaration node) {
+		return visit((AbstractTypeDeclaration) node);
+	}
+
+	@Override
+	public void endVisit(RecordDeclaration node) {
+		endVisit((AbstractTypeDeclaration) node);
+	}
+
 	//---- Begin MethodReference Hierarchy ----------------------------------
 	public boolean visit(MethodReference node) {
 		return visit((Expression)node);
@@ -559,6 +579,16 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 		endVisit((Name)node);
 	}
 
+	@Override
+	public boolean visit(ModuleQualifiedName node) {
+		return visit((Name)node);
+	}
+
+	@Override
+	public void endVisit(ModuleQualifiedName node) {
+		endVisit((Name)node);
+	}
+
 	@Override
 	public boolean visit(SimpleName node) {
 		return visit((Name)node);
