@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,9 +14,10 @@
 package org.eclipse.jdt.internal.corext.dom;
 
 import java.util.ArrayList;
+import java.util.List;
 
+import org.eclipse.jdt.core.Flags;
 import org.eclipse.jdt.core.compiler.IProblem;
-import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.ASTNode;
 import org.eclipse.jdt.core.dom.ASTVisitor;
 import org.eclipse.jdt.core.dom.BreakStatement;
@@ -28,7 +29,11 @@ import org.eclipse.jdt.core.dom.ITypeBinding;
 import org.eclipse.jdt.core.dom.IVariableBinding;
 import org.eclipse.jdt.core.dom.LabeledStatement;
 import org.eclipse.jdt.core.dom.NodeFinder;
+import org.eclipse.jdt.core.dom.RecordDeclaration;
 import org.eclipse.jdt.core.dom.SimpleName;
+import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
+
+import org.eclipse.jdt.internal.ui.util.ASTHelper;
 
 
 /**
@@ -43,6 +48,137 @@ public class LinkedNodeFinder  {
 	}
 
 
+	public static SimpleName getAssociatedRecordComponentNode(SimpleName simpleName) {
+		SimpleName rcName= null;
+		if (simpleName == null) {
+			return null;
+		}
+		if (!ASTHelper.isRecordDeclarationNodeSupportedInAST(simpleName.getAST())) {
+			return null;
+		}
+		IBinding binding= simpleName.resolveBinding();
+		IVariableBinding rcBinding= null;
+		ITypeBinding recordTypeBinding= null;
+		ITypeBinding tBinding= null;
+		String recCompName= null;
+		if (binding instanceof IVariableBinding) {
+			IVariableBinding vbinding= (IVariableBinding) binding;
+			IVariableBinding bBinding= vbinding.getVariableDeclaration();
+			if (bBinding == null) {
+				return null;
+			}
+			if (!bBinding.isField()) {
+				if (bBinding.isParameter()) {
+					IMethodBinding mBinding= bBinding.getDeclaringMethod();
+					if (mBinding != null
+							&& (mBinding.isCompactConstructor()
+									|| mBinding.isCanonicalConstructor())) {
+						ITypeBinding typeBinding= mBinding.getDeclaringClass();
+						if (typeBinding != null
+								&& typeBinding.isRecord()) {
+							recordTypeBinding= typeBinding;
+							recCompName= bBinding.getName();
+							tBinding= bBinding.getType();
+						}
+					}
+				}
+				if (recordTypeBinding == null) {
+					return null;
+				}
+			}
+			if (recordTypeBinding == null) {
+				ITypeBinding cBinding= vbinding.getDeclaringClass();
+				if (cBinding == null) {
+					return null;
+				}
+				ITypeBinding typeBinding= cBinding.getTypeDeclaration();
+				if (typeBinding== null || !typeBinding.isRecord()) {
+					return null;
+				}
+				int modifiers= bBinding.getModifiers();
+				if (Flags.isFinal(modifiers)
+						&& !Flags.isStatic(modifiers)) {
+					rcBinding= bBinding;
+				}
+			}
+		} else if (binding instanceof IMethodBinding) {
+			IMethodBinding mBinding = (IMethodBinding)binding;
+			ITypeBinding cBinding= mBinding.getDeclaringClass();
+			if (cBinding == null) {
+				return null;
+			}
+			ITypeBinding typeBinding= cBinding.getTypeDeclaration();
+			IMethodBinding bBinding= mBinding.getMethodDeclaration();
+			if (bBinding == null ||
+					typeBinding == null ||
+					bBinding.getParameterTypes().length != 0 ||
+					!typeBinding.isRecord()) {
+				return null;
+			}
+			if (typeBinding.isRecord()) {
+				recordTypeBinding= typeBinding;
+				recCompName= simpleName.getIdentifier();
+				tBinding= bBinding.getReturnType();
+			}
+
+		} else {
+			return null;
+		}
+		if (recCompName != null
+				&& recordTypeBinding != null
+				&& tBinding != null) {
+			IVariableBinding varBindings[]= recordTypeBinding.getDeclaredFields();
+			if (varBindings != null) {
+				for (IVariableBinding varBinding : varBindings) {
+					String name= varBinding.getName();
+					if (simpleName.getIdentifier().equals(name)) {
+						int modifiers= varBinding.getModifiers();
+						if (tBinding.isEqualTo(varBinding.getType())
+								&& Flags.isFinal(modifiers)
+								&& !Flags.isStatic(modifiers)) {
+							rcBinding= varBinding;
+							break;
+						}
+					}
+				}
+			}
+		}
+		RecordDeclaration recordDeclaration= null;
+		if (rcBinding != null) {
+			ITypeBinding cBinding= rcBinding.getDeclaringClass();
+			if (cBinding != null) {
+				ITypeBinding typeBinding= cBinding.getTypeDeclaration();
+				if (typeBinding != null) {
+					ASTNode root= simpleName.getRoot();
+					if (root instanceof CompilationUnit) {
+						CompilationUnit astRoot= (CompilationUnit) root;
+						ASTNode foundNode= astRoot.findDeclaringNode(typeBinding);
+						if (foundNode instanceof RecordDeclaration) {
+							recordDeclaration= (RecordDeclaration) foundNode;
+						}
+					}
+				}
+			}
+		}
+		if (recordDeclaration != null) {
+			List<ASTNode> ff=recordDeclaration.recordComponents();
+			if (ff != null) {
+				for (ASTNode nd : ff) {
+					if (nd instanceof SingleVariableDeclaration) {
+						SimpleName name= ((SingleVariableDeclaration) nd).getName();
+						if (simpleName.getIdentifier().equals(name.getIdentifier())) {
+							rcName= name;
+							break;
+						}
+					}
+				}
+			}
+		}
+		return rcName;
+	}
+
+
+
 	/**
 	 * Find all nodes connected to the given binding. e.g. Declaration of a field and all references.
 	 * For types this includes also the constructor declaration, for methods also overridden methods
@@ -69,6 +205,11 @@ public class LinkedNodeFinder  {
 	public static SimpleName[] findByNode(ASTNode root, SimpleName name) {
 		IBinding binding = name.resolveBinding();
 		if (binding != null) {
+			SimpleName recNode= getAssociatedRecordComponentNode(name);
+			if (recNode != null) {
+				IBinding recBinding= recNode.resolveBinding();
+				return findByBinding(root, recBinding);
+			}
 			return findByBinding(root, binding);
 		}
 		SimpleName[] names= findByProblems(root, name);
@@ -127,7 +268,7 @@ public class LinkedNodeFinder  {
 
 
 	public static SimpleName[] findByProblems(ASTNode parent, SimpleName nameNode) {
-		if (nameNode.getAST().apiLevel() >= AST.JLS10 && nameNode.isVar()) {
+		if (nameNode.getAST().apiLevel() >= ASTHelper.JLS10 && nameNode.isVar()) {
 			return null;
 		}
 		ArrayList<SimpleName> res= new ArrayList<>();
@@ -157,9 +298,8 @@ public class LinkedNodeFinder  {
 				if ((nameNodeKind & currKind) != 0) {
 					ASTNode node= NodeFinder.perform(parent, probStart, (probEnd - probStart));
 					if (node instanceof SimpleName && name.equals(((SimpleName) node).getIdentifier())) {
-						if (node instanceof SimpleName && name.equals(((SimpleName) node).getIdentifier())) {
-							if (node.getAST().apiLevel() < AST.JLS10 || !((SimpleName) node).isVar())
-								res.add((SimpleName) node);
+						if (node.getAST().apiLevel() < ASTHelper.JLS10 || !((SimpleName) node).isVar()) {
+							res.add((SimpleName) node);
 						}
 					}
 				}
@@ -230,7 +370,7 @@ public class LinkedNodeFinder  {
 
 		@Override
 		public boolean visit(SimpleName node) {
-			if (node.getAST().apiLevel() >= AST.JLS10 && node.isVar()) {
+			if (node.getAST().apiLevel() >= ASTHelper.JLS10 && node.isVar()) {
 				return false;
 			}
 			IBinding binding= node.resolveBinding();
@@ -238,9 +378,17 @@ public class LinkedNodeFinder  {
 				return false;
 			}
 			binding= getDeclaration(binding);
-
+			SimpleName rcNode= getAssociatedRecordComponentNode(node);
 			if (fBinding == binding) {
 				fResult.add(node);
+			} else if (rcNode != null) {
+				IBinding rcBinding= rcNode.resolveBinding();
+				if (rcBinding != null) {
+					rcBinding= getDeclaration(rcBinding);
+					if (fBinding == rcBinding) {
+						fResult.add(node);
+					}
+				}
 			} else if (binding.getKind() != fBinding.getKind()) {
 				return false;
 			} else if (binding.getKind() == IBinding.METHOD) {
