@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,6 +14,7 @@
  *     Samrat Dhillon <samrat.dhillon@gmail.com> - [introduce factory] Introduce Factory on an abstract class adds a statement to create an instance of that class - https://bugs.eclipse.org/bugs/show_bug.cgi?id=395016
  *     Yves Joan <yves.joan@oracle.com> - [reorg] Copy action should NOT add 'copy of' prefix - https://bugs.eclipse.org/bugs/show_bug.cgi?id=151668
  *     Red Hat Inc. - copied to jdt.core.manipulation
+ *     Pierre-Yves B. <pyvesdev@gmail.com> - [inline] Allow inlining of local variable initialized to null. - https://bugs.eclipse.org/93850
  *******************************************************************************/
 package org.eclipse.jdt.internal.corext.refactoring;
 
@@ -523,10 +524,16 @@ public final class RefactoringCoreMessages extends NLS {
 
 	public static String ExtractMethodAnalyzer_branch_mismatch;
 
+	public static String ExtractMethodAnalyzer_break_parent_missing;
+
 	public static String ExtractMethodAnalyzer_cannot_determine_return_type;
 
 	public static String ExtractMethodAnalyzer_cannot_extract_anonymous_type;
 
+	public static String ExtractMethodAnalyzer_cannot_extract_break;
+
+	public static String ExtractMethodAnalyzer_cannot_extract_continue;
+
 	public static String ExtractMethodAnalyzer_cannot_extract_for_initializer;
 
 	public static String ExtractMethodAnalyzer_cannot_extract_for_updater;
@@ -551,6 +558,8 @@ public final class RefactoringCoreMessages extends NLS {
 
 	public static String ExtractMethodAnalyzer_cannot_extract_variable_declaration_fragment_from_field;
 
+	public static String ExtractMethodAnalyzer_cannot_extract_yield;
+
 	public static String ExtractMethodAnalyzer_compile_errors;
 
 	public static String ExtractMethodAnalyzer_compile_errors_no_parent_binding;
@@ -654,7 +663,7 @@ public final class RefactoringCoreMessages extends NLS {
 	public static String ExtractTempRefactoring_convention;
 
 	public static String ExtractTempRefactoring_declare_final;
-	
+
 	public static String ExtractTempRefactoring_declare_var_type;
 
 	public static String ExtractTempRefactoring_declare_local_variable;
@@ -877,8 +886,6 @@ public final class RefactoringCoreMessages extends NLS {
 
 	public static String InlineTemRefactoring_error_message_fieldsCannotBeInlined;
 
-	public static String InlineTemRefactoring_error_message_nulLiteralsCannotBeInlined;
-
 	public static String IntroduceFactory_addFactoryMethod;
 
 	public static String IntroduceFactory_callSitesInBinaryClass;
@@ -1354,7 +1361,7 @@ public final class RefactoringCoreMessages extends NLS {
 	public static String MoveMembersRefactoring_only_public_static;
 
 	public static String MoveMembersRefactoring_only_public_static_18;
-	
+
 	public static String MoveMembersRefactoring_read_only;
 
 	public static String MoveMembersRefactoring_referenceUpdate;
@@ -1493,6 +1500,8 @@ public final class RefactoringCoreMessages extends NLS {
 
 	public static String PullUpRefactoring_moving_static_method_to_interface;
 
+	public static String PullUpRefactoring_moving_fromto_default_package;
+
 	public static String PullUPRefactoring_no_all_binary;
 
 	public static String PullUpRefactoring_no_java_lang_Object;
@@ -1631,6 +1640,8 @@ public final class RefactoringCoreMessages extends NLS {
 
 	public static String RenameFieldRefactoring_already_exists;
 
+	public static String RenameFieldRefactoring_recordromponent_accessor_method_already_exists;
+
 	public static String RenameFieldRefactoring_another_name;
 
 	public static String RenameFieldRefactoring_another_name2;
@@ -1851,6 +1862,18 @@ public final class RefactoringCoreMessages extends NLS {
 
 	public static String RenameTypeParameterRefactoring_update_type_parameter_reference;
 
+	public static String RenameModuleRefactoring_name;
+
+	public static String RenameModuleRefactoring_deleted;
+
+	public static String RenameModuleRefactoring_Update_module_declaration;
+
+	public static String RenameModuleRefactoring_Update_module_reference;
+
+	public static String RenameModuleRefactoring_descriptor_description_short;
+
+	public static String RenameModuleProcessor_descriptor_description;
+
 	public static String ReferencesInBinaryContext_binaryRefsNotUpdated;
 
 	public static String RenameTypeProcessor_cannot_rename_fields_same_new_name;
@@ -2309,6 +2332,12 @@ public final class RefactoringCoreMessages extends NLS {
 
 	public static String SurroundWithTryCatchRefactoring_notMultipleexceptions;
 
+	public static String SurroundWithTryWithResourcesRefactoring_name;
+
+	public static String SurroundWithTryWithResourcesRefactoring_notAutoclosable;
+
+	public static String SurroundWithTryWithResourcesRefactoring_notAutoclosableNoExceptions;
+
 	public static String TargetProvider_cannot_local_method_in_binary;
 
 	public static String TargetProvider_inaccurate_match;
