@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -24,12 +24,12 @@
  *     Nikolay Metchev <nikolaymetchev@gmail.com> - Anonymous class using final parameter breaks method inlining - https://bugs.eclipse.org/269401
  *     Microsoft Corporation - copied to jdt.core.manipulation
  *     Pierre-Yves B. <pyvesdev@gmail.com> - [inline] Inlining a local variable leads to ambiguity with overloaded methods - https://bugs.eclipse.org/434747
+ *     Microsoft Corporation - read formatting options from the compilation unit
  *******************************************************************************/
 package org.eclipse.jdt.internal.corext.refactoring.code;
 
 import java.util.ArrayList;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 
@@ -459,7 +459,7 @@ public class CallInliner {
 	}
 
 	public TextEdit getModifications() {
-		return fRewrite.rewriteAST(fBuffer.getDocument(), fCUnit.getJavaProject().getOptions(true));
+		return fRewrite.rewriteAST(fBuffer.getDocument(), fCUnit.getOptions(true));
 	}
 
 	private void computeRealArguments() {
@@ -564,8 +564,8 @@ public class CallInliner {
 	private void addNewLocals(TextEditGroup textEditGroup) {
 		if (fLocals.isEmpty())
 			return;
-		for (Iterator<VariableDeclarationStatement> iter= fLocals.iterator(); iter.hasNext();) {
-			ASTNode element= iter.next();
+		for (VariableDeclarationStatement variableDeclarationStatement : fLocals) {
+			ASTNode element= variableDeclarationStatement;
 			fListRewrite.insertAt(element, fInsertionIndex++, textEditGroup);
 		}
 	}
@@ -711,8 +711,7 @@ public class CallInliner {
 	private Set<Expression> crossCheckArguments(List<Expression> arguments) {
 		final Set<IBinding> assigned= new HashSet<>();
 		final Set<Expression> result= new HashSet<>();
-		for (Iterator<Expression> iter= arguments.iterator(); iter.hasNext();) {
-			final Expression expression= iter.next();
+		for (Expression expression : arguments) {
 			expression.accept(new ASTVisitor() {
 				@Override
 				public boolean visit(Assignment node) {
@@ -728,8 +727,7 @@ public class CallInliner {
 				}
 			});
 		}
-		for (Iterator<Expression> iter= arguments.iterator(); iter.hasNext();) {
-			final Expression expression= iter.next();
+		for (Expression expression : arguments) {
 			if (!result.contains(expression)) {
 				expression.accept(new HierarchicalASTVisitor() {
 					@Override
