@@ -93,6 +93,10 @@ import org.eclipse.jdt.core.refactoring.IJavaRefactorings;
 import org.eclipse.jdt.core.refactoring.descriptors.ConvertAnonymousDescriptor;
 import org.eclipse.jdt.core.refactoring.descriptors.JavaRefactoringDescriptor;
 
+import org.eclipse.jdt.internal.core.manipulation.BindingLabelProviderCore;
+import org.eclipse.jdt.internal.core.manipulation.JavaElementLabelsCore;
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
+import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.core.refactoring.descriptors.RefactoringSignatureDescriptorFactory;
 import org.eclipse.jdt.internal.corext.dom.ASTNodeFactory;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
@@ -114,11 +118,6 @@ import org.eclipse.jdt.internal.corext.util.Messages;
 
 import org.eclipse.jdt.internal.ui.text.correction.ModifierCorrectionSubProcessorCore;
 
-import org.eclipse.jdt.internal.core.manipulation.BindingLabelProviderCore;
-import org.eclipse.jdt.internal.core.manipulation.JavaElementLabelsCore;
-import org.eclipse.jdt.internal.core.manipulation.StubUtility;
-import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
-
 public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 
 	private static final String ATTRIBUTE_VISIBILITY= "visibility"; //$NON-NLS-1$
@@ -285,7 +284,7 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 	public RefactoringStatus checkInitialConditions(IProgressMonitor pm) throws CoreException {
         RefactoringStatus result= Checks.validateModifiesFiles(
         	ResourceUtil.getFiles(new ICompilationUnit[]{fCu}),
-			getValidationContext());
+			getValidationContext(), pm);
 		if (result.hasFatalError())
 		    return result;
 
@@ -319,8 +318,8 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 			if (declaration instanceof TypeDeclaration) {
 				final AbstractTypeDeclaration[] nested= ((TypeDeclaration) declaration).getTypes();
 				fClassNamesUsed= new HashSet<>(nested.length);
-				for (int index= 0; index < nested.length; index++)
-					fClassNamesUsed.add(nested[index].getName().getIdentifier());
+				for (AbstractTypeDeclaration element : nested)
+					fClassNamesUsed.add(element.getName().getIdentifier());
 			} else
 				fClassNamesUsed= Collections.emptySet();
 		}
@@ -395,7 +394,7 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 			@Override
 			public boolean visit(QualifiedName node) {
 				final IBinding binding= node.resolveBinding();
-				if (binding != null && binding instanceof IVariableBinding) {
+				if (binding instanceof IVariableBinding) {
 					IVariableBinding variable= (IVariableBinding) binding;
 					if (!variable.isEnumConstant() && variable.isField())
 						accessedFields.add(binding);
@@ -406,7 +405,7 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 			@Override
 			public boolean visit(SimpleName node) {
 				final IBinding binding= node.resolveBinding();
-				if (binding != null && binding instanceof IVariableBinding) {
+				if (binding instanceof IVariableBinding) {
 					IVariableBinding variable= (IVariableBinding) binding;
 					if (!variable.isEnumConstant() && variable.isField())
 						accessedFields.add(binding);
@@ -519,8 +518,8 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 		for (final Iterator<ITypeBinding> iterator= parameters.iterator(); iterator.hasNext();) {
 			match= false;
 			binding= iterator.next();
-			for (int index= 0; index < variables.length; index++) {
-				variable= variables[index];
+			for (ITypeBinding variable2 : variables) {
+				variable= variable2;
 				if (variable.equals(binding))
 					match= true;
 			}
@@ -568,10 +567,10 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 			comment.addSetting(RefactoringCoreMessages.ConvertAnonymousToNestedRefactoring_declare_static);
 		arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_INPUT, JavaRefactoringDescriptorUtil.elementToHandle(projectName, fCu));
 		arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_NAME, fClassName);
-		arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_SELECTION, Integer.valueOf(fSelectionStart).toString() + ' ' + Integer.valueOf(fSelectionLength).toString());
-		arguments.put(ATTRIBUTE_FINAL, Boolean.valueOf(fDeclareFinal).toString());
-		arguments.put(ATTRIBUTE_STATIC, Boolean.valueOf(fDeclareStatic).toString());
-		arguments.put(ATTRIBUTE_VISIBILITY, Integer.valueOf(fVisibility).toString());
+		arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_SELECTION, Integer.toString(fSelectionStart) + ' ' + Integer.toString(fSelectionLength));
+		arguments.put(ATTRIBUTE_FINAL, Boolean.toString(fDeclareFinal));
+		arguments.put(ATTRIBUTE_STATIC, Boolean.toString(fDeclareStatic));
+		arguments.put(ATTRIBUTE_VISIBILITY, Integer.toString(fVisibility));
 
 		ConvertAnonymousDescriptor descriptor= RefactoringSignatureDescriptorFactory.createConvertAnonymousDescriptor(projectName, description, comment.asString(), arguments, flags);
 		return new RefactoringChangeDescriptor(descriptor);
@@ -589,8 +588,8 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 		SimpleName newNameNode= ast.newSimpleName(fClassName);
 		if (parameters.length > 0) {
 			final ParameterizedType parameterized= ast.newParameterizedType(ast.newSimpleType(newNameNode));
-			for (int index= 0; index < parameters.length; index++)
-				parameterized.typeArguments().add(ast.newSimpleType(ast.newSimpleName(parameters[index].getName())));
+			for (ITypeBinding parameter : parameters)
+				parameterized.typeArguments().add(ast.newSimpleType(ast.newSimpleName(parameter.getName())));
 			type= parameterized;
 		} else
 			type= ast.newSimpleType(newNameNode);
@@ -611,10 +610,8 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 	}
 
 	private void addArgumentsForLocalsUsedInInnerClass(ClassInstanceCreation newClassCreation) {
-        IVariableBinding[] usedLocals= getUsedLocalVariables();
-        for (int i= 0; i < usedLocals.length; i++) {
+        for (final IVariableBinding binding : getUsedLocalVariables()) {
             final AST ast= fAnonymousInnerClassNode.getAST();
-			final IVariableBinding binding= usedLocals[i];
 			Name name= null;
 			if (binding.isEnumConstant())
 				name= ast.newQualifiedName(ast.newSimpleName(binding.getDeclaringClass().getName()), ast.newSimpleName(binding.getName()));
@@ -686,9 +683,9 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 		newDeclaration.setName(ast.newSimpleName(fClassName));
 
 		TypeParameter parameter= null;
-		for (int index= 0; index < typeParameters.length; index++) {
+		for (ITypeBinding typeParameter : typeParameters) {
 			parameter= ast.newTypeParameter();
-			parameter.setName(ast.newSimpleName(typeParameters[index].getName()));
+			parameter.setName(ast.newSimpleName(typeParameter.getName()));
 			newDeclaration.typeParameters().add(parameter);
 		}
 		setSuperType(newDeclaration);
@@ -754,17 +751,16 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 			BodyDeclaration body= iterator.next();
 
 			for (int i= 0; i < bindings.length; i++) {
-				SimpleName[] names= LinkedNodeFinder.findByBinding(body, bindings[i]);
 				String fieldName= fieldNames[i];
-				for (int k= 0; k < names.length; k++) {
+				for (SimpleName name : LinkedNodeFinder.findByBinding(body, bindings[i])) {
 					SimpleName newNode= ast.newSimpleName(fieldName);
 					if (useThisAccess) {
 						FieldAccess access= ast.newFieldAccess();
 						access.setExpression(ast.newThisExpression());
 						access.setName(newNode);
-						astRewrite.replace(names[k], access, null);
+						astRewrite.replace(name, access, null);
 					} else {
-						astRewrite.replace(names[k], newNode, null);
+						astRewrite.replace(name, newNode, null);
 					}
 					addLinkedPosition(KEY_FIELD_NAME_EXT + i, newNode, astRewrite, false);
 				}
@@ -780,9 +776,7 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 			// move initialization of existing fields to constructor if an outer is referenced
 			List<Statement> bodyStatements= newConstructorDecl.getBody().statements();
 
-			List<VariableDeclarationFragment> fieldsToInitializeInConstructor= getFieldsToInitializeInConstructor();
-			for (Iterator<VariableDeclarationFragment> iter= fieldsToInitializeInConstructor.iterator(); iter.hasNext();) {
-				VariableDeclarationFragment fragment= iter.next();
+			for (VariableDeclarationFragment fragment : getFieldsToInitializeInConstructor()) {
 				Expression initializer= fragment.getInitializer();
 				Expression replacement= (Expression) astRewrite.get(fragment, VariableDeclarationFragment.INITIALIZER_PROPERTY);
 				if (replacement == initializer) {
@@ -833,8 +827,8 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
         final Set<IBinding> result= new HashSet<>(0);
         collectRefrencedVariables(fAnonymousInnerClassNode, result);
         ArrayList<IVariableBinding> usedLocals= new ArrayList<>();
-        for (Iterator<IBinding> iterator= result.iterator(); iterator.hasNext();) {
-        	IVariableBinding next= (IVariableBinding) iterator.next();
+        for (IBinding iBinding : result) {
+        	IVariableBinding next= (IVariableBinding) iBinding;
 			if (isBindingToTemp(next)) {
         		usedLocals.add(next);
         	}
@@ -857,7 +851,7 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
     private boolean isBindingToTemp(IVariableBinding variable) {
 		if (variable.isField())
 			return false;
-		if (!Modifier.isFinal(variable.getModifiers()) && !JavaModelUtil.is18OrHigher(fCu.getJavaProject()))
+		if (!Modifier.isFinal(variable.getModifiers()) && !JavaModelUtil.is1d8OrHigher(fCu.getJavaProject()))
 			return false;
 		ASTNode declaringNode= fCompilationUnitNode.findDeclaringNode(variable);
 		if (declaringNode == null)
@@ -991,8 +985,7 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
             Object element= iter.next();
             if (element instanceof FieldDeclaration) {
             	List<VariableDeclarationFragment> fragments= ((FieldDeclaration) element).fragments();
-                for (Iterator<VariableDeclarationFragment> fragmentIter= fragments.iterator(); fragmentIter.hasNext(); ) {
-                    VariableDeclarationFragment fragment= fragmentIter.next();
+                for (VariableDeclarationFragment fragment : fragments) {
                     if (isToBeInitializerInConstructor(fragment, result))
                         result.add(fragment);
                 }
@@ -1011,12 +1004,11 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 
         ITypeBinding anonType= fAnonymousInnerClassNode.resolveBinding();
 
-        for (Iterator<IBinding> iterator= localsUsed.iterator(); iterator.hasNext();) {
-			IVariableBinding curr= (IVariableBinding) iterator.next();
-			if (isBindingToTemp(curr)) { // reference a local from outside
+        for (IBinding iBinding : localsUsed) {
+			IVariableBinding curr= (IVariableBinding) iBinding;
+			if (isBindingToTemp(curr) // Reference a local from outside
+					|| (curr.isField() && curr.getDeclaringClass() == anonType && fieldsToInitialize.contains(fCompilationUnitNode.findDeclaringNode(curr)))) { // References a field that references a local from outside
 				return true;
-			} else if (curr.isField() && (curr.getDeclaringClass() == anonType) && fieldsToInitialize.contains(fCompilationUnitNode.findDeclaringNode(curr))) {
-				return true; // references a field that references a local from outside
 			}
 		}
         return false;
@@ -1029,9 +1021,7 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
         if (anonConstr == null)
             return null;
         ITypeBinding superClass= anonConstr.getDeclaringClass().getSuperclass();
-        IMethodBinding[] superMethods= superClass.getDeclaredMethods();
-        for (int i= 0; i < superMethods.length; i++) {
-            IMethodBinding superMethod= superMethods[i];
+        for (IMethodBinding superMethod : superClass.getDeclaredMethods()) {
             if (superMethod.isConstructor() && parameterTypesMatch(superMethod, anonConstr))
                 return superMethod;
         }
@@ -1055,9 +1045,8 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
         IMethodBinding constructorBinding= getSuperConstructorBinding();
         if (constructorBinding == null)
             return;
-        ITypeBinding[] exceptions= constructorBinding.getExceptionTypes();
-        for (int i= 0; i < exceptions.length; i++) {
-			Type exceptionType= importRewrite.addImport(exceptions[i], fAnonymousInnerClassNode.getAST());
+        for (ITypeBinding exception : constructorBinding.getExceptionTypes()) {
+			Type exceptionType= importRewrite.addImport(exception, fAnonymousInnerClassNode.getAST());
 			newConstructor.thrownExceptionTypes().add(exceptionType);
         }
     }
@@ -1075,7 +1064,7 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
         if (binding == null)
             return;
 		Type newType= (Type) ASTNode.copySubtree(fAnonymousInnerClassNode.getAST(), classInstanceCreation.getType());
-		if (binding.getSuperclass().getQualifiedName().equals("java.lang.Object")) { //$NON-NLS-1$
+		if ("java.lang.Object".equals(binding.getSuperclass().getQualifiedName())) { //$NON-NLS-1$
             Assert.isTrue(binding.getInterfaces().length <= 1);
             if (binding.getInterfaces().length == 0)
                 return;
@@ -1187,9 +1176,9 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 			int length= -1;
 			final StringTokenizer tokenizer= new StringTokenizer(selection);
 			if (tokenizer.hasMoreTokens())
-				offset= Integer.valueOf(tokenizer.nextToken()).intValue();
+				offset= Integer.parseInt(tokenizer.nextToken());
 			if (tokenizer.hasMoreTokens())
-				length= Integer.valueOf(tokenizer.nextToken()).intValue();
+				length= Integer.parseInt(tokenizer.nextToken());
 			if (offset >= 0 && length >= 0) {
 				fSelectionStart= offset;
 				fSelectionLength= length;
@@ -1199,12 +1188,12 @@ public class ConvertAnonymousToNestedRefactoring extends Refactoring {
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, JavaRefactoringDescriptorUtil.ATTRIBUTE_SELECTION));
 		final String declareStatic= arguments.getAttribute(ATTRIBUTE_STATIC);
 		if (declareStatic != null) {
-			fDeclareStatic= Boolean.valueOf(declareStatic).booleanValue();
+			fDeclareStatic= Boolean.parseBoolean(declareStatic);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_STATIC));
 		final String declareFinal= arguments.getAttribute(ATTRIBUTE_FINAL);
 		if (declareFinal != null) {
-			fDeclareFinal= Boolean.valueOf(declareFinal).booleanValue();
+			fDeclareFinal= Boolean.parseBoolean(declareFinal);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_FINAL));
 		return new RefactoringStatus();
