@@ -227,7 +227,7 @@ public final class MemberVisibilityAdjustor {
 		 * @param monitor the progress monitor to use
 		 * @throws JavaModelException if an error occurs
 		 */
-		public void rewriteVisibility(MemberVisibilityAdjustor adjustor, IProgressMonitor monitor) throws JavaModelException;
+		void rewriteVisibility(MemberVisibilityAdjustor adjustor, IProgressMonitor monitor) throws JavaModelException;
 	}
 
 	/** Description of an outgoing member visibility adjustment */
@@ -508,20 +508,18 @@ public final class MemberVisibilityAdjustor {
 		if (member instanceof IType) {
 			// recursively check accessibility of member type's members
 			final IJavaElement[] typeMembers= ((IType) member).getChildren();
-			for (int i= 0; i < typeMembers.length; i++) {
-				if (! (typeMembers[i] instanceof IInitializer))
-					adjustMemberVisibility((IMember) typeMembers[i], monitor);
+			for (IJavaElement typeMember : typeMembers) {
+				if (! (typeMember instanceof IInitializer))
+					adjustMemberVisibility((IMember) typeMember, monitor);
 			}
 		}
 
 		if (member.equals(fReferenced) || Modifier.isPublic(member.getFlags()))
 			return;
 
-		final SearchResultGroup[] references= findReferences(member, monitor);
-		for (int i= 0; i < references.length; i++) {
-			final SearchMatch[] searchResults= references[i].getSearchResults();
-			for (int k= 0; k < searchResults.length; k++) {
-				final IJavaElement referenceToMember= (IJavaElement) searchResults[k].getElement();
+		for (SearchResultGroup reference : findReferences(member, monitor)) {
+			for (SearchMatch searchResult : reference.getSearchResults()) {
+				final IJavaElement referenceToMember= (IJavaElement) searchResult.getElement();
 				if (fAdjustments.get(member) == null && referenceToMember instanceof IMember && !isInsideMovedMember(referenceToMember)) {
 					// check whether the member is still visible from the
 					// destination. As we are moving a type, the destination is
@@ -579,12 +577,10 @@ public final class MemberVisibilityAdjustor {
 		try {
 			monitor.beginTask("", groups.length); //$NON-NLS-1$
 			monitor.setTaskName(RefactoringCoreMessages.MemberVisibilityAdjustor_checking);
-			SearchMatch[] matches= null;
 			boolean adjusted= false;
-			for (int index= 0; index < groups.length; index++) {
-				matches= groups[index].getSearchResults();
-				for (int offset= 0; offset < matches.length; offset++) {
-					final Object element= matches[offset].getElement();
+			for (SearchResultGroup group : groups) {
+				for (SearchMatch match : group.getSearchResults()) {
+					final Object element= match.getElement();
 					if (element instanceof IMember && !isInsideMovedMember((IMember) element)) {
 						// found one reference which is not inside the moved
 						// element => adjust visibility of the moved element
@@ -683,16 +679,11 @@ public final class MemberVisibilityAdjustor {
 		try {
 			monitor.beginTask("", groups.length); //$NON-NLS-1$
 			monitor.setTaskName(RefactoringCoreMessages.MemberVisibilityAdjustor_checking);
-			IJavaElement element= null;
-			SearchMatch[] matches= null;
-			SearchResultGroup group= null;
-			for (int index= 0; index < groups.length; index++) {
-				group= groups[index];
-				element= JavaCore.create(group.getResource());
+			for (SearchResultGroup group : groups) {
+				IJavaElement element= JavaCore.create(group.getResource());
 				if (element instanceof ICompilationUnit) {
-					matches= group.getSearchResults();
-					for (int offset= 0; offset < matches.length; offset++)
-						adjustOutgoingVisibility(matches[offset], new SubProgressMonitor(monitor, 1));
+					for (SearchMatch match : group.getSearchResults())
+						adjustOutgoingVisibility(match, new SubProgressMonitor(monitor, 1));
 				} // else if (element != null)
 				// fStatus.merge(RefactoringStatus.createStatus(fFailureSeverity, RefactoringCoreMessages.getFormattedString("MemberVisibilityAdjustor.binary.outgoing.project", new String[] { element.getJavaProject().getElementName(), getLabel(fReferenced)}), null, null, RefactoringStatusEntry.NO_CODE, null)); //$NON-NLS-1$
 				// else if (group.getResource() != null)
@@ -713,7 +704,7 @@ public final class MemberVisibilityAdjustor {
 	 * @param monitor the progress monitor to use
 	 * @throws JavaModelException if an error occurs during search
 	 */
-	public final void adjustVisibility(final IProgressMonitor monitor) throws JavaModelException {
+	public void adjustVisibility(final IProgressMonitor monitor) throws JavaModelException {
 		try {
 			monitor.beginTask("", 7); //$NON-NLS-1$
 			monitor.setTaskName(RefactoringCoreMessages.MemberVisibilityAdjustor_checking);
@@ -782,11 +773,10 @@ public final class MemberVisibilityAdjustor {
 						case IJavaElement.FIELD:
 						case IJavaElement.METHOD: {
 							final IMember member= (IMember) referencing;
-							if (typeReferenced.equals(member.getDeclaringType()))
+							if (typeReferenced.equals(member.getDeclaringType())
+									|| (referencedUnit != null && referencedUnit.equals(member.getCompilationUnit()))) {
 								keyword= ModifierKeyword.PRIVATE_KEYWORD;
-							else if (referencedUnit != null && referencedUnit.equals(member.getCompilationUnit()))
-								keyword= ModifierKeyword.PRIVATE_KEYWORD;
-							else if (typeReferenced.getPackageFragment().equals(member.getDeclaringType().getPackageFragment()))
+							} else if (typeReferenced.getPackageFragment().equals(member.getDeclaringType().getPackageFragment()))
 								keyword= null;
 							break;
 						}
@@ -812,11 +802,10 @@ public final class MemberVisibilityAdjustor {
 						case IJavaElement.FIELD:
 						case IJavaElement.METHOD: {
 							final IMember member= (IMember) referencing;
-							if (fieldReferenced.getDeclaringType().equals(member.getDeclaringType()))
+							if (fieldReferenced.getDeclaringType().equals(member.getDeclaringType())
+									|| (referencedUnit != null && referencedUnit.equals(member.getCompilationUnit()))) {
 								keyword= ModifierKeyword.PRIVATE_KEYWORD;
-							else if (referencedUnit != null && referencedUnit.equals(member.getCompilationUnit()))
-								keyword= ModifierKeyword.PRIVATE_KEYWORD;
-							else if (fieldReferenced.getDeclaringType().getPackageFragment().equals(member.getDeclaringType().getPackageFragment()))
+							} else if (fieldReferenced.getDeclaringType().getPackageFragment().equals(member.getDeclaringType().getPackageFragment()))
 								keyword= null;
 							break;
 						}
@@ -842,11 +831,10 @@ public final class MemberVisibilityAdjustor {
 						case IJavaElement.FIELD:
 						case IJavaElement.METHOD: {
 							final IMember member= (IMember) referencing;
-							if (methodReferenced.getDeclaringType().equals(member.getDeclaringType()))
+							if (methodReferenced.getDeclaringType().equals(member.getDeclaringType())
+									|| (referencedUnit != null && referencedUnit.equals(member.getCompilationUnit()))) {
 								keyword= ModifierKeyword.PRIVATE_KEYWORD;
-							else if (referencedUnit != null && referencedUnit.equals(member.getCompilationUnit()))
-								keyword= ModifierKeyword.PRIVATE_KEYWORD;
-							else if (methodReferenced.getDeclaringType().getPackageFragment().equals(member.getDeclaringType().getPackageFragment()))
+							} else if (methodReferenced.getDeclaringType().getPackageFragment().equals(member.getDeclaringType().getPackageFragment()))
 								keyword= null;
 							break;
 						}
@@ -984,7 +972,7 @@ public final class MemberVisibilityAdjustor {
 	 *
 	 * @return the visibility adjustments
 	 */
-	public final Map<IMember, IncomingMemberVisibilityAdjustment> getAdjustments() {
+	public Map<IMember, IncomingMemberVisibilityAdjustment> getAdjustments() {
 		return fAdjustments;
 	}
 
@@ -1057,9 +1045,9 @@ public final class MemberVisibilityAdjustor {
 	 * @param monitor the progress monitor to use
 	 * @throws JavaModelException if an error occurs during search
 	 */
-	public final void rewriteVisibility(final ICompilationUnit unit, final IProgressMonitor monitor) throws JavaModelException {
+	public void rewriteVisibility(final ICompilationUnit unit, final IProgressMonitor monitor) throws JavaModelException {
 		try {
-			monitor.beginTask("", fAdjustments.keySet().size()); //$NON-NLS-1$
+			monitor.beginTask("", fAdjustments.size()); //$NON-NLS-1$
 			monitor.setTaskName(RefactoringCoreMessages.MemberVisibilityAdjustor_adjusting);
 			IMember member= null;
 			IVisibilityAdjustment adjustment= null;
@@ -1083,9 +1071,9 @@ public final class MemberVisibilityAdjustor {
 	 * @param monitor the progress monitor to use
 	 * @throws JavaModelException if an error occurs during search
 	 */
-	public final void rewriteVisibility(final IProgressMonitor monitor) throws JavaModelException {
+	public void rewriteVisibility(final IProgressMonitor monitor) throws JavaModelException {
 		try {
-			monitor.beginTask("", fAdjustments.keySet().size()); //$NON-NLS-1$
+			monitor.beginTask("", fAdjustments.size()); //$NON-NLS-1$
 			monitor.setTaskName(RefactoringCoreMessages.MemberVisibilityAdjustor_adjusting);
 			IMember member= null;
 			IVisibilityAdjustment adjustment= null;
@@ -1110,7 +1098,7 @@ public final class MemberVisibilityAdjustor {
 	 *
 	 * @param adjustments the existing adjustments to set
 	 */
-	public final void setAdjustments(final Map<IMember, IncomingMemberVisibilityAdjustment> adjustments) {
+	public void setAdjustments(final Map<IMember, IncomingMemberVisibilityAdjustment> adjustments) {
 		Assert.isNotNull(adjustments);
 		fAdjustments= adjustments;
 	}
@@ -1122,7 +1110,7 @@ public final class MemberVisibilityAdjustor {
 	 *
 	 * @param severity the severity of failure messages
 	 */
-	public final void setFailureSeverity(final int severity) {
+	public void setFailureSeverity(final int severity) {
 		Assert.isTrue(isStatusSeverity(severity));
 	}
 
@@ -1133,7 +1121,7 @@ public final class MemberVisibilityAdjustor {
 	 *
 	 * @param incoming <code>true</code> if incoming references should be adjusted, <code>false</code> otherwise
 	 */
-	public final void setIncoming(final boolean incoming) {
+	public void setIncoming(final boolean incoming) {
 		fIncoming= incoming;
 	}
 
@@ -1144,7 +1132,7 @@ public final class MemberVisibilityAdjustor {
 	 *
 	 * @param outgoing <code>true</code> if outgoing references should be adjusted, <code>false</code> otherwise
 	 */
-	public final void setOutgoing(final boolean outgoing) {
+	public void setOutgoing(final boolean outgoing) {
 		fOutgoing= outgoing;
 	}
 
@@ -1156,7 +1144,7 @@ public final class MemberVisibilityAdjustor {
 	 * @param rewrite the AST rewrite to set
 	 * @param root the root of the AST used in the rewrite
 	 */
-	public final void setRewrite(final ASTRewrite rewrite, final CompilationUnit root) {
+	public void setRewrite(final ASTRewrite rewrite, final CompilationUnit root) {
 		Assert.isTrue(rewrite == null || root != null);
 		fRewrite= rewrite;
 		fRoot= root;
@@ -1169,7 +1157,7 @@ public final class MemberVisibilityAdjustor {
 	 *
 	 * @param rewrites the map of compilation units to compilation unit rewrites to set
 	 */
-	public final void setRewrites(final Map<ICompilationUnit, CompilationUnitRewrite> rewrites) {
+	public void setRewrites(final Map<ICompilationUnit, CompilationUnitRewrite> rewrites) {
 		Assert.isNotNull(rewrites);
 		fRewrites= rewrites;
 	}
@@ -1181,7 +1169,7 @@ public final class MemberVisibilityAdjustor {
 	 *
 	 * @param scope the search scope to set
 	 */
-	public final void setScope(final IJavaSearchScope scope) {
+	public void setScope(final IJavaSearchScope scope) {
 		Assert.isNotNull(scope);
 		fScope= scope;
 	}
@@ -1193,7 +1181,7 @@ public final class MemberVisibilityAdjustor {
 	 *
 	 * @param owner the working copy owner, or <code>null</code> to use none
 	 */
-	public final void setOwner(final WorkingCopyOwner owner) {
+	public void setOwner(final WorkingCopyOwner owner) {
 		fOwner= owner;
 	}
 
@@ -1204,7 +1192,7 @@ public final class MemberVisibilityAdjustor {
 	 *
 	 * @param status the refactoring status to set
 	 */
-	public final void setStatus(final RefactoringStatus status) {
+	public void setStatus(final RefactoringStatus status) {
 		Assert.isNotNull(status);
 		fStatus= status;
 	}
@@ -1216,7 +1204,7 @@ public final class MemberVisibilityAdjustor {
 	 *
 	 * @param severity the severity of visibility messages
 	 */
-	public final void setVisibilitySeverity(final int severity) {
+	public void setVisibilitySeverity(final int severity) {
 		Assert.isTrue(isStatusSeverity(severity));
 		fVisibilitySeverity= severity;
 	}
@@ -1237,10 +1225,7 @@ public final class MemberVisibilityAdjustor {
 			keyword= ModifierKeyword.PRIVATE_KEYWORD;
 		else {
 			final ITypeHierarchy hierarchy= getTypeHierarchy(referencing, new SubProgressMonitor(monitor, 1));
-			final IType[] types= hierarchy.getSupertypes(referencing);
-			IType superType= null;
-			for (int index= 0; index < types.length; index++) {
-				superType= types[index];
+			for (IType superType : hierarchy.getSupertypes(referencing)) {
 				if (superType.equals(referenced.getDeclaringType())) {
 					keyword= ModifierKeyword.PROTECTED_KEYWORD;
 					return keyword;
@@ -1275,10 +1260,7 @@ public final class MemberVisibilityAdjustor {
 			tmp= tmp.getDeclaringType();
 		}
 		final ITypeHierarchy hierarchy= getTypeHierarchy(referencing, new SubProgressMonitor(monitor, 1));
-		final IType[] types= hierarchy.getSupertypes(referencing);
-		IType superType= null;
-		for (int index= 0; index < types.length; index++) {
-			superType= types[index];
+		for (IType superType : hierarchy.getSupertypes(referencing)) {
 			if (superType.equals(referenced.getDeclaringType())) {
 				return ModifierKeyword.PROTECTED_KEYWORD;
 			}
@@ -1310,10 +1292,7 @@ public final class MemberVisibilityAdjustor {
 			keyword= ModifierKeyword.PRIVATE_KEYWORD;
 		else {
 			final ITypeHierarchy hierarchy= getTypeHierarchy(referencing, new SubProgressMonitor(monitor, 1));
-			final IType[] types= hierarchy.getSupertypes(referencing);
-			IType superType= null;
-			for (int index= 0; index < types.length; index++) {
-				superType= types[index];
+			for (IType superType : hierarchy.getSupertypes(referencing)) {
 				if (superType.equals(referenced)) {
 					keyword= null;
 					return keyword;
