@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -12,6 +12,7 @@
  *     IBM Corporation - initial API and implementation
  *     Samrat Dhillon samrat.dhillon@gmail.com - [move member type] Moving a member interface to its own file adds the host's type parameters to it - https://bugs.eclipse.org/bugs/show_bug.cgi?id=385237
  *     Microsoft Corporation - copied to jdt.core.manipulation
+ *     Microsoft Corporation - read formatting options from the compilation unit
  *******************************************************************************/
 package org.eclipse.jdt.internal.corext.refactoring.structure;
 
@@ -36,7 +37,6 @@ import org.eclipse.text.edits.TextEdit;
 import org.eclipse.text.edits.TextEditGroup;
 
 import org.eclipse.ltk.core.refactoring.Change;
-import org.eclipse.ltk.core.refactoring.IRefactoringStatusEntryComparator;
 import org.eclipse.ltk.core.refactoring.Refactoring;
 import org.eclipse.ltk.core.refactoring.RefactoringDescriptor;
 import org.eclipse.ltk.core.refactoring.RefactoringStatus;
@@ -195,8 +195,8 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 				expression.accept(this);
 			}
 			List<Expression> arguments= node.arguments();
-			for (int i= 0; i < arguments.size(); i++) {
-				arguments.get(i).accept(this);
+			for (Expression argument : arguments) {
+				argument.accept(this);
 			}
 			return false;
 		}
@@ -355,35 +355,28 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 	}
 
 	private static boolean containsNonStatic(MethodInvocation[] invocations) {
-		for (int i= 0; i < invocations.length; i++) {
-			if (!isStatic(invocations[i]))
+		for (MethodInvocation invocation : invocations) {
+			if (!isStatic(invocation))
 				return true;
 		}
 		return false;
 	}
 
 	private static boolean containsNonStatic(SimpleName[] fieldNames) {
-		for (int i= 0; i < fieldNames.length; i++) {
-			if (!isStaticFieldName(fieldNames[i]))
+		for (SimpleName fieldName : fieldNames) {
+			if (!isStaticFieldName(fieldName))
 				return true;
 		}
 		return false;
 	}
 
 	private static boolean containsStatusEntry(final RefactoringStatus status, final RefactoringStatusEntry other) {
-		return status.getEntries(new IRefactoringStatusEntryComparator() {
-
-			@Override
-			public final int compare(final RefactoringStatusEntry entry1, final RefactoringStatusEntry entry2) {
-				return entry1.getMessage().compareTo(entry2.getMessage());
-			}
-		}, other).length > 0;
+		return status.getEntries((entry1, entry2) -> entry1.getMessage().compareTo(entry2.getMessage()), other).length > 0;
 	}
 
 	private static AbstractTypeDeclaration findTypeDeclaration(IType enclosing, AbstractTypeDeclaration[] declarations) {
 		String typeName= enclosing.getElementName();
-		for (int i= 0; i < declarations.length; i++) {
-			AbstractTypeDeclaration declaration= declarations[i];
+		for (AbstractTypeDeclaration declaration : declarations) {
 			if (declaration.getName().getIdentifier().equals(typeName))
 				return declaration;
 		}
@@ -395,8 +388,7 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 		types.add(type);
 		AbstractTypeDeclaration[] declarations= (AbstractTypeDeclaration[]) unit.types().toArray(new AbstractTypeDeclaration[unit.types().size()]);
 		AbstractTypeDeclaration declaration= null;
-		for (final Iterator<IType> iterator= types.iterator(); iterator.hasNext();) {
-			IType enclosing= iterator.next();
+		for (IType enclosing : types) {
 			declaration= findTypeDeclaration(enclosing, declarations);
 			Assert.isNotNull(declaration);
 			declarations= getAbstractTypeDeclarations(declaration);
@@ -436,8 +428,8 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 		try {
 			IField[] fields= type.getFields();
 			List<String> result= new ArrayList<>(fields.length);
-			for (int i= 0; i < fields.length; i++) {
-				result.add(fields[i].getElementName());
+			for (IField field : fields) {
+				result.add(field.getElementName());
 			}
 			return result.toArray(new String[result.size()]);
 		} catch (JavaModelException e) {
@@ -446,17 +438,15 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 	}
 
 	private static Set<ICompilationUnit> getMergedSet(Set<ICompilationUnit> s1, Set<ICompilationUnit> s2) {
-		Set<ICompilationUnit> result= new HashSet<>();
-		result.addAll(s1);
+		Set<ICompilationUnit> result= new HashSet<>(s1);
 		result.addAll(s2);
 		return result;
 	}
 
 	private static String[] getParameterNamesOfAllConstructors(IType type) throws JavaModelException {
-		IMethod[] constructors= JavaElementUtil.getAllConstructors(type);
 		Set<String> result= new HashSet<>();
-		for (int i= 0; i < constructors.length; i++) {
-			result.addAll(Arrays.asList(constructors[i].getParameterNames()));
+		for (IMethod constructor : JavaElementUtil.getAllConstructors(type)) {
+			result.addAll(Arrays.asList(constructor.getParameterNames()));
 		}
 		return result.toArray(new String[result.size()]);
 	}
@@ -545,7 +535,7 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 		fQualifiedTypeName= JavaModelUtil.concatenateName(fType.getPackageFragment().getElementName(), fType.getElementName());
 		fEnclosingInstanceFieldName= getInitialNameForEnclosingInstanceField();
 		fSourceRewrite= new CompilationUnitRewrite(fType.getCompilationUnit());
-		fIsInstanceFieldCreationPossible= !(JdtFlags.isStatic(fType) || fType.isAnnotation() || fType.isEnum() || (fType.getDeclaringType() == null && !JavaElementUtil.isMainType(fType)));
+		fIsInstanceFieldCreationPossible= !JdtFlags.isStatic(fType) && !fType.isAnnotation() && !fType.isEnum() && (fType.getDeclaringType() != null || JavaElementUtil.isMainType(fType));
 		fIsInstanceFieldCreationMandatory= fIsInstanceFieldCreationPossible && isInstanceFieldCreationMandatory();
 		fCreateInstanceField= fIsInstanceFieldCreationMandatory;
 	}
@@ -581,9 +571,8 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 				names.add(parameter.getName().getIdentifier());
 			}
 			final ListRewrite rewriter= rewrite.getListRewrite(type, TypeDeclaration.TYPE_PARAMETERS_PROPERTY);
-			String name= null;
-			for (int index= 0; index < parameters.length; index++) {
-				name= parameters[index].getName();
+			for (ITypeBinding parameter2 : parameters) {
+				String name= parameter2.getName();
 				if (!names.contains(name)) {
 					parameter= type.getAST().newTypeParameter();
 					parameter.setName(type.getAST().newSimpleName(name));
@@ -693,9 +682,7 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 	private RefactoringStatus checkConstructorParameterNames() {
 		RefactoringStatus result= new RefactoringStatus();
 		CompilationUnit cuNode= new RefactoringASTParser(IASTSharedValues.SHARED_AST_LEVEL).parse(fType.getCompilationUnit(), false);
-		MethodDeclaration[] nodes= getConstructorDeclarationNodes(findTypeDeclaration(fType, cuNode));
-		for (int i= 0; i < nodes.length; i++) {
-			MethodDeclaration constructor= nodes[i];
+		for (MethodDeclaration constructor : getConstructorDeclarationNodes(findTypeDeclaration(fType, cuNode))) {
 			for (Iterator<SingleVariableDeclaration> iter= constructor.parameters().iterator(); iter.hasNext();) {
 				SingleVariableDeclaration param= iter.next();
 				if (fEnclosingInstanceFieldName.equals(param.getName().getIdentifier())) {
@@ -742,7 +729,7 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 			result.merge(checkConstructorParameterNames());
 			result.merge(checkTypeNameInPackage());
 			fChangeManager= createChangeManager(new SubProgressMonitor(pm, 1), result);
-			result.merge(Checks.validateModifiesFiles(ResourceUtil.getFiles(fChangeManager.getAllCompilationUnits()), getValidationContext()));
+			result.merge(Checks.validateModifiesFiles(ResourceUtil.getFiles(fChangeManager.getAllCompilationUnits()), getValidationContext(), pm));
 			return result;
 		} finally {
 			pm.done();
@@ -797,10 +784,10 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 			arguments.put(ATTRIBUTE_FIELD_NAME, fEnclosingInstanceFieldName);
 		if (fNameForEnclosingInstanceConstructorParameter != null && !"".equals(fNameForEnclosingInstanceConstructorParameter)) //$NON-NLS-1$
 			arguments.put(ATTRIBUTE_PARAMETER_NAME, fNameForEnclosingInstanceConstructorParameter);
-		arguments.put(ATTRIBUTE_FIELD, Boolean.valueOf(fCreateInstanceField).toString());
-		arguments.put(ATTRIBUTE_FINAL, Boolean.valueOf(fMarkInstanceFieldAsFinal).toString());
-		arguments.put(ATTRIBUTE_POSSIBLE, Boolean.valueOf(fIsInstanceFieldCreationPossible).toString());
-		arguments.put(ATTRIBUTE_MANDATORY, Boolean.valueOf(fIsInstanceFieldCreationMandatory).toString());
+		arguments.put(ATTRIBUTE_FIELD, Boolean.toString(fCreateInstanceField));
+		arguments.put(ATTRIBUTE_FINAL, Boolean.toString(fMarkInstanceFieldAsFinal));
+		arguments.put(ATTRIBUTE_POSSIBLE, Boolean.toString(fIsInstanceFieldCreationPossible));
+		arguments.put(ATTRIBUTE_MANDATORY, Boolean.toString(fIsInstanceFieldCreationMandatory));
 		final DynamicValidationRefactoringChange result= new DynamicValidationRefactoringChange(descriptor, RefactoringCoreMessages.MoveInnerToTopRefactoring_move_to_Top);
 		result.addAll(fChangeManager.getAllChanges());
 		result.add(createCompilationUnitForMovedType(new SubProgressMonitor(monitor, 1)));
@@ -824,7 +811,7 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 			adjustor.adjustVisibility(new SubProgressMonitor(monitor, 1));
 			final Map<String, ITypeBinding> parameters= new LinkedHashMap<>();
 			addTypeParameters(fSourceRewrite.getRoot(), fType, parameters);
-			final ITypeBinding[] bindings= new ITypeBinding[parameters.values().size()];
+			final ITypeBinding[] bindings= new ITypeBinding[parameters.size()];
 			parameters.values().toArray(bindings);
 			final Map<ICompilationUnit, SearchMatch[]> typeReferences= createTypeReferencesMapping(new SubProgressMonitor(monitor, 1), status);
 			Map<ICompilationUnit, SearchMatch[]> constructorReferences= null;
@@ -844,8 +831,7 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 			}
 			monitor.worked(1);
 			ICompilationUnit inputCU= fType.getCompilationUnit();
-			for (final Iterator<ICompilationUnit> iterator= getMergedSet(typeReferences.keySet(), constructorReferences.keySet()).iterator(); iterator.hasNext();) {
-				final ICompilationUnit unit= iterator.next();
+			for (ICompilationUnit unit : getMergedSet(typeReferences.keySet(), constructorReferences.keySet())) {
 				final CompilationUnitRewrite targetRewrite= getCompilationUnitRewrite(unit);
 				createCompilationUnitRewrite(bindings, targetRewrite, typeReferences, constructorReferences, adjustor.getAdjustments().containsKey(fType), inputCU, unit, false, status, monitor);
 				if (unit.equals(inputCU)) {
@@ -908,8 +894,8 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 				fTypeImports= new HashSet<>();
 				fStaticImports= new HashSet<>();
 				ImportRewriteUtil.collectImports(fType.getJavaProject(), declaration, fTypeImports, fStaticImports, false);
-				if (binding != null)
-					fTypeImports.remove(binding);
+				handleParametrizedTypeImports(fTypeImports);
+				removeEnclosingTypeImports(binding);
 			}
 			addEnclosingInstanceTypeParameters(parameters, declaration, rewrite);
 			modifyAccessToEnclosingInstance(targetRewrite, declaration, monitor);
@@ -943,12 +929,57 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 				ModifierRewrite.create(rewrite, declaration).setModifiers(newFlags, groupMove);
 			}
 		}
-		ASTNode[] references= getReferenceNodesIn(root, typeReferences, targetUnit);
-		for (int index= 0; index < references.length; index++)
-			updateTypeReference(parameters, references[index], targetRewrite, targetUnit);
-		references= getReferenceNodesIn(root, constructorReferences, targetUnit);
-		for (int index= 0; index < references.length; index++)
-			updateConstructorReference(parameters, references[index], targetRewrite, targetUnit);
+		for (ASTNode reference : getReferenceNodesIn(root, typeReferences, targetUnit))
+			updateTypeReference(parameters, reference, targetRewrite, targetUnit);
+		for (ASTNode reference : getReferenceNodesIn(root, constructorReferences, targetUnit))
+			updateConstructorReference(parameters, reference, targetRewrite, targetUnit);
+	}
+
+	private void removeEnclosingTypeImports(final ITypeBinding binding) {
+		if (binding != null && fTypeImports != null) {
+			Iterator<ITypeBinding> iterator= fTypeImports.iterator();
+			while (iterator.hasNext()) {
+				ITypeBinding typeBinding=  iterator.next();
+				ITypeBinding parentBinding= typeBinding;
+				while (parentBinding != null) {
+					if (parentBinding == binding) {
+						iterator.remove();
+						break;
+					}
+					parentBinding= parentBinding.getDeclaringClass();
+				}
+			}
+		}
+	}
+
+	private void handleParametrizedTypeImports(Collection<ITypeBinding> imports) {
+		if (imports != null) {
+			Iterator<ITypeBinding> iterator= imports.iterator();
+			Collection<ITypeBinding> additionalTypeImports= new HashSet<>();
+			while (iterator.hasNext()) {
+				ITypeBinding typeBinding=  iterator.next();
+				if (typeBinding.isParameterizedType()) {
+					addParametrizedTypeArgumentImports(additionalTypeImports, typeBinding);
+					iterator.remove();
+				}
+			}
+			imports.addAll(additionalTypeImports);
+		}
+	}
+
+	private void addParametrizedTypeArgumentImports(Collection<ITypeBinding> importsList,ITypeBinding typeBinding) {
+		if (importsList != null && typeBinding != null && typeBinding.isParameterizedType()) {
+			ITypeBinding basicType= typeBinding.getTypeDeclaration();
+			ITypeBinding[] typeArguments= typeBinding.getTypeArguments();
+			importsList.add(basicType);
+			for (ITypeBinding typeArgument : typeArguments) {
+				if (typeArgument.isParameterizedType()) {
+					addParametrizedTypeArgumentImports(importsList, typeArgument);
+				} else {
+					importsList.add(typeArgument);
+				}
+			}
+		}
 	}
 
 	private void createConstructor(final AbstractTypeDeclaration declaration, final ASTRewrite rewrite) throws CoreException {
@@ -989,10 +1020,8 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 
 	// Map<ICompilationUnit, SearchMatch[]>
 	private Map<ICompilationUnit, SearchMatch[]> createConstructorReferencesMapping(IProgressMonitor pm, RefactoringStatus status) throws JavaModelException {
-		SearchResultGroup[] groups= ConstructorReferenceFinder.getConstructorReferences(fType, pm, status);
 		Map<ICompilationUnit, SearchMatch[]> result= new HashMap<>();
-		for (int i= 0; i < groups.length; i++) {
-			SearchResultGroup group= groups[i];
+		for (SearchResultGroup group : ConstructorReferenceFinder.getConstructorReferences(fType, pm, status)) {
 			ICompilationUnit cu= group.getCompilationUnit();
 			if (cu == null)
 				continue;
@@ -1038,8 +1067,8 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 		final Type type= ASTNodeFactory.newType(ast, fType.getDeclaringType().getTypeQualifiedName('.'));
 		if (parameters.length > 0) {
 			final ParameterizedType parameterized= ast.newParameterizedType(type);
-			for (int index= 0; index < parameters.length; index++)
-				parameterized.typeArguments().add(ast.newSimpleType(ast.newSimpleName(parameters[index].getElementName())));
+			for (ITypeParameter parameter : parameters)
+				parameterized.typeArguments().add(ast.newSimpleType(ast.newSimpleName(parameter.getElementName())));
 			return parameterized;
 		}
 		return type;
@@ -1114,10 +1143,8 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 		engine.setScope(RefactoringScopeFactory.create(fType));
 		engine.setStatus(status);
 		engine.searchPattern(new SubProgressMonitor(pm, 1));
-		final SearchResultGroup[] groups= (SearchResultGroup[]) engine.getResults();
 		Map<ICompilationUnit, SearchMatch[]> result= new HashMap<>();
-		for (int i= 0; i < groups.length; i++) {
-			SearchResultGroup group= groups[i];
+		for (SearchResultGroup group : (SearchResultGroup[]) engine.getResults()) {
 			ICompilationUnit cu= group.getCompilationUnit();
 			if (cu == null)
 				continue;
@@ -1129,7 +1156,7 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 	private String getAlignedSourceBlock(final ICompilationUnit unit, final String block) {
 		Assert.isNotNull(block);
 		final String[] lines= Strings.convertIntoLines(block);
-		Strings.trimIndentation(lines, unit.getJavaProject(), false);
+		Strings.trimIndentation(lines, unit, false);
 		return Strings.concatenate(lines, StubUtility.getLineDelimiterUsed(fType.getJavaProject()));
 	}
 
@@ -1142,11 +1169,10 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 
 	private MethodDeclaration[] getConstructorDeclarationNodes(final AbstractTypeDeclaration declaration) {
 		if (declaration instanceof TypeDeclaration) {
-			final MethodDeclaration[] declarations= ((TypeDeclaration) declaration).getMethods();
 			final List<MethodDeclaration> result= new ArrayList<>(2);
-			for (int index= 0; index < declarations.length; index++) {
-				if (declarations[index].isConstructor())
-					result.add(declarations[index]);
+			for (MethodDeclaration declaration2 : ((TypeDeclaration) declaration).getMethods()) {
+				if (declaration2.isConstructor())
+					result.add(declaration2);
 			}
 			return result.toArray(new MethodDeclaration[result.size()]);
 		}
@@ -1176,7 +1202,7 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 		if (suggestedNames.length > 0)
 			return suggestedNames[0];
 		String name= enclosingType.getElementName();
-		if (name.equals("")) //$NON-NLS-1$
+		if (name.isEmpty())
 			return ""; //$NON-NLS-1$
 		return Character.toLowerCase(name.charAt(0)) + name.substring(1);
 	}
@@ -1219,8 +1245,8 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 			raw= true;
 		if (parameters != null && parameters.length > 0 && !raw) {
 			final ParameterizedType type= ast.newParameterizedType(ast.newSimpleType(ast.newName(fQualifiedTypeName)));
-			for (int index= 0; index < parameters.length; index++)
-				type.typeArguments().add(ast.newSimpleType(ast.newSimpleName(parameters[index].getName())));
+			for (ITypeBinding parameter : parameters)
+				type.typeArguments().add(ast.newSimpleType(ast.newSimpleName(parameter.getName())));
 			return type;
 		}
 		return ast.newName(fQualifiedTypeName);
@@ -1234,8 +1260,8 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 			raw= true;
 		if (parameters != null && parameters.length > 0 && !raw) {
 			final ParameterizedType type= ast.newParameterizedType(ast.newSimpleType(ast.newSimpleName(fType.getElementName())));
-			for (int index= 0; index < parameters.length; index++)
-				type.typeArguments().add(ast.newSimpleType(ast.newSimpleName(parameters[index].getName())));
+			for (ITypeBinding parameter : parameters)
+				type.typeArguments().add(ast.newSimpleType(ast.newSimpleName(parameter.getName())));
 			return type;
 		}
 		return ast.newSimpleType(ast.newSimpleName(fType.getElementName()));
@@ -1349,14 +1375,10 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 	}
 
 	private void modifyAccessToFieldsFromEnclosingInstance(CompilationUnitRewrite targetRewrite, SimpleName[] simpleNames, AbstractTypeDeclaration declaration) {
-		IBinding binding= null;
-		SimpleName simpleName= null;
-		IVariableBinding variable= null;
-		for (int index= 0; index < simpleNames.length; index++) {
-			simpleName= simpleNames[index];
-			binding= simpleName.resolveBinding();
-			if (binding != null && binding instanceof IVariableBinding && !(simpleName.getParent() instanceof FieldAccess)) {
-				variable= (IVariableBinding) binding;
+		for (SimpleName simpleName : simpleNames) {
+			IBinding binding= simpleName.resolveBinding();
+			if (binding instanceof IVariableBinding && !(simpleName.getParent() instanceof FieldAccess)) {
+				IVariableBinding variable= (IVariableBinding) binding;
 				final FieldAccess access= simpleName.getAST().newFieldAccess();
 				access.setExpression(createAccessExpressionToEnclosingInstanceFieldText(simpleName, variable, declaration));
 				access.setName(simpleName.getAST().newSimpleName(simpleName.getIdentifier()));
@@ -1367,18 +1389,15 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 	}
 
 	private void modifyAccessToMethodsFromEnclosingInstance(CompilationUnitRewrite targetRewrite, MethodInvocation[] methodInvocations, AbstractTypeDeclaration declaration) {
-		IMethodBinding binding= null;
-		MethodInvocation invocation= null;
-		for (int index= 0; index < methodInvocations.length; index++) {
-			invocation= methodInvocations[index];
-			binding= invocation.resolveMethodBinding();
+		for (MethodInvocation invocation : methodInvocations) {
+			IMethodBinding binding= invocation.resolveMethodBinding();
 			if (binding != null) {
 				final Expression target= invocation.getExpression();
 				if (target == null) {
 					final Expression expression= createAccessExpressionToEnclosingInstanceFieldText(invocation, binding, declaration);
 					targetRewrite.getASTRewrite().set(invocation, MethodInvocation.EXPRESSION_PROPERTY, expression, null);
 				} else {
-					if (!(invocation.getExpression() instanceof ThisExpression) || !(((ThisExpression) invocation.getExpression()).getQualifier() != null))
+					if (!(invocation.getExpression() instanceof ThisExpression) || (((ThisExpression) invocation.getExpression()).getQualifier() == null))
 						continue;
 					targetRewrite.getASTRewrite().replace(target, createAccessExpressionToEnclosingInstanceFieldText(invocation, binding, declaration), null);
 					targetRewrite.getImportRemover().registerRemovedNode(target);
@@ -1388,11 +1407,10 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 	}
 
 	private void modifyConstructors(AbstractTypeDeclaration declaration, ASTRewrite rewrite) throws CoreException {
-		final MethodDeclaration[] declarations= getConstructorDeclarationNodes(declaration);
-		for (int index= 0; index < declarations.length; index++) {
-			Assert.isTrue(declarations[index].isConstructor());
-			addParameterToConstructor(rewrite, declarations[index]);
-			setEnclosingInstanceFieldInConstructor(rewrite, declarations[index]);
+		for (MethodDeclaration declaration2 : getConstructorDeclarationNodes(declaration)) {
+			Assert.isTrue(declaration2.isConstructor());
+			addParameterToConstructor(rewrite, declaration2);
+			setEnclosingInstanceFieldInConstructor(rewrite, declaration2);
 		}
 	}
 
@@ -1607,22 +1625,22 @@ public final class MoveInnerToTopRefactoring extends Refactoring {
 			fNameForEnclosingInstanceConstructorParameter= parameterName;
 		final String createField= arguments.getAttribute(ATTRIBUTE_FIELD);
 		if (createField != null) {
-			fCreateInstanceField= Boolean.valueOf(createField).booleanValue();
+			fCreateInstanceField= Boolean.parseBoolean(createField);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_FIELD));
 		final String markFinal= arguments.getAttribute(ATTRIBUTE_FINAL);
 		if (markFinal != null) {
-			fMarkInstanceFieldAsFinal= Boolean.valueOf(markFinal).booleanValue();
+			fMarkInstanceFieldAsFinal= Boolean.parseBoolean(markFinal);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_FINAL));
 		final String possible= arguments.getAttribute(ATTRIBUTE_POSSIBLE);
 		if (possible != null) {
-			fIsInstanceFieldCreationPossible= Boolean.valueOf(possible).booleanValue();
+			fIsInstanceFieldCreationPossible= Boolean.parseBoolean(possible);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_POSSIBLE));
 		final String mandatory= arguments.getAttribute(ATTRIBUTE_MANDATORY);
 		if (mandatory != null)
-			fIsInstanceFieldCreationMandatory= Boolean.valueOf(mandatory).booleanValue();
+			fIsInstanceFieldCreationMandatory= Boolean.parseBoolean(mandatory);
 		else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_MANDATORY));
 		return new RefactoringStatus();
