@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -24,6 +24,7 @@ import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.core.runtime.Path;
 import org.eclipse.core.runtime.SubMonitor;
 
@@ -36,6 +37,8 @@ import org.eclipse.text.edits.TextEdit;
 import org.eclipse.ltk.core.refactoring.resource.Resources;
 
 import org.eclipse.jdt.core.ClasspathContainerInitializer;
+import org.eclipse.jdt.core.CompletionProposal;
+import org.eclipse.jdt.core.CompletionRequestor;
 import org.eclipse.jdt.core.Flags;
 import org.eclipse.jdt.core.IClasspathContainer;
 import org.eclipse.jdt.core.IClasspathEntry;
@@ -77,7 +80,7 @@ public final class JavaModelUtil {
 	 */
 	public static final String VERSION_LATEST;
 	static {
-		VERSION_LATEST= JavaCore.VERSION_13; // make sure it is not inlined
+		VERSION_LATEST= JavaCore.VERSION_16; // make sure it is not inlined
 	}
 
 	public static final int VALIDATE_EDIT_CHANGED_CONTENT= 10003;
@@ -460,7 +463,7 @@ public final class JavaModelUtil {
 	 * @throws JavaModelException thrown when the field can not be accessed
 	 */
 	public static boolean isBoolean(IField field) throws JavaModelException{
-		return field.getTypeSignature().equals(Signature.SIG_BOOLEAN);
+		return Signature.SIG_BOOLEAN.equals(field.getTypeSignature());
 	}
 
 	/**
@@ -604,8 +607,8 @@ public final class JavaModelUtil {
 
 	public static boolean isExcludedPath(IPath resourcePath, IPath[] exclusionPatterns) {
 		char[] path = resourcePath.toString().toCharArray();
-		for (int i = 0, length = exclusionPatterns.length; i < length; i++) {
-			char[] pattern= exclusionPatterns[i].toString().toCharArray();
+		for (IPath exclusionPattern : exclusionPatterns) {
+			char[] pattern= exclusionPattern.toString().toCharArray();
 			if (CharOperation.pathMatch(pattern, path, true, '/')) {
 				return true;
 			}
@@ -626,8 +629,8 @@ public final class JavaModelUtil {
 	public static boolean isExcluded(IPath resourcePath, char[][] exclusionPatterns) {
 		if (exclusionPatterns == null) return false;
 		char[] path = resourcePath.toString().toCharArray();
-		for (int i = 0, length = exclusionPatterns.length; i < length; i++)
-			if (CharOperation.pathMatch(exclusionPatterns[i], path, true, '/'))
+		for (char[] exclusionPattern : exclusionPatterns)
+			if (CharOperation.pathMatch(exclusionPattern, path, true, '/'))
 				return true;
 		return false;
 	}
@@ -786,19 +789,27 @@ public final class JavaModelUtil {
 	}
 
 
+	public static boolean is20OrHigher(String compliance) {
+		return !isVersionLessThan(compliance, JavaCore.VERSION_1_2);
+	}
+
+	public static boolean is40OrHigher(String compliance) {
+		return !isVersionLessThan(compliance, JavaCore.VERSION_1_4);
+	}
+
 	public static boolean is50OrHigher(String compliance) {
 		return !isVersionLessThan(compliance, JavaCore.VERSION_1_5);
 	}
 
-	public static boolean is16OrHigher(String compliance) {
+	public static boolean is1d6OrHigher(String compliance) {
 		return !isVersionLessThan(compliance, JavaCore.VERSION_1_6);
 	}
 
-	public static boolean is17OrHigher(String compliance) {
+	public static boolean is1d7OrHigher(String compliance) {
 		return !isVersionLessThan(compliance, JavaCore.VERSION_1_7);
 	}
 
-	public static boolean is18OrHigher(String compliance) {
+	public static boolean is1d8OrHigher(String compliance) {
 		return !isVersionLessThan(compliance, JavaCore.VERSION_1_8);
 	}
 
@@ -822,6 +833,38 @@ public final class JavaModelUtil {
 		return !isVersionLessThan(compliance, JavaCore.VERSION_13);
 	}
 
+	public static boolean is14OrHigher(String compliance) {
+		return !isVersionLessThan(compliance, JavaCore.VERSION_14);
+	}
+
+	public static boolean is15OrHigher(String compliance) {
+		return !isVersionLessThan(compliance, JavaCore.VERSION_15);
+	}
+
+	public static boolean is16OrHigher(String compliance) {
+		return !isVersionLessThan(compliance, JavaCore.VERSION_16);
+	}
+
+	/**
+	 * Checks if the given project or workspace has source compliance 1.2 or greater.
+	 *
+	 * @param project the project to test or <code>null</code> to test the workspace settings
+	 * @return <code>true</code> if the given project or workspace has source compliance 1.2 or greater.
+	 */
+	public static boolean is1d2OrHigher(IJavaProject project) {
+		return is20OrHigher(getSourceCompliance(project));
+	}
+
+	/**
+	 * Checks if the given project or workspace has source compliance 1.4 or greater.
+	 *
+	 * @param project the project to test or <code>null</code> to test the workspace settings
+	 * @return <code>true</code> if the given project or workspace has source compliance 1.4 or greater.
+	 */
+	public static boolean is1d4OrHigher(IJavaProject project) {
+		return is40OrHigher(getSourceCompliance(project));
+	}
+
 	/**
 	 * Checks if the given project or workspace has source compliance 1.5 or greater.
 	 *
@@ -838,8 +881,8 @@ public final class JavaModelUtil {
 	 * @param project the project to test or <code>null</code> to test the workspace settings
 	 * @return <code>true</code> if the given project or workspace has source compliance 1.7 or greater.
 	 */
-	public static boolean is17OrHigher(IJavaProject project) {
-		return is17OrHigher(getSourceCompliance(project));
+	public static boolean is1d7OrHigher(IJavaProject project) {
+		return is1d7OrHigher(getSourceCompliance(project));
 	}
 
 	/**
@@ -849,8 +892,8 @@ public final class JavaModelUtil {
 	 * @return <code>true</code> if the given project or workspace has source compliance 1.8 or
 	 *         greater.
 	 */
-	public static boolean is18OrHigher(IJavaProject project) {
-		return is18OrHigher(getSourceCompliance(project));
+	public static boolean is1d8OrHigher(IJavaProject project) {
+		return is1d8OrHigher(getSourceCompliance(project));
 	}
 
 	/**
@@ -898,10 +941,60 @@ public final class JavaModelUtil {
 		return is13OrHigher(getSourceCompliance(project));
 	}
 
-	private static String getSourceCompliance(IJavaProject project) {
+	/**
+	 * Checks if the given project or workspace has source compliance 14 or greater.
+	 *
+	 * @param project the project to test or <code>null</code> to test the workspace settings
+	 * @return <code>true</code> if the given project or workspace has source compliance 14 or
+	 *         greater.
+	 */
+	public static boolean is14OrHigher(IJavaProject project) {
+		return is14OrHigher(getSourceCompliance(project));
+	}
+
+	/**
+	 * Checks if the given project or workspace has source compliance 15 or greater.
+	 *
+	 * @param project the project to test or <code>null</code> to test the workspace settings
+	 * @return <code>true</code> if the given project or workspace has source compliance 15 or
+	 *         greater.
+	 */
+	public static boolean is15OrHigher(IJavaProject project) {
+		return is15OrHigher(getSourceCompliance(project));
+	}
+
+	/**
+	 * Checks if the given project or workspace has source compliance 16 or greater.
+	 *
+	 * @param project the project to test or <code>null</code> to test the workspace settings
+	 * @return <code>true</code> if the given project or workspace has source compliance 16 or
+	 *         greater.
+	 */
+	public static boolean is16OrHigher(IJavaProject project) {
+		return is16OrHigher(getSourceCompliance(project));
+	}
+
+	public static String getSourceCompliance(IJavaProject project) {
 		return project != null ? project.getOption(JavaCore.COMPILER_SOURCE, true) : JavaCore.getOption(JavaCore.COMPILER_SOURCE);
 	}
 
+	/**
+	 * Checks if the given project or workspace has source compliance greater than or equal to the
+	 * latest supported Java version.
+	 *
+	 * @param project the project to test or <code>null</code> to test the workspace settings
+	 *
+	 * @return <code>true</code> if the given project or workspace has source compliance greater
+	 *         than or equal to the latest supported Java version.
+	 */
+	public static boolean isLatestOrHigherJavaVersion(IJavaProject project) {
+		return isLatestOrHigherJavaVersion(getSourceCompliance(project));
+	}
+
+	public static boolean isLatestOrHigherJavaVersion(String compliance) {
+		return !isVersionLessThan(compliance, JavaCore.latestSupportedJavaVersion());
+	}
+
 	/**
 	 * Checks if the JRE of the given project or workspace default JRE have source compliance 1.5 or
 	 * greater.
@@ -931,6 +1024,12 @@ public final class JavaModelUtil {
 		String version= vMInstall.getJavaVersion();
 		if (version == null) {
 			return defaultCompliance;
+		} else if (version.startsWith(JavaCore.VERSION_16)) {
+			return JavaCore.VERSION_16;
+		} else if (version.startsWith(JavaCore.VERSION_15)) {
+			return JavaCore.VERSION_15;
+		} else if (version.startsWith(JavaCore.VERSION_14)) {
+			return JavaCore.VERSION_14;
 		} else if (version.startsWith(JavaCore.VERSION_13)) {
 			return JavaCore.VERSION_13;
 		} else if (version.startsWith(JavaCore.VERSION_12)) {
@@ -951,11 +1050,9 @@ public final class JavaModelUtil {
 			return JavaCore.VERSION_1_5;
 		} else if (version.startsWith(JavaCore.VERSION_1_4)) {
 			return JavaCore.VERSION_1_4;
-		} else if (version.startsWith(JavaCore.VERSION_1_3)) {
-			return JavaCore.VERSION_1_3;
-		} else if (version.startsWith(JavaCore.VERSION_1_2)) {
-			return JavaCore.VERSION_1_3;
-		} else if (version.startsWith(JavaCore.VERSION_1_1)) {
+		} else if (version.startsWith(JavaCore.VERSION_1_3)
+				|| version.startsWith(JavaCore.VERSION_1_2)
+				|| version.startsWith(JavaCore.VERSION_1_1)) {
 			return JavaCore.VERSION_1_3;
 		}
 		return JavaCore.isSupportedJavaVersion(version) ? defaultCompliance : JavaModelUtil.VERSION_LATEST;
@@ -964,14 +1061,20 @@ public final class JavaModelUtil {
 	public static String getExecutionEnvironmentCompliance(IExecutionEnvironment executionEnvironment) {
 		Map<String, String> complianceOptions= executionEnvironment.getComplianceOptions();
 		if (complianceOptions != null) {
-			Object compliance= complianceOptions.get(JavaCore.COMPILER_COMPLIANCE);
-			if (compliance instanceof String)
-				return (String)compliance;
+			String compliance= complianceOptions.get(JavaCore.COMPILER_COMPLIANCE);
+			if (compliance != null)
+				return compliance;
 		}
 
 		// fallback:
 		String desc= executionEnvironment.getId();
-		if (desc.indexOf(JavaCore.VERSION_13) != -1) {
+		if (desc.indexOf(JavaCore.VERSION_16) != -1) {
+			return JavaCore.VERSION_16;
+		} else if (desc.indexOf(JavaCore.VERSION_15) != -1) {
+			return JavaCore.VERSION_15;
+		} else if (desc.indexOf(JavaCore.VERSION_14) != -1) {
+			return JavaCore.VERSION_14;
+		} else if (desc.indexOf(JavaCore.VERSION_13) != -1) {
 			return JavaCore.VERSION_13;
 		} else if (desc.indexOf(JavaCore.VERSION_12) != -1) {
 			return JavaCore.VERSION_12;
@@ -1125,4 +1228,60 @@ public final class JavaModelUtil {
 			cu.save(subMonitor.split(1), true);
 		}
 	}
+
+	private JavaModelUtil() {
+	}
+
+	public static String[] getStaticImportFavorites(ICompilationUnit cu, final String elementName, boolean isMethod, String[] favorites) throws JavaModelException {
+		StringBuilder dummyCU= new StringBuilder();
+		String packName= cu.getParent().getElementName();
+		IType type= cu.findPrimaryType();
+		if (type == null)
+			return new String[0];
+
+		if (packName.length() > 0) {
+			dummyCU.append("package ").append(packName).append(';'); //$NON-NLS-1$
+		}
+		dummyCU.append("public class ").append(type.getElementName()).append("{\n static {\n").append(elementName); // static initializer  //$NON-NLS-1$//$NON-NLS-2$
+		int offset= dummyCU.length();
+		dummyCU.append("\n}\n }"); //$NON-NLS-1$
+
+		ICompilationUnit newCU= null;
+		try {
+			newCU= cu.getWorkingCopy(null);
+			newCU.getBuffer().setContents(dummyCU.toString());
+
+			final HashSet<String> result= new HashSet<>();
+
+			CompletionRequestor requestor= new CompletionRequestor(true) {
+				@Override
+				public void accept(CompletionProposal proposal) {
+					if (elementName.equals(new String(proposal.getName()))) {
+						for (CompletionProposal curr : proposal.getRequiredProposals()) {
+							if (curr.getKind() == CompletionProposal.METHOD_IMPORT || curr.getKind() == CompletionProposal.FIELD_IMPORT) {
+								result.add(concatenateName(Signature.toCharArray(curr.getDeclarationSignature()), curr.getName()));
+							}
+						}
+					}
+				}
+			};
+
+			if (isMethod) {
+				requestor.setIgnored(CompletionProposal.METHOD_REF, false);
+				requestor.setAllowsRequiredProposals(CompletionProposal.METHOD_REF, CompletionProposal.METHOD_IMPORT, true);
+			} else {
+				requestor.setIgnored(CompletionProposal.FIELD_REF, false);
+				requestor.setAllowsRequiredProposals(CompletionProposal.FIELD_REF, CompletionProposal.FIELD_IMPORT, true);
+			}
+			requestor.setFavoriteReferences(favorites);
+
+			newCU.codeComplete(offset, requestor, new NullProgressMonitor());
+
+			return result.toArray(new String[result.size()]);
+		} finally {
+			if (newCU != null) {
+				newCU.discardWorkingCopy();
+			}
+		}
+	}
 }
