@@ -143,9 +143,8 @@ public class MethodOverrideTester {
 				}
 			}
 		}
-		IType[] interfaces= fHierarchy.getSuperInterfaces(type);
-		for (int i= 0; i < interfaces.length; i++) {
-			IMethod res= findOverriddenMethodInHierarchy(interfaces[i], overriding);
+		for (IType intf : fHierarchy.getSuperInterfaces(type)) {
+			IMethod res= findOverriddenMethodInHierarchy(intf, overriding);
 			if (res != null) {
 				return res; // methods from interfaces are always public and therefore visible
 			}
@@ -173,9 +172,8 @@ public class MethodOverrideTester {
 				return res;
 			}
 		}
-		IType[] superInterfaces= fHierarchy.getSuperInterfaces(type);
-		for (int i= 0; i < superInterfaces.length; i++) {
-			IMethod res= findOverriddenMethodInHierarchy(superInterfaces[i], overriding);
+		for (IType superInterface : fHierarchy.getSuperInterfaces(type)) {
+			IMethod res= findOverriddenMethodInHierarchy(superInterface, overriding);
 			if (res != null) {
 				return res;
 			}
@@ -195,9 +193,7 @@ public class MethodOverrideTester {
 		int flags= overriding.getFlags();
 		if (Flags.isPrivate(flags) || Flags.isStatic(flags) || overriding.isConstructor())
 			return null;
-		IMethod[] overriddenMethods= overriddenType.getMethods();
-		for (int i= 0; i < overriddenMethods.length; i++) {
-			IMethod overridden= overriddenMethods[i];
+		for (IMethod overridden : overriddenType.getMethods()) {
 			flags= overridden.getFlags();
 			if (Flags.isPrivate(flags) || Flags.isStatic(flags) || overridden.isConstructor())
 				continue;
@@ -219,9 +215,7 @@ public class MethodOverrideTester {
 		int flags= overridden.getFlags();
 		if (Flags.isPrivate(flags) || Flags.isStatic(flags) || overridden.isConstructor())
 			return null;
-		IMethod[] overridingMethods= overridingType.getMethods();
-		for (int i= 0; i < overridingMethods.length; i++) {
-			IMethod overriding= overridingMethods[i];
+		for (IMethod overriding : overridingType.getMethods()) {
 			flags= overriding.getFlags();
 			if (Flags.isPrivate(flags) || Flags.isStatic(flags) || overriding.isConstructor())
 				continue;
@@ -410,8 +404,7 @@ public class MethodOverrideTester {
 		ITypeParameter[] typeParameters= instantiatedType.getTypeParameters();
 
 		if (instantiatingType == null) { // the focus type
-			for (int i= 0; i < typeParameters.length; i++) {
-				ITypeParameter curr= typeParameters[i];
+			for (ITypeParameter curr : typeParameters) {
 				// use star to make type variables different from type refs
 				s.addSubstitution(curr.getElementName(), '*' + curr.getElementName(), getTypeParameterErasure(curr, instantiatedType));
 			}
@@ -424,8 +417,7 @@ public class MethodOverrideTester {
 					s.addSubstitution(curr.getElementName(), substString, erasure);
 				}
 			} else if (typeArguments.length == 0) { // raw type reference
-				for (int i= 0; i < typeParameters.length; i++) {
-					ITypeParameter curr= typeParameters[i];
+				for (ITypeParameter curr : typeParameters) {
 					String erasure= getTypeParameterErasure(curr, instantiatedType);
 					s.addSubstitution(curr.getElementName(), erasure, erasure);
 				}
