@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -26,8 +26,6 @@ import java.util.Map;
 import com.ibm.icu.text.UTF16;
 
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.ModifyEvent;
-import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
@@ -167,7 +165,7 @@ public class NewTestCaseWizardPageOne extends NewTypeWizardPage {
 	private Link fLink;
 	private Label fImage;
 
-	private JUnitVersion fJUnitVersion;
+	private JUnitVersion fJUnitVersion= JUnitVersion.VERSION_3;
 
 	/**
 	 * Available JUnit versions.
@@ -175,7 +173,36 @@ public class NewTestCaseWizardPageOne extends NewTypeWizardPage {
 	 * @since 3.11
 	 */
 	public enum JUnitVersion {
-		VERSION_3, VERSION_4, VERSION_5
+		VERSION_3(new String[] {
+				/* IDX_SETUP_CLASS */ WizardMessages.NewTestCaseWizardPageOne_methodStub_setUpBeforeClass,
+				/* IDX_TEARDOWN_CLASS */ WizardMessages.NewTestCaseWizardPageOne_methodStub_tearDownAfterClass,
+				/* IDX_SETUP */ WizardMessages.NewTestCaseWizardPageOne_methodStub_setUp,
+				/* IDX_TEARDOWN */ WizardMessages.NewTestCaseWizardPageOne_methodStub_tearDown,
+				/* IDX_CONSTRUCTOR */ WizardMessages.NewTestCaseWizardPageOne_methodStub_constructor
+		}),
+		VERSION_4(new String[] {
+				/* IDX_SETUP_CLASS */ WizardMessages.NewJ4TestCaseWizardPageOne_methodStub_setUpBeforeClass,
+				/* IDX_TEARDOWN_CLASS */ WizardMessages.NewJ4TestCaseWizardPageOne_methodStub_tearDownAfterClass,
+				/* IDX_SETUP */ WizardMessages.NewJ4TestCaseWizardPageOne_methodStub_setUp,
+				/* IDX_TEARDOWN */ WizardMessages.NewJ4TestCaseWizardPageOne_methodStub_tearDown,
+				/* IDX_CONSTRUCTOR */ WizardMessages.NewTestCaseWizardPageOne_methodStub_constructor
+		}),
+		VERSION_5(new String[] {
+				/* IDX_SETUP_CLASS */ WizardMessages.NewJ5TestCaseWizardPageOne_methodStub_setUpBeforeClass,
+				/* IDX_TEARDOWN_CLASS */ WizardMessages.NewJ5TestCaseWizardPageOne_methodStub_tearDownAfterClass,
+				/* IDX_SETUP */ WizardMessages.NewJ5TestCaseWizardPageOne_methodStub_setUp,
+				/* IDX_TEARDOWN */ WizardMessages.NewJ5TestCaseWizardPageOne_methodStub_tearDown,
+				/* IDX_CONSTRUCTOR */ WizardMessages.NewTestCaseWizardPageOne_methodStub_constructor
+		});
+
+		/**
+		 * @since 3.12
+		 */
+		public final String[] buttonNames;
+
+		JUnitVersion(String[] buttonNames) {
+			this.buttonNames= buttonNames;
+		}
 	}
 
 	/**
@@ -191,16 +218,9 @@ public class NewTestCaseWizardPageOne extends NewTypeWizardPage {
 		setTitle(WizardMessages.NewTestCaseWizardPageOne_title);
 		setDescription(WizardMessages.NewTestCaseWizardPageOne_description);
 
-		String[] buttonNames= new String[] {
-			/* IDX_SETUP_CLASS */ WizardMessages.NewTestCaseWizardPageOne_methodStub_setUpBeforeClass,
-			/* IDX_TEARDOWN_CLASS */ WizardMessages.NewTestCaseWizardPageOne_methodStub_tearDownAfterClass,
-			/* IDX_SETUP */ WizardMessages.NewTestCaseWizardPageOne_methodStub_setUp,
-			/* IDX_TEARDOWN */ WizardMessages.NewTestCaseWizardPageOne_methodStub_tearDown,
-			/* IDX_CONSTRUCTOR */ WizardMessages.NewTestCaseWizardPageOne_methodStub_constructor
-		};
 		enableCommentControl(true);
 
-		fMethodStubsButtons= new MethodStubsSelectionButtonGroup(SWT.CHECK, buttonNames, 2) {
+		fMethodStubsButtons= new MethodStubsSelectionButtonGroup(SWT.CHECK, fJUnitVersion, 2) {
 			@Override
 			protected void doWidgetSelected(SelectionEvent e) {
 				super.doWidgetSelected(e);
@@ -216,7 +236,7 @@ public class NewTestCaseWizardPageOne extends NewTypeWizardPage {
 		fClassUnderTestText= ""; //$NON-NLS-1$
 
 		fJUnitStatus= new JUnitStatus();
-		setJUnitVersion(JUnitVersion.VERSION_3);
+		setJUnitVersion(fJUnitVersion);
 	}
 
 	/**
@@ -394,8 +414,9 @@ public class NewTestCaseWizardPageOne extends NewTypeWizardPage {
 
 	private void internalSetJUnit(JUnitVersion version) {
 		fJUnitVersion= version;
+		fMethodStubsButtons.updateButtons(version);
 		fJUnitStatus= junitStatusChanged();
-		if (isDefaultSuperClass() || getSuperClass().trim().equals("")) //$NON-NLS-1$
+		if (isDefaultSuperClass() || "".equals(getSuperClass().trim())) //$NON-NLS-1$
 			setSuperClass(getDefaultSuperClassName(), true);
 		fSuperClassStatus= superClassChanged(); //validate superclass field when toggled
 		handleFieldChanged(JUNIT4TOGGLE);
@@ -410,13 +431,13 @@ public class NewTestCaseWizardPageOne extends NewTypeWizardPage {
 	 */
 	private boolean isDefaultSuperClass() {
 		String superClass= getSuperClass();
-		return superClass.equals(getJUnit3TestSuperclassName()) || superClass.equals("java.lang.Object"); //$NON-NLS-1$
+		return superClass.equals(getJUnit3TestSuperclassName()) || "java.lang.Object".equals(superClass); //$NON-NLS-1$
 	}
 
 	@Override
 	protected void handleFieldChanged(String fieldName) {
 		super.handleFieldChanged(fieldName);
-		if (fieldName.equals(CONTAINER)) {
+		if (CONTAINER.equals(fieldName)) {
 			fClassUnderTestStatus= classUnderTestChanged();
 			if (fClassUnderTestButton != null && !fClassUnderTestButton.isDisposed()) {
 				fClassUnderTestButton.setEnabled(getPackageFragmentRoot() != null);
@@ -424,7 +445,7 @@ public class NewTestCaseWizardPageOne extends NewTypeWizardPage {
 			fJUnitStatus= junitStatusChanged();
 
 			updateBuildPathMessage();
-		} else if (fieldName.equals(JUNIT4TOGGLE)) {
+		} else if (JUNIT4TOGGLE.equals(fieldName)) {
 			updateBuildPathMessage();
 			boolean isJUnit3= getJUnitVersion() == JUnitVersion.VERSION_3;
 			fMethodStubsButtons.setEnabled(IDX_SETUP_CLASS, !isJUnit3);
@@ -519,12 +540,7 @@ public class NewTestCaseWizardPageOne extends NewTypeWizardPage {
 		fClassUnderTestControl.setEnabled(true);
 		fClassUnderTestControl.setFont(composite.getFont());
 		fClassUnderTestControl.setText(fClassUnderTestText);
-		fClassUnderTestControl.addModifyListener(new ModifyListener() {
-			@Override
-			public void modifyText(ModifyEvent e) {
-				internalSetClassUnderText(((Text) e.widget).getText());
-			}
-		});
+		fClassUnderTestControl.addModifyListener(modifyEvent -> internalSetClassUnderText(((Text) modifyEvent.widget).getText()));
 		GridData gd= new GridData();
 		gd.horizontalAlignment= GridData.FILL;
 		gd.grabExcessHorizontalSpace= true;
@@ -1023,8 +1039,7 @@ public class NewTestCaseWizardPageOne extends NewTypeWizardPage {
 		}
 		/* find overloaded methods */
 		IMethod[] allMethodsArray= fPage2.getAllMethods();
-		List<IMethod> allMethods= new ArrayList<>();
-		allMethods.addAll(Arrays.asList(allMethodsArray));
+		List<IMethod> allMethods= new ArrayList<>(Arrays.asList(allMethodsArray));
 		List<IMethod> overloadedMethods= getOverloadedMethods(allMethods);
 
 		/* used when for example both sum and Sum methods are present. Then
@@ -1159,7 +1174,7 @@ public class NewTestCaseWizardPageOne extends NewTypeWizardPage {
 
 	private void appendParameterNamesToMethodName(StringBuffer buffer, String[] parameters) {
 		for (String parameter : parameters) {
-			final StringBuffer buf= new StringBuffer(Signature.getSimpleName(Signature.toString(Signature.getElementType(parameter))));
+			final StringBuilder buf= new StringBuilder(Signature.getSimpleName(Signature.toString(Signature.getElementType(parameter))));
 			final char character= buf.charAt(0);
 			if (buf.length() > 0 && !Character.isUpperCase(character))
 				buf.setCharAt(0, Character.toUpperCase(character));
@@ -1298,7 +1313,7 @@ public class NewTestCaseWizardPageOne extends NewTypeWizardPage {
 				status.setError(WizardMessages.NewTestCaseWizardPageOne_error_superclass_empty);
 			return status;
 		}
-		if (!isJUnit3 && superClassName.equals("java.lang.Object")) //$NON-NLS-1$
+		if (!isJUnit3 && "java.lang.Object".equals(superClassName)) //$NON-NLS-1$
 			return status;
 		if (getPackageFragmentRoot() != null) {
 			try {
