@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2016 IBM Corporation and others.
+ * Copyright (c) 2005, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,8 +13,15 @@
  *******************************************************************************/
 package org.eclipse.jdt.text.tests;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNull;
+
 import java.util.Arrays;
-import java.util.Comparator;
+
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 
@@ -23,55 +30,42 @@ import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.IPackageFragment;
 import org.eclipse.jdt.core.IPackageFragmentRoot;
 import org.eclipse.jdt.core.JavaModelException;
+import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.ASTParser;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 
-import org.eclipse.jdt.ui.tests.core.ProjectTestSetup;
-
-import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
-import org.eclipse.jdt.internal.ui.search.BreakContinueTargetFinder;
 import org.eclipse.jdt.internal.core.manipulation.search.IOccurrencesFinder.OccurrenceLocation;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
+
+import org.eclipse.jdt.internal.ui.search.BreakContinueTargetFinder;
 
 /**
  * Tests for the BreakContinueTargerFinder class.
  *
  * @since 3.2
  */
-public class BreakContinueTargetFinderTest extends TestCase{
-	private static final Class<BreakContinueTargetFinderTest> THIS= BreakContinueTargetFinderTest.class;
-
-	public static Test suite() {
-		return new ProjectTestSetup(new TestSuite(THIS));
-	}
-
-	public static Test setUpTest(Test test) {
-		return new ProjectTestSetup(test);
-	}
+public class BreakContinueTargetFinderTest {
+	@Rule
+	public ProjectTestSetup pts= new ProjectTestSetup();
 
 	private ASTParser fParser;
 	private BreakContinueTargetFinder fFinder;
 	private IJavaProject fJProject1;
 	private IPackageFragmentRoot fSourceFolder;
 
-	/*
-	 * @see junit.framework.TestCase#setUp()
-	 */
-	@Override
-	protected void setUp() throws Exception {
-		fParser = ASTParser.newParser(IASTSharedValues.SHARED_AST_LEVEL);
+	@Before
+	public void setUp() throws Exception {
+		fParser = ASTParser.newParser(AST.getJLSLatest());
 		fFinder= new BreakContinueTargetFinder();
 
-		fJProject1= ProjectTestSetup.getProject();
+		fJProject1= pts.getProject();
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 	}
 
-	@Override
-	protected void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJProject1, ProjectTestSetup.getDefaultClasspath());
+	@After
+	public void tearDown() throws Exception {
+		JavaProjectHelper.clear(fJProject1, pts.getDefaultClasspath());
 	}
 
 	private OccurrenceLocation[] getHighlights(StringBuffer source, int offset, int length) throws Exception {
@@ -100,12 +94,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 	}
 
 	private void sortByStartIndex(OccurrenceLocation[] OccurrenceLocations) {
-		Arrays.sort(OccurrenceLocations, new Comparator<OccurrenceLocation>() {
-			@Override
-			public int compare(OccurrenceLocation node0, OccurrenceLocation node1) {
-				return node0.getOffset() - node1.getOffset();
-			}
-		});
+		Arrays.sort(OccurrenceLocations, (node0, node1) -> node0.getOffset() - node1.getOffset());
 	}
 
 	//pattern must be found - otherwise it's assumed to be an error
@@ -126,6 +115,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 	    return find(s, pattern, ithOccurrence-1, idx+1);
 	}
 
+	@Test
 	public void testBreakFor() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -141,6 +131,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testBreakForeach() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -156,6 +147,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testBreakWhile() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -172,6 +164,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testBreakDo() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -188,6 +181,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testBreakSwitch() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -204,6 +198,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testLabeledBreakFor() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -221,6 +216,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testLabeledBreakFor1() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -238,6 +234,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testBreakFor2() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -255,6 +252,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testLabeledBreakIf() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -277,6 +275,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testContinueFor() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -292,6 +291,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testContinueForeach() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -307,6 +307,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testContinueWhile() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -323,6 +324,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testContinueDo() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -340,6 +342,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 	}
 
 	//continue skips over switches
+	@Test
 	public void testContinueSwitch() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -358,6 +361,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testLabeledContinueFor() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -375,6 +379,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testLabeledContinueFor1() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -392,6 +397,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testLabeledContinueFor2() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
@@ -409,6 +415,7 @@ public class BreakContinueTargetFinderTest extends TestCase{
 		checkSelection(s, offset, length, ranges);
 	}
 
+	@Test
 	public void testContinueFor2() throws Exception {
 		StringBuffer s= new StringBuffer();
 		s.append("class A{\n");
