@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2008 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,9 +13,14 @@
  *******************************************************************************/
 package org.eclipse.jdt.text.tests;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
 
 import org.eclipse.jface.preference.PreferenceStore;
 
@@ -23,27 +28,19 @@ import org.eclipse.jface.text.BadLocationException;
 import org.eclipse.jface.text.Document;
 import org.eclipse.jface.text.IDocument;
 import org.eclipse.jface.text.IDocumentPartitioner;
-import org.eclipse.jface.text.IDocumentPartitioningListener;
 import org.eclipse.jface.text.ITypedRegion;
 import org.eclipse.jface.text.TypedRegion;
 
 import org.eclipse.jdt.ui.text.IJavaPartitions;
 import org.eclipse.jdt.ui.text.JavaTextTools;
 
-
-public class JavaPartitionerTest extends TestCase {
-
+public class JavaPartitionerTest {
 	private JavaTextTools fTextTools;
 	private Document fDocument;
 	protected boolean fDocumentPartitioningChanged;
 
-
-	public JavaPartitionerTest(String name) {
-		super(name);
-	}
-
-	@Override
-	protected void setUp() {
+	@Before
+	public void setUp() {
 
 		fTextTools= new JavaTextTools(new PreferenceStore());
 
@@ -54,20 +51,11 @@ public class JavaPartitionerTest extends TestCase {
 		fDocument.set("xxx\n/*xxx*/\nxxx\n/**xxx*/\nxxx\n/**/\nxxx\n/***/\nxxx");
 
 		fDocumentPartitioningChanged= false;
-		fDocument.addDocumentPartitioningListener(new IDocumentPartitioningListener() {
-			@Override
-			public void documentPartitioningChanged(IDocument document) {
-				fDocumentPartitioningChanged= true;
-			}
-		});
+		fDocument.addDocumentPartitioningListener(document -> fDocumentPartitioningChanged= true);
 	}
 
-	public static Test suite() {
-		return new TestSuite(JavaPartitionerTest.class);
-	}
-
-	@Override
-	protected void tearDown () {
+	@After
+	public void tearDown () {
 		fTextTools.dispose();
 		fTextTools= null;
 
@@ -87,11 +75,12 @@ public class JavaPartitionerTest extends TestCase {
 		for (int i= 0; i < expectation.length; i++) {
 			ITypedRegion e= expectation[i];
 			ITypedRegion r= result[i];
-			assertTrue(print(r) + " != " + print(e), r.equals(e));
+			assertEquals(print(r) + " != " + print(e), r, e);
 		}
 
 	}
 
+	@Test
 	public void testInitialPartitioning() {
 		try {
 
@@ -112,17 +101,18 @@ public class JavaPartitionerTest extends TestCase {
 
 			checkPartitioning(expectation, result);
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testIntraPartitionChange() {
 		try {
 
 			fDocument.replace(34, 3, "y");
 			//	"xxx\n/*xxx*/\nxxx\n/**xxx*/\nxxx\n/**/\ny\n/***/\nxxx");
 
-			assertTrue(!fDocumentPartitioningChanged);
+			assertFalse(fDocumentPartitioningChanged);
 
 			ITypedRegion[] result= fDocument.computePartitioning(0, fDocument.getLength());
 			TypedRegion[] expectation= {
@@ -139,10 +129,11 @@ public class JavaPartitionerTest extends TestCase {
 
 			checkPartitioning(expectation, result);
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testIntraPartitionChange2() {
 		try {
 
@@ -166,9 +157,10 @@ public class JavaPartitionerTest extends TestCase {
 
 			checkPartitioning(expectation, result);
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
+	@Test
 	public void testInsertNewPartition() {
 		try {
 
@@ -194,10 +186,11 @@ public class JavaPartitionerTest extends TestCase {
 
 			checkPartitioning(expectation, result);
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testRemovePartition1() {
 		try {
 
@@ -220,10 +213,11 @@ public class JavaPartitionerTest extends TestCase {
 
 			checkPartitioning(expectation, result);
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testRemovePartition2() {
 
 		testJoinPartition3();
@@ -249,11 +243,12 @@ public class JavaPartitionerTest extends TestCase {
 
 			checkPartitioning(expectation, result);
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
 
+	@Test
 	public void testJoinPartitions1() {
 		try {
 
@@ -275,10 +270,11 @@ public class JavaPartitionerTest extends TestCase {
 
 			checkPartitioning(expectation, result);
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testJoinPartitions2() {
 		try {
 
@@ -300,10 +296,11 @@ public class JavaPartitionerTest extends TestCase {
 
 			checkPartitioning(expectation, result);
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testJoinPartition3() {
 		try {
 
@@ -325,11 +322,12 @@ public class JavaPartitionerTest extends TestCase {
 
 			checkPartitioning(expectation, result);
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
 
+	@Test
 	public void testSplitPartition1() {
 
 		testJoinPartitions1();
@@ -346,12 +344,13 @@ public class JavaPartitionerTest extends TestCase {
 
 
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 
 		testInitialPartitioning();
 	}
 
+	@Test
 	public void testSplitPartition2() {
 
 		testJoinPartitions2();
@@ -366,12 +365,13 @@ public class JavaPartitionerTest extends TestCase {
 			assertTrue(fDocumentPartitioningChanged);
 
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 
 		testInitialPartitioning();
 	}
 
+	@Test
 	public void testSplitPartition3() {
 
 		fDocumentPartitioningChanged= false;
@@ -397,10 +397,11 @@ public class JavaPartitionerTest extends TestCase {
 
 			checkPartitioning(expectation, result);
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testCorruptPartitioning1() {
 		try {
 
@@ -428,10 +429,11 @@ public class JavaPartitionerTest extends TestCase {
 			};
 
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testCorruptPartitioning2() {
 		try {
 
@@ -463,10 +465,11 @@ public class JavaPartitionerTest extends TestCase {
 			};
 
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testCorruptPartitioning3() {
 		try {
 
@@ -496,10 +499,11 @@ public class JavaPartitionerTest extends TestCase {
 			};
 
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testOpenPartition1() {
 		try {
 
@@ -523,10 +527,11 @@ public class JavaPartitionerTest extends TestCase {
 
 			checkPartitioning(expectation, result);
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testOpenPartition2() {
 		try {
 
@@ -552,11 +557,12 @@ public class JavaPartitionerTest extends TestCase {
 
 			checkPartitioning(expectation, result);
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
 
+	@Test
 	public void testChangeContentTypeOfPartition() {
 		try {
 
@@ -581,25 +587,27 @@ public class JavaPartitionerTest extends TestCase {
 
 			checkPartitioning(expectation, result);
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testPartitionFinder() {
 		try {
 
 			for (ITypedRegion expected : fDocument.computePartitioning(0, fDocument.getLength())) {
 				for (int j= 0; j < expected.getLength(); j++) {
 					ITypedRegion result= fDocument.getPartition(expected.getOffset() + j);
-					assertTrue(expected.equals(result));
+					assertEquals(expected, result);
 				}
 			}
 
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testExtendPartition() {
 		try {
 
@@ -621,10 +629,11 @@ public class JavaPartitionerTest extends TestCase {
 			checkPartitioning(expectation, result);
 
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testTransformPartition() {
 		try {
 
@@ -646,10 +655,11 @@ public class JavaPartitionerTest extends TestCase {
 			checkPartitioning(expectation, result);
 
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testTogglePartition() {
 		try {
 
@@ -677,10 +687,11 @@ public class JavaPartitionerTest extends TestCase {
 			checkPartitioning(expectation2, result);
 
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testEditing1() {
 		try {
 
@@ -714,10 +725,11 @@ public class JavaPartitionerTest extends TestCase {
 
 
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testEditing2() {
 		try {
 
@@ -759,10 +771,11 @@ public class JavaPartitionerTest extends TestCase {
 			checkPartitioning(expectation, result);
 
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 
+	@Test
 	public void testEditing3() {
 		try {
 
@@ -796,7 +809,7 @@ public class JavaPartitionerTest extends TestCase {
 			checkPartitioning(expectation, result);
 
 		} catch (BadLocationException x) {
-			assertTrue(false);
+			fail();
 		}
 	}
 }
