@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2008 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,19 +13,16 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.refactoring;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+	RenameVirtualMethodInClassTests.class,
+	RenameMethodInInterfaceTests.class,
+	RenamePrivateMethodTests.class,
+	RenameStaticMethodTests.class,
+	RippleMethodFinderTests.class
+})
 public class RenameMethodTests {
-	private static final Class<RenameMethodTests> clazz= RenameMethodTests.class;
-
-	public static Test suite() {
-		TestSuite suite= new TestSuite(clazz.getName());
-		suite.addTest(RenameVirtualMethodInClassTests.suite());
-		suite.addTest(RenameMethodInInterfaceTests.suite());
-		suite.addTest(RenamePrivateMethodTests.suite());
-		suite.addTest(RenameStaticMethodTests.suite());
-		suite.addTest(RippleMethodFinderTests.suite());
-		return suite;
-	}
 }
