@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2008 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -26,11 +26,7 @@ import org.eclipse.jdt.internal.corext.refactoring.structure.MoveStaticMembersPr
 import org.eclipse.jdt.internal.ui.preferences.JavaPreferencesSettings;
 
 
-public abstract class AbstractMoveStaticMemberPrefTest extends RepeatingRefactoringPerformanceTestCase {
-
-	public AbstractMoveStaticMemberPrefTest(String name) {
-		super(name);
-	}
+public abstract class AbstractMoveStaticMemberPrefTest extends RepeatingRefactoringPerformanceTestCaseCommon {
 
 	@Override
 	protected void doExecuteRefactoring(int numberOfCus, int numberOfRefs, boolean measure) throws Exception {
