@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -103,11 +103,15 @@ public final class ReferenceTracker {
 	}
 
 	private static boolean setAccessible(Field fld, boolean enable) {
-		boolean isAccessible= fld.isAccessible();
-		if (isAccessible != enable) {
-			fld.setAccessible(enable);
+		try {
+			boolean isAccessible= fld.isAccessible();
+			if (isAccessible != enable) {
+				fld.setAccessible(enable);
+			}
+			return isAccessible;
+		} catch (RuntimeException ex) {
+			throw new RuntimeException("JVM settings `--add-modules ALL-SYSTEM --add-opens java.base/jdk.internal.loader=ALL-UNNAMED --add-opens jdk.localedata/sun.util.resources.cldr.provider=ALL-UNNAMED --add-opens jdk.localedata/sun.util.resources.provider=ALL-UNNAMED --add-opens java.base/jdk.internal.module=ALL-UNNAMED --add-opens java.base/java.lang.module=ALL-UNNAMED --add-opens java.base/jdk.internal.reflect=ALL-UNNAMED --add-opens java.base/jdk.internal.ref=ALL-UNNAMED --add-opens java.base/jdk.internal.math=ALL-UNNAMED --add-opens java.base/jdk.internal.misc=ALL-UNNAMED --add-opens java.base/jdk.internal.icu.impl=ALL-UNNAMED --add-opens java.base/jdk.internal.icu.text=ALL-UNNAMED --illegal-access=permit` are probably missing.\nException : \n" + ex.getMessage(), ex);
 		}
-		return isAccessible;
 	}
 
 	private void visit(ReferencedObject ref) {
