@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2012 IBM Corporation and others.
+ * Copyright (c) 2005, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,9 +13,7 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.performance.views;
 
-import junit.framework.Test;
-
-import org.eclipse.test.OrderedTestSuite;
+import org.junit.Test;
 
 import org.eclipse.core.resources.ResourcesPlugin;
 
@@ -24,20 +22,11 @@ import org.eclipse.ui.IWorkbenchWindow;
 import org.eclipse.ui.PlatformUI;
 
 import org.eclipse.jdt.ui.JavaUI;
-import org.eclipse.jdt.ui.tests.performance.JdtPerformanceTestCase;
+import org.eclipse.jdt.ui.tests.performance.JdtPerformanceTestCaseCommon;
 
-public class PackageExplorerEmptyPerfTest extends JdtPerformanceTestCase {
-
-	public static Test suite() {
-		return new OrderedTestSuite(PackageExplorerEmptyPerfTest.class, new String[] {
-			"testOpen"
-		});
-	}
-
-	public PackageExplorerEmptyPerfTest(String name) {
-		super(name);
-	}
+public class PackageExplorerEmptyPerfTest extends JdtPerformanceTestCaseCommon {
 
+	@Test
 	public void testOpen() throws Exception {
 		IWorkbenchWindow activeWorkbenchWindow= PlatformUI.getWorkbench().getActiveWorkbenchWindow();
 		IWorkbenchPage page= activeWorkbenchWindow.getActivePage();
