@@ -41,6 +41,7 @@ public class TestOptions {
 		result.put(JavaCore.COMPILER_PB_RAW_TYPE_REFERENCE, JavaCore.IGNORE);
 		result.put(JavaCore.COMPILER_PB_UNUSED_WARNING_TOKEN, JavaCore.IGNORE);
 		result.put(JavaCore.COMPILER_PB_DEAD_CODE, JavaCore.IGNORE);
+		result.put(JavaCore.CODEASSIST_SUBWORD_MATCH, JavaCore.DISABLED);
 		// should cover all compiler settings
 		result.putAll(TestFormatterOptions.getSettings());
 		return result;
@@ -63,6 +64,9 @@ public class TestOptions {
 		project.setOptions(options);
 	}
 
+	private TestOptions() {
+	}
+
 }
 
 class TestFormatterOptions {
