@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2013 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,8 +13,8 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
 import org.eclipse.jdt.ui.tests.dialogs.DialogsTest;
 import org.eclipse.jdt.ui.tests.dialogs.PreferencesTest;
@@ -23,21 +23,11 @@ import org.eclipse.jdt.ui.tests.dialogs.WizardsTest;
 /**
  * Test all areas of the UI.
  */
-public class UIInteractiveSuite extends TestSuite {
-
-	/**
-	 * @return Returns the suite.  This is required to
-	 * use the JUnit Launcher.
-	 */
-	public static Test suite() {
-		return new UIInteractiveSuite();
-	}
-
-	public UIInteractiveSuite() {
-		super(UIInteractiveSuite.class.getName());
-		addTest(PreferencesTest.suite());
-		addTest(WizardsTest.suite());
-		addTest(DialogsTest.suite());
-	}
-
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+	PreferencesTest.class,
+	WizardsTest.class,
+	DialogsTest.class
+	})
+public class UIInteractiveSuite {
 }
