@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2018 IBM Corporation and others.
+ * Copyright (c) 2008, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,24 +13,19 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.buildpath;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
 
 /**
  * @since 3.5
  */
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+	BuildpathModifierActionEnablementTest.class,
+	BuildpathModifierActionTest.class,
+	CPUserLibraryTest.class,
+	BuildpathProblemQuickFixTest.class
+})
 public class BuildpathTestSuite {
-
-	public static Test suite() {
-		TestSuite suite= new TestSuite(BuildpathTestSuite.class.getName());
-		//$JUnit-BEGIN$
-		suite.addTest(BuildpathModifierActionEnablementTest.suite());
-		suite.addTest(BuildpathModifierActionTest.suite());
-		suite.addTest(CPUserLibraryTest.suite());
-		suite.addTest(BuildpathProblemQuickFixTest.suite());
-		//$JUnit-END$
-		return suite;
-	}
-
 }
