@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,12 +13,18 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.core;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.fail;
+
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Set;
 
+import org.junit.Test;
+
 import org.eclipse.core.runtime.Assert;
 
 import org.eclipse.jdt.core.dom.ASTNode;
@@ -39,12 +45,8 @@ import org.eclipse.jdt.core.dom.VariableDeclaration;
 
 import org.eclipse.jdt.internal.corext.dom.HierarchicalASTVisitor;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 @SuppressWarnings("javadoc")
-public class HierarchicalASTVisitorTest extends TestCase {
+public class HierarchicalASTVisitorTest {
 	private static class TestHierarchicalASTVisitor extends HierarchicalASTVisitor {
 
 		//---- BEGIN <REGION TO BE UPDATED IN RESPONSE TO ASTNode HIERARCHY CHANGES> ---------------------
@@ -351,12 +353,12 @@ public class HierarchicalASTVisitorTest extends TestCase {
 		private static void checkRequiredMethodsForNonLeaf(Class<? extends ASTNode> clazz, boolean isEndVisit) {
 			Assert.isTrue(ASTNode.class.isAssignableFrom(clazz));
 			try {
-				TestHierarchicalASTVisitor.class.getDeclaredMethod(getVisitMethodName(isEndVisit), new Class[] { clazz });
+				TestHierarchicalASTVisitor.class.getDeclaredMethod(getVisitMethodName(isEndVisit), clazz);
 			} catch (NoSuchMethodException e) {
 				fail("Test must be updated since TestHierarchicalASTVisitor (declared within test class), is missing a method corresponding to non-leaf node class '" + getSimpleName(clazz) + "'");
 			}
 			try {
-				TestHierarchicalASTVisitor.class.getDeclaredMethod(getSuperVisitName(isEndVisit), new Class[] { clazz });
+				TestHierarchicalASTVisitor.class.getDeclaredMethod(getSuperVisitName(isEndVisit), clazz);
 			} catch (NoSuchMethodException e) {
 				fail("Test must be updated since TestHierarchicalASTVisitor (declared within test class), is missing a method corresponding to non-leaf node class '" + getSimpleName(clazz) + "'");
 			}
@@ -380,20 +382,14 @@ public class HierarchicalASTVisitorTest extends TestCase {
 			 * to reflectively instantiate an appropriately typed node.
 			 */
 			try {
-				Method method= TestHierarchicalASTVisitor.class.getMethod(isLeaf ? getVisitMethodName(isEndVisit) : "superVisit", new Class[] { clazz });
+				Method method= TestHierarchicalASTVisitor.class.getMethod(isLeaf ? getVisitMethodName(isEndVisit) : "superVisit", clazz);
 				method.invoke(this, new Object[] { null });
-			} catch (NoSuchMethodException e) {
-				/* This should have already been discovered by
+			} catch (NoSuchMethodException | IllegalAccessException | InvocationTargetException e) {
+				/* NoSuchMethodException should have already been discovered by
 				 * hasRequiredMethodsForNonLeaf(..)
 				 */
 				e.printStackTrace();
 				Assert.isTrue(false);
-			} catch (IllegalAccessException e) {
-				e.printStackTrace();
-				Assert.isTrue(false);
-			} catch (InvocationTargetException e) {
-				e.printStackTrace();
-				Assert.isTrue(false);
 			}
 
 			/*
@@ -413,7 +409,7 @@ public class HierarchicalASTVisitorTest extends TestCase {
 			 * method corresponding to XX's superclass, YY. We check here that
 			 * fNodeClassForCalledMethod was set to the superclass of clazz.
 			 */
-			assertTrue(getSuperMethodNotCalledMessageFor(clazz, isEndVisit), clazz.getSuperclass().equals(fNodeClassForCalledMethod));
+			assertEquals(getSuperMethodNotCalledMessageFor(clazz, isEndVisit), clazz.getSuperclass(), fNodeClassForCalledMethod);
 		}
 		private String getSuperMethodNotCalledMessageFor(Class<? extends ASTNode> clazz, boolean isEndVisit) {
 			return getMethodSignatureFor(clazz, isEndVisit) + " in HierarchicalASTVisitor should call " + getMethodSignatureFor(clazz.getSuperclass(), isEndVisit) + ", the visitor method for its superclass.";
@@ -428,18 +424,9 @@ public class HierarchicalASTVisitorTest extends TestCase {
 		}
 	}
 
-	private static final Class<HierarchicalASTVisitorTest> THIS_CLASS= HierarchicalASTVisitorTest.class;
-
 	private Set<Class<? extends ASTNode>> fLeaves;
 
-	public HierarchicalASTVisitorTest(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return new TestSuite(THIS_CLASS);
-	}
-
+	@Test
 	public void test() {
 		fLeaves= getLeafASTNodeDescendants();
 		Set<Class<? extends ASTNode>> allASTNodeDescendants= computeAllDescendantsFromLeaves(fLeaves.iterator(), ASTNode.class);
@@ -492,10 +479,10 @@ public class HierarchicalASTVisitorTest extends TestCase {
 	private void checkHierarchicalASTVisitorMethodExistsFor(Class<? extends ASTNode> nodeClass, boolean isEndVisit) {
 		Assert.isTrue(ASTNode.class.isAssignableFrom(nodeClass));
 		try {
-			HierarchicalASTVisitor.class.getDeclaredMethod(getVisitMethodName(isEndVisit), new Class[] { nodeClass });
+			HierarchicalASTVisitor.class.getDeclaredMethod(getVisitMethodName(isEndVisit), nodeClass);
 		} catch (NoSuchMethodException e) {
 			String signature= getVisitMethodName(isEndVisit) + "(" + getSimpleName(nodeClass) + ")";
-			assertTrue("HierarchicalASTVisitor must be updated to reflect a change in the ASTNode hierarchy.  No method " + signature + " was found in HierarchicalASTVisitor.", false);
+			fail("HierarchicalASTVisitor must be updated to reflect a change in the ASTNode hierarchy.  No method " + signature + " was found in HierarchicalASTVisitor.");
 		}
 	}
 
