@@ -20,40 +20,21 @@ package org.eclipse.jdt.ui.tests.core.rules;
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 
 import org.eclipse.core.runtime.CoreException;
-import org.eclipse.core.runtime.IPath;
 
-import org.eclipse.core.resources.IProject;
-import org.eclipse.core.resources.ResourcesPlugin;
-
-import org.eclipse.jdt.core.IClasspathEntry;
 import org.eclipse.jdt.core.IJavaProject;
-import org.eclipse.jdt.core.JavaCore;
 
 /**
- * Setups the tests related to Java 5.
+ * Setups the tests related to Java 5 (i.e. Tiger).
  */
 public class Java1d5ProjectTestSetup extends ProjectTestSetup {
-	public static final String PROJECT_NAME1d5= "TestSetupProject1d5";
 
-	public static IJavaProject getProject() {
-		IProject project= ResourcesPlugin.getWorkspace().getRoot().getProject(PROJECT_NAME1d5);
-		return JavaCore.create(project);
-	}
-
-	public static IClasspathEntry[] getDefaultClasspath() throws CoreException {
-		IPath[] rtJarPath= JavaProjectHelper.findRtJar(JavaProjectHelper.RT_STUBS_15);
-		return new IClasspathEntry[] { JavaCore.newLibraryEntry(rtJarPath[0], rtJarPath[1], rtJarPath[2], true) };
-	}
-
-	@Override
-	protected boolean projectExists() {
-		return getProject().exists();
+	public Java1d5ProjectTestSetup() {
+		super("TestSetupProject1d5", JavaProjectHelper.RT_STUBS_15);
 	}
 
 	@Override
 	protected IJavaProject createAndInitializeProject() throws CoreException {
-		IJavaProject javaProject= JavaProjectHelper.createJavaProject(PROJECT_NAME1d5, "bin");
-		javaProject.setRawClasspath(getDefaultClasspath(), null);
+		IJavaProject javaProject= super.createAndInitializeProject();
 		JavaProjectHelper.set15CompilerOptions(javaProject);
 		return javaProject;
 	}
