@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2013, 2014 IBM Corporation and others.
+ * Copyright (c) 2013, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,13 +13,16 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.hover;
 
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
 import java.io.File;
 import java.net.URL;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
-import org.junit.Assert;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.JavaTestPlugin;
@@ -44,36 +47,28 @@ import org.eclipse.jdt.internal.core.JavaElement;
 import org.eclipse.jdt.internal.corext.CorextMessages;
 
 import org.eclipse.jdt.ui.tests.core.CoreTests;
-import org.eclipse.jdt.ui.tests.core.ProjectTestSetup;
+import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
 
 import org.eclipse.jdt.internal.ui.text.java.hover.JavadocBrowserInformationControlInput;
 import org.eclipse.jdt.internal.ui.text.java.hover.JavadocHover;
 
-
 /**
  * Tests for fetching package Javadoc.
  *
  * @since 3.9
  */
 public class PackageJavadocTests extends CoreTests {
-
-
-	public PackageJavadocTests(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return setUpTest(new TestSuite(PackageJavadocTests.class));
-	}
+	@Rule
+	public ProjectTestSetup pts= new ProjectTestSetup();
 
 	private IJavaProject fJProject1;
 
-
+	@Test
 	public void testGetDocFromPackageHtml_src() throws Exception {
-
 		File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(new Path("testresources/PackageJavadocTests/JavadocHover_src.zip"));
 
-		assertTrue("junit src not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("JUnit src should be found", junitSrcArchive);
+		assertTrue("JUnit src should exist", junitSrcArchive.exists());
 
 		JavaProjectHelper.addSourceContainerWithImport(fJProject1, "src", junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING);
 		ICompilationUnit cu= (ICompilationUnit)fJProject1.findElement(new Path("junit/javadochoverhtml/JavaDocHoverTest.java"));
@@ -85,15 +80,16 @@ public class PackageJavadocTests extends CoreTests {
 		JavadocBrowserInformationControlInput hoverInfo= JavadocHover.getHoverInfo(elements, cu, new Region(21, 16), null);
 		String actualHtmlContent= hoverInfo.getHtml();
 
-		//checking for some part of the expected Javadoc which could be retrieved.
-		Assert.assertTrue(actualHtmlContent, actualHtmlContent.contains("Test package documentation in package.html"));
+		// Checking for some part of the expected Javadoc which could be retrieved.
+		assertTrue(actualHtmlContent, actualHtmlContent.contains("Test package documentation in package.html"));
 	}
 
-
+	@Test
 	public void testGetDocFromPackageInfoJava_src() throws Exception {
 		File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(new Path("testresources/PackageJavadocTests/JavadocHover_src.zip"));
 
-		assertTrue("junit src not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("JUnit src should be found", junitSrcArchive);
+		assertTrue("JUnit src should exist", junitSrcArchive.exists());
 
 		JavaProjectHelper.addSourceContainerWithImport(fJProject1, "src", junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING);
 		ICompilationUnit cu= (ICompilationUnit)fJProject1.findElement(new Path("junit/javadochover/Activator.java"));
@@ -105,14 +101,15 @@ public class PackageJavadocTests extends CoreTests {
 		JavadocBrowserInformationControlInput hoverInfo= JavadocHover.getHoverInfo(elements, cu, new Region(21, 12), null);
 		String actualHtmlContent= hoverInfo.getHtml();
 
-		Assert.assertTrue(actualHtmlContent, actualHtmlContent.contains("This is the test content"));
+		assertTrue(actualHtmlContent, actualHtmlContent.contains("This is the test content"));
 	}
 
+	@Test
 	public void testGetDocFromPackageHtml_archive() throws Exception {
-
 		File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(new Path("testresources/PackageJavadocTests/JavadocHover_src.zip"));
 
-		assertTrue("junit src not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("JUnit src should be found", junitSrcArchive);
+		assertTrue("JUnit src should exist", junitSrcArchive.exists());
 
 		JavaProjectHelper.addSourceContainerWithImport(fJProject1, "src", junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING);
 		ICompilationUnit cu= (ICompilationUnit)fJProject1.findElement(new Path("junit/javadochoverhtml/JavaDocHoverTest.java"));
@@ -124,12 +121,15 @@ public class PackageJavadocTests extends CoreTests {
 		JavadocBrowserInformationControlInput hoverInfo= JavadocHover.getHoverInfo(elements, cu, new Region(67, 10), null);
 		String actualHtmlContent= hoverInfo.getHtml();
 
-		Assert.assertTrue(actualHtmlContent, actualHtmlContent.contains("Test package documentation in package.html"));
+		assertTrue(actualHtmlContent, actualHtmlContent.contains("Test package documentation in package.html"));
 	}
 
+	@Test
 	public void testGetDocFromPackageInfoJava_archive() throws Exception {
 		File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(new Path("testresources/PackageJavadocTests/JavadocHover_src.zip"));
-		assertTrue("junit src not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("JUnit src should be found", junitSrcArchive);
+		assertTrue("JUnit src should exist", junitSrcArchive.exists());
+
 		JavaProjectHelper.addSourceContainerWithImport(fJProject1, "src", junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING);
 		ICompilationUnit cu= (ICompilationUnit)fJProject1.findElement(new Path("junit/javadochoverhtml/JavaDocHoverTest.java"));
 		assertNotNull("JavaDocHoverTest.java", cu);
@@ -143,26 +143,29 @@ public class PackageJavadocTests extends CoreTests {
 		IPackageFragmentRoot jarRoot= this.fJProject1.getPackageFragmentRoot(ResourcesPlugin.getWorkspace().getRoot().getFile(new Path("/TestSetupProject/testData.zip")));
 		IPackageFragment packageFragment= jarRoot.getPackageFragment("org.eclipse.jdt.ui.tests");
 		assertNotNull(packageFragment);
+
 		IPath sourceAttachmentPath= jarRoot.getSourceAttachmentPath();
-		Assert.assertNotNull(sourceAttachmentPath);
+		assertNotNull(sourceAttachmentPath);
 
 		int offset= cu.getSource().indexOf("org.eclipse.jdt.ui.tests");
 		int length= "org.eclipse.jdt.ui.tests".length();
 		IJavaElement[] codeSelect= cu.codeSelect(offset, length);
-		Assert.assertNotNull(codeSelect);
-		Assert.assertTrue("No package found !", codeSelect.length > 0);
+		assertNotNull(codeSelect);
+		assertTrue("No package found !", codeSelect.length > 0);
+
 		packageFragment= (IPackageFragment)codeSelect[0];
 		JavadocBrowserInformationControlInput hoverInfo= JavadocHover.getHoverInfo(new IJavaElement[] { packageFragment }, cu, new Region(offset, length), null);
 		String actualHtmlContent= hoverInfo.getHtml();
 
-		Assert.assertTrue(actualHtmlContent, actualHtmlContent.contains("This is the package documentation for org.eclipse.jdt.ui.tests"));
-
+		assertTrue(actualHtmlContent, actualHtmlContent.contains("This is the package documentation for org.eclipse.jdt.ui.tests"));
 	}
 
-
+	@Test
 	public void testGetDocFromSourceAttachmentRootPath() throws Exception {
 		File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(new Path("testresources/PackageJavadocTests/JavadocHover_src.zip"));
-		assertTrue("junit src not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("JUnit src should be found", junitSrcArchive);
+		assertTrue("JUnit src should exist", junitSrcArchive.exists());
+
 		JavaProjectHelper.addSourceContainerWithImport(fJProject1, "src", junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING);
 		ICompilationUnit cu= (ICompilationUnit)fJProject1.findElement(new Path("junit/javadochoverhtml/JavaDocHoverTest.java"));
 		assertNotNull("JavaDocHoverTest.java", cu);
@@ -174,32 +177,37 @@ public class PackageJavadocTests extends CoreTests {
 		JavaProjectHelper.addLibraryWithImport(fJProject1, new Path(clsJarPath.getAbsolutePath()), new Path(srcJarPath.getAbsolutePath()), new Path("src"));
 		fJProject1.open(null);
 		IPackageFragmentRoot jarRoot= this.fJProject1.getPackageFragmentRoot(ResourcesPlugin.getWorkspace().getRoot().getFile(new Path("/TestSetupProject/testData.zip")));
-		Assert.assertTrue(jarRoot != null && jarRoot.exists());
+		assertNotNull(jarRoot);
+		assertTrue(jarRoot.exists());
+
 		IPackageFragment packageFragment= jarRoot.getPackageFragment("org.eclipse.jdt.ui.tests.html");
-		Assert.assertTrue(packageFragment != null && packageFragment.exists());
+		assertNotNull(packageFragment);
+		assertTrue(packageFragment.exists());
+
 		IPath sourceAttachmentPath= jarRoot.getSourceAttachmentPath();
-		Assert.assertNotNull(sourceAttachmentPath);
+		assertNotNull(sourceAttachmentPath);
 
 		int offset= cu.getSource().indexOf("org.eclipse.jdt.ui.tests.html");
 		int length= "org.eclipse.jdt.ui.tests.html".length();
 		IJavaElement[] codeSelect= cu.codeSelect(offset, length);
-		Assert.assertNotNull(codeSelect);
-		Assert.assertTrue("No package found !", codeSelect.length > 0);
+
+		assertNotNull(codeSelect);
+		assertTrue("No package found !", codeSelect.length > 0);
+
 		packageFragment= (IPackageFragment)codeSelect[0];
 		JavadocBrowserInformationControlInput hoverInfo= JavadocHover.getHoverInfo(new IJavaElement[] { packageFragment }, cu, new Region(offset, length), null);
 		String actualHtmlContent= hoverInfo.getHtml();
 
-
-		Assert.assertTrue(actualHtmlContent, actualHtmlContent.contains("This is the package documentation for org.eclipse.jdt.ui.tests.html."));
-
+		assertTrue(actualHtmlContent, actualHtmlContent.contains("This is the package documentation for org.eclipse.jdt.ui.tests.html."));
 	}
 
-
+	@Test
 	public void testGetPackageAttacheddoc() throws Exception {
 		//  https://docs.oracle.com/javase/8/docs/api/
 		File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(new Path("testresources/PackageJavadocTests/JavadocHover_src.zip"));
 
-		assertTrue("junit src not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("JUnit src should be found", junitSrcArchive);
+		assertTrue("JUnit src should exist", junitSrcArchive.exists());
 
 		JavaProjectHelper.addSourceContainerWithImport(fJProject1, "src", junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING);
 		ICompilationUnit cu= (ICompilationUnit)fJProject1.findElement(new Path("junit/javadochoverhtml/JavaDocHoverTest.java"));
@@ -221,26 +229,25 @@ public class PackageJavadocTests extends CoreTests {
 		int offset= cu.getSource().indexOf("java.math");
 		int length= "java.math".length();
 		IJavaElement[] codeSelect= cu.codeSelect(offset, length);
-		Assert.assertNotNull(codeSelect);
-		Assert.assertTrue("No package found !", codeSelect.length > 0);
+		assertNotNull(codeSelect);
+		assertTrue("No package found !", codeSelect.length > 0);
 
 		JavadocBrowserInformationControlInput hoverInfo= JavadocHover.getHoverInfo(codeSelect, cu, new Region(offset, length), null);
 		String actualHtmlContent= hoverInfo.getHtml();
-		Assert.assertNotNull(actualHtmlContent, actualHtmlContent);
+		assertNotNull(actualHtmlContent, actualHtmlContent);
 
 		String connectionTestUrl= "https://docs.oracle.com/";
 		try {
-			//trying to connect to the internet. Exception will be thrown if there is no net connection.
+			// Trying to connect to the internet. Exception will be thrown if there is no net connection.
 			new URL(connectionTestUrl).openConnection().connect();
-			Assert.assertTrue(actualHtmlContent, actualHtmlContent.contains("Provides classes for performing arbitrary-precision integer"));
+			assertTrue(actualHtmlContent, actualHtmlContent.contains("Provides classes for performing arbitrary-precision integer"));
 		} catch (Exception e) {
 			System.out.println("PackageJavadocTests.testGetPackageAttacheddoc(): no internet connection to access docs at " + connectionTestUrl);
 			e.printStackTrace(System.out);
-			//there is no internet connection, so the Javadoc cannot be retrieved.
-			Assert.assertTrue(actualHtmlContent, actualHtmlContent.contains(CorextMessages.JavaDocLocations_noAttachedSource) || actualHtmlContent.contains(CorextMessages.JavaDocLocations_error_gettingJavadoc)
+			// There is no internet connection, so the Javadoc cannot be retrieved.
+			assertTrue(actualHtmlContent, actualHtmlContent.contains(CorextMessages.JavaDocLocations_noAttachedSource) || actualHtmlContent.contains(CorextMessages.JavaDocLocations_error_gettingJavadoc)
 					|| actualHtmlContent.contains(CorextMessages.JavaDocLocations_error_gettingAttachedJavadoc));
 		}
-
 	}
 
 	/**
@@ -249,11 +256,12 @@ public class PackageJavadocTests extends CoreTests {
 	 *
 	 * @throws Exception when the test case fails
 	 */
+	@Test
 	public void testPackageInfoWithReferenceLinks() throws Exception {
-
 		File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(new Path("testresources/PackageJavadocTests/JavadocHover_src.zip"));
 
-		assertTrue("junit src not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("JUnit src should be found", junitSrcArchive);
+		assertTrue("JUnit src should exist", junitSrcArchive.exists());
 
 		JavaProjectHelper.addSourceContainerWithImport(fJProject1, "src", junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING);
 		ICompilationUnit cu= (ICompilationUnit)fJProject1.findElement(new Path("junit/checkPackageInfo/TestNPEHover.java"));
@@ -265,12 +273,15 @@ public class PackageJavadocTests extends CoreTests {
 		JavadocBrowserInformationControlInput hoverInfo= JavadocHover.getHoverInfo(elements, cu, new Region(21, 12), null);
 		String actualHtmlContent= hoverInfo.getHtml();
 
-		Assert.assertTrue(actualHtmlContent, actualHtmlContent.contains("The pack is a test package. This doc contains references"));
+		assertTrue(actualHtmlContent, actualHtmlContent.contains("The pack is a test package. This doc contains references"));
 	}
 
+	@Test
 	public void testPackageWithNoJavadoc() throws Exception {
 		File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(new Path("testresources/PackageJavadocTests/JavadocHover_src.zip"));
-		assertTrue("junit src not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("JUnit src should be found", junitSrcArchive);
+		assertTrue("JUnit src should exist", junitSrcArchive.exists());
+
 		JavaProjectHelper.addSourceContainerWithImport(fJProject1, "src", junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING);
 		ICompilationUnit cu= (ICompilationUnit)fJProject1.findElement(new Path("junit/javadochoverhtml/JavaDocHoverTest.java"));
 		assertNotNull("JavaDocHoverTest.java", cu);
@@ -282,34 +293,41 @@ public class PackageJavadocTests extends CoreTests {
 		JavaProjectHelper.addLibraryWithImport(fJProject1, new Path(clsJarPath.getAbsolutePath()), new Path(srcJarPath.getAbsolutePath()), new Path("src"));
 		fJProject1.open(null);
 		IPackageFragmentRoot jarRoot= this.fJProject1.getPackageFragmentRoot(ResourcesPlugin.getWorkspace().getRoot().getFile(new Path("/TestSetupProject/testData.zip")));
-		Assert.assertTrue(jarRoot != null && jarRoot.exists());
+		assertNotNull(jarRoot);
+		assertTrue(jarRoot.exists());
+
 		IPackageFragment packageFragment= jarRoot.getPackageFragment("org.eclipse.jdt.ui.tests.noJavadoc");
-		Assert.assertTrue(packageFragment != null && packageFragment.exists());
+		assertNotNull(packageFragment);
+		assertTrue(packageFragment.exists());
+
 		IPath sourceAttachmentPath= jarRoot.getSourceAttachmentPath();
-		Assert.assertNotNull(sourceAttachmentPath);
+		assertNotNull(sourceAttachmentPath);
 
 		int offset= cu.getSource().indexOf("org.eclipse.jdt.ui.tests.noJavadoc");
 		int length= "org.eclipse.jdt.ui.tests.noJavadoc".length();
 		IJavaElement[] codeSelect= cu.codeSelect(offset, length);
-		Assert.assertNotNull(codeSelect);
-		Assert.assertTrue("No package found !", codeSelect.length > 0);
+		assertNotNull(codeSelect);
+		assertTrue("No package found !", codeSelect.length > 0);
+
 		packageFragment= (IPackageFragment)codeSelect[0];
 		JavadocBrowserInformationControlInput hoverInfo= JavadocHover.getHoverInfo(new IJavaElement[] { packageFragment }, cu, new Region(offset, length), null);
 		String actualHtmlContent= hoverInfo.getHtml();
 
-		Assert.assertTrue(actualHtmlContent, actualHtmlContent.contains(CorextMessages.JavaDocLocations_noAttachedJavadoc));
+		assertTrue(actualHtmlContent, actualHtmlContent.contains(CorextMessages.JavaDocLocations_noAttachedJavadoc));
 	}
 
+	@Test
 	public void testFailToAccessAttachedJavadoc() throws Exception {
 		File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(new Path("testresources/PackageJavadocTests/JavadocHover_src.zip"));
 
-		assertTrue("junit src not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("JUnit src should be found", junitSrcArchive);
+		assertTrue("JUnit src should exist", junitSrcArchive.exists());
 
 		JavaProjectHelper.addSourceContainerWithImport(fJProject1, "src", junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING);
 		ICompilationUnit cu= (ICompilationUnit)fJProject1.findElement(new Path("junit/javadochoverhtml/JavaDocHoverTest.java"));
 		assertNotNull("JavaDocHoverTest.java", cu);
 
-		//set a wrong Javadoc location URL
+		// Set a wrong Javadoc location URL
 		IClasspathAttribute attribute=
 				JavaCore.newClasspathAttribute(
 						IClasspathAttribute.JAVADOC_LOCATION_ATTRIBUTE_NAME,
@@ -325,33 +343,25 @@ public class PackageJavadocTests extends CoreTests {
 		int offset= cu.getSource().indexOf("java.math");
 		int length= "java.math".length();
 		IJavaElement[] codeSelect= cu.codeSelect(offset, length);
-		Assert.assertNotNull(codeSelect);
-		Assert.assertTrue("No package found !", codeSelect.length > 0);
+		assertNotNull(codeSelect);
+		assertTrue("No package found !", codeSelect.length > 0);
 
 		JavadocBrowserInformationControlInput hoverInfo= JavadocHover.getHoverInfo(codeSelect, cu, new Region(offset, length), null);
 		String actualHtmlContent= hoverInfo.getHtml();
-		Assert.assertNotNull(actualHtmlContent);
+		assertNotNull(actualHtmlContent);
 
 		// Need to check both conditions for now. See https://bugs.eclipse.org/403036 and https://bugs.eclipse.org/403154 for details.
-		Assert.assertTrue(actualHtmlContent,
+		assertTrue(actualHtmlContent,
 				actualHtmlContent.contains(CorextMessages.JavaDocLocations_error_gettingAttachedJavadoc) || actualHtmlContent.contains(CorextMessages.JavaDocLocations_noAttachedSource));
-
 	}
 
-	public static Test setUpTest(Test test) {
-		return new ProjectTestSetup(test);
+	@Before
+	public void setUp() throws Exception {
+		fJProject1= pts.getProject();
 	}
 
-	@Override
-	protected void setUp() throws Exception {
-		fJProject1= ProjectTestSetup.getProject();
-
+	@After
+	public void tearDown() throws Exception {
+		JavaProjectHelper.clear(fJProject1, pts.getDefaultClasspath());
 	}
-
-
-	@Override
-	protected void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJProject1, ProjectTestSetup.getDefaultClasspath());
-	}
-
 }
