@@ -15,7 +15,6 @@ package org.eclipse.jdt.ui.tests.packageview;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
 import java.io.ByteArrayInputStream;
@@ -25,8 +24,6 @@ import java.util.Arrays;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 
@@ -71,7 +68,6 @@ import org.eclipse.jdt.internal.ui.util.CoreUtility;
  *
  * @since 3.0+
  */
-@RunWith(JUnit4.class)
 public class ContentProviderTests5{
 	private boolean fEnableAutoBuildAfterTesting;
 	private ITreeContentProvider fProvider;
@@ -109,7 +105,7 @@ public class ContentProviderTests5{
 
 		//add rt.jar
 		jdk= JavaProjectHelper.addVariableRTJar(fJProject, "JRE_LIB_TEST", null, null);
-		assertTrue("jdk not found", jdk != null);
+		assertNotNull("jdk not found", jdk);
 
 		setUpView();
 	}
@@ -128,7 +124,7 @@ public class ContentProviderTests5{
 			fProvider= (ITreeContentProvider) packageExplorerPart.getTreeViewer().getContentProvider();
 			setFolding(false);
 		} else {
-			assertTrue("Unable to get view", false);
+			fail("Unable to get view");
 		}
 		assertNotNull(fProvider);
 	}
