@@ -20,8 +20,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.TestOptions;
@@ -59,11 +57,10 @@ import org.eclipse.jdt.internal.ui.javaeditor.JavaEditor;
 import org.eclipse.jdt.internal.ui.text.correction.JavaCorrectionAssistant;
 import org.eclipse.jdt.internal.ui.text.correction.JavaCorrectionProcessor;
 
-@RunWith(JUnit4.class)
 public class MarkerResolutionTest extends QuickFixTest {
 
 	@Rule
-    public ProjectTestSetup projectsetup = new ProjectTestSetup();
+    public ProjectTestSetup projectSetup = new ProjectTestSetup();
 
 	private static final class TextViewerContext implements IQuickAssistInvocationContext {
 
@@ -116,18 +113,16 @@ public class MarkerResolutionTest extends QuickFixTest {
 		IPreferenceStore store= JavaPlugin.getDefault().getPreferenceStore();
 		store.setValue(PreferenceConstants.CODEGEN_ADD_COMMENTS, false);
 
-		fJProject1= ProjectTestSetup.getProject();
+		fJProject1= projectSetup.getProject();
 
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 	}
 
-
 	@After
 	public void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJProject1, ProjectTestSetup.getDefaultClasspath());
+		JavaProjectHelper.clear(fJProject1, projectSetup.getDefaultClasspath());
 	}
 
-
 	private IMarker createMarker(ICompilationUnit cu, int line, int offset, int len) throws CoreException {
 		IFile file= (IFile) cu.getResource();
 		IMarker marker= file.createMarker(AddTestMarkersAction.MARKER_TYPE);
@@ -147,7 +142,7 @@ public class MarkerResolutionTest extends QuickFixTest {
 			return;
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class E {\n");
@@ -176,7 +171,7 @@ public class MarkerResolutionTest extends QuickFixTest {
 
 			proposals[0].apply(doc);
 
-			buf= new StringBuffer();
+			buf= new StringBuilder();
 			buf.append("PACKAGE test1;\n");
 			buf.append("import java.util.Vector;\n");
 			buf.append("public class E {\n");
@@ -196,7 +191,7 @@ public class MarkerResolutionTest extends QuickFixTest {
 			return;
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class E {\n");
@@ -223,7 +218,7 @@ public class MarkerResolutionTest extends QuickFixTest {
 
 			proposals[0].apply(doc);
 
-			buf= new StringBuffer();
+			buf= new StringBuilder();
 			buf.append("\n");
 			buf.append("package TEST1;\n");
 			buf.append("import java.util.Vector;\n");
