@@ -29,8 +29,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.TestOptions;
@@ -69,12 +67,10 @@ import org.eclipse.jdt.internal.ui.propertiesfileeditor.PropertiesFileEditor;
 import org.eclipse.jdt.internal.ui.propertiesfileeditor.PropertiesFileEditorMessages;
 import org.eclipse.jdt.internal.ui.propertiesfileeditor.PropertiesQuickAssistProcessor;
 
-
-@RunWith(JUnit4.class)
 public class PropertiesFileQuickAssistTest {
 
 	@Rule
-    public ProjectTestSetup projectsetup = new ProjectTestSetup();
+    public ProjectTestSetup projectSetup = new ProjectTestSetup();
 
 	private IJavaProject fJProject;
 	private IPackageFragmentRoot fSourceFolder;
@@ -92,7 +88,7 @@ public class PropertiesFileQuickAssistTest {
 
 		setPreferences();
 
-		fJProject= ProjectTestSetup.getProject();
+		fJProject= projectSetup.getProject();
 
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject, "src");
 
@@ -112,7 +108,7 @@ public class PropertiesFileQuickAssistTest {
 
 	@After
 	public void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJProject, ProjectTestSetup.getDefaultClasspath());
+		JavaProjectHelper.clear(fJProject, projectSetup.getDefaultClasspath());
 	}
 
 	private static IFile createPropertyFile(IPackageFragment pack, String name, String content) throws UnsupportedEncodingException, CoreException {
@@ -182,7 +178,7 @@ public class PropertiesFileQuickAssistTest {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -196,7 +192,7 @@ public class PropertiesFileQuickAssistTest {
 		ICompilationUnit cu= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_2=Hello2\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
@@ -212,7 +208,7 @@ public class PropertiesFileQuickAssistTest {
 		proposal.apply(context.getDocument());
 
 		// Accessor class
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -232,7 +228,7 @@ public class PropertiesFileQuickAssistTest {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -246,7 +242,7 @@ public class PropertiesFileQuickAssistTest {
 		ICompilationUnit cu= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_2=Hello2\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
@@ -263,7 +259,7 @@ public class PropertiesFileQuickAssistTest {
 		proposal.apply(context.getDocument());
 
 		// Accessor class
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -284,7 +280,7 @@ public class PropertiesFileQuickAssistTest {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -301,7 +297,7 @@ public class PropertiesFileQuickAssistTest {
 		ICompilationUnit cu= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_2=Hello2\n");
 		buf.append("Test_3=Hello3\n");
@@ -320,7 +316,7 @@ public class PropertiesFileQuickAssistTest {
 		proposal.apply(context.getDocument());
 
 		// Accessor class
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -343,7 +339,7 @@ public class PropertiesFileQuickAssistTest {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -361,7 +357,7 @@ public class PropertiesFileQuickAssistTest {
 		ICompilationUnit cu= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_2=Hello2\n");
 		buf.append("Test_3=Hello3\n");
@@ -382,7 +378,7 @@ public class PropertiesFileQuickAssistTest {
 		proposal.apply(context.getDocument());
 
 		// Accessor class
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -407,7 +403,7 @@ public class PropertiesFileQuickAssistTest {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -425,7 +421,7 @@ public class PropertiesFileQuickAssistTest {
 		ICompilationUnit cu= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_3=Hello3\n");
 		buf.append("Test_4=Hello4\n");
@@ -446,7 +442,7 @@ public class PropertiesFileQuickAssistTest {
 		proposal.apply(context.getDocument());
 
 		// Accessor class
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -472,7 +468,7 @@ public class PropertiesFileQuickAssistTest {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class RandomName extends NLS {\n");
@@ -486,7 +482,7 @@ public class PropertiesFileQuickAssistTest {
 		ICompilationUnit cu= pack1.createCompilationUnit("RandomName.java", buf.toString(), false, null);
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_2=Hello2\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
@@ -502,7 +498,7 @@ public class PropertiesFileQuickAssistTest {
 		proposal.apply(context.getDocument());
 
 		// Accessor class
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class RandomName extends NLS {\n");
@@ -522,7 +518,7 @@ public class PropertiesFileQuickAssistTest {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -536,7 +532,7 @@ public class PropertiesFileQuickAssistTest {
 		pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_2=Hello2\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
@@ -552,7 +548,7 @@ public class PropertiesFileQuickAssistTest {
 		proposal.apply(context.getDocument());
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_2=Hello2\n");
 		checkContentOfFile("property file", file, buf.toString());
 	}
@@ -562,7 +558,7 @@ public class PropertiesFileQuickAssistTest {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -576,7 +572,7 @@ public class PropertiesFileQuickAssistTest {
 		pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_2=Hello2\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
@@ -593,7 +589,7 @@ public class PropertiesFileQuickAssistTest {
 		proposal.apply(context.getDocument());
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		checkContentOfFile("property file", file, buf.toString());
 	}
 
@@ -602,7 +598,7 @@ public class PropertiesFileQuickAssistTest {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -618,7 +614,7 @@ public class PropertiesFileQuickAssistTest {
 		ICompilationUnit cu= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_2=Hello2\n");
 		IFile file= createPropertyFile(pack1, "Accessor.properties", buf.toString());
@@ -634,7 +630,7 @@ public class PropertiesFileQuickAssistTest {
 		proposal.apply(context.getDocument());
 
 		// Accessor class
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -649,7 +645,7 @@ public class PropertiesFileQuickAssistTest {
 		checkContentOfCu("nls file", cu, buf.toString());
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_2=Hello2\n");
 		checkContentOfFile("property file", file, buf.toString());
 	}
@@ -659,7 +655,7 @@ public class PropertiesFileQuickAssistTest {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -679,7 +675,7 @@ public class PropertiesFileQuickAssistTest {
 		ICompilationUnit cu= pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_2=Hello2\n");
 		buf.append("Test_3=Hello3\n");
@@ -700,7 +696,7 @@ public class PropertiesFileQuickAssistTest {
 		proposal.apply(context.getDocument());
 
 		// Accessor class
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -718,7 +714,7 @@ public class PropertiesFileQuickAssistTest {
 		checkContentOfCu("nls file", cu, buf.toString());
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_2=Hello2\n");
 		buf.append("Test_5=Hello5\n");
@@ -731,7 +727,7 @@ public class PropertiesFileQuickAssistTest {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -747,7 +743,7 @@ public class PropertiesFileQuickAssistTest {
 		pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_2=Hello2\n");
 		buf.append("    \n");
@@ -769,7 +765,7 @@ public class PropertiesFileQuickAssistTest {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -785,7 +781,7 @@ public class PropertiesFileQuickAssistTest {
 		pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_2=Hello2\n");
 		buf.append("    \n");
@@ -807,7 +803,7 @@ public class PropertiesFileQuickAssistTest {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
 
 		// Accessor class
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("import org.eclipse.osgi.util.NLS;\n");
 		buf.append("public class Accessor extends NLS {\n");
@@ -823,7 +819,7 @@ public class PropertiesFileQuickAssistTest {
 		pack1.createCompilationUnit("Accessor.java", buf.toString(), false, null);
 
 		// property file
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("Test_1=Hello1\n");
 		buf.append("Test_2=Hello2\n");
 		buf.append("    \n");
