@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -15,23 +15,29 @@
 package org.eclipse.jdt.ui.tests.quickfix;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.List;
 import java.util.stream.Collectors;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.StringAsserts;
+
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IStatus;
 
 import org.eclipse.core.resources.IFile;
+
 import org.eclipse.jface.text.BadLocationException;
 import org.eclipse.jface.text.Document;
 import org.eclipse.jface.text.IDocument;
@@ -42,8 +48,12 @@ import org.eclipse.ltk.core.refactoring.TextFileChange;
 
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.IJavaElement;
+import org.eclipse.jdt.core.IPackageFragment;
+import org.eclipse.jdt.core.IPackageFragmentRoot;
 import org.eclipse.jdt.core.IProblemRequestor;
 import org.eclipse.jdt.core.IType;
+import org.eclipse.jdt.core.JavaCore;
+import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.WorkingCopyOwner;
 import org.eclipse.jdt.core.compiler.IProblem;
 import org.eclipse.jdt.core.dom.AbstractTypeDeclaration;
@@ -74,87 +84,35 @@ import org.eclipse.jdt.internal.ui.text.correction.proposals.LinkedNamesAssistPr
 import org.eclipse.jdt.internal.ui.text.correction.proposals.NewCUUsingWizardProposal;
 import org.eclipse.jdt.internal.ui.text.correction.proposals.RenameRefactoringProposal;
 import org.eclipse.jdt.internal.ui.text.template.contentassist.SurroundWithTemplateProposal;
-import org.junit.runner.RunWith;
-import org.junit.runners.Suite;
 
 /**
  */
-@RunWith(Suite.class)
-@Suite.SuiteClasses({
-	QuickFixTest9.class,
-	QuickFixTest18.class,
-	QuickFixTest13.class,
-	SerialVersionQuickFixTest.class,
-	UtilitiesTest.class,
-	UnresolvedTypesQuickFixTest.class,
-	UnresolvedVariablesQuickFixTest.class,
-	UnresolvedMethodsQuickFixTest.class,
-	UnresolvedMethodsQuickFixTest18.class,
-	ReturnTypeQuickFixTest.class,
-	LocalCorrectionsQuickFixTest.class,
-	LocalCorrectionsQuickFixTest17.class,
-	LocalCorrectionsQuickFixTest18.class,
-	TypeMismatchQuickFixTests.class,
-	ReorgQuickFixTest.class,
-	ModifierCorrectionsQuickFixTest.class,
-	ModifierCorrectionsQuickFixTest17.class,
-	ModifierCorrectionsQuickFixTest9.class,
-	GetterSetterQuickFixTest.class,
-	AssistQuickFixTest.class,
-	AssistQuickFixTest17.class,
-	AssistQuickFixTest18.class,
-	AssistQuickFixTest12.class,
-	ChangeNonStaticToStaticTest.class,
-	MarkerResolutionTest.class,
-	JavadocQuickFixTest.class,
-	JavadocQuickFixTest9.class,
-	ConvertForLoopQuickFixTest.class,
-	ConvertIterableLoopQuickFixTest.class,
-	AdvancedQuickAssistTest.class,
-	AdvancedQuickAssistTest17.class,
-	AdvancedQuickAssistTest18.class,
-	CleanUpTestCase.class,
-	QuickFixEnablementTest.class,
-	SurroundWithTemplateTest.class,
-	TypeParameterMismatchTest.class,
-	PropertiesFileQuickAssistTest.class,
-	NullAnnotationsQuickFixTest.class,
-	NullAnnotationsQuickFixTest18.class,
-	NullAnnotationsQuickFixTest18Mix.class,
-	AnnotateAssistTest15.class,
-	AnnotateAssistTest18.class,
-	TypeAnnotationQuickFixTest.class
-})
-
 public class QuickFixTest {
 
+	protected static String MODULE_INFO_FILE_CONTENT = ""
+			+ "module test {\n"
+			+ "}\n";
+
 	public static void assertCorrectLabels(List<? extends ICompletionProposal> proposals) {
-		for (int i= 0; i < proposals.size(); i++) {
-			ICompletionProposal proposal= proposals.get(i);
+		for (ICompletionProposal proposal : proposals) {
 			String name= proposal.getDisplayString();
 			if (name == null || name.length() == 0 || name.charAt(0) == '!' || name.contains("{0}") || name.contains("{1}")) {
-				assertTrue("wrong proposal label: " + name, false);
-			}
-			if (proposal.getImage() == null) {
-				assertTrue("wrong proposal image", false);
+				fail("wrong proposal label: " + name);
 			}
+			assertNotNull("wrong proposal image", proposal.getImage());
 		}
 	}
 
 	public static void assertCorrectContext(IInvocationContext context, ProblemLocation problem) {
 		if (problem.getProblemId() != 0) {
-			if (!JavaCorrectionProcessor.hasCorrections(context.getCompilationUnit(), problem.getProblemId(), problem.getMarkerType())) {
-				assertTrue("Problem type not marked with light bulb: " + problem, false);
-			}
+			assertTrue("Problem type not marked with light bulb: " + problem, JavaCorrectionProcessor.hasCorrections(context.getCompilationUnit(), problem.getProblemId(), problem.getMarkerType()));
 		}
 	}
 
-
 	public static void assertNumberOf(String name, int nProblems, int nProblemsExpected) {
-		assertTrue("Wrong number of " + name + ", is: " + nProblems + ", expected: " + nProblemsExpected, nProblems == nProblemsExpected);
+		assertEquals("Wrong number of " + name + ", is: " + nProblems + ", expected: " + nProblemsExpected, nProblems, nProblemsExpected);
 	}
 
-
 	public static void assertEqualString(String actual, String expected) {
 		StringAsserts.assertEqualString(actual, expected);
 	}
@@ -184,21 +142,21 @@ public class QuickFixTest {
 	}
 
 	public static void assertCommandIdDoesNotExist(List<? extends ICompletionProposal> actualProposals, String commandId) {
-		assertTrue(findProposalByCommandId(commandId, actualProposals) == null);
+		assertNull(findProposalByCommandId(commandId, actualProposals));
 	}
 
 	public static void assertProposalDoesNotExist(List<? extends ICompletionProposal> actualProposals, String proposalName) {
-		assertTrue(findProposalByName(proposalName, actualProposals) == null);
+		assertNull(findProposalByName(proposalName, actualProposals));
 	}
 
 	public static void assertProposalExists(List<? extends ICompletionProposal> actualProposals, String proposalName) {
-		assertTrue(findProposalByName(proposalName, actualProposals) != null);
+		assertNotNull(findProposalByName(proposalName, actualProposals));
 	}
 
 	public static TypeDeclaration findTypeDeclaration(CompilationUnit astRoot, String simpleTypeName) {
 		List<AbstractTypeDeclaration> types= astRoot.types();
-		for (int i= 0; i < types.size(); i++) {
-			TypeDeclaration elem= (TypeDeclaration) types.get(i);
+		for (AbstractTypeDeclaration type : types) {
+			TypeDeclaration elem= (TypeDeclaration) type;
 			if (simpleTypeName.equals(elem.getName().getIdentifier())) {
 				return elem;
 			}
@@ -218,8 +176,7 @@ public class QuickFixTest {
 	public static VariableDeclarationFragment findFieldDeclaration(TypeDeclaration typeDecl, String fieldName) {
 		for (FieldDeclaration field : typeDecl.getFields()) {
 			List<VariableDeclarationFragment> list= field.fragments();
-			for (int k= 0; k < list.size(); k++) {
-				VariableDeclarationFragment fragment= list.get(k);
+			for (VariableDeclarationFragment fragment : list) {
 				if (fieldName.equals(fragment.getName().getIdentifier())) {
 					return fragment;
 				}
@@ -285,7 +242,6 @@ public class QuickFixTest {
 		return corrections;
 	}
 
-
 	protected static void assertNumberOfProblems(int nProblems, IProblem[] problems) {
 		if (problems.length != nProblems) {
 			StringBuilder buf= new StringBuilder("Wrong number of problems, is: ");
@@ -295,7 +251,7 @@ public class QuickFixTest {
 				buf.append('[').append(problem.getSourceStart()).append(" ,").append(problem.getSourceEnd()).append(']');
 				buf.append('\n');
 			}
-			assertTrue(buf.toString(), false);
+			fail(buf.toString());
 		}
 	}
 
@@ -378,7 +334,6 @@ public class QuickFixTest {
 		}
 	}
 
-
 	protected static final ArrayList<IJavaCompletionProposal> collectAssists(IInvocationContext context, Class<?>[] filteredTypes) throws CoreException {
 		ArrayList<IJavaCompletionProposal> proposals= new ArrayList<>();
 		IStatus status= JavaCorrectionProcessor.collectAssists(context, new IProblemLocation[0], proposals);
@@ -388,7 +343,6 @@ public class QuickFixTest {
 			assertTrue("should be marked as 'has assist'", JavaCorrectionProcessor.hasAssists(context));
 		}
 
-
 		if (filteredTypes != null && filteredTypes.length > 0) {
 			for (Iterator<IJavaCompletionProposal> iter= proposals.iterator(); iter.hasNext(); ) {
 				if (isFiltered(iter.next(), filteredTypes)) {
@@ -408,7 +362,7 @@ public class QuickFixTest {
 		return false;
 	}
 
-	protected static final ArrayList<IJavaCompletionProposal> collectAssists(IInvocationContext context, boolean includeLinkedRename) throws CoreException {
+	public static final ArrayList<IJavaCompletionProposal> collectAssists(IInvocationContext context, boolean includeLinkedRename) throws CoreException {
 		Class<?>[] filteredTypes= includeLinkedRename ? null : new Class[] { LinkedNamesAssistProposal.class, RenameRefactoringProposal.class };
 		return collectAssists(context, filteredTypes);
 	}
@@ -423,7 +377,6 @@ public class QuickFixTest {
 		expecteds.add(expected.toString());
 	}
 
-
 	protected static String[] getPreviewContents(List<IJavaCompletionProposal> proposals) throws CoreException, BadLocationException {
 		String[] res= new String[proposals.size()];
 		for (int i= 0; i < proposals.size(); i++) {
@@ -432,7 +385,6 @@ public class QuickFixTest {
 		return res;
 	}
 
-
 	private static String getProposalPreviewContent(ICompletionProposal curr) throws CoreException, BadLocationException {
 		String previewContent = null;
 		if (curr instanceof ReorgCorrectionsSubProcessor.ClasspathFixCorrectionProposal) {
@@ -458,7 +410,6 @@ public class QuickFixTest {
 		return "";
 	}
 
-
 	private static String getTemplatePreviewContent(SurroundWithTemplateProposal proposal) {
 		return proposal.getPreviewContent();
 	}
@@ -479,7 +430,7 @@ public class QuickFixTest {
 
 	protected static String[] getAllDisplayStrings(ArrayList<IJavaCompletionProposal> proposals) {
 		return proposals.stream()
-				.map(proposal -> proposal.getDisplayString())
+				.map(IJavaCompletionProposal::getDisplayString)
 				.filter(displayString -> displayString != null && !displayString.isEmpty())
 				.toArray(String[]::new);
 	}
@@ -515,20 +466,18 @@ public class QuickFixTest {
 		if (proposals.size() != expectedProposals) {
 			StringBuffer buf= new StringBuffer();
 			buf.append("Wrong number of proposals, is: ").append(proposals.size()). append(", expected: ").append(expectedProposals).append('\n');
-			for (int i= 0; i < proposals.size(); i++) {
-				ICompletionProposal curr= proposals.get(i);
+			for (ICompletionProposal curr : proposals) {
 				buf.append(" - ").append(curr.getDisplayString()).append('\n');
 				if (curr instanceof CUCorrectionProposal) {
 					appendSource(((CUCorrectionProposal) curr), buf);
 				}
 			}
-			assertTrue(buf.toString(), false);
+			fail(buf.toString());
 		}
 	}
 
 	protected static ICommandAccess findProposalByCommandId(String commandId, List<? extends ICompletionProposal> proposals) {
-		for (int i= 0; i < proposals.size(); i++) {
-			Object curr= proposals.get(i);
+		for (ICompletionProposal curr : proposals) {
 			if (curr instanceof ICommandAccess) {
 				if (commandId.equals(((ICommandAccess) curr).getCommandId())) {
 					return (ICommandAccess) curr;
@@ -539,10 +488,9 @@ public class QuickFixTest {
 	}
 
 	protected static ICompletionProposal findProposalByName(String name, List<? extends ICompletionProposal> proposals) {
-		for (int i= 0; i < proposals.size(); i++) {
-			Object curr= proposals.get(i);
-			if (curr instanceof ICompletionProposal && name.equals(((ICompletionProposal)curr).getDisplayString()))
-				return (ICompletionProposal)curr;
+		for (ICompletionProposal curr : proposals) {
+			if (name.equals(curr.getDisplayString()))
+				return curr;
 		}
 		return null;
 	}
@@ -558,9 +506,7 @@ public class QuickFixTest {
 
 	protected static void assertNoErrors(IInvocationContext context) {
 		for (IProblem problem : context.getASTRoot().getProblems()) {
-			if (problem.isError()) {
-				assertTrue("source has error: " + problem.getMessage(), false);
-			}
+			assertFalse("source has error: " + problem.getMessage(), problem.isError());
 		}
 	}
 
@@ -573,7 +519,6 @@ public class QuickFixTest {
 		return getPreviewsInBufAppend(cu, proposals);
 	}
 
-
 	protected static String getPreviewsInBufAppend(ICompilationUnit cu, List<IJavaCompletionProposal> proposals) throws CoreException, BadLocationException {
 		StringBuffer buf= new StringBuffer();
 		String[] previewContents= getPreviewContents(proposals);
@@ -606,7 +551,6 @@ public class QuickFixTest {
 		return buf.toString();
 	}
 
-
 	private static void wrapInBufAppend(String curr, StringBuffer buf) {
 		buf.append("buf.append(\"");
 
@@ -657,4 +601,50 @@ public class QuickFixTest {
 			assertEquals("Unexpected choice", expectedChoices[i], sortedChoices.get(i));
 		}
 	}
+	protected void assertLinkedChoicesContains(ICompletionProposal proposal, String linkedGroup, String[] expectedChoices) throws CoreException{
+		assertTrue("Not a LinkedCorrectionProposal", proposal instanceof LinkedCorrectionProposal);
+		LinkedCorrectionProposal linkedProposal = (LinkedCorrectionProposal)proposal;
+		linkedProposal.getChange(); // force computing the proposal details
+		LinkedProposalModel linkedProposalModel = linkedProposal.getLinkedProposalModel();
+		LinkedProposalPositionGroup positionGroup = linkedProposalModel.getPositionGroup(linkedGroup, false);
+		Proposal[] choices = positionGroup.getProposals();
+		assertTrue("Contains less number of choices", choices.length >= expectedChoices.length);
+		List<String> sortedChoices= Arrays.stream(choices)
+									.map(Proposal::getDisplayString)
+									.sorted()
+									.collect(Collectors.toList());
+		for (int i=0; i<expectedChoices.length; i++) {
+			assertTrue("choice not found" + expectedChoices[i], sortedChoices.contains(expectedChoices[i]));
+		}
+	}
+
+	/**
+	 * Computes the number of warnings the java file "filename" has.
+	 * Then check if the "preview" source code has the same number of warnings.
+	 * Throw error if the number changes.
+	 *
+	 * @param pack
+	 * @param preview
+	 * @param className
+	 * @param filename
+	 * @param fSourceFolder
+	 * @throws JavaModelException
+	 */
+	protected void assertNoAdditionalProblems(IPackageFragment pack, String preview, String className, String filename, IPackageFragmentRoot fSourceFolder) throws JavaModelException {
+		Hashtable<String, String> options= JavaCore.getOptions();
+		options.put(JavaCore.COMPILER_PB_UNUSED_LOCAL, JavaCore.ERROR);
+		JavaCore.setOptions(options);
+
+		ICompilationUnit cu= pack.getCompilationUnit(filename);
+		CompilationUnit astRoot= getASTRoot(cu);
+		IProblem[] problems= astRoot.getProblems();
+		int nrofproblems= problems.length;
+
+		pack.delete(true, null);
+		pack= fSourceFolder.createPackageFragment(className, false, null);
+		cu= pack.createCompilationUnit(filename, preview, false, null);
+		astRoot= getASTRoot(cu);
+		problems= astRoot.getProblems();
+		assertNumberOfProblems(nrofproblems, problems);
+	}
 }
