@@ -14,6 +14,7 @@
 package org.eclipse.jdt.ui.tests.quickfix;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
 
 import java.io.File;
@@ -24,8 +25,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.JavaTestPlugin;
@@ -69,11 +68,10 @@ import org.eclipse.jdt.internal.ui.text.correction.ProblemLocation;
 import org.eclipse.jdt.internal.ui.text.correction.proposals.CorrectMainTypeNameProposal;
 import org.eclipse.jdt.internal.ui.text.correction.proposals.CorrectPackageDeclarationProposal;
 
-@RunWith(JUnit4.class)
 public class ReorgQuickFixTest extends QuickFixTest {
 
 	@Rule
-    public ProjectTestSetup projectsetup = new ProjectTestSetup();
+    public ProjectTestSetup projectSetup = new ProjectTestSetup();
 
 	private IJavaProject fJProject1;
 	private IPackageFragmentRoot fSourceFolder;
@@ -89,21 +87,20 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		IPreferenceStore store= JavaPlugin.getDefault().getPreferenceStore();
 		store.setValue(PreferenceConstants.CODEGEN_ADD_COMMENTS, false);
 
-		fJProject1= ProjectTestSetup.getProject();
+		fJProject1= projectSetup.getProject();
 
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 	}
 
 	@After
 	public void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJProject1, ProjectTestSetup.getDefaultClasspath());
+		JavaProjectHelper.clear(fJProject1, projectSetup.getDefaultClasspath());
 	}
 
-
 	@Test
 	public void testUnusedImports() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class E {\n");
@@ -123,7 +120,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) p1;
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("}\n");
@@ -133,7 +130,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testUnusedImportsInDefaultPackage() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class E {\n");
 		buf.append("}\n");
@@ -152,7 +149,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) p1;
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("\n");
 		buf.append("public class E {\n");
 		buf.append("}\n");
@@ -162,7 +159,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testUnusedImportOnDemand() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("import java.util.Vector;\n");
@@ -186,7 +183,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) p1;
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("import java.util.Vector;\n");
@@ -200,15 +197,15 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testCollidingImports() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
-		buf.append("import java.security.Permission;\n");
-		buf.append("import java.security.acl.Permission;\n");
+		buf.append("import java.util.Date;\n");
+		buf.append("import java.sql.Date;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("\n");
 		buf.append("public class E {\n");
-		buf.append("    Permission p;\n");
+		buf.append("    Date d;\n");
 		buf.append("    Vector v;\n");
 		buf.append("}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("E.java", buf.toString(), false, null);
@@ -226,14 +223,14 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) p1;
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
-		buf.append("import java.security.Permission;\n");
+		buf.append("import java.util.Date;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("\n");
 		buf.append("public class E {\n");
-		buf.append("    Permission p;\n");
+		buf.append("    Date d;\n");
 		buf.append("    Vector v;\n");
 		buf.append("}\n");
 		assertEqualString(preview, buf.toString());
@@ -242,7 +239,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testWrongPackageStatement() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("\n");
 		buf.append("public class E {\n");
@@ -256,15 +253,15 @@ public class ReorgQuickFixTest extends QuickFixTest {
 
 		boolean hasRename= true, hasMove= true;
 
-		for (int i= 0; i < proposals.size(); i++) {
-			ChangeCorrectionProposal curr= (ChangeCorrectionProposal) proposals.get(i);
+		for (IJavaCompletionProposal proposal2 : proposals) {
+			ChangeCorrectionProposal curr= (ChangeCorrectionProposal) proposal2;
 			if (curr instanceof CorrectPackageDeclarationProposal) {
 				assertTrue("Duplicated proposal", hasRename);
 				hasRename= false;
 
 				CUCorrectionProposal proposal= (CUCorrectionProposal) curr;
 				String preview= getPreviewContent(proposal);
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("\n");
 				buf.append("public class E {\n");
@@ -278,7 +275,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 				IPackageFragment pack2= fSourceFolder.getPackageFragment("test2");
 				ICompilationUnit cu2= pack2.getCompilationUnit("E.java");
 				assertTrue("CU does not exist", cu2.exists());
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test2;\n");
 				buf.append("\n");
 				buf.append("public class E {\n");
@@ -291,7 +288,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testWrongPackageStatementInEnum() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("\n");
 		buf.append("public enum E {\n");
@@ -305,15 +302,15 @@ public class ReorgQuickFixTest extends QuickFixTest {
 
 		boolean hasRename= true, hasMove= true;
 
-		for (int i= 0; i < proposals.size(); i++) {
-			ChangeCorrectionProposal curr= (ChangeCorrectionProposal) proposals.get(i);
+		for (IJavaCompletionProposal proposal2 : proposals) {
+			ChangeCorrectionProposal curr= (ChangeCorrectionProposal) proposal2;
 			if (curr instanceof CorrectPackageDeclarationProposal) {
 				assertTrue("Duplicated proposal", hasRename);
 				hasRename= false;
 
 				CUCorrectionProposal proposal= (CUCorrectionProposal) curr;
 				String preview= getPreviewContent(proposal);
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("\n");
 				buf.append("public enum E {\n");
@@ -327,7 +324,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 				IPackageFragment pack2= fSourceFolder.getPackageFragment("test2");
 				ICompilationUnit cu2= pack2.getCompilationUnit("E.java");
 				assertTrue("CU does not exist", cu2.exists());
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test2;\n");
 				buf.append("\n");
 				buf.append("public enum E {\n");
@@ -340,7 +337,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testWrongPackageStatementFromDefault() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("\n");
 		buf.append("public class E {\n");
@@ -354,15 +351,15 @@ public class ReorgQuickFixTest extends QuickFixTest {
 
 		boolean hasRename= true, hasMove= true;
 
-		for (int i= 0; i < proposals.size(); i++) {
-			ChangeCorrectionProposal curr= (ChangeCorrectionProposal) proposals.get(i);
+		for (IJavaCompletionProposal proposal2 : proposals) {
+			ChangeCorrectionProposal curr= (ChangeCorrectionProposal) proposal2;
 			if (curr instanceof CorrectPackageDeclarationProposal) {
 				assertTrue("Duplicated proposal", hasRename);
 				hasRename= false;
 
 				CUCorrectionProposal proposal= (CUCorrectionProposal) curr;
 				String preview= getPreviewContent(proposal);
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("\n");
 				buf.append("\n");
 				buf.append("public class E {\n");
@@ -376,7 +373,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 				IPackageFragment pack2= fSourceFolder.getPackageFragment("test2");
 				ICompilationUnit cu2= pack2.getCompilationUnit("E.java");
 				assertTrue("CU does not exist", cu2.exists());
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test2;\n");
 				buf.append("\n");
 				buf.append("public class E {\n");
@@ -389,7 +386,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testWrongDefaultPackageStatement() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test2", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("public class E {\n");
 		buf.append("}\n");
 		ICompilationUnit cu= pack1.createCompilationUnit("E.java", buf.toString(), false, null);
@@ -401,15 +398,15 @@ public class ReorgQuickFixTest extends QuickFixTest {
 
 		boolean hasRename= true, hasMove= true;
 
-		for (int i= 0; i < proposals.size(); i++) {
-			ChangeCorrectionProposal curr= (ChangeCorrectionProposal) proposals.get(i);
+		for (IJavaCompletionProposal proposal2 : proposals) {
+			ChangeCorrectionProposal curr= (ChangeCorrectionProposal) proposal2;
 			if (curr instanceof CorrectPackageDeclarationProposal) {
 				assertTrue("Duplicated proposal", hasRename);
 				hasRename= false;
 
 				CUCorrectionProposal proposal= (CUCorrectionProposal) curr;
 				String preview= getPreviewContent(proposal);
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test2;\n");
 				buf.append("\n");
 				buf.append("public class E {\n");
@@ -423,7 +420,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 				IPackageFragment pack2= fSourceFolder.getPackageFragment("");
 				ICompilationUnit cu2= pack2.getCompilationUnit("E.java");
 				assertTrue("CU does not exist", cu2.exists());
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("public class E {\n");
 				buf.append("}\n");
 				assertEqualStringIgnoreDelim(cu2.getSource(), buf.toString());
@@ -434,7 +431,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testWrongPackageStatementButColliding() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test2;\n");
 		buf.append("\n");
 		buf.append("public class E {\n");
@@ -455,7 +452,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 		String preview= getPreviewContent(proposal);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("public class E {\n");
@@ -466,7 +463,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testWrongTypeName() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("public class E {\n");
@@ -480,15 +477,15 @@ public class ReorgQuickFixTest extends QuickFixTest {
 
 		boolean hasRename= true, hasMove= true;
 
-		for (int i= 0; i < proposals.size(); i++) {
-			ChangeCorrectionProposal curr= (ChangeCorrectionProposal) proposals.get(i);
+		for (IJavaCompletionProposal proposal2 : proposals) {
+			ChangeCorrectionProposal curr= (ChangeCorrectionProposal) proposal2;
 			if (curr instanceof CorrectMainTypeNameProposal) {
 				assertTrue("Duplicated proposal", hasRename);
 				hasRename= false;
 
 				CUCorrectionProposal proposal= (CUCorrectionProposal) curr;
 				String preview= getPreviewContent(proposal);
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("\n");
 				buf.append("public class X {\n");
@@ -501,7 +498,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 
 				ICompilationUnit cu2= pack1.getCompilationUnit("E.java");
 				assertTrue("CU does not exist", cu2.exists());
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("\n");
 				buf.append("public class E {\n");
@@ -514,7 +511,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testWrongTypeName_bug180330() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("p", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("public class \\u0042 {\n");
 		buf.append("}\n");
@@ -528,15 +525,15 @@ public class ReorgQuickFixTest extends QuickFixTest {
 
 		boolean hasRename= true, hasMove= true;
 
-		for (int i= 0; i < proposals.size(); i++) {
-			ChangeCorrectionProposal curr= (ChangeCorrectionProposal) proposals.get(i);
+		for (IJavaCompletionProposal proposal2 : proposals) {
+			ChangeCorrectionProposal curr= (ChangeCorrectionProposal) proposal2;
 			if (curr instanceof CorrectMainTypeNameProposal) {
 				assertTrue("Duplicated proposal", hasRename);
 				hasRename= false;
 
 				CUCorrectionProposal proposal= (CUCorrectionProposal) curr;
 				String preview= getPreviewContent(proposal);
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package p;\n");
 				buf.append("public class C {\n");
 				buf.append("}\n");
@@ -548,7 +545,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 
 				ICompilationUnit cu2= pack1.getCompilationUnit("B.java");
 				assertTrue("CU does not exist", cu2.exists());
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package p;\n");
 				buf.append("public class \\u0042 {\n");
 				buf.append("}\n");
@@ -560,7 +557,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testWrongTypeNameButColliding() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("public class X {\n");
@@ -581,7 +578,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 
 		String preview= getPreviewContent(proposal);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("public class E {\n");
@@ -592,7 +589,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testWrongTypeNameWithConstructor() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("public class X {\n");
@@ -616,7 +613,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 
 		String preview= getPreviewContent(proposal);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("public class E {\n");
@@ -630,7 +627,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testWrongTypeNameInEnum() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("public enum X {\n");
@@ -654,7 +651,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 
 		String preview= getPreviewContent(proposal);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("public enum E {\n");
@@ -668,7 +665,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testWrongTypeNameInAnnot() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("public @interface X {\n");
@@ -689,7 +686,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 
 		String preview= getPreviewContent(proposal);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("public @interface E {\n");
@@ -700,7 +697,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testTodoTasks1() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -722,7 +719,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -734,7 +731,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testTodoTasks2() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -754,7 +751,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -767,7 +764,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testTodoTasks3() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -787,7 +784,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -799,7 +796,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testTodoTasks4() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -821,7 +818,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -833,7 +830,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testTodoTasks5() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -855,7 +852,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -870,7 +867,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testTodoTasks6() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -890,7 +887,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -903,7 +900,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testTodoTasks7() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -923,7 +920,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -937,7 +934,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 	@Test
 	public void testAddToClasspathSourceFolder() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import mylib.Foo;\n");
 		buf.append("public class E {\n");
@@ -949,7 +946,7 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		try {
 			IPackageFragmentRoot otherRoot= JavaProjectHelper.addSourceContainer(otherProject, "src");
 			IPackageFragment otherPack= otherRoot.createPackageFragment("mylib", false, null);
-			buf= new StringBuffer();
+			buf= new StringBuilder();
 			buf.append("package mylib;\n");
 			buf.append("public class Foo {\n");
 			buf.append("}\n");
@@ -981,7 +978,8 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		IJavaProject otherProject= JavaProjectHelper.createJavaProject("other", "bin");
 		try {
 			File lib= JavaTestPlugin.getDefault().getFileInPlugin(JavaProjectHelper.MYLIB);
-			assertTrue("lib does not exist",  lib != null && lib.exists());
+			assertNotNull("lib does not exist", lib);
+			assertTrue("lib does not exist", lib.exists());
 			IPackageFragmentRoot otherRoot= JavaProjectHelper.addLibraryWithImport(otherProject, Path.fromOSString(lib.getPath()), null, null);
 
 			MultiStatus status= new MultiStatus(JavaUI.ID_PLUGIN, IStatus.OK, "", null);
@@ -1018,7 +1016,8 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		IJavaProject otherProject= JavaProjectHelper.createJavaProject("other", "bin");
 		try {
 			File lib= JavaTestPlugin.getDefault().getFileInPlugin(JavaProjectHelper.MYLIB);
-			assertTrue("lib does not exist",  lib != null && lib.exists());
+			assertNotNull("lib does not exist", lib);
+			assertTrue("lib does not exist", lib.exists());
 
 			IPath path= Path.fromOSString(lib.getPath());
 
@@ -1053,7 +1052,8 @@ public class ReorgQuickFixTest extends QuickFixTest {
 		IJavaProject otherProject= JavaProjectHelper.createJavaProject("other", "bin");
 		try {
 			File lib= JavaTestPlugin.getDefault().getFileInPlugin(JavaProjectHelper.MYLIB);
-			assertTrue("lib does not exist",  lib != null && lib.exists());
+			assertNotNull("lib does not exist", lib);
+			assertTrue("lib does not exist", lib.exists());
 			IPath path= Path.fromOSString(lib.getPath());
 			final IClasspathEntry[] entries= { JavaCore.newLibraryEntry(path, null, null) };
 			final IPath containerPath= new Path(JavaCore.USER_LIBRARY_CONTAINER_ID).append("MyUserLibrary");
