@@ -17,8 +17,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.ui.tests.core.rules.LeakTestSetup;
 
@@ -30,11 +28,10 @@ import org.eclipse.jdt.ui.tests.core.rules.LeakTestSetup;
  *
  * @since 3.4
  */
-@RunWith(JUnit4.class)
 public class SearchLeakTestWrapper {
 
 	@Rule
-	public LeakTestSetup projectsetup = new LeakTestSetup();
+	public LeakTestSetup projectSetup = new LeakTestSetup();
 
 	SearchLeakTest fTest;
 
