@@ -15,6 +15,7 @@
 package org.eclipse.jdt.ui.tests.search;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNull;
 
 import java.util.List;
 
@@ -22,8 +23,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.swt.events.TreeListener;
 import org.eclipse.swt.widgets.Control;
@@ -50,11 +49,10 @@ import org.eclipse.jdt.internal.ui.search.LevelTreeContentProvider;
 
 /**
  */
-@RunWith(JUnit4.class)
 public class TreeContentProviderTest {
 
 	@Rule
-	public JUnitSourceSetup projectsetup = new JUnitSourceSetup();
+	public JUnitSourceSetup projectSetup = new JUnitSourceSetup();
 
 	private LevelTreeContentProvider fProvider;
 	private JavaSearchResult fResult;
@@ -170,19 +168,19 @@ public class TreeContentProviderTest {
 
 		fProvider.setLevel(LevelTreeContentProvider.LEVEL_TYPE);
 		assertEquals(type, fProvider.getParent(method));
-		assertEquals(fProvider.getParent(type), null);
+		assertNull(fProvider.getParent(type));
 
 		fProvider.setLevel(LevelTreeContentProvider.LEVEL_PACKAGE);
 		assertEquals(type, fProvider.getParent(method));
 		assertEquals(fProvider.getParent(type), pkg);
-		assertEquals(fProvider.getParent(pkg), null);
+		assertNull(fProvider.getParent(pkg));
 
 		fProvider.setLevel(LevelTreeContentProvider.LEVEL_PROJECT);
 		assertEquals(type, fProvider.getParent(method));
 		assertEquals(fProvider.getParent(type), pkg);
 		assertEquals(fProvider.getParent(pkg), root);
 		assertEquals(fProvider.getParent(root), project);
-		assertEquals(fProvider.getParent(project), null);
+		assertNull(fProvider.getParent(project));
 	}
 
 	@Test
