@@ -15,13 +15,10 @@ package org.eclipse.jdt.ui.tests.wizardapi;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
 
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.core.runtime.IPath;
 
@@ -42,10 +39,9 @@ import org.eclipse.jdt.launching.JavaRuntime;
 import org.eclipse.jdt.ui.PreferenceConstants;
 import org.eclipse.jdt.ui.wizards.NewJavaProjectWizardPage;
 
-@RunWith(JUnit4.class)
 public class NewJavaProjectWizardTest {
 
-	private class TestNewJavaProjectWizardPage extends NewJavaProjectWizardPage {
+	private static class TestNewJavaProjectWizardPage extends NewJavaProjectWizardPage {
 
 		private IProject fNewProject;
 
@@ -84,9 +80,6 @@ public class NewJavaProjectWizardTest {
 
 	private TestNewJavaProjectWizardPage fWizardPage;
 
-	/**
-	 * @see TestCase#setUp()
-	 */
 	@Before
 	public void setUp() throws Exception {
 		IWorkspaceRoot root= ResourcesPlugin.getWorkspace().getRoot();
@@ -97,9 +90,6 @@ public class NewJavaProjectWizardTest {
 		fWizardPage.setProjectHandle(project);
 	}
 
-	/**
-	 * @see TestCase#tearDown()
-	 */
 	@After
 	public void tearDown() throws Exception {
 		IWorkspaceRoot root= ResourcesPlugin.getWorkspace().getRoot();
@@ -123,7 +113,7 @@ public class NewJavaProjectWizardTest {
 	private void assertBasicBuildPath(IProject project, IPath outputLocation, IClasspathEntry[] classpath) {
 		assertNotNull("a", outputLocation);
 		assertNotNull("b", classpath);
-		assertTrue("c", classpath.length == 2);
+		assertEquals("c", 2, classpath.length);
 
 		if (PreferenceConstants.getPreferenceStore().getBoolean(PreferenceConstants.SRCBIN_FOLDERS_IN_NEWPROJ)) {
 			assertEquals("d", outputLocation, project.getFolder("bin").getFullPath());
@@ -191,7 +181,7 @@ public class NewJavaProjectWizardTest {
 	private void assertUserBuildPath(IProject project, IPath outputLocation, IClasspathEntry[] classpath) {
 		assertNotNull("a", outputLocation);
 		assertNotNull("b", classpath);
-		assertTrue("c", classpath.length == 3);
+		assertEquals("c", 3, classpath.length);
 
 		assertEquals("d", outputLocation, project.getFolder("dbin").getFullPath());
 		assertEquals("e", classpath[0].getPath(), project.getFolder("dsrc1").getFullPath());
