@@ -26,8 +26,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.StringAsserts;
@@ -64,13 +62,12 @@ import org.eclipse.jdt.internal.ui.javaeditor.EditorUtility;
 /**
  *
  */
-@RunWith(JUnit4.class)
 public class NewTypeWizardTest {
 	private IJavaProject fJProject1;
 	private IPackageFragmentRoot fSourceFolder;
 
 	@Rule
-	public ProjectTestSetup projectsetup = new ProjectTestSetup();
+	public ProjectTestSetup projectSetup = new ProjectTestSetup();
 
 	@Before
 	public void setUp() throws Exception {
@@ -98,14 +95,14 @@ public class NewTypeWizardTest {
 		StubUtility.setCodeTemplate(CodeTemplateContextType.ANNOTATIONBODY_ID, "/* annotation body */\n", null);
 
 
-		fJProject1= ProjectTestSetup.getProject();
+		fJProject1= projectSetup.getProject();
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 	}
 
 
 	@After
 	public void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJProject1, ProjectTestSetup.getDefaultClasspath());
+		JavaProjectHelper.clear(fJProject1, projectSetup.getDefaultClasspath());
 	}
 
 	@Test
@@ -194,7 +191,7 @@ public class NewTypeWizardTest {
 	public void testCreateClass3() throws Exception {
 
 		IPackageFragment pack0= fSourceFolder.createPackageFragment("pack", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack;\n");
 		buf.append("public class A<T> {\n");
 		buf.append("    public abstract void foo(T t);\n");
@@ -222,7 +219,7 @@ public class NewTypeWizardTest {
 
 		String actual= wizardPage.getCreatedType().getCompilationUnit().getSource();
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("/**\n");
 		buf.append(" * File\n");
 		buf.append(" */\n");
@@ -253,7 +250,7 @@ public class NewTypeWizardTest {
 	public void testCreateClass4() throws Exception {
 
 		IPackageFragment pack0= fSourceFolder.createPackageFragment("pack", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack;\n");
 		buf.append("public class A<T> {\n");
 		buf.append("    public A(T t);\n");
@@ -281,7 +278,7 @@ public class NewTypeWizardTest {
 
 		String actual= wizardPage.getCreatedType().getCompilationUnit().getSource();
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("/**\n");
 		buf.append(" * File\n");
 		buf.append(" */\n");
@@ -319,7 +316,7 @@ public class NewTypeWizardTest {
 	public void testCreateInnerClass1() throws Exception {
 
 		IPackageFragment pack0= fSourceFolder.createPackageFragment("pack", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack;\n");
 		buf.append("public class A<T> {\n");
 		buf.append("    public abstract void foo(T t);\n");
@@ -348,7 +345,7 @@ public class NewTypeWizardTest {
 
 		String actual= wizardPage.getCreatedType().getCompilationUnit().getSource();
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package pack;\n");
 		buf.append("\n");
 		buf.append("import java.util.ArrayList;\n");
@@ -423,7 +420,7 @@ public class NewTypeWizardTest {
 	public void testCreateClassExtraImports2() throws Exception {
 
 		IPackageFragment pack0= fSourceFolder.createPackageFragment("pack", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack;\n");
 		buf.append("public class A {\n");
 		buf.append("    public static class Inner {\n");
@@ -457,7 +454,7 @@ public class NewTypeWizardTest {
 
 		String actual= wizardPage.getCreatedType().getCompilationUnit().getSource();
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("/**\n");
 		buf.append(" * File\n");
 		buf.append(" */\n");
@@ -489,7 +486,7 @@ public class NewTypeWizardTest {
 	public void testCreateClassExtraImports3() throws Exception {
 
 		IPackageFragment pack0= fSourceFolder.createPackageFragment("pack", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack;\n");
 		buf.append("public class A {\n");
 		buf.append("    public static class Inner {\n");
@@ -499,7 +496,7 @@ public class NewTypeWizardTest {
 		pack0.createCompilationUnit("A.java", buf.toString(), false, null);
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("import java.util.Map;\n"); // an unused import: should not be touched
@@ -528,7 +525,7 @@ public class NewTypeWizardTest {
 
 		String actual= wizardPage.getCreatedType().getCompilationUnit().getSource();
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("import java.util.Map;\n");
@@ -774,7 +771,7 @@ public class NewTypeWizardTest {
 	{
 		// Foo1.java and Foo2.java in test1
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n\n");
 		buf.append("public class Foo1 {\n\n");
 		buf.append("}\n");
@@ -783,7 +780,7 @@ public class NewTypeWizardTest {
 
 		// Foo3.java in test2
 		pack1= fSourceFolder.createPackageFragment("test2", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test2;\n\n");
 		buf.append("public class Foo3 {\n\n");
 		buf.append("}\n");
