@@ -21,14 +21,13 @@ import static org.eclipse.jdt.core.util.ExternalAnnotationUtil.annotateMethodPar
 import static org.eclipse.jdt.core.util.ExternalAnnotationUtil.annotateMethodReturnType;
 import static org.eclipse.jdt.core.util.ExternalAnnotationUtil.annotateMethodTypeParameter;
 import static org.eclipse.jdt.core.util.ExternalAnnotationUtil.extractGenericSignature;
-import static org.eclipse.jdt.core.util.ExternalAnnotationUtil.extractGenericTypeSignature;
 import static org.eclipse.jdt.core.util.ExternalAnnotationUtil.extractGenericTypeParametersSignature;
+import static org.eclipse.jdt.core.util.ExternalAnnotationUtil.extractGenericTypeSignature;
 import static org.eclipse.jdt.core.util.ExternalAnnotationUtil.getAnnotationFile;
 import static org.eclipse.jdt.internal.ui.text.spelling.WordCorrectionProposal.getHtmlRepresentation;
 
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
-import java.util.ArrayList;
 import java.util.List;
 
 import org.eclipse.swt.graphics.Image;
@@ -187,9 +186,7 @@ public class ExternalNullAnnotationChangeProposals {
 		public void apply(IDocument document) {
 			try {
 				doAnnotateMember(new NullProgressMonitor());
-			} catch (CoreException e) {
-				JavaPlugin.log(e);
-			} catch (IOException e) {
+			} catch (CoreException | IOException e) {
 				JavaPlugin.log(e);
 			}
 		}
@@ -378,7 +375,7 @@ public class ExternalNullAnnotationChangeProposals {
 	}
 
 	/* Quick assist on class file, propose changes on any type detail. */
-	public static void collectExternalAnnotationProposals(ICompilationUnit cu, ASTNode coveringNode, int offset, ArrayList<IJavaCompletionProposal> resultingCollection) {
+	public static void collectExternalAnnotationProposals(ICompilationUnit cu, ASTNode coveringNode, int offset, List<IJavaCompletionProposal> resultingCollection) {
 
 		IJavaProject javaProject= cu.getJavaProject();
 		if (JavaCore.DISABLED.equals(javaProject.getOption(JavaCore.COMPILER_ANNOTATION_NULL_ANALYSIS, true)))
@@ -472,10 +469,11 @@ public class ExternalNullAnnotationChangeProposals {
 			rendererNullable.addDimension(i == outerExtraDims);
 			rendererRemove.addDimension(i == outerExtraDims);
 		}
-		boolean useJava8= JavaModelUtil.is18OrHigher(javaProject.getOption(JavaCore.COMPILER_SOURCE, true));
+		boolean useJava8= JavaModelUtil.is1d8OrHigher(javaProject.getOption(JavaCore.COMPILER_SOURCE, true));
 		if (!useJava8 && (outer != inner || outerExtraDims > 0)) { // below 1.8 we can only annotate the top type (not type parameter)
 			// still need to handle ParameterizedType (outer) with SimpleType (inner)
-			if (!(outer.getNodeType() == ASTNode.PARAMETERIZED_TYPE && inner.getParent() == outer))
+			if ((outer.getNodeType() != ASTNode.PARAMETERIZED_TYPE)
+					|| (inner.getParent() != outer))
 				return;
 		}
 		try {
@@ -643,7 +641,7 @@ public class ExternalNullAnnotationChangeProposals {
 	/* Create one proposal from each of the three given renderers. */
 	static void createProposalsForType(ICompilationUnit cu, ASTNode type, int dims,
 			int outerDims, boolean annotateVarargs, int offset,
-			TypeRenderer rendererNonNull, TypeRenderer rendererNullable, TypeRenderer rendererRemove, ProposalCreator creator, ArrayList<IJavaCompletionProposal> resultingCollection) {
+			TypeRenderer rendererNonNull, TypeRenderer rendererNullable, TypeRenderer rendererRemove, ProposalCreator creator, List<IJavaCompletionProposal> resultingCollection) {
 		SignatureAnnotationChangeProposal operation;
 		String label;
 		// propose adding @NonNull:
@@ -674,10 +672,8 @@ public class ExternalNullAnnotationChangeProposals {
 			ArrayType arrayType= (ArrayType) type;
 			left= new StringBuilder(arrayType.getElementType().toString());
 			dimsRight= new StringBuilder();
-			@SuppressWarnings("rawtypes")
-			List dimensions= arrayType.dimensions();
-			for (int i= 0; i < dimensions.size(); i++) {
-				Dimension dimension= (Dimension) dimensions.get(i);
+			for (Object dimension2 : arrayType.dimensions()) {
+				Dimension dimension= (Dimension) dimension2;
 				if (dimension.getStartPosition() + dimension.getLength() <= offset)
 					left.append("[]"); //$NON-NLS-1$
 				else
@@ -712,10 +708,8 @@ public class ExternalNullAnnotationChangeProposals {
 		if (type.getNodeType() == ASTNode.ARRAY_TYPE) {
 			ArrayType arrayType= (ArrayType) type;
 			StringBuilder buf= new StringBuilder(arrayType.getElementType().toString());
-			@SuppressWarnings("rawtypes")
-			List dimensions= arrayType.dimensions();
-			for (int i= 0; i < dimensions.size(); i++) {
-				Dimension dimension= (Dimension) dimensions.get(i);
+			for (Object dimension2 : arrayType.dimensions()) {
+				Dimension dimension= (Dimension) dimension2;
 				if (dimension.getStartPosition() + dimension.getLength() > offset)
 					buf.append("[]"); //$NON-NLS-1$
 			}
@@ -799,12 +793,11 @@ public class ExternalNullAnnotationChangeProposals {
 
 		@Override
 		public boolean visit(ArrayType array) {
-			@SuppressWarnings("rawtypes")
-			List dimensions= array.dimensions();
+			List<?> dimensions= array.dimensions();
 			boolean annotated= false;
-			for (int i= 0; i < dimensions.size(); i++) {
+			for (Object dimension2 : dimensions) {
 				fBuffer.append('[');
-				Dimension dimension= (Dimension) dimensions.get(i);
+				Dimension dimension= (Dimension) dimension2;
 				if (!annotated && array == fFocusType && dimension.getStartPosition() + dimension.getLength() > fOffset) {
 					fBuffer.append(fAnnotation);
 					annotated= true;
@@ -875,4 +868,7 @@ public class ExternalNullAnnotationChangeProposals {
 			return type.getBinaryName().replace('.', '/');
 		}
 	}
+
+	private ExternalNullAnnotationChangeProposals() {
+	}
 }
