@@ -17,7 +17,6 @@ package org.eclipse.jdt.internal.corext.fix;
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Target;
 import java.util.EnumSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 
@@ -334,8 +333,7 @@ public class NullAnnotationsRewriteOperations {
 					return;
 				}
 
-				for (Iterator<IExtendedModifier> iterator= modifiers.iterator(); iterator.hasNext();) {
-					IExtendedModifier modifier= iterator.next();
+				for (IExtendedModifier modifier : modifiers) {
 					if (modifier instanceof MarkerAnnotation) {
 						MarkerAnnotation annotation= (MarkerAnnotation) modifier;
 						IAnnotationBinding annotationBinding= annotation.resolveAnnotationBinding();
@@ -372,13 +370,12 @@ public class NullAnnotationsRewriteOperations {
 		public void rewriteAST(CompilationUnitRewrite cuRewrite, LinkedProposalModel linkedModel) throws CoreException {
 
 			if (fProblem.getProblemId() == IProblem.MissingNonNullByDefaultAnnotationOnPackage) {
-				ASTNode selectedNode= fCompilationUnit.getPackage();
-				if (selectedNode instanceof PackageDeclaration) {
+				PackageDeclaration packageDeclaration= fCompilationUnit.getPackage();
+				if (packageDeclaration != null) {
 					String nonNullByDefaultAnnotationname= NullAnnotationsFix.getNonNullByDefaultAnnotationName(fCompilationUnit.getJavaElement(), true);
 					String label= Messages.format(FixMessages.NullAnnotationsRewriteOperations_add_missing_default_nullness_annotation, new String[] { nonNullByDefaultAnnotationname });
 					TextEditGroup group= createTextEditGroup(label, cuRewrite);
 					ASTRewrite astRewrite= cuRewrite.getASTRewrite();
-					PackageDeclaration packageDeclaration= (PackageDeclaration) selectedNode;
 					AST ast= cuRewrite.getRoot().getAST();
 					ListRewrite listRewrite= astRewrite.getListRewrite(packageDeclaration, PackageDeclaration.ANNOTATIONS_PROPERTY);
 					Annotation newAnnotation= ast.newMarkerAnnotation();
@@ -418,7 +415,7 @@ public class NullAnnotationsRewriteOperations {
 
 		private boolean usesNullTypeAnnotations(IJavaElement cu, String annotationName) {
 			IJavaProject project= (IJavaProject) cu.getAncestor(IJavaElement.JAVA_PROJECT);
-			if (!JavaModelUtil.is18OrHigher(project)) {
+			if (!JavaModelUtil.is1d8OrHigher(project)) {
 				return false;
 			}
 			try {
@@ -430,7 +427,14 @@ public class NullAnnotationsRewriteOperations {
 					if (annotationType.isBinary()) {
 						if (annotation.getElementName().equals(Target.class.getName())) {
 							for (IMemberValuePair valuePair : annotation.getMemberValuePairs()) {
-								if (TYPE_USE_NAME.equals(valuePair.getValue())) {
+								Object value= valuePair.getValue();
+								if (value instanceof Object[]) {
+									for (Object val : (Object[]) value) {
+										if (TYPE_USE_NAME.equals(val)) {
+											return true;
+										}
+									}
+								} else if (TYPE_USE_NAME.equals(value)) {
 									return true;
 								}
 							}
@@ -843,4 +847,7 @@ public class NullAnnotationsRewriteOperations {
 			return null;
 		}
 	}
+
+	private NullAnnotationsRewriteOperations() {
+	}
 }
