@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2011 IBM Corporation and others.
+ * Copyright (c) 2005, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -55,6 +55,7 @@ import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.ILocalVariable;
 import org.eclipse.jdt.core.IMember;
 import org.eclipse.jdt.core.IMethod;
+import org.eclipse.jdt.core.IModuleDescription;
 import org.eclipse.jdt.core.IPackageFragment;
 import org.eclipse.jdt.core.IPackageFragmentRoot;
 import org.eclipse.jdt.core.IType;
@@ -77,12 +78,12 @@ import org.eclipse.jdt.internal.corext.refactoring.code.IntroduceIndirectionRefa
 import org.eclipse.jdt.internal.corext.refactoring.code.IntroduceParameterRefactoring;
 import org.eclipse.jdt.internal.corext.refactoring.code.ReplaceInvocationsRefactoring;
 import org.eclipse.jdt.internal.corext.refactoring.generics.InferTypeArgumentsRefactoring;
+import org.eclipse.jdt.internal.corext.refactoring.reorg.IReorgPolicy.ICopyPolicy;
+import org.eclipse.jdt.internal.corext.refactoring.reorg.IReorgPolicy.IMovePolicy;
 import org.eclipse.jdt.internal.corext.refactoring.reorg.JavaCopyProcessor;
 import org.eclipse.jdt.internal.corext.refactoring.reorg.JavaDeleteProcessor;
 import org.eclipse.jdt.internal.corext.refactoring.reorg.JavaMoveProcessor;
 import org.eclipse.jdt.internal.corext.refactoring.reorg.ReorgPolicyFactory;
-import org.eclipse.jdt.internal.corext.refactoring.reorg.IReorgPolicy.ICopyPolicy;
-import org.eclipse.jdt.internal.corext.refactoring.reorg.IReorgPolicy.IMovePolicy;
 import org.eclipse.jdt.internal.corext.refactoring.sef.SelfEncapsulateFieldRefactoring;
 import org.eclipse.jdt.internal.corext.refactoring.structure.ChangeSignatureProcessor;
 import org.eclipse.jdt.internal.corext.refactoring.structure.ChangeTypeRefactoring;
@@ -175,6 +176,8 @@ public final class RefactoringExecutionStarter {
 				return RenameSupport.create((ITypeParameter) element, newName, flags);
 			case IJavaElement.LOCAL_VARIABLE:
 				return RenameSupport.create((ILocalVariable) element, newName, flags);
+			case IJavaElement.JAVA_MODULE:
+				return RenameSupport.create((IModuleDescription) element, newName, flags);
 		}
 		return null;
 	}
@@ -226,14 +229,14 @@ public final class RefactoringExecutionStarter {
 
 	public static void startCleanupRefactoring(ICompilationUnit[] cus, ICleanUp[] cleanUps, boolean useOptionsFromProfile, Shell shell, boolean showWizard, String actionName) throws InvocationTargetException {
 		final CleanUpRefactoring refactoring= new CleanUpRefactoring(actionName);
-		for (int i= 0; i < cus.length; i++) {
-			refactoring.addCompilationUnit(cus[i]);
+		for (ICompilationUnit cu : cus) {
+			refactoring.addCompilationUnit(cu);
 		}
 
 		if (!showWizard) {
 			refactoring.setUseOptionsFromProfile(useOptionsFromProfile);
-			for (int i= 0; i < cleanUps.length; i++) {
-				refactoring.addCleanUp(cleanUps[i]);
+			for (ICleanUp cleanUp : cleanUps) {
+				refactoring.addCleanUp(cleanUp);
 			}
 
 			IRunnableContext context;
@@ -403,8 +406,7 @@ public final class RefactoringExecutionStarter {
 	public static void startMoveStaticMembersRefactoring(final IMember[] members, final Shell shell) throws JavaModelException {
 		if (!RefactoringAvailabilityTester.isMoveStaticAvailable(members))
 			return;
-		final Set<IMember> set= new HashSet<>();
-		set.addAll(Arrays.asList(members));
+		final Set<IMember> set= new HashSet<>(Arrays.asList(members));
 		final IMember[] elements= set.toArray(new IMember[set.size()]);
 		IJavaProject project= null;
 		if (elements.length > 0)
