@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,12 +10,12 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Microsoft Corporation - read formatting options from the compilation unit
  *******************************************************************************/
 package org.eclipse.jdt.internal.corext.refactoring.nls;
 
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 
@@ -134,7 +134,7 @@ public class AccessorClassModifier {
 		if (document == null)
 			document= new Document(fCU.getSource());
 
-		return fASTRewrite.rewriteAST(document, fCU.getJavaProject().getOptions(true));
+		return fASTRewrite.rewriteAST(document, fCU.getOptions(true));
 	}
 
 	public static Change create(ICompilationUnit cu, NLSSubstitution[] substitutions) throws CoreException {
@@ -182,8 +182,7 @@ public class AccessorClassModifier {
 		MultiTextEdit multiTextEdit= new MultiTextEdit();
 		change.setEdit(multiTextEdit);
 
-		for (int i= 0; i < fields.size(); i++) {
-			String field= fields.get(i);
+		for (String field : fields) {
 			NLSSubstitution substitution= new NLSSubstitution(NLSSubstitution.EXTERNALIZED, field, null, null, null);
 			sourceModification.addKey(substitution, change);
 		}
@@ -204,8 +203,7 @@ public class AccessorClassModifier {
 		MultiTextEdit multiTextEdit= new MultiTextEdit();
 		change.setEdit(multiTextEdit);
 
-		for (int i= 0; i < fields.size(); i++) {
-			String field= fields.get(i);
+		for (String field : fields) {
 			NLSSubstitution substitution= new NLSSubstitution(NLSSubstitution.EXTERNALIZED, field, null, null, null);
 			sourceModification.removeKey(substitution, change);
 		}
@@ -292,8 +290,7 @@ public class AccessorClassModifier {
 			fFields.add(fieldDeclaration);
 		} else {
 			ArrayList<String> identifiers= new ArrayList<>();
-			for (Iterator<FieldDeclaration> iterator= fFields.iterator(); iterator.hasNext();) {
-				FieldDeclaration field= iterator.next();
+			for (FieldDeclaration field : fFields) {
 				VariableDeclarationFragment fragment= (VariableDeclarationFragment) field.fragments().get(0);
 				identifiers.add(fragment.getName().getIdentifier());
 			}
@@ -310,9 +307,8 @@ public class AccessorClassModifier {
 					String afterKey= identifiers.get(insertionPosition + 1);
 					int distBefore= NLSUtil.invertDistance(key, beforeKey);
 					int distAfter= NLSUtil.invertDistance(key, afterKey);
-					if (distBefore > distAfter) {
-						fListRewrite.insertAfter(fieldDeclaration, fFields.get(insertionPosition), editGroup);
-					} else if (distBefore == distAfter && Collator.getInstance().compare(beforeKey, afterKey) < 0) {
+					if (distBefore > distAfter
+							|| (distBefore == distAfter && Collator.getInstance().compare(beforeKey, afterKey) < 0)) {
 						fListRewrite.insertAfter(fieldDeclaration, fFields.get(insertionPosition), editGroup);
 					} else {
 						fListRewrite.insertBefore(fieldDeclaration, fFields.get(insertionPosition + 1), editGroup);
