@@ -73,6 +73,8 @@ import org.eclipse.jdt.core.search.SearchMatch;
 import org.eclipse.jdt.core.search.SearchPattern;
 import org.eclipse.jdt.core.search.SearchRequestor;
 
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
+import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.core.refactoring.descriptors.RefactoringSignatureDescriptorFactory;
 import org.eclipse.jdt.internal.corext.refactoring.Checks;
 import org.eclipse.jdt.internal.corext.refactoring.CollectingSearchRequestor;
@@ -111,9 +113,6 @@ import org.eclipse.jdt.ui.refactoring.RefactoringSaveHelper;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 
-import org.eclipse.jdt.internal.core.manipulation.StubUtility;
-import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
-
 public class RenamePackageProcessor extends JavaRenameProcessor implements
 		IReferenceUpdating, ITextUpdating, IQualifiedNameUpdating, IResourceMapper, IJavaElementMapper {
 
@@ -189,8 +188,7 @@ public class RenamePackageProcessor extends JavaRenameProcessor implements
 
 	@Override
 	protected IFile[] getChangedFiles() throws CoreException {
-		Set<IFile> combined= new HashSet<>();
-		combined.addAll(Arrays.asList(ResourceUtil.getFiles(fChangeManager.getAllCompilationUnits())));
+		Set<IFile> combined= new HashSet<>(Arrays.asList(ResourceUtil.getFiles(fChangeManager.getAllCompilationUnits())));
 		if (fRenameSubpackages) {
 			for (IPackageFragment pack : JavaElementUtil.getPackageAndSubpackages(fPackage)) {
 				combined.addAll(Arrays.asList(ResourceUtil.getFiles(pack.getCompilationUnits())));
@@ -483,14 +481,8 @@ public class RenamePackageProcessor extends JavaRenameProcessor implements
 	 */
 	public static boolean isPackageNameOkInRoot(String newName, IPackageFragmentRoot root) throws CoreException {
 		IPackageFragment pack= root.getPackageFragment(newName);
-		if (! pack.exists())
-			return true;
-		else if (pack.containsJavaResources())
-			return false;
-		else if (pack.getNonJavaResources().length != 0)
-			return false;
-		else
-			return true;
+		return !pack.exists()
+				|| (!pack.containsJavaResources() && pack.getNonJavaResources().length == 0);
 	}
 
 	private RefactoringStatus checkPackageInCurrentRoot(String newName) throws CoreException {
@@ -1121,22 +1113,22 @@ public class RenamePackageProcessor extends JavaRenameProcessor implements
 			fFilePatterns= ""; //$NON-NLS-1$
 		final String references= extended.getAttribute(JavaRefactoringDescriptorUtil.ATTRIBUTE_REFERENCES);
 		if (references != null) {
-			fUpdateReferences= Boolean.valueOf(references).booleanValue();
+			fUpdateReferences= Boolean.parseBoolean(references);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, JavaRefactoringDescriptorUtil.ATTRIBUTE_REFERENCES));
 		final String matches= extended.getAttribute(ATTRIBUTE_TEXTUAL_MATCHES);
 		if (matches != null) {
-			fUpdateTextualMatches= Boolean.valueOf(matches).booleanValue();
+			fUpdateTextualMatches= Boolean.parseBoolean(matches);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_TEXTUAL_MATCHES));
 		final String qualified= extended.getAttribute(ATTRIBUTE_QUALIFIED);
 		if (qualified != null) {
-			fUpdateQualifiedNames= Boolean.valueOf(qualified).booleanValue();
+			fUpdateQualifiedNames= Boolean.parseBoolean(qualified);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_QUALIFIED));
 		final String hierarchical= extended.getAttribute(ATTRIBUTE_HIERARCHICAL);
 		if (hierarchical != null) {
-			fRenameSubpackages= Boolean.valueOf(hierarchical).booleanValue();
+			fRenameSubpackages= Boolean.parseBoolean(hierarchical);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_HIERARCHICAL));
 		return new RefactoringStatus();
