@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -33,6 +33,7 @@ import org.eclipse.jdt.core.ITypeHierarchy;
 import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.Signature;
 
+import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.corext.refactoring.Checks;
 import org.eclipse.jdt.internal.corext.refactoring.JavaRefactoringArguments;
 import org.eclipse.jdt.internal.corext.refactoring.RefactoringAvailabilityTester;
@@ -42,8 +43,6 @@ import org.eclipse.jdt.internal.corext.refactoring.util.TextChangeManager;
 import org.eclipse.jdt.internal.corext.util.JdtFlags;
 import org.eclipse.jdt.internal.corext.util.Messages;
 
-import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
-
 
 public class RenameVirtualMethodProcessor extends RenameMethodProcessor {
 
@@ -259,4 +258,16 @@ public class RenameVirtualMethodProcessor extends RenameMethodProcessor {
 		else
 			return RefactoringCoreMessages.DelegateMethodCreator_keep_original_renamed_singular;
 	}
+
+	/*
+	@Override
+	protected SearchPattern createOccurrenceSearchPattern() {
+		SearchPattern pattern= null;
+		if (fIsRecordAccessor) {
+			pattern= SearchPattern.createFieldOrAccessorMethodORPattern(getMethod());
+		} else {
+			pattern= super.createOccurrenceSearchPattern();
+		}
+		return pattern;
+	}*/
 }
