@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -17,6 +17,7 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -29,7 +30,9 @@ import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IAdaptable;
 import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.OperationCanceledException;
+import org.eclipse.core.runtime.Platform;
 
 import org.eclipse.core.resources.IContainer;
 import org.eclipse.core.resources.IFile;
@@ -37,6 +40,7 @@ import org.eclipse.core.resources.IFolder;
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.resources.IResourceVisitor;
+import org.eclipse.core.resources.ResourcesPlugin;
 import org.eclipse.core.resources.mapping.IResourceChangeDescriptionFactory;
 
 import org.eclipse.core.filebuffers.FileBuffers;
@@ -180,8 +184,7 @@ public final class JavaDeleteProcessor extends DeleteProcessor {
 	private String[] getAffectedProjectNatures() throws CoreException {
 		String[] jNatures= JavaProcessors.computeAffectedNaturs(fJavaElements);
 		String[] rNatures= ResourceProcessors.computeAffectedNatures(fResources);
-		Set<String> result= new HashSet<>();
-		result.addAll(Arrays.asList(jNatures));
+		Set<String> result= new HashSet<>(Arrays.asList(jNatures));
 		result.addAll(Arrays.asList(rNatures));
 		return result.toArray(new String[result.size()]);
 	}
@@ -240,9 +243,39 @@ public final class JavaDeleteProcessor extends DeleteProcessor {
 	public RefactoringStatus checkInitialConditions(IProgressMonitor pm) throws CoreException {
 		Assert.isNotNull(fDeleteQueries);//must be set before checking activation
 		RefactoringStatus result= new RefactoringStatus();
-		result.merge(RefactoringStatus.create(Resources.checkInSync(ReorgUtils.getNotLinked(fResources))));
+		IResource[] resources= ReorgUtils.getNotLinked(fResources);
+		IStatus status= Resources.checkInSync(resources);
+		if (!status.isOK()) {
+			boolean autoRefresh= Platform.getPreferencesService().getBoolean(ResourcesPlugin.PI_RESOURCES, ResourcesPlugin.PREF_LIGHTWEIGHT_AUTO_REFRESH, false, null);
+			if (autoRefresh) {
+				for (IResource resource : resources) {
+					try {
+						resource.refreshLocal(IResource.DEPTH_INFINITE, pm);
+					} catch (CoreException e) {
+						break;
+					}
+					status= Resources.checkInSync(resources);
+				}
+			}
+		}
+		result.merge(RefactoringStatus.create(status));
 		IResource[] javaResources= ReorgUtils.getResources(fJavaElements);
-		result.merge(RefactoringStatus.create(Resources.checkInSync(ReorgUtils.getNotNulls(javaResources))));
+		resources= ReorgUtils.getNotNulls(javaResources);
+		status= Resources.checkInSync(resources);
+		if (!status.isOK()) {
+			boolean autoRefresh= Platform.getPreferencesService().getBoolean(ResourcesPlugin.PI_RESOURCES, ResourcesPlugin.PREF_LIGHTWEIGHT_AUTO_REFRESH, false, null);
+			if (autoRefresh) {
+				for (IResource resource : resources) {
+					try {
+						resource.refreshLocal(IResource.DEPTH_INFINITE, pm);
+					} catch (CoreException e) {
+						break;
+					}
+					status= Resources.checkInSync(resources);
+				}
+			}
+		}
+		result.merge(RefactoringStatus.create(status));
 		for (IJavaElement element : fJavaElements) {
 			if (element instanceof IType && ((IType)element).isAnonymous()) {
 				// work around for bug https://bugs.eclipse.org/bugs/show_bug.cgi?id=44450
@@ -397,11 +430,10 @@ public final class JavaDeleteProcessor extends DeleteProcessor {
 			return;
 
 		// Move from inner to outer packages
-		Collections.sort(initialPackagesToDelete, (one, two) -> two.getElementName().compareTo(one.getElementName()));
+		Collections.sort(initialPackagesToDelete, Comparator.comparing(IPackageFragment::getElementName).reversed());
 
 		// Get resources and java elements which will be deleted as well
-		final Set<IResource> deletedChildren= new HashSet<>();
-		deletedChildren.addAll(Arrays.asList(fResources));
+		final Set<IResource> deletedChildren= new HashSet<>(Arrays.asList(fResources));
 		for (IJavaElement javaElement : fJavaElements) {
 			if (!ReorgUtils.isInsideCompilationUnit(javaElement)) {
 				deletedChildren.add(javaElement.getResource());
@@ -609,12 +641,12 @@ public final class JavaDeleteProcessor extends DeleteProcessor {
 		 	if (fAccessorsDeleted)
 				comment.addSetting(RefactoringCoreMessages.JavaDeleteProcessor_delete_accessors);
 			final DeleteDescriptor descriptor= RefactoringSignatureDescriptorFactory.createDeleteDescriptor(project, description, comment.asString(), arguments, flags);
-			arguments.put(ATTRIBUTE_DELETE_SUBPACKAGES, Boolean.valueOf(fDeleteSubPackages).toString());
-			arguments.put(ATTRIBUTE_SUGGEST_ACCESSORS, Boolean.valueOf(fSuggestGetterSetterDeletion).toString());
-			arguments.put(ATTRIBUTE_RESOURCES, Integer.valueOf(fResources.length).toString());
+			arguments.put(ATTRIBUTE_DELETE_SUBPACKAGES, Boolean.toString(fDeleteSubPackages));
+			arguments.put(ATTRIBUTE_SUGGEST_ACCESSORS, Boolean.toString(fSuggestGetterSetterDeletion));
+			arguments.put(ATTRIBUTE_RESOURCES, Integer.toString(fResources.length));
 			for (int offset= 0; offset < fResources.length; offset++)
 				arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_ELEMENT + (offset + 1), JavaRefactoringDescriptorUtil.resourceToHandle(project, fResources[offset]));
-			arguments.put(ATTRIBUTE_ELEMENTS, Integer.valueOf(fJavaElements.length).toString());
+			arguments.put(ATTRIBUTE_ELEMENTS, Integer.toString(fJavaElements.length));
 			for (int offset= 0; offset < fJavaElements.length; offset++)
 				arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_ELEMENT + (offset + fResources.length + 1), JavaRefactoringDescriptorUtil.elementToHandle(project, fJavaElements[offset]));
 			return new DynamicValidationRefactoringChange(descriptor, RefactoringCoreMessages.DeleteRefactoring_7, new Change[] { fDeleteChange});
@@ -794,12 +826,12 @@ public final class JavaDeleteProcessor extends DeleteProcessor {
 		final RefactoringStatus status= new RefactoringStatus();
 		final String subPackages= extended.getAttribute(ATTRIBUTE_DELETE_SUBPACKAGES);
 		if (subPackages != null) {
-			fDeleteSubPackages= Boolean.valueOf(subPackages).booleanValue();
+			fDeleteSubPackages= Boolean.parseBoolean(subPackages);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_DELETE_SUBPACKAGES));
 		final String suggest= extended.getAttribute(ATTRIBUTE_SUGGEST_ACCESSORS);
 		if (suggest != null) {
-			fSuggestGetterSetterDeletion= Boolean.valueOf(suggest).booleanValue();
+			fSuggestGetterSetterDeletion= Boolean.parseBoolean(suggest);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_SUGGEST_ACCESSORS));
 		int resourceCount= 0;
