@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -23,9 +23,12 @@ import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IAdaptable;
 import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.OperationCanceledException;
+import org.eclipse.core.runtime.Platform;
 
 import org.eclipse.core.resources.IResource;
+import org.eclipse.core.resources.ResourcesPlugin;
 
 import org.eclipse.ltk.core.refactoring.Change;
 import org.eclipse.ltk.core.refactoring.ChangeDescriptor;
@@ -53,7 +56,7 @@ import org.eclipse.jdt.ui.refactoring.IRefactoringProcessorIds;
 
 public final class JavaMoveProcessor extends MoveProcessor implements IQualifiedNameUpdating, IReorgDestinationValidator {
 
-	private ICreateTargetQueries fCreateTargetQueries;
+	private MonitoringCreateTargetQueries fCreateTargetQueries;
 
 	private IMovePolicy fMovePolicy;
 
@@ -128,9 +131,39 @@ public final class JavaMoveProcessor extends MoveProcessor implements IQualified
 		pm.beginTask("", 1); //$NON-NLS-1$
 		try {
 			RefactoringStatus result= new RefactoringStatus();
-			result.merge(RefactoringStatus.create(Resources.checkInSync(ReorgUtils.getNotNulls(fMovePolicy.getResources()))));
+			IResource[] resources= ReorgUtils.getNotNulls(fMovePolicy.getResources());
+			IStatus status= Resources.checkInSync(resources);
+			if (!status.isOK()) {
+				boolean autoRefresh= Platform.getPreferencesService().getBoolean(ResourcesPlugin.PI_RESOURCES, ResourcesPlugin.PREF_LIGHTWEIGHT_AUTO_REFRESH, false, null);
+				if (autoRefresh) {
+					for (IResource resource : resources) {
+						try {
+							resource.refreshLocal(IResource.DEPTH_INFINITE, pm);
+						} catch (CoreException e) {
+							break;
+						}
+						status= Resources.checkInSync(resources);
+					}
+				}
+			}
+			result.merge(RefactoringStatus.create(status));
 			IResource[] javaResources= ReorgUtils.getResources(fMovePolicy.getJavaElements());
-			result.merge(RefactoringStatus.create(Resources.checkInSync(ReorgUtils.getNotNulls(javaResources))));
+			resources= ReorgUtils.getNotNulls(javaResources);
+			status= Resources.checkInSync(resources);
+			if (!status.isOK()) {
+				boolean autoRefresh= Platform.getPreferencesService().getBoolean(ResourcesPlugin.PI_RESOURCES, ResourcesPlugin.PREF_LIGHTWEIGHT_AUTO_REFRESH, false, null);
+				if (autoRefresh) {
+					for (IResource resource : resources) {
+						try {
+							resource.refreshLocal(IResource.DEPTH_INFINITE, pm);
+						} catch (CoreException e) {
+							break;
+						}
+						status= Resources.checkInSync(resources);
+					}
+				}
+			}
+			result.merge(RefactoringStatus.create(status));
 			return result;
 		} finally {
 			pm.done();
@@ -161,8 +194,8 @@ public final class JavaMoveProcessor extends MoveProcessor implements IQualified
 				}
 			};
 			CreateTargetExecutionLog log= null;
-			if (fCreateTargetQueries instanceof MonitoringCreateTargetQueries) {
-				final MonitoringCreateTargetQueries queries= (MonitoringCreateTargetQueries) fCreateTargetQueries;
+			if (fCreateTargetQueries != null) {
+				final MonitoringCreateTargetQueries queries= fCreateTargetQueries;
 				final ICreateTargetQueries delegate= queries.getDelegate();
 				if (delegate instanceof LoggedCreateTargetQueries)
 					log= queries.getCreateTargetExecutionLog();
@@ -188,8 +221,7 @@ public final class JavaMoveProcessor extends MoveProcessor implements IQualified
 	private String[] getAffectedProjectNatures() throws CoreException {
 		String[] jNatures= JavaProcessors.computeAffectedNaturs(fMovePolicy.getJavaElements());
 		String[] rNatures= ResourceProcessors.computeAffectedNatures(fMovePolicy.getResources());
-		Set<String> result= new HashSet<>();
-		result.addAll(Arrays.asList(jNatures));
+		Set<String> result= new HashSet<>(Arrays.asList(jNatures));
 		result.addAll(Arrays.asList(rNatures));
 		return result.toArray(new String[result.size()]);
 	}
