@@ -56,6 +56,7 @@ import org.eclipse.jdt.core.dom.IBinding;
 import org.eclipse.jdt.core.dom.IMethodBinding;
 import org.eclipse.jdt.core.dom.ITypeBinding;
 import org.eclipse.jdt.core.dom.IVariableBinding;
+import org.eclipse.jdt.core.dom.ImportDeclaration;
 import org.eclipse.jdt.core.dom.MethodDeclaration;
 import org.eclipse.jdt.core.dom.Modifier;
 import org.eclipse.jdt.core.dom.NodeFinder;
@@ -79,10 +80,13 @@ import org.eclipse.jdt.core.search.IJavaSearchConstants;
 import org.eclipse.jdt.core.search.IJavaSearchScope;
 import org.eclipse.jdt.core.search.SearchPattern;
 
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
+import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.core.refactoring.descriptors.RefactoringSignatureDescriptorFactory;
 import org.eclipse.jdt.internal.corext.codemanipulation.ContextSensitiveImportRewriteContext;
 import org.eclipse.jdt.internal.corext.dom.ASTNodeFactory;
 import org.eclipse.jdt.internal.corext.dom.Bindings;
+import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
 import org.eclipse.jdt.internal.corext.refactoring.Checks;
 import org.eclipse.jdt.internal.corext.refactoring.CollectingSearchRequestor;
 import org.eclipse.jdt.internal.corext.refactoring.JDTRefactoringDescriptorComment;
@@ -119,9 +123,6 @@ import org.eclipse.jdt.internal.corext.util.SearchUtils;
 import org.eclipse.jdt.ui.JavaElementLabels;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
-import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
-import org.eclipse.jdt.internal.core.manipulation.StubUtility;
-import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.ui.viewsupport.BindingLabelProvider;
 
 /**
@@ -276,11 +277,11 @@ public class ChangeTypeRefactoring extends Refactoring {
 		fValidTypes= new HashSet<>();
 	}
 
-    public ChangeTypeRefactoring(JavaRefactoringArguments arguments, RefactoringStatus status) {
+	public ChangeTypeRefactoring(JavaRefactoringArguments arguments, RefactoringStatus status) {
    		this(null, 0, 0, null);
    		RefactoringStatus initializeStatus= initialize(arguments);
    		status.merge(initializeStatus);
-    }
+	}
 
 	// ------------------------------------------------------------------------------------------------- //
 
@@ -484,7 +485,7 @@ public class ChangeTypeRefactoring extends Refactoring {
 		pm.beginTask(RefactoringCoreMessages.ChangeTypeRefactoring_checking_preconditions, 1);
 
 		RefactoringStatus result= Checks.validateModifiesFiles(
-			ResourceUtil.getFiles(fAffectedUnits), getValidationContext());
+			ResourceUtil.getFiles(fAffectedUnits), getValidationContext(), pm);
 
 		pm.done();
 		return result;
@@ -512,7 +513,7 @@ public class ChangeTypeRefactoring extends Refactoring {
 			comment.addSetting(Messages.format(RefactoringCoreMessages.ChangeTypeRefactoring_refactored_type_pattern, BindingLabelProvider.getBindingLabel(fSelectedType, JavaElementLabels.ALL_FULLY_QUALIFIED)));
 			final GeneralizeTypeDescriptor descriptor= RefactoringSignatureDescriptorFactory.createGeneralizeTypeDescriptor(project, description, comment.asString(), arguments, (RefactoringDescriptor.STRUCTURAL_CHANGE | JavaRefactoringDescriptor.JAR_REFACTORING | JavaRefactoringDescriptor.JAR_SOURCE_ATTACHMENT));
 			arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_INPUT, JavaRefactoringDescriptorUtil.elementToHandle(project, fCu));
-			arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_SELECTION, Integer.valueOf(fSelectionStart).toString() + " " + Integer.valueOf(fSelectionLength).toString()); //$NON-NLS-1$
+			arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_SELECTION, Integer.toString(fSelectionStart) + " " + Integer.toString(fSelectionLength)); //$NON-NLS-1$
 			arguments.put(ATTRIBUTE_TYPE, fSelectedType.getQualifiedName());
 			final DynamicValidationRefactoringChange result= new DynamicValidationRefactoringChange(descriptor, RefactoringCoreMessages.ChangeTypeRefactoring_allChanges);
 			for (Map.Entry<ICompilationUnit, Set<ConstraintVariable>> entry : relevantVarsByUnit.entrySet()) {
@@ -544,12 +545,14 @@ public class ChangeTypeRefactoring extends Refactoring {
 		MultiTextEdit root= new MultiTextEdit();
 		unitChange.setEdit(root); // Adam sez don't need this, but then unitChange.addGroupDescription() fails an assertion!
 
+		ImportRemover remover= new ImportRemover(fCu.getJavaProject(), unit);
 		String typeName= updateImports(unit, root);
-		updateCu(unit, vars, unitChange, unitRewriter, typeName);
+		updateCu(unit, vars, unitChange, unitRewriter, typeName, remover);
+		removeUnusedImport(remover,unit, root);
 		root.addChild(unitRewriter.rewriteAST());
 	}
 
-	private class SourceRangeComputer extends TargetSourceRangeComputer {
+	private static class SourceRangeComputer extends TargetSourceRangeComputer {
 		@Override
 		public SourceRange computeSourceRange(ASTNode node) {
 			return new SourceRange(node.getStartPosition(),node.getLength());
@@ -557,26 +560,26 @@ public class ChangeTypeRefactoring extends Refactoring {
 	}
 
 	private void updateCu(CompilationUnit unit, Set<ConstraintVariable> vars, CompilationUnitChange unitChange,
-		ASTRewrite unitRewriter, String typeName) throws JavaModelException {
+		ASTRewrite unitRewriter, String typeName, ImportRemover remover) throws JavaModelException {
 
-        // use custom SourceRangeComputer to avoid losing comments
+		// use custom SourceRangeComputer to avoid losing comments
 		unitRewriter.setTargetSourceRangeComputer(new SourceRangeComputer());
 
 		for (ConstraintVariable cv : vars) {
 			ASTNode decl= findDeclaration(unit, cv);
 			if ((decl instanceof SimpleName || decl instanceof QualifiedName) && cv instanceof ExpressionVariable) {
 				ASTNode gp= decl.getParent().getParent();
-				updateType(unit, getType(gp), unitChange, unitRewriter, typeName);   // local variable or parameter
-			} else if (decl instanceof MethodDeclaration || decl instanceof FieldDeclaration) {
-				updateType(unit, getType(decl), unitChange, unitRewriter, typeName); // method return or field type
-			} else if (decl instanceof ParameterizedType){
-				updateType(unit, getType(decl), unitChange, unitRewriter, typeName);
+				updateType(unit, getType(gp), unitChange, unitRewriter, typeName, remover);   // local variable or parameter
+			} else if (decl instanceof MethodDeclaration
+					|| decl instanceof FieldDeclaration // Method return or field type
+					|| decl instanceof ParameterizedType) {
+				updateType(unit, getType(decl), unitChange, unitRewriter, typeName, remover);
 			}
 		}
 	}
 
 	private void updateType(CompilationUnit cu, Type oldType, CompilationUnitChange unitChange,
-							ASTRewrite unitRewriter, String typeName) {
+							ASTRewrite unitRewriter, String typeName, ImportRemover remover) {
 
 		String oldName= fSelectionTypeBinding.getName();
 		String[] keys= { BasicElementLabels.getJavaElementName(oldName), BasicElementLabels.getJavaElementName(typeName)};
@@ -591,7 +594,7 @@ public class ChangeTypeRefactoring extends Refactoring {
 			}
 		}
 
-	    //TODO handle types other than simple & parameterized (e.g., arrays)
+		//TODO handle types other than simple & parameterized (e.g., arrays)
 		Assert.isTrue(fSelectedType.isClass() || fSelectedType.isInterface());
 
 		Type newType= null;
@@ -602,6 +605,7 @@ public class ChangeTypeRefactoring extends Refactoring {
 		}
 
 		unitRewriter.replace(nodeToReplace, newType, gd);
+		remover.registerRemovedNode(nodeToReplace);
 		unitChange.addTextEditGroup(gd);
 	}
 
@@ -957,11 +961,11 @@ public class ChangeTypeRefactoring extends Refactoring {
 	}
 
 	// ------------------------------------------------------------------------------------------------- //
-    // Methods for examining & solving type constraints. This includes:
-    //  (1) locating the ConstraintVariable corresponding to the selected ASTNode
-    //  (2) finding all ConstraintVariables "related" to (1) via overriding, method calls, field access
-    //  (3) find all ITypeConstraints of interest that mention ConstraintVariables in (2)
-    //  (4) determining all ITypes for which the ITypeConstraints in (3) are satisfied
+	// Methods for examining & solving type constraints. This includes:
+	//  (1) locating the ConstraintVariable corresponding to the selected ASTNode
+	//  (2) finding all ConstraintVariables "related" to (1) via overriding, method calls, field access
+	//  (3) find all ITypeConstraints of interest that mention ConstraintVariables in (2)
+	//  (4) determining all ITypes for which the ITypeConstraints in (3) are satisfied
 
 	/**
 	 * Find a ConstraintVariable that corresponds to the selected ASTNode.
@@ -1139,17 +1143,17 @@ public class ChangeTypeRefactoring extends Refactoring {
 	static String print(Collection<ITypeBinding> types){
 		if (types.isEmpty())
 			return "{ }"; //$NON-NLS-1$
-		String result = "{ "; //$NON-NLS-1$
+		StringBuilder result = new StringBuilder("{ "); //$NON-NLS-1$
 		for (Iterator<ITypeBinding> it=types.iterator(); it.hasNext(); ){
 			ITypeBinding type= it.next();
-			result += type.getQualifiedName();
+			result.append(type.getQualifiedName());
 			if (it.hasNext()){
-				result += ", ";  //$NON-NLS-1$
+				result.append(", ");  //$NON-NLS-1$
 			} else {
-				result += " }"; //$NON-NLS-1$
+				result.append(" }"); //$NON-NLS-1$
 			}
 		}
-		return result;
+		return result.toString();
 	}
 
 
@@ -1163,20 +1167,20 @@ public class ChangeTypeRefactoring extends Refactoring {
 	 * @throws JavaModelException
 	 */
 	private Collection<ITypeBinding> computeValidTypes(ITypeBinding originalType,
-													Collection<ConstraintVariable> relevantVars,
-													Collection<ITypeConstraint> relevantConstraints,
-													IProgressMonitor pm) throws JavaModelException {
+			Collection<ConstraintVariable> relevantVars,
+			Collection<ITypeConstraint> relevantConstraints,
+			IProgressMonitor pm) throws JavaModelException {
 
 		Collection<ITypeBinding> result= new HashSet<>();
 
-		Collection<ITypeBinding> allTypes = new HashSet<>();
-		allTypes.addAll(getAllSuperTypes(originalType));
-
+		Collection<ITypeBinding> allTypes= new HashSet<>(getAllSuperTypes(originalType));
 		pm.beginTask(RefactoringCoreMessages.ChangeTypeRefactoring_analyzingMessage, allTypes.size());
 
 		for (ITypeBinding type : allTypes) {
 			if (isValid(type, relevantVars, relevantConstraints, new SubProgressMonitor(pm, 1))) {
-				result.add(type);
+				if (checkTypeParameterConflict(relevantVars, type)) {
+					result.add(type);
+				}
 			}
 		}
 		// "changing" to the original type is a no-op
@@ -1190,6 +1194,51 @@ public class ChangeTypeRefactoring extends Refactoring {
 		return result;
 	}
 
+	/*
+	 * check if replacement type is conflicting with existing type usage for classes with overridden
+	 * method.
+	 *
+	 * @return TRUE if no conflict found
+	 */
+	private boolean checkTypeParameterConflict(Collection<ConstraintVariable> relevantVars, ITypeBinding replaceTypeTo) {
+		for (ConstraintVariable constraintVariable : relevantVars) {
+			if (constraintVariable instanceof ParameterTypeVariable) {
+				ParameterTypeVariable parameterTypeVariable= (ParameterTypeVariable) constraintVariable;
+				ITypeBinding declaringClass= parameterTypeVariable.getMethodBinding().getDeclaringClass();
+				ITypeBinding[] parameterTypeVariableTypes= parameterTypeVariable.getMethodBinding().getParameterTypes();
+				List<IMethodBinding> possibleConflictMethods= new ArrayList<>();
+				for (IMethodBinding declaredMethod : declaringClass.getDeclaredMethods()) {
+					if (declaredMethod.getName().equals(parameterTypeVariable.getMethodBinding().getName()) &&
+							declaredMethod.getParameterTypes().length == parameterTypeVariableTypes.length) {
+						// if method name and number of parameters match it might be a conflict
+						possibleConflictMethods.add(declaredMethod);
+					}
+				}
+				if (possibleConflictMethods.size() < 2) {
+					continue; // no conflicting methods
+				}
+				mLoop: for (IMethodBinding declaredMethod : possibleConflictMethods) {
+					ITypeBinding[] parameterTypes= declaredMethod.getParameterTypes();
+					/* check if other parameter Types are equal, if not this method is ok */
+					for (int i= 0; i < parameterTypes.length; i++) {
+						if (i == fParamIndex) {
+							continue;
+						}
+						if (!Bindings.equals(parameterTypes[i], parameterTypeVariableTypes[i])) {
+							continue mLoop;
+						}
+					}
+					// if all method parameter Types are equal then we have a conflict with the Type we want to replace to
+					// so we return false to remove it from allowed types
+					if (Bindings.equals(parameterTypes[fParamIndex], replaceTypeTo)) {
+						return false;
+					}
+				}
+			}
+		}
+		return true;
+	}
+
 	/**
 	 * Determines if a given type satisfies a set of type constraints.
 	 * @param type
@@ -1200,8 +1249,8 @@ public class ChangeTypeRefactoring extends Refactoring {
 	 * @throws JavaModelException
 	 */
 	private boolean isValid(ITypeBinding type,
-						    Collection<ConstraintVariable> relevantVars,
-						    Collection<ITypeConstraint> constraints,
+							Collection<ConstraintVariable> relevantVars,
+							Collection<ITypeConstraint> constraints,
 							IProgressMonitor pm) throws JavaModelException {
 		pm.beginTask(RefactoringCoreMessages.ChangeTypeRefactoring_analyzingMessage, constraints.size());
 
@@ -1278,7 +1327,8 @@ public class ChangeTypeRefactoring extends Refactoring {
 					if (memberBinding instanceof IMethodBinding) {
 						IMethodBinding methodBinding= Bindings.findMethodInHierarchy(superType, memberBinding.getName(), (ITypeBinding[]) null);
 						if (methodBinding == null) {
-							if (!(superType.isInterface() && isMethodFromObject)) {
+							if (!superType.isInterface()
+									|| !isMethodFromObject) {
 								return false;
 							}
 						}
@@ -1326,16 +1376,14 @@ public class ChangeTypeRefactoring extends Refactoring {
 		if (fMethodBinding != null && fCuToSearchResultGroup.containsKey(unit)){
 			SearchResultGroup group= fCuToSearchResultGroup.get(unit);
 			for (ASTNode node : ASTNodeSearchUtil.getAstNodes(group.getSearchResults(), cu)) {
-				if (fMethodBinding != null){
-					// find MethodDeclaration above it in the tree
-					ASTNode n= node;
-					while (n != null && !(n instanceof MethodDeclaration)) {
-						n = n.getParent();
-					}
-					MethodDeclaration md= (MethodDeclaration) n;
-					if (md != null)
-						md.accept(fCollector);
+				// find MethodDeclaration above it in the tree
+				ASTNode n= node;
+				while (n != null && !(n instanceof MethodDeclaration)) {
+					n = n.getParent();
 				}
+				MethodDeclaration md= (MethodDeclaration) n;
+				if (md != null)
+					md.accept(fCollector);
 			}
 		} else {
 			cu.accept(fCollector);
@@ -1360,6 +1408,36 @@ public class ChangeTypeRefactoring extends Refactoring {
 		return typeName;
 	}
 
+	private void removeUnusedImport(ImportRemover remover, CompilationUnit astRoot, MultiTextEdit rootEdit) throws CoreException{
+		List<ImportDeclaration> declList= astRoot.imports();
+		ImportDeclaration oldImport= null;
+		String importStr= getImport(fSelectionTypeBinding.getQualifiedName());
+		for (ImportDeclaration decl: declList) {
+			if (decl.getName().getFullyQualifiedName().equals(importStr)) {
+				oldImport= decl;
+				break;
+			}
+		}
+		if (oldImport != null) {
+			ImportRewrite rewrite= StubUtility.createImportRewrite(astRoot, true);
+			remover.applyRemoves(rewrite);
+			rootEdit.addChild(rewrite.rewriteImports(null));
+		}
+	}
+
+	private String getImport(String qualifiedTypeName) {
+		String finalStr= qualifiedTypeName;
+		int angleBracketOffset= qualifiedTypeName.indexOf('<');
+		if (angleBracketOffset != -1) {
+			finalStr= qualifiedTypeName.substring(0, angleBracketOffset);
+		}
+		int bracketOffset= qualifiedTypeName.indexOf('[');
+		if (bracketOffset != -1) {
+			finalStr= qualifiedTypeName.substring(0, bracketOffset);
+		}
+		return finalStr;
+	}
+
 	//	------------------------------------------------------------------------------------------------- //
 	// Miscellaneous helper methods
 
@@ -1446,39 +1524,37 @@ public class ChangeTypeRefactoring extends Refactoring {
 			return fAffectedUnits;
 		}
 		if (fMethodBinding != null) {
-			if (fMethodBinding != null) {
 
+			IMethod selectedMethod= (IMethod) fMethodBinding.getJavaElement();
+			if (selectedMethod == null) {
+				// can't happen since we checked it up front in check initial conditions
+				Assert.isTrue(false, RefactoringCoreMessages.ChangeTypeRefactoring_no_method);
+			}
 
-				IMethod selectedMethod= (IMethod) fMethodBinding.getJavaElement();
-				if (selectedMethod == null) {
-					// can't happen since we checked it up front in check initial conditions
-					Assert.isTrue(false, RefactoringCoreMessages.ChangeTypeRefactoring_no_method);
-				}
+			// the following code fragment appears to be the source of a memory leak, when
+			// GT is repeatedly applied
 
-				// the following code fragment appears to be the source of a memory leak, when
-				// GT is repeatedly applied
+			IMethod root= selectedMethod;
+			if (! root.getDeclaringType().isInterface() && MethodChecks.isVirtual(root)) {
+				final SubProgressMonitor subMonitor= new SubProgressMonitor(pm, 5);
+				IMethod inInterface= MethodChecks.isDeclaredInInterface(root, root.getDeclaringType().newTypeHierarchy(new SubProgressMonitor(subMonitor, 1)), subMonitor);
+				if (inInterface != null && !inInterface.equals(root))
+					root= inInterface;
+			}
 
-				IMethod root= selectedMethod;
-				if (! root.getDeclaringType().isInterface() && MethodChecks.isVirtual(root)) {
-					final SubProgressMonitor subMonitor= new SubProgressMonitor(pm, 5);
-					IMethod inInterface= MethodChecks.isDeclaredInInterface(root, root.getDeclaringType().newTypeHierarchy(new SubProgressMonitor(subMonitor, 1)), subMonitor);
-					if (inInterface != null && !inInterface.equals(root))
-						root= inInterface;
-				}
+			// end code fragment
 
-				// end code fragment
+			IMethod[] rippleMethods= RippleMethodFinder2.getRelatedMethods(
+					root, new SubProgressMonitor(pm, 15), null);
+			SearchPattern pattern= RefactoringSearchEngine.createOrPattern(
+					rippleMethods, IJavaSearchConstants.ALL_OCCURRENCES);
 
-				IMethod[] rippleMethods= RippleMethodFinder2.getRelatedMethods(
-						root, new SubProgressMonitor(pm, 15), null);
-				SearchPattern pattern= RefactoringSearchEngine.createOrPattern(
-						rippleMethods, IJavaSearchConstants.ALL_OCCURRENCES);
+			// To compute the scope we have to use the selected method. Otherwise we
+			// might start from the wrong project.
+			IJavaSearchScope scope= RefactoringScopeFactory.create(selectedMethod);
+			CollectingSearchRequestor csr= new CollectingSearchRequestor();
 
-				// To compute the scope we have to use the selected method. Otherwise we
-				// might start from the wrong project.
-				IJavaSearchScope scope= RefactoringScopeFactory.create(selectedMethod);
-				CollectingSearchRequestor csr= new CollectingSearchRequestor();
-
-				SearchResultGroup[] groups= RefactoringSearchEngine.search(
+			SearchResultGroup[] groups= RefactoringSearchEngine.search(
 					pattern,
 					null,
 					scope,
@@ -1486,8 +1562,7 @@ public class ChangeTypeRefactoring extends Refactoring {
 					new SubProgressMonitor(pm, 80),
 					new RefactoringStatus()); //TODO: deal with errors from non-CU matches
 
-				fAffectedUnits= getCus(groups);
-			}
+			fAffectedUnits= getCus(groups);
 		} else if (fFieldBinding != null) {
 			IField iField= (IField) fFieldBinding.getJavaElement();
 			if (iField == null) {
@@ -1561,11 +1636,11 @@ public class ChangeTypeRefactoring extends Refactoring {
 		return result.toArray(new ICompilationUnit[result.size()]);
 	}
 
-    /**
+	/**
 	 * This always includes the type itself. It will include type
 	 * Object for any type other than Object
-     * @param type
-     * @return the super types
+	 * @param type
+	 * @return the super types
 	 */
 	public Set<ITypeBinding> getAllSuperTypes(ITypeBinding type){
 		Set<ITypeBinding> result= new HashSet<>();
@@ -1582,15 +1657,15 @@ public class ChangeTypeRefactoring extends Refactoring {
 		return result;
 	}
 
-    private ITypeBinding findSuperTypeByName(ITypeBinding type, String superTypeName){
-    	Set<ITypeBinding> superTypes= getAllSuperTypes(type);
-    	for (ITypeBinding sup : superTypes) {
-    		if (sup.getQualifiedName().equals(superTypeName)){
-    			return sup;
-    		}
-    	}
-    	return null;
-    }
+	private ITypeBinding findSuperTypeByName(ITypeBinding type, String superTypeName){
+		Set<ITypeBinding> superTypes= getAllSuperTypes(type);
+		for (ITypeBinding sup : superTypes) {
+			if (sup.getQualifiedName().equals(superTypeName)){
+				return sup;
+			}
+		}
+		return null;
+	}
 
 	public boolean isSubTypeOf(ITypeBinding type1, ITypeBinding type2){
 
@@ -1616,9 +1691,9 @@ public class ChangeTypeRefactoring extends Refactoring {
 			int length= -1;
 			final StringTokenizer tokenizer= new StringTokenizer(selection);
 			if (tokenizer.hasMoreTokens())
-				offset= Integer.valueOf(tokenizer.nextToken()).intValue();
+				offset= Integer.parseInt(tokenizer.nextToken());
 			if (tokenizer.hasMoreTokens())
-				length= Integer.valueOf(tokenizer.nextToken()).intValue();
+				length= Integer.parseInt(tokenizer.nextToken());
 			if (offset >= 0 && length >= 0) {
 				fSelectionStart= offset;
 				fSelectionLength= length;
