@@ -17,7 +17,6 @@ package org.eclipse.jdt.internal.corext.refactoring.structure;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
@@ -78,8 +77,8 @@ import org.eclipse.jdt.core.dom.TypeDeclaration;
 import org.eclipse.jdt.core.dom.VariableDeclaration;
 import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
 import org.eclipse.jdt.core.dom.rewrite.ASTRewrite;
-import org.eclipse.jdt.core.dom.rewrite.ListRewrite;
 import org.eclipse.jdt.core.dom.rewrite.ImportRewrite.TypeLocation;
+import org.eclipse.jdt.core.dom.rewrite.ListRewrite;
 import org.eclipse.jdt.core.refactoring.descriptors.ExtractClassDescriptor;
 import org.eclipse.jdt.core.refactoring.descriptors.ExtractClassDescriptor.Field;
 import org.eclipse.jdt.core.refactoring.descriptors.JavaRefactoringDescriptor;
@@ -87,12 +86,13 @@ import org.eclipse.jdt.core.search.IJavaSearchConstants;
 import org.eclipse.jdt.core.search.SearchMatch;
 import org.eclipse.jdt.core.search.SearchPattern;
 
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
+import org.eclipse.jdt.internal.core.manipulation.dom.ASTResolving;
+import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.corext.codemanipulation.ContextSensitiveImportRewriteContext;
 import org.eclipse.jdt.internal.corext.codemanipulation.GetterSetterUtil;
-import org.eclipse.jdt.internal.corext.codemanipulation.StubUtility;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
 import org.eclipse.jdt.internal.corext.dom.Bindings;
-import org.eclipse.jdt.internal.corext.dom.TypeBindingVisitor;
 import org.eclipse.jdt.internal.corext.refactoring.Checks;
 import org.eclipse.jdt.internal.corext.refactoring.JDTRefactoringDescriptorComment;
 import org.eclipse.jdt.internal.corext.refactoring.ParameterInfo;
@@ -109,9 +109,6 @@ import org.eclipse.jdt.internal.corext.util.Messages;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 
-import org.eclipse.jdt.internal.core.manipulation.dom.ASTResolving;
-import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
-
 public class ExtractClassRefactoring extends Refactoring {
 
 	public static class ExtractClassDescriptorVerification {
@@ -166,9 +163,7 @@ public class ExtractClassRefactoring extends Refactoring {
 
 		private void validateFieldNames(RefactoringStatus status, String parameterName, IType type) {
 			if (type.getField(parameterName).exists()) {
-				Field[] fields= fDescriptor.getFields();
-				for (int i= 0; i < fields.length; i++) {
-					Field field= fields[i];
+				for (Field field : fDescriptor.getFields()) {
 					if (parameterName.equals(field.getFieldName())){
 						if (!field.isCreateField())
 							status.addError(Messages.format(RefactoringCoreMessages.ExtractClassRefactoring_error_field_already_exists, BasicElementLabels.getJavaElementName(parameterName)));
@@ -179,10 +174,8 @@ public class ExtractClassRefactoring extends Refactoring {
 
 		public RefactoringStatus validateFields() {
 			RefactoringStatus status= new RefactoringStatus();
-			Field[] fields= fDescriptor.getFields();
 			Set<String> names= new HashSet<>();
-			for (int i= 0; i < fields.length; i++) {
-				Field field= fields[i];
+			for (Field field : fDescriptor.getFields()) {
 				if (field.isCreateField()) {
 					if (names.contains(field.getNewFieldName())) {
 						status.addError(Messages.format(RefactoringCoreMessages.ExtractClassRefactoring_error_duplicate_field_name, BasicElementLabels.getJavaElementName(field.getNewFieldName())));
@@ -191,7 +184,7 @@ public class ExtractClassRefactoring extends Refactoring {
 					status.merge(Checks.checkFieldName(field.getNewFieldName(), fDescriptor.getType()));
 				}
 			}
-			if (names.size() == 0) {
+			if (names.isEmpty()) {
 				status.addError(RefactoringCoreMessages.ExtractClassRefactoring_error_msg_one_field);
 			}
 			validateFieldNames(status, fDescriptor.getFieldName(), fDescriptor.getType());
@@ -256,12 +249,12 @@ public class ExtractClassRefactoring extends Refactoring {
 				if (initializer != null) {
 					FieldReferenceFinder frf= new FieldReferenceFinder();
 					initializer.accept(frf);
-					hasFieldReferences= Boolean.valueOf(frf.fFieldRefFound);
+					hasFieldReferences= frf.fFieldRefFound;
 				} else {
 					hasFieldReferences= Boolean.FALSE;
 				}
 			}
-			return hasFieldReferences.booleanValue();
+			return hasFieldReferences;
 		}
 
 		private FieldInfo(ParameterInfo parameterInfo, IField ifield) {
@@ -346,8 +339,7 @@ public class ExtractClassRefactoring extends Refactoring {
 		result.merge(fVerification.validateAll());
 		try {
 			pm.beginTask(RefactoringCoreMessages.ExtractClassRefactoring_progress_final_conditions, 95);
-			for (Iterator<FieldInfo> iter= fVariables.values().iterator(); iter.hasNext();) {
-				FieldInfo fi= iter.next();
+			for (FieldInfo fi : fVariables.values()) {
 				boolean createField= isCreateField(fi);
 				if (createField) {
 					IField field= fi.ifield;
@@ -416,10 +408,8 @@ public class ExtractClassRefactoring extends Refactoring {
 		if (fDescriptor.isCreateTopLevel())
 			comment.addSetting(Messages.format(RefactoringCoreMessages.ExtractClassRefactoring_comment_package, BasicElementLabels.getJavaElementName(fDescriptor.getPackage())));
 
-		Field[] fields= fDescriptor.getFields();
 		ArrayList<String> strings= new ArrayList<>();
-		for (int i= 0; i < fields.length; i++) {
-			Field field= fields[i];
+		for (Field field : fDescriptor.getFields()) {
 			if (field.isCreateField()) {
 				strings.add(Messages.format(RefactoringCoreMessages.ExtractClassRefactoring_comment_field_renamed, new Object[] { BasicElementLabels.getJavaElementName(field.getFieldName()), BasicElementLabels.getJavaElementName(field.getNewFieldName()) }));
 			}
@@ -442,8 +432,7 @@ public class ExtractClassRefactoring extends Refactoring {
 			FieldDeclaration parent= (FieldDeclaration) fieldInfo.declaration.getParent();
 			List<IExtendedModifier> modifiers= parent.modifiers();
 			ListRewrite listRewrite= cuRewrite.getASTRewrite().getListRewrite(field, FieldDeclaration.MODIFIERS2_PROPERTY);
-			for (Iterator<IExtendedModifier> iterator= modifiers.iterator(); iterator.hasNext();) {
-				IExtendedModifier mod= iterator.next();
+			for (IExtendedModifier mod : modifiers) {
 				//Temporarily disabled until initialization of final fields is handled correctly
 //				if (mod.isModifier()) {
 //					Modifier modifier= (Modifier) mod;
@@ -456,8 +445,7 @@ public class ExtractClassRefactoring extends Refactoring {
 			}
 			if (fieldInfo.initializer != null && fieldInfo.hasFieldReference()) {
 				List<VariableDeclarationFragment> fragments= field.fragments();
-				for (Iterator<VariableDeclarationFragment> iterator= fragments.iterator(); iterator.hasNext();) {
-					VariableDeclarationFragment vdf= iterator.next();
+				for (VariableDeclarationFragment vdf : fragments) {
 					vdf.setInitializer((Expression) moveNode(cuRewrite, fieldInfo.initializer));
 				}
 			}
@@ -516,8 +504,7 @@ public class ExtractClassRefactoring extends Refactoring {
 		pof.setCreateGetter(fDescriptor.isCreateGetterSetter());
 		pof.setCreateSetter(fDescriptor.isCreateGetterSetter());
 		List<ParameterInfo> variables= new ArrayList<>();
-		for (Iterator<FieldInfo> iterator= fVariables.values().iterator(); iterator.hasNext();) {
-			FieldInfo info= iterator.next();
+		for (FieldInfo info : fVariables.values()) {
 			boolean createField= isCreateField(info);
 			info.pi.setCreateField(createField);
 			if (createField) {
@@ -531,9 +518,7 @@ public class ExtractClassRefactoring extends Refactoring {
 	}
 
 	private Field getField(String name) {
-		Field[] fields= fDescriptor.getFields();
-		for (int i= 0; i < fields.length; i++) {
-			Field field= fields[i];
+		for (Field field : fDescriptor.getFields()) {
 			if (field.getFieldName().equals(name))
 				return field;
 		}
@@ -549,12 +534,11 @@ public class ExtractClassRefactoring extends Refactoring {
 			if (pm.isCanceled())
 				throw new OperationCanceledException();
 			List<IField> validIFields= new ArrayList<>();
-			for (Iterator<FieldInfo> iterator= fVariables.values().iterator(); iterator.hasNext();) {
-				FieldInfo info= iterator.next();
+			for (FieldInfo info : fVariables.values()) {
 				if (isCreateField(info))
 					validIFields.add(info.ifield);
 			}
-			if (validIFields.size() == 0) {
+			if (validIFields.isEmpty()) {
 				status.addWarning(RefactoringCoreMessages.ExtractClassRefactoring_warning_no_fields_moved, JavaStatusContext.create(type));
 				return status;
 			}
@@ -563,8 +547,7 @@ public class ExtractClassRefactoring extends Refactoring {
 			SubProgressMonitor spm= new SubProgressMonitor(pm, 90);
 			spm.beginTask(RefactoringCoreMessages.ExtractClassRefactoring_progress_updating_references, results.length * 10);
 			try {
-				for (int i= 0; i < results.length; i++) {
-					SearchResultGroup group= results[i];
+				for (SearchResultGroup group : results) {
 					ICompilationUnit unit= group.getCompilationUnit();
 
 					CompilationUnitRewrite cuRewrite;
@@ -599,9 +582,7 @@ public class ExtractClassRefactoring extends Refactoring {
 		RefactoringStatus status= new RefactoringStatus();
 		String parameterName= fDescriptor.getFieldName();
 
-		SearchMatch[] searchResults= group.getSearchResults();
-		for (int j= 0; j < searchResults.length; j++) {
-			SearchMatch searchMatch= searchResults[j];
+		for (SearchMatch searchMatch : group.getSearchResults()) {
 			ASTNode node= NodeFinder.perform(cuRewrite.getRoot(), searchMatch.getOffset(), searchMatch.getLength());
 			ASTNode parent= node.getParent();
 			boolean isDeclaration= parent instanceof VariableDeclaration && ((VariableDeclaration)parent).getInitializer() != node;
@@ -738,15 +719,14 @@ public class ExtractClassRefactoring extends Refactoring {
 		TextEditGroup removeFieldGroup= fBaseCURewrite.createGroupDescription(RefactoringCoreMessages.ExtractClassRefactoring_group_remove_field);
 		FieldDeclaration lastField= null;
 		initializeDeclaration(typeNode);
-		for (Iterator<FieldInfo> iter= fVariables.values().iterator(); iter.hasNext();) {
-			FieldInfo pi= iter.next();
+		for (FieldInfo pi : fVariables.values()) {
 			if (isCreateField(pi)) {
 				VariableDeclarationFragment vdf= pi.declaration;
 				FieldDeclaration parent= (FieldDeclaration) vdf.getParent();
-				if (lastField == null)
-					lastField= parent;
-				else if (lastField.getStartPosition() < parent.getStartPosition())
+				if (lastField == null
+						|| lastField.getStartPosition() < parent.getStartPosition()) {
 					lastField= parent;
+				}
 
 				ListRewrite listRewrite= rewrite.getListRewrite(parent, FieldDeclaration.FRAGMENTS_PROPERTY);
 				removeNode(vdf, removeFieldGroup, fBaseCURewrite);
@@ -783,22 +763,19 @@ public class ExtractClassRefactoring extends Refactoring {
 				}
 			}
 		}
-		FieldDeclaration fieldDeclaration= createParameterObjectField(pof, typeNode, modifier);
+		FieldDeclaration fieldDeclaration= createParameterObjectField(pof, typeNode, modifier, removeFieldGroup);
 		ListRewrite bodyDeclList= rewrite.getListRewrite(typeNode, TypeDeclaration.BODY_DECLARATIONS_PROPERTY);
 		if (lastField != null)
-			bodyDeclList.insertAfter(fieldDeclaration, lastField, null);
+			bodyDeclList.insertAfter(fieldDeclaration, lastField, removeFieldGroup);
 		else
-			bodyDeclList.insertFirst(fieldDeclaration, null);
+			bodyDeclList.insertFirst(fieldDeclaration, removeFieldGroup);
 		return fieldDeclaration;
 	}
 
 	private void initializeDeclaration(TypeDeclaration node) {
-		FieldDeclaration[] fields= node.getFields();
-		for (int i= 0; i < fields.length; i++) {
-			FieldDeclaration fieldDeclaration= fields[i];
-			List<VariableDeclarationFragment> fragments= fieldDeclaration.fragments();
-			for (Iterator<VariableDeclarationFragment> iterator= fragments.iterator(); iterator.hasNext();) {
-				VariableDeclarationFragment vdf= iterator.next();
+		for (FieldDeclaration fieldDeclaration : node.getFields()) {
+			for (Object element : fieldDeclaration.fragments()) {
+				VariableDeclarationFragment vdf=(VariableDeclarationFragment) element;
 				FieldInfo fieldInfo= getFieldInfo(vdf.getName().getIdentifier());
 				if (fieldInfo != null) {
 					Assert.isNotNull(vdf);
@@ -814,13 +791,12 @@ public class ExtractClassRefactoring extends Refactoring {
 		baseCURewrite.getImportRemover().registerRemovedNode(parent);
 	}
 
-	private FieldDeclaration createParameterObjectField(ParameterObjectFactory pof, TypeDeclaration typeNode, int modifier) {
+	private FieldDeclaration createParameterObjectField(ParameterObjectFactory pof, TypeDeclaration typeNode, int modifier, TextEditGroup removeFieldGroup) {
 		AST ast= fBaseCURewrite.getAST();
 		ClassInstanceCreation creation= ast.newClassInstanceCreation();
 		creation.setType(pof.createType(fDescriptor.isCreateTopLevel(), fBaseCURewrite, typeNode.getStartPosition()));
 		ListRewrite listRewrite= fBaseCURewrite.getASTRewrite().getListRewrite(creation, ClassInstanceCreation.ARGUMENTS_PROPERTY);
-		for (Iterator<FieldInfo> iter= fVariables.values().iterator(); iter.hasNext();) {
-			FieldInfo fi= iter.next();
+		for (FieldInfo fi : fVariables.values()) {
 			if (isCreateField(fi)) {
 				Expression expression= fi.initializer;
 				if (expression != null && !fi.hasFieldReference()) {
@@ -834,9 +810,9 @@ public class ExtractClassRefactoring extends Refactoring {
 						ArrayCreation arrayCreation= ast.newArrayCreation();
 						arrayCreation.setType((ArrayType) addImport);
 						arrayCreation.setInitializer((ArrayInitializer) createMoveTarget);
-						listRewrite.insertLast(arrayCreation, null);
+						listRewrite.insertLast(arrayCreation, removeFieldGroup);
 					} else {
-						listRewrite.insertLast(createMoveTarget, null);
+						listRewrite.insertLast(createMoveTarget, removeFieldGroup);
 					}
 				}
 			}
@@ -863,12 +839,9 @@ public class ExtractClassRefactoring extends Refactoring {
 	}
 
 	private void importNodeTypes(ASTNode node, final CompilationUnitRewrite cuRewrite) {
-		ASTResolving.visitAllBindings(node, new TypeBindingVisitor() {
-			@Override
-			public boolean visit(ITypeBinding nodeBinding) {
-				ParameterObjectFactory.importBinding(nodeBinding, cuRewrite, null, TypeLocation.OTHER);
-				return false;
-			}
+		ASTResolving.visitAllBindings(node, nodeBinding -> {
+			ParameterObjectFactory.importBinding(nodeBinding, cuRewrite, null, TypeLocation.OTHER);
+			return false;
 		});
 	}
 
