@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -65,21 +65,20 @@ import org.eclipse.jdt.core.dom.rewrite.ImportRewrite.TypeLocation;
 import org.eclipse.jdt.core.dom.rewrite.ListRewrite;
 import org.eclipse.jdt.core.refactoring.CompilationUnitChange;
 
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
+import org.eclipse.jdt.internal.core.manipulation.dom.ASTResolving;
+import org.eclipse.jdt.internal.core.manipulation.util.Strings;
 import org.eclipse.jdt.internal.corext.codemanipulation.ContextSensitiveImportRewriteContext;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
 import org.eclipse.jdt.internal.corext.dom.CodeScopeBuilder;
+import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
+import org.eclipse.jdt.internal.corext.dom.Selection;
 import org.eclipse.jdt.internal.corext.fix.LinkedProposalModel;
 import org.eclipse.jdt.internal.corext.refactoring.Checks;
 import org.eclipse.jdt.internal.corext.refactoring.RefactoringCoreMessages;
 import org.eclipse.jdt.internal.corext.refactoring.util.RefactoringASTParser;
 import org.eclipse.jdt.internal.corext.refactoring.util.ResourceUtil;
 import org.eclipse.jdt.internal.corext.refactoring.util.SelectionAwareSourceRangeComputer;
-import org.eclipse.jdt.internal.core.manipulation.StubUtility;
-import org.eclipse.jdt.internal.core.manipulation.dom.ASTResolving;
-import org.eclipse.jdt.internal.core.manipulation.util.Strings;
-
-import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
-import org.eclipse.jdt.internal.corext.dom.Selection;
 
 import org.eclipse.jdt.internal.ui.text.correction.QuickAssistProcessor;
 
@@ -192,7 +191,7 @@ public class SurroundWithTryCatchRefactoring extends Refactoring {
 	public RefactoringStatus checkFinalConditions(IProgressMonitor pm) throws CoreException {
 		return Checks.validateModifiesFiles(
 			ResourceUtil.getFiles(new ICompilationUnit[]{fCUnit}),
-			getValidationContext());
+			getValidationContext(), pm);
 	}
 
 	/* non Java-doc
@@ -313,8 +312,7 @@ public class SurroundWithTryCatchRefactoring extends Refactoring {
 					}
 				}
 				List<VariableDeclarationFragment> fragments= copy.fragments();
-				for (Iterator<VariableDeclarationFragment> iter= fragments.iterator(); iter.hasNext();) {
-					VariableDeclarationFragment fragment= iter.next();
+				for (VariableDeclarationFragment fragment : fragments) {
 					fragment.setInitializer(null);
 				}
 
@@ -342,8 +340,7 @@ public class SurroundWithTryCatchRefactoring extends Refactoring {
 				fragments= statement.fragments();
 				if (!fragments.isEmpty()) {
 					List<ExpressionStatement> newExpressionStatements= new ArrayList<>();
-					for (Iterator<VariableDeclarationFragment> iter= fragments.iterator(); iter.hasNext();) {
-						VariableDeclarationFragment fragment= iter.next();
+					for (VariableDeclarationFragment fragment : fragments) {
 						Expression initializer= fragment.getInitializer();
 						if (initializer != null) {
 							Assignment assignment= ast.newAssignment();
@@ -422,13 +419,10 @@ public class SurroundWithTryCatchRefactoring extends Refactoring {
 	}
 
 	public static List<ITypeBinding> filterSubtypeExceptions(ITypeBinding[] exceptions) {
-		List<ITypeBinding> filteredExceptions= new ArrayList<>();
-		filteredExceptions.addAll(Arrays.asList(exceptions));
-
+		List<ITypeBinding> filteredExceptions= new ArrayList<>(Arrays.asList(exceptions));
 		for (Iterator<ITypeBinding> subtypeIterator= filteredExceptions.iterator(); subtypeIterator.hasNext();) {
 			ITypeBinding iTypeBinding= subtypeIterator.next();
-			for (Iterator<ITypeBinding> supertypeIterator= filteredExceptions.iterator(); supertypeIterator.hasNext();) {
-				ITypeBinding superTypeBinding= supertypeIterator.next();
+			for (ITypeBinding superTypeBinding : filteredExceptions) {
 				if (!iTypeBinding.equals(superTypeBinding) && iTypeBinding.isSubTypeCompatible(superTypeBinding)) {
 					subtypeIterator.remove();
 					break;
