@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2020 IBM Corporation and others.
+ * Copyright (c) 2020, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -58,6 +58,7 @@ import org.eclipse.jdt.core.dom.Modifier;
 import org.eclipse.jdt.core.dom.SimpleName;
 import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
 import org.eclipse.jdt.core.dom.Statement;
+import org.eclipse.jdt.core.dom.ThrowStatement;
 import org.eclipse.jdt.core.dom.TryStatement;
 import org.eclipse.jdt.core.dom.Type;
 import org.eclipse.jdt.core.dom.UnionType;
@@ -190,7 +191,7 @@ public class SurroundWithTryWithResourcesRefactoring extends Refactoring {
 	public RefactoringStatus checkFinalConditions(IProgressMonitor pm) throws CoreException {
 		return Checks.validateModifiesFiles(
 			ResourceUtil.getFiles(new ICompilationUnit[]{fCUnit}),
-			getValidationContext());
+			getValidationContext(), pm);
 	}
 
 	/* non Java-doc
@@ -238,12 +239,27 @@ public class SurroundWithTryWithResourcesRefactoring extends Refactoring {
 		return fRootNode.getAST();
 	}
 
+	@SuppressWarnings("null")
 	private void createTryWithResourcesStatement(org.eclipse.jdt.core.IBuffer buffer, String lineDelimiter) throws CoreException {
 		List<Statement> result= new ArrayList<>(1);
-		TryStatement tryStatement= getAST().newTryStatement();
+		boolean modifyExistingTry= false;
+		TryStatement tryStatement= null;
 		ITypeBinding[] exceptions= fAnalyzer.getExceptions(fAnalyzer.getSelection());
 		ImportRewriteContext context= new ContextSensitiveImportRewriteContext(fAnalyzer.getEnclosingBodyDeclaration(), fImportRewrite);
 
+		TryStatement enclosingTry= (TryStatement)ASTResolving.findAncestor(fSelectedNodes[0], ASTNode.TRY_STATEMENT);
+		ListRewrite resourcesRewriter= null;
+		ListRewrite clausesRewriter= null;
+		ListRewrite statements= null;
+		if (enclosingTry == null || enclosingTry.getBody() == null || enclosingTry.getBody().statements().get(0) != fSelectedNodes[0]) {
+			tryStatement= getAST().newTryStatement();
+			statements= fRewriter.getListRewrite(tryStatement.getBody(), Block.STATEMENTS_PROPERTY);
+		} else {
+			modifyExistingTry= true;
+			resourcesRewriter= fRewriter.getListRewrite(enclosingTry, TryStatement.RESOURCES2_PROPERTY);
+			clausesRewriter= fRewriter.getListRewrite(enclosingTry, TryStatement.CATCH_CLAUSES_PROPERTY);
+		}
+
 		CatchClause catchClause= getAST().newCatchClause();
 		SingleVariableDeclaration decl= getAST().newSingleVariableDeclaration();
 		String varName= StubUtility.getExceptionVariableName(fCUnit.getJavaProject());
@@ -251,101 +267,95 @@ public class SurroundWithTryWithResourcesRefactoring extends Refactoring {
 		decl.setName(getAST().newSimpleName(name));
 
 
-		List<ASTNode> variableDeclarations= getSpecialVariableDeclarationStatements();
-		ListRewrite statements= fRewriter.getListRewrite(tryStatement.getBody(), Block.STATEMENTS_PROPERTY);
 		boolean selectedNodeRemoved= false;
 		ASTNode expressionStatement= null;
-		for (ASTNode node : fSelectedNodes) {
-			if (fAutoClosableNodes.contains(node)) {
-				continue;
-			}
-			if (node instanceof VariableDeclarationStatement && variableDeclarations.contains(node)) {
-				AST ast= getAST();
-				VariableDeclarationStatement statement= (VariableDeclarationStatement)node;
-				// Create a copy and remove the initializer
-				VariableDeclarationStatement copy= (VariableDeclarationStatement)ASTNode.copySubtree(ast, statement);
-				List<IExtendedModifier> modifiers= copy.modifiers();
-				for (Iterator<IExtendedModifier> iter= modifiers.iterator(); iter.hasNext();) {
-					IExtendedModifier modifier= iter.next();
-					if (modifier.isModifier() && Modifier.isFinal(((Modifier)modifier).getKeyword().toFlagValue())) {
-						iter.remove();
-					}
-				}
-				List<VariableDeclarationFragment> fragments= copy.fragments();
-				for (Iterator<VariableDeclarationFragment> iter= fragments.iterator(); iter.hasNext();) {
-					VariableDeclarationFragment fragment= iter.next();
-					fragment.setInitializer(null);
-				}
+		ASTNode replacementNode= null;
+		List<ASTNode> nodesInRange= new ArrayList<>();
 
-				// "var" type cannot have null initializer, so change to inferred type
-				if (ASTNodes.isVarType(statement, fRootNode)) {
-					ITypeBinding binding= statement.getType().resolveBinding();
-					if (binding != null) {
-						Type varType= fImportRewrite.addImport(binding, getAST(), context, TypeLocation.LOCAL_VARIABLE);
-						copy.setType(varType);
-					}
+		if (!modifyExistingTry) {
+			List<ASTNode> variableDeclarations= getSpecialVariableDeclarationStatements();
+			for (ASTNode node : fSelectedNodes) {
+				if (fAutoClosableNodes.contains(node)) {
+					continue;
 				}
-
-				CompilationUnit root= (CompilationUnit)statement.getRoot();
-				int extendedStart= root.getExtendedStartPosition(statement);
-				// we have a leading comment and the comment is covered by the selection
-				if (extendedStart != statement.getStartPosition() && extendedStart >= fSelection.getOffset()) {
-					String commentToken= buffer.getText(extendedStart, statement.getStartPosition() - extendedStart);
-					commentToken= Strings.trimTrailingTabsAndSpaces(commentToken);
-					Type type= statement.getType();
-					String typeName= buffer.getText(type.getStartPosition(), type.getLength());
-					copy.setType((Type)fRewriter.createStringPlaceholder(commentToken + typeName, type.getNodeType()));
-				}
-				result.add(copy);
-				// convert the fragments into expression statements
-				fragments= statement.fragments();
-				if (!fragments.isEmpty()) {
-					List<ExpressionStatement> newExpressionStatements= new ArrayList<>();
-					for (Iterator<VariableDeclarationFragment> iter= fragments.iterator(); iter.hasNext();) {
-						VariableDeclarationFragment fragment= iter.next();
-						Expression initializer= fragment.getInitializer();
-						if (initializer != null) {
-							Assignment assignment= ast.newAssignment();
-							assignment.setLeftHandSide((Expression)fRewriter.createCopyTarget(fragment.getName()));
-							assignment.setRightHandSide((Expression)fRewriter.createCopyTarget(initializer));
-							newExpressionStatements.add(ast.newExpressionStatement(assignment));
+				if (node instanceof VariableDeclarationStatement && variableDeclarations.contains(node)) {
+					AST ast= getAST();
+					VariableDeclarationStatement statement= (VariableDeclarationStatement)node;
+					// Create a copy and remove the initializer
+					VariableDeclarationStatement copy= (VariableDeclarationStatement)ASTNode.copySubtree(ast, statement);
+					List<IExtendedModifier> modifiers= copy.modifiers();
+					for (Iterator<IExtendedModifier> iter= modifiers.iterator(); iter.hasNext();) {
+						IExtendedModifier modifier= iter.next();
+						if (modifier.isModifier() && Modifier.isFinal(((Modifier)modifier).getKeyword().toFlagValue())) {
+							iter.remove();
 						}
 					}
-					if (!newExpressionStatements.isEmpty()) {
-						if (fSelectedNodes.length == 1) {
-							expressionStatement= fRewriter.createGroupNode(newExpressionStatements.toArray(new ASTNode[newExpressionStatements.size()]));
+					List<VariableDeclarationFragment> fragments= copy.fragments();
+					for (VariableDeclarationFragment fragment : fragments) {
+						fragment.setInitializer(null);
+					}
+
+					// "var" type cannot have null initializer, so change to inferred type
+					if (ASTNodes.isVarType(statement, fRootNode)) {
+						ITypeBinding binding= statement.getType().resolveBinding();
+						if (binding != null) {
+							Type varType= fImportRewrite.addImport(binding, getAST(), context, TypeLocation.LOCAL_VARIABLE);
+							copy.setType(varType);
+						}
+					}
+
+					CompilationUnit root= (CompilationUnit)statement.getRoot();
+					int extendedStart= root.getExtendedStartPosition(statement);
+					// we have a leading comment and the comment is covered by the selection
+					if (extendedStart != statement.getStartPosition() && extendedStart >= fSelection.getOffset()) {
+						String commentToken= buffer.getText(extendedStart, statement.getStartPosition() - extendedStart);
+						commentToken= Strings.trimTrailingTabsAndSpaces(commentToken);
+						Type type= statement.getType();
+						String typeName= buffer.getText(type.getStartPosition(), type.getLength());
+						copy.setType((Type)fRewriter.createStringPlaceholder(commentToken + typeName, type.getNodeType()));
+					}
+					result.add(copy);
+					// convert the fragments into expression statements
+					fragments= statement.fragments();
+					if (!fragments.isEmpty()) {
+						List<ExpressionStatement> newExpressionStatements= new ArrayList<>();
+						for (VariableDeclarationFragment fragment : fragments) {
+							Expression initializer= fragment.getInitializer();
+							if (initializer != null) {
+								Assignment assignment= ast.newAssignment();
+								assignment.setLeftHandSide((Expression)fRewriter.createCopyTarget(fragment.getName()));
+								assignment.setRightHandSide((Expression)fRewriter.createCopyTarget(initializer));
+								newExpressionStatements.add(ast.newExpressionStatement(assignment));
+							}
+						}
+						if (!newExpressionStatements.isEmpty()) {
+							if (fSelectedNodes.length == 1) {
+								expressionStatement= fRewriter.createGroupNode(newExpressionStatements.toArray(new ASTNode[newExpressionStatements.size()]));
+							} else {
+								fRewriter.replace(
+										statement,
+										fRewriter.createGroupNode(newExpressionStatements.toArray(new ASTNode[newExpressionStatements.size()])),
+										null);
+							}
 						} else {
-							fRewriter.replace(
-								statement,
-								fRewriter.createGroupNode(newExpressionStatements.toArray(new ASTNode[newExpressionStatements.size()])),
-								null);
+							fRewriter.remove(statement, null);
+							selectedNodeRemoved= true;
 						}
 					} else {
 						fRewriter.remove(statement, null);
 						selectedNodeRemoved= true;
 					}
-				} else {
-					fRewriter.remove(statement, null);
-					selectedNodeRemoved= true;
 				}
 			}
-		}
-		result.add(tryStatement);
-		ASTNode replacementNode;
-		if (result.size() == 1) {
-			replacementNode= result.get(0);
-		} else {
-			replacementNode= fRewriter.createGroupNode(result.toArray(new ASTNode[result.size()]));
-		}
+			result.add(tryStatement);
+			if (result.size() == 1) {
+				replacementNode= result.get(0);
+			} else {
+				replacementNode= fRewriter.createGroupNode(result.toArray(new ASTNode[result.size()]));
+			}
 
-		ASTNode node= fSelectedNodes[0];
-		ASTNode parentStatement= ASTResolving.findAncestor(node, ASTNode.VARIABLE_DECLARATION_STATEMENT);
-		List<ASTNode> coveredStatements= new ArrayList<>();
-		if (fSelectedNodes == null || fSelectedNodes.length == 0 && parentStatement != null
-				&& (parentStatement instanceof VariableDeclarationStatement)
-				&& (parentStatement instanceof ExpressionStatement)) {
-			coveredStatements.add(parentStatement);
-		} else {
+			ASTNode node= fSelectedNodes[0];
+			List<ASTNode> coveredStatements= new ArrayList<>();
 			for (ASTNode coveredNode : fSelectedNodes) {
 				Statement statement= ASTResolving.findParentStatement(coveredNode);
 				if (statement == null) {
@@ -355,46 +365,45 @@ public class SurroundWithTryWithResourcesRefactoring extends Refactoring {
 					coveredStatements.add(statement);
 				}
 			}
-		}
 
-		Selection nodesInRangeSelection= fAnalyzer.getSelection();
-		List<ASTNode> nodesInRange= new ArrayList<>();
-		if (!fAutoClosableNodes.isEmpty()) {
-			ASTNode parentBodyDeclaration= ASTResolving.findParentBodyDeclaration(node);
-			int start= fAutoClosableNodes.get(0).getStartPosition();
-			ASTNode lastSelectedNode= fSelectedNodes[fSelectedNodes.length - 1];
-			int end= lastSelectedNode.getStartPosition() + lastSelectedNode.getLength();
+			Selection nodesInRangeSelection= fAnalyzer.getSelection();
+			if (!fAutoClosableNodes.isEmpty()) {
+				ASTNode parentBodyDeclaration= ASTResolving.findParentBodyDeclaration(node);
+				int start= fAutoClosableNodes.get(0).getStartPosition();
+				ASTNode lastSelectedNode= fSelectedNodes[fSelectedNodes.length - 1];
+				int end= lastSelectedNode.getStartPosition() + lastSelectedNode.getLength();
 
-			for (ASTNode astNode : fAutoClosableNodes) {
-				int endPosition= findEndPosition(astNode);
-				end= Math.max(end, endPosition);
-			}
-
-			// recursive loop to find all nodes affected by wrapping in try block
-			nodesInRange= findNodesInRange(parentBodyDeclaration, start, end);
-			int oldEnd= end;
-			int newEnd= end;
-			while (true) {
-				newEnd= oldEnd;
-				for (ASTNode astNode : nodesInRange) {
+				for (ASTNode astNode : fAutoClosableNodes) {
 					int endPosition= findEndPosition(astNode);
-					newEnd= Math.max(newEnd, endPosition);
+					end= Math.max(end, endPosition);
 				}
-				if (newEnd > oldEnd) {
-					oldEnd= newEnd;
-					nodesInRange= findNodesInRange(parentBodyDeclaration, start, newEnd);
-					continue;
+
+				// recursive loop to find all nodes affected by wrapping in try block
+				nodesInRange= findNodesInRange(parentBodyDeclaration, start, end);
+				int oldEnd= end;
+				int newEnd= end;
+				while (true) {
+					newEnd= oldEnd;
+					for (ASTNode astNode : nodesInRange) {
+						int endPosition= findEndPosition(astNode);
+						newEnd= Math.max(newEnd, endPosition);
+					}
+					if (newEnd > oldEnd) {
+						oldEnd= newEnd;
+						nodesInRange= findNodesInRange(parentBodyDeclaration, start, newEnd);
+						continue;
+					}
+					break;
 				}
-				break;
+				if (nodesInRange.size() > 0) {
+					// must recalculate exceptions as additional lines are now in try statement
+					ASTNode lastNode= nodesInRange.get(nodesInRange.size() - 1);
+					nodesInRangeSelection= Selection.createFromStartEnd(start, lastNode.getStartPosition() + lastNode.getLength());
+					exceptions= fAnalyzer.getExceptions(nodesInRangeSelection);
+				}
+				nodesInRange.removeAll(fAutoClosableNodes);
+				nodesInRange.removeAll(Arrays.asList(fSelectedNodes));
 			}
-			if (nodesInRange.size() > 0) {
-				// must recalculate exceptions as additional lines are now in try statement
-				ASTNode lastNode= nodesInRange.get(nodesInRange.size() - 1);
-				nodesInRangeSelection= Selection.createFromStartEnd(start, lastNode.getStartPosition() + lastNode.getLength());
-				exceptions= fAnalyzer.getExceptions(nodesInRangeSelection);
-			}
-			nodesInRange.removeAll(fAutoClosableNodes);
-			nodesInRange.removeAll(Arrays.asList(fSelectedNodes));
 		}
 
 		// add required resource statements
@@ -419,19 +428,9 @@ public class SurroundWithTryWithResourcesRefactoring extends Refactoring {
 				if (typeBinding != null) {
 					IMethodBinding close= findAutocloseMethod(typeBinding);
 					if (close != null) {
-						ITypeBinding[] thrownExceptions= fAnalyzer.getThrownExceptions();
 						for (ITypeBinding exceptionType : close.getExceptionTypes()) {
 							if (!allExceptions.contains(exceptionType)) {
-								boolean isThrown= false;
-								for (ITypeBinding thrownException : thrownExceptions) {
-									if (exceptionType.isAssignmentCompatible(thrownException)) {
-										isThrown= true;
-										break;
-									}
-								}
-								if (!isThrown) {
-									allExceptions.add(exceptionType);
-								}
+								allExceptions.add(exceptionType);
 							}
 						}
 					}
@@ -464,7 +463,15 @@ public class SurroundWithTryWithResourcesRefactoring extends Refactoring {
 					VariableDeclarationExpression newVariableDeclarationExpression= ast.newVariableDeclarationExpression(newVariableDeclarationFragment);
 					newVariableDeclarationExpression.setType(
 							(Type) fRewriter.createStringPlaceholder(commentToken + typeName, type.getNodeType()));
-					tryStatement.resources().add(newVariableDeclarationExpression);
+					if (modifyExistingTry) {
+						if (enclosingTry.resources().isEmpty()) {
+							resourcesRewriter.insertFirst(newVariableDeclarationExpression, null);
+						} else {
+							resourcesRewriter.insertLast(newVariableDeclarationExpression, null);
+						}
+					} else {
+						tryStatement.resources().add(newVariableDeclarationExpression);
+					}
 					commentToken= null;
 				}
 //				String commentToken2= ""; //$NON-NLS-1$
@@ -479,11 +486,30 @@ public class SurroundWithTryWithResourcesRefactoring extends Refactoring {
 			}
 		}
 
-		List<ITypeBinding> filteredExceptions= filterSubtypeExceptions(allExceptions);
-		if (allExceptions.size() > 0) {
+		List<ITypeBinding> mustRethrowList= new ArrayList<>();
+		List<ITypeBinding> catchExceptions= fAnalyzer.calculateCatchesAndRethrows(ASTNodes.filterSubtypes(allExceptions), mustRethrowList);
+		List<ITypeBinding> filteredExceptions= ASTNodes.filterSubtypes(catchExceptions);
+		if (catchExceptions.size() > 0) {
+			LinkedProposalModel linkedProposalModel= new LinkedProposalModel();
+			int i= 0;
+			if (!modifyExistingTry) {
+				for (ITypeBinding mustThrow : mustRethrowList) {
+					CatchClause newClause= ast.newCatchClause();
+					SingleVariableDeclaration newDecl= ast.newSingleVariableDeclaration();
+					newDecl.setName(ast.newSimpleName(name));
+					Type importType= fImportRewrite.addImport(mustThrow, ast, context, TypeLocation.EXCEPTION);
+					newDecl.setType(importType);
+					newClause.setException(newDecl);
+					ThrowStatement newThrowStatement= ast.newThrowStatement();
+					newThrowStatement.setExpression(ast.newSimpleName(name));
+					linkedProposalModel.getPositionGroup(GROUP_EXC_NAME + i, true).addPosition(fRewriter.track(decl.getName()), false);
+					newClause.getBody().statements().add(newThrowStatement);
+					tryStatement.catchClauses().add(newClause);
+					++i;
+				}
+			}
 			UnionType unionType= getAST().newUnionType();
 			List<Type> types= unionType.types();
-			int i=0;
 			for (ITypeBinding exception : filteredExceptions) {
 				Type type= fImportRewrite.addImport(exception, getAST(), context, TypeLocation.EXCEPTION);
 				types.add(type);
@@ -498,7 +524,11 @@ public class SurroundWithTryWithResourcesRefactoring extends Refactoring {
 			if (st != null) {
 				catchClause.getBody().statements().add(st);
 			}
-			tryStatement.catchClauses().add(catchClause);
+			if (modifyExistingTry) {
+				clausesRewriter.insertLast(catchClause, null);
+			} else {
+				tryStatement.catchClauses().add(catchClause);
+			}
 		}
 
 
@@ -534,6 +564,11 @@ public class SurroundWithTryWithResourcesRefactoring extends Refactoring {
 					statements.insertLast(fRewriter.createMoveTarget(selectedNode), null);
 			}
 			fRewriter.replace(selectedNode, replacementNode, null);
+		} else if (modifyExistingTry) {
+			ListRewrite source= fRewriter.getListRewrite(enclosingTry.getBody(), Block.STATEMENTS_PROPERTY);
+			for (ASTNode node : fAutoClosableNodes) {
+				source.remove(node, null);
+			}
 		} else {
 			ListRewrite source= fRewriter.getListRewrite(
 					fSelectedNodes[0].getParent(),
@@ -558,11 +593,11 @@ public class SurroundWithTryWithResourcesRefactoring extends Refactoring {
 
 	}
 
-	private IMethodBinding findAutocloseMethod(ITypeBinding type) {
+	public static IMethodBinding findAutocloseMethod(ITypeBinding type) {
 		while (type != null) {
 			IMethodBinding[] methods= type.getDeclaredMethods();
 			for (IMethodBinding method : methods) {
-				if (method.getName().equals("close") && method.getParameterTypes().length == 0) { //$NON-NLS-1$
+				if ("close".equals(method.getName()) && method.getParameterTypes().length == 0) { //$NON-NLS-1$
 					return method;
 				}
 			}
@@ -590,7 +625,7 @@ public class SurroundWithTryWithResourcesRefactoring extends Refactoring {
 	}
 
 	// find all nodes (statements) that are within the start/end positions
-	private List<ASTNode> findNodesInRange(ASTNode astNode, final int start, final int end) {
+	public static List<ASTNode> findNodesInRange(ASTNode astNode, final int start, final int end) {
 		List<ASTNode> nodesInRange= new ArrayList<>();
 		astNode.accept(new ASTVisitor() {
 			int pre= start;
@@ -611,7 +646,8 @@ public class SurroundWithTryWithResourcesRefactoring extends Refactoring {
 							Statement pStatement= (Statement) statement.getParent();
 							switch (pStatement.getNodeType()) {
 								case ASTNode.BLOCK:
-									if (pStatement.getParent().getNodeType() != ASTNode.METHOD_DECLARATION) {
+									if (pStatement.getParent().getNodeType() != ASTNode.METHOD_DECLARATION &&
+									pStatement.getParent().getNodeType() != ASTNode.TRY_STATEMENT) {
 										statement= pStatement;
 										continue;
 									} else {
@@ -637,23 +673,6 @@ public class SurroundWithTryWithResourcesRefactoring extends Refactoring {
 		return nodesInRange;
 	}
 
-	private List<ITypeBinding> filterSubtypeExceptions(List<ITypeBinding> exceptions) {
-		List<ITypeBinding> filteredExceptions= new ArrayList<>();
-		filteredExceptions.addAll(exceptions);
-
-		for (Iterator<ITypeBinding> subtypeIterator= filteredExceptions.iterator(); subtypeIterator.hasNext();) {
-			ITypeBinding iTypeBinding= subtypeIterator.next();
-			for (Iterator<ITypeBinding> supertypeIterator= filteredExceptions.iterator(); supertypeIterator.hasNext();) {
-				ITypeBinding superTypeBinding= supertypeIterator.next();
-				if (!iTypeBinding.equals(superTypeBinding) && iTypeBinding.isSubTypeCompatible(superTypeBinding)) {
-					subtypeIterator.remove();
-					break;
-				}
-			}
-		}
-		return filteredExceptions;
-	}
-
 	private List<ASTNode> getSpecialVariableDeclarationStatements() {
 		List<ASTNode> result= new ArrayList<>(3);
 		for (VariableDeclaration local : fAnalyzer.getAffectedLocals()) {
