@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Microsoft Corporation - read formatting options from the compilation unit
  *******************************************************************************/
 package org.eclipse.jdt.internal.ui.refactoring.reorg;
 
@@ -21,7 +22,6 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -50,7 +50,6 @@ import org.eclipse.core.resources.IFolder;
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.resources.IStorage;
-import org.eclipse.core.resources.IWorkspaceRunnable;
 
 import org.eclipse.core.filebuffers.ITextFileBuffer;
 
@@ -238,12 +237,7 @@ public class PasteAction extends SelectionDispatchAction{
 	private static Object getContents(final Clipboard clipboard, final Transfer transfer, Shell shell) {
 		//see bug 33028 for explanation why we need this
 		final Object[] result= new Object[1];
-		shell.getDisplay().syncExec(new Runnable() {
-			@Override
-			public void run() {
-				result[0]= clipboard.getContents(transfer);
-			}
-		});
+		shell.getDisplay().syncExec(() -> result[0]= clipboard.getContents(transfer));
 		return result[0];
 	}
 
@@ -360,7 +354,7 @@ public class PasteAction extends SelectionDispatchAction{
 		public abstract void paste(IJavaElement[] selectedJavaElements, IResource[] selectedResources, IWorkingSet[] selectedWorkingSets, TransferData[] availableTypes) throws JavaModelException, InterruptedException, InvocationTargetException;
 	}
 
-    private static class TextPaster extends Paster {
+	private static class TextPaster extends Paster {
 
 		private static class ParsedCu {
 			private final String fText;
@@ -440,8 +434,7 @@ public class PasteAction extends SelectionDispatchAction{
 				int maxVisibility= JdtFlags.VISIBILITY_CODE_INVALID;
 
 				// Public types must be in separate CUs:
-				for (Iterator<AbstractTypeDeclaration> iter= types.iterator(); iter.hasNext(); ) {
-					AbstractTypeDeclaration type= iter.next();
+				for (AbstractTypeDeclaration type : types) {
 					if (typeName == null) {
 						// first in group:
 						maxVisibility= JdtFlags.getVisibilityCode(type);
@@ -554,7 +547,7 @@ public class PasteAction extends SelectionDispatchAction{
 						return new ByteArrayInputStream(text.getBytes(getCharset()));
 					} catch (UnsupportedEncodingException e) {
 						throw new CoreException(new Status(IStatus.ERROR, JavaPlugin.getPluginId(),
-			                    IJavaStatusConstants.INTERNAL_ERROR, JavaUIMessages.JavaPlugin_internal_error, e));
+								IJavaStatusConstants.INTERNAL_ERROR, JavaUIMessages.JavaPlugin_internal_error, e));
 					}
 				}
 				@Override
@@ -708,33 +701,29 @@ public class PasteAction extends SelectionDispatchAction{
 
 					final ArrayList<ICompilationUnit> cus= new ArrayList<>();
 					try {
-						JavaCore.run(new IWorkspaceRunnable() {
-							@Override
-							public void run(IProgressMonitor pm) throws CoreException {
-								pm.beginTask("", 1 + fParsedCus.length); //$NON-NLS-1$
+						JavaCore.run(pm -> {
+							pm.beginTask("", 1 + fParsedCus.length); //$NON-NLS-1$
 
-								if (fDestination == null) {
-									fDestination= createNewProject(new SubProgressMonitor(pm, 1));
-								} else {
-									pm.worked(1);
-								}
-								IConfirmQuery confirmQuery= new ReorgQueries(getShell()).createYesYesToAllNoNoToAllQuery(ReorgMessages.PasteAction_TextPaster_confirmOverwriting, true, IReorgQueries.CONFIRM_OVERWRITING);
-								for (ParsedCu parsedCu : fParsedCus) {
-									if (pm.isCanceled())
-										break;
-									ICompilationUnit cu= pasteCU(parsedCu, new SubProgressMonitor(pm, 1), confirmQuery);
-									if (cu != null)
-										cus.add(cu);
-								}
+							if (fDestination == null) {
+								fDestination= createNewProject(new SubProgressMonitor(pm, 1));
+							} else {
+								pm.worked(1);
+							}
+							IConfirmQuery confirmQuery= new ReorgQueries(getShell()).createYesYesToAllNoNoToAllQuery(ReorgMessages.PasteAction_TextPaster_confirmOverwriting, true, IReorgQueries.CONFIRM_OVERWRITING);
+							for (ParsedCu parsedCu : fParsedCus) {
+								if (pm.isCanceled())
+									break;
+								ICompilationUnit cu= pasteCU(parsedCu, new SubProgressMonitor(pm, 1), confirmQuery);
+								if (cu != null)
+									cus.add(cu);
+							}
 
-								if (selectedWorkingSets.length == 1) {
-									IWorkingSet ws= selectedWorkingSets[0];
-									if (!IWorkingSetIDs.OTHERS.equals(ws.getId())) {
-										ArrayList<IAdaptable> newElements= new ArrayList<>();
-										newElements.addAll(Arrays.asList(ws.getElements()));
-										newElements.addAll(Arrays.asList(ws.adaptElements(new IAdaptable[] { fDestination.getJavaProject() })));
-										ws.setElements(newElements.toArray(new IAdaptable[newElements.size()]));
-									}
+							if (selectedWorkingSets.length == 1) {
+								IWorkingSet ws= selectedWorkingSets[0];
+								if (!IWorkingSetIDs.OTHERS.equals(ws.getId())) {
+									ArrayList<IAdaptable> newElements= new ArrayList<>(Arrays.asList(ws.getElements()));
+									newElements.addAll(Arrays.asList(ws.adaptElements(new IAdaptable[] { fDestination.getJavaProject() })));
+									ws.setElements(newElements.toArray(new IAdaptable[newElements.size()]));
 								}
 							}
 						}, monitor);
@@ -957,13 +946,11 @@ public class PasteAction extends SelectionDispatchAction{
 					DocumentRewriteSession rewriteSession= null;
 					if (document instanceof IDocumentExtension4)
 						rewriteSession= ((IDocumentExtension4) document).startRewriteSession(DocumentRewriteSessionType.UNRESTRICTED_SMALL);
-					TextEdit edit= rewrite.rewriteAST(document, cu.getJavaProject().getOptions(true));
+					TextEdit edit= rewrite.rewriteAST(document, cu.getOptions(true));
 					try {
 						edit.apply(document, TextEdit.UPDATE_REGIONS);
 						return textPosition;
-					} catch (MalformedTreeException e) {
-						JavaPlugin.log(e);
-					} catch (BadLocationException e) {
+					} catch (MalformedTreeException | BadLocationException e) {
 						JavaPlugin.log(e);
 					} finally {
 						if (rewriteSession != null)
@@ -1045,10 +1032,7 @@ public class PasteAction extends SelectionDispatchAction{
 		private IEditorPart openCu(ICompilationUnit cu) {
 			try {
 				return JavaUI.openInEditor(cu, true, true);
-			} catch (PartInitException e) {
-				JavaPlugin.log(e);
-				return null;
-			} catch (JavaModelException e) {
+			} catch (PartInitException | JavaModelException e) {
 				JavaPlugin.log(e);
 				return null;
 			}
@@ -1154,7 +1138,7 @@ public class PasteAction extends SelectionDispatchAction{
 				return null;
 			}
 		}
-    }
+	}
 
 	private static class WorkingSetPaster extends Paster {
 		protected WorkingSetPaster(Shell shell, Clipboard clipboard) {
@@ -1177,13 +1161,11 @@ public class PasteAction extends SelectionDispatchAction{
 				List<IJavaElement> realJavaElements= new ArrayList<>();
 				List<IResource> realResource= new ArrayList<>();
 				ReorgUtils.splitIntoJavaElementsAndResources(resources, realJavaElements, realResource);
-				for (Iterator<IJavaElement> iter= realJavaElements.iterator(); iter.hasNext();) {
-					IJavaElement element= iter.next();
+				for (IJavaElement element : realJavaElements) {
 					if (!ReorgUtils.containsElementOrParent(elements, element))
 						elements.add(element);
 				}
-				for (Iterator<IResource> iter= realResource.iterator(); iter.hasNext();) {
-					IResource element= iter.next();
+				for (IResource element : realResource) {
 					if (!ReorgUtils.containsElementOrParent(elements, element))
 						elements.add(element);
 				}
@@ -1204,9 +1186,9 @@ public class PasteAction extends SelectionDispatchAction{
 		}
 	}
 
-    private static class ProjectPaster extends Paster{
+	private static class ProjectPaster extends Paster{
 
-    	protected ProjectPaster(Shell shell, Clipboard clipboard) {
+		protected ProjectPaster(Shell shell, Clipboard clipboard) {
 			super(shell, clipboard);
 		}
 
@@ -1219,7 +1201,7 @@ public class PasteAction extends SelectionDispatchAction{
 			if (! resourceTransfer)
 				return canPasteJavaProjects(availableDataTypes);
 			return canPasteJavaProjects(availableDataTypes) && canPasteSimpleProjects(availableDataTypes);
-    	}
+		}
 
 		@Override
 		public void paste(IJavaElement[] javaElements, IResource[] resources, IWorkingSet[] selectedWorkingSets, TransferData[] availableTypes) {
@@ -1270,9 +1252,9 @@ public class PasteAction extends SelectionDispatchAction{
 			}
 			return true;
 		}
-    }
+	}
 
-    private static class FilePaster extends Paster{
+	private static class FilePaster extends Paster{
 		protected FilePaster(Shell shell, Clipboard clipboard) {
 			super(shell, clipboard);
 		}
@@ -1317,7 +1299,7 @@ public class PasteAction extends SelectionDispatchAction{
 			boolean isPackageFragmentRoot= target instanceof IPackageFragmentRoot;
 			boolean isContainer= target instanceof IContainer;
 
-			if (!(isPackageFragment || isJavaProject || isPackageFragmentRoot || isContainer))
+			if (!isPackageFragment && !isJavaProject && !isPackageFragmentRoot && !isContainer)
 				return false;
 
 			if (isContainer) {
@@ -1354,8 +1336,8 @@ public class PasteAction extends SelectionDispatchAction{
 		private Object getCommonParent(IJavaElement[] javaElements, IResource[] resources) {
 			return new ParentChecker(resources, javaElements).getCommonParent();
 		}
-    }
-    private static class JavaElementAndResourcePaster extends Paster {
+	}
+	private static class JavaElementAndResourcePaster extends Paster {
 
 		protected JavaElementAndResourcePaster(Shell shell, Clipboard clipboard) {
 			super(shell, clipboard);
@@ -1411,9 +1393,9 @@ public class PasteAction extends SelectionDispatchAction{
 			fAvailableTypes= availableTypes;
 			return isAvailable(JavaElementTransfer.getInstance(), availableTypes) || isAvailable(ResourceTransfer.getInstance(), availableTypes);
 		}
-    }
+	}
 
-    private static class TypedSourcePaster extends Paster{
+	private static class TypedSourcePaster extends Paster{
 
 		protected TypedSourcePaster(Shell shell, Clipboard clipboard) {
 			super(shell, clipboard);
@@ -1431,9 +1413,9 @@ public class PasteAction extends SelectionDispatchAction{
 			if (selectedResources.length != 0 || selectedWorkingSets.length != 0)
 				return false;
 			TypedSource[] typedSources= getClipboardTypedSources(fAvailableTypes);
-			Object destination= getTarget(selectedJavaElements, selectedResources);
-			if (destination instanceof IJavaElement)
-				return ReorgTypedSourcePasteStarter.create(typedSources, (IJavaElement)destination) != null;
+			IJavaElement destination= getTarget(selectedJavaElements, selectedResources);
+			if (destination != null)
+				return ReorgTypedSourcePasteStarter.create(typedSources, destination) != null;
 			return false;
 		}
 
@@ -1550,7 +1532,7 @@ public class PasteAction extends SelectionDispatchAction{
 			@Override
 			public RefactoringStatus checkFinalConditions(IProgressMonitor pm) throws CoreException {
 				RefactoringStatus result= Checks.validateModifiesFiles(
-					ResourceUtil.getFiles(new ICompilationUnit[]{getDestinationCu()}), getValidationContext());
+					ResourceUtil.getFiles(new ICompilationUnit[]{getDestinationCu()}), getValidationContext(), pm);
 				return result;
 			}
 
@@ -1572,14 +1554,15 @@ public class PasteAction extends SelectionDispatchAction{
 					}
 				}
 				final CompilationUnitChange result= new CompilationUnitChange(ReorgMessages.PasteAction_change_name, getDestinationCu());
+				ICompilationUnit destinationCu= getDestinationCu();
 				try {
-					ITextFileBuffer buffer= RefactoringFileBuffers.acquire(getDestinationCu());
-					TextEdit rootEdit= rewrite.rewriteAST(buffer.getDocument(), fDestination.getJavaProject().getOptions(true));
-					if (getDestinationCu().isWorkingCopy())
+					ITextFileBuffer buffer= RefactoringFileBuffers.acquire(destinationCu);
+					TextEdit rootEdit= rewrite.rewriteAST(buffer.getDocument(), destinationCu.getOptions(true));
+					if (destinationCu.isWorkingCopy())
 						result.setSaveMode(TextFileChange.LEAVE_DIRTY);
 					TextChangeCompatibility.addTextEdit(result, ReorgMessages.PasteAction_edit_name, rootEdit);
 				} finally {
-					RefactoringFileBuffers.release(getDestinationCu());
+					RefactoringFileBuffers.release(destinationCu);
 				}
 				return result;
 			}
@@ -1675,5 +1658,5 @@ public class PasteAction extends SelectionDispatchAction{
 				return ReorgMessages.PasteAction_name;
 			}
 		}
-    }
+	}
 }
