@@ -28,7 +28,6 @@ import org.eclipse.jface.dialogs.Dialog;
 import org.eclipse.jface.viewers.DoubleClickEvent;
 import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.ITreeContentProvider;
 import org.eclipse.jface.viewers.SelectionChangedEvent;
@@ -74,12 +73,7 @@ abstract class ReorgUserInputPage extends UserInputWizardPage{
 
 		fViewer= createViewer(result);
 		fViewer.setSelection(new StructuredSelection(initialSelection), true);
-		fViewer.addSelectionChangedListener(new ISelectionChangedListener(){
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				ReorgUserInputPage.this.viewerSelectionChanged(event);
-			}
-		});
+		fViewer.addSelectionChangedListener(ReorgUserInputPage.this::viewerSelectionChanged);
 		fViewer.addDoubleClickListener(new TreeViewerDoubleClickListener());
 		Dialog.applyDialogFont(result);
 	}
