@@ -208,6 +208,7 @@ public final class ActionMessages extends NLS {
 	public static String AddUnimplementedConstructorsAction_not_applicable;
 	public static String AddUnimplementedConstructorsAction_interface_not_applicable;
 	public static String AddUnimplementedConstructorsAction_enum_not_applicable;
+	public static String AddUnimplementedConstructorsAction_record_not_applicable;
 	public static String AddUnimplementedConstructorsAction_annotation_not_applicable;
 	public static String AddUnimplementedConstructorsAction_methods_selected;
 	public static String AddUnimplementedConstructorsAction_error_nothing_found;
@@ -219,6 +220,7 @@ public final class ActionMessages extends NLS {
 	public static String GenerateConstructorUsingFieldsAction_tooltip;
 	public static String GenerateConstructorUsingFieldsAction_error_title;
 	public static String GenerateConstructorUsingFieldsAction_not_applicable;
+	public static String GenerateConstructorUsingFieldsAction_record_not_applicable;
 	public static String GenerateConstructorUsingFieldsAction_fields_selected;
 	public static String GenerateConstructorUsingFieldsAction_error_duplicate_constructor;
 	public static String GenerateConstructorUsingFieldsAction_error_nothing_found;
@@ -425,6 +427,9 @@ public final class ActionMessages extends NLS {
 	public static String OpenNewEnumWizardAction_text;
 	public static String OpenNewEnumWizardAction_description;
 	public static String OpenNewEnumWizardAction_tooltip;
+	public static String OpenNewRecordWizardAction_text;
+	public static String OpenNewRecordWizardAction_description;
+	public static String OpenNewRecordWizardAction_tooltip;
 	public static String OpenNewInterfaceWizardAction_text;
 	public static String OpenNewInterfaceWizardAction_description;
 	public static String OpenNewInterfaceWizardAction_tooltip;
@@ -455,6 +460,10 @@ public final class ActionMessages extends NLS {
 	public static String CreateModuleInfoAction_dialog_finish_button_label;
 	public static String CreateModuleInfoAction_dialog_cancel_button_label;
 
+	public static String EnablePreviewFeaturesAction_convert_message_compliance;
+	public static String EnablePreviewFeaturesAction_error_message_compliance;
+	public static String EnablePreviewFeaturesAction_error_title;
+
 	public static String GenerateToStringAction_label;
 	public static String GenerateToStringAction_description;
 	public static String GenerateToStringAction_tooltip;
