@@ -15,7 +15,6 @@
 package org.eclipse.jdt.internal.ui.actions;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.ResourceBundle;
 
 import org.eclipse.swt.custom.BusyIndicator;
@@ -122,10 +121,10 @@ public class IndentAction extends TextEditorAction {
 	 */
 	private final boolean fIsTabAction;
 
-	public static String TEXT_BLOCK_STR= "\"\"\""; //$NON-NLS-1$
-	public static String POTENTIAL_TEXT_BLOCK_STR= "\"\""; //$NON-NLS-1$
-	public static String SPACE_STR= " "; //$NON-NLS-1$
-	public static String EMPTY_STR= ""; //$NON-NLS-1$
+	public static final String TEXT_BLOCK_STR= "\"\"\""; //$NON-NLS-1$
+	public static final String POTENTIAL_TEXT_BLOCK_STR= "\"\""; //$NON-NLS-1$
+	public static final String SPACE_STR= " "; //$NON-NLS-1$
+	public static final String EMPTY_STR= ""; //$NON-NLS-1$
 	private static String TAB_STR= "\t"; //$NON-NLS-1$
 
 	/**
@@ -171,47 +170,44 @@ public class IndentAction extends TextEditorAction {
 				return;
 			}
 
-			Runnable runnable= new Runnable() {
-				@Override
-				public void run() {
-					IRewriteTarget target= getTextEditor().getAdapter(IRewriteTarget.class);
-					if (target != null)
-						target.beginCompoundChange();
+			Runnable runnable= () -> {
+				IRewriteTarget target= getTextEditor().getAdapter(IRewriteTarget.class);
+				if (target != null)
+					target.beginCompoundChange();
 
-					try {
-						JavaHeuristicScanner scanner= new JavaHeuristicScanner(document);
-						JavaIndenter indenter= new JavaIndenter(document, scanner, getJavaProject());
-						final boolean multiLine= nLines > 1;
-						boolean hasChanged= false;
-						for (int i= 0; i < nLines; i++) {
-							hasChanged |= indentLine(document, firstLine + i, offset, indenter, scanner, multiLine);
-						}
-
-						// update caret position: move to new position when indenting just one line
-						// keep selection when indenting multiple
-						int newOffset, newLength;
-						if (!fIsTabAction && multiLine) {
-							newOffset= offset;
-							newLength= end.getOffset() - offset;
-						} else {
-							newOffset= fCaretOffset;
-							newLength= 0;
-						}
-
-						// always reset the selection if anything was replaced
-						// but not when we had a single line non-tab invocation
-						if (newOffset != -1 && (hasChanged || newOffset != offset || newLength != length))
-							selectAndReveal(newOffset, newLength);
-
-						document.removePosition(end);
-					} catch (BadLocationException e) {
-						// will only happen on concurrent modification
-						JavaPlugin.log(new Status(IStatus.ERROR, JavaPlugin.getPluginId(), IStatus.OK, "ConcurrentModification in IndentAction", e)); //$NON-NLS-1$
-
-					} finally {
-						if (target != null)
-							target.endCompoundChange();
+				try {
+					JavaHeuristicScanner scanner= new JavaHeuristicScanner(document);
+					JavaIndenter indenter= new JavaIndenter(document, scanner, getJavaProject());
+					final boolean multiLine= nLines > 1;
+					boolean hasChanged= false;
+					for (int i= 0; i < nLines; i++) {
+						hasChanged |= indentLine(document, firstLine + i, offset, indenter, scanner, multiLine);
 					}
+
+					// update caret position: move to new position when indenting just one line
+					// keep selection when indenting multiple
+					int newOffset, newLength;
+					if (!fIsTabAction && multiLine) {
+						newOffset= offset;
+						newLength= end.getOffset() - offset;
+					} else {
+						newOffset= fCaretOffset;
+						newLength= 0;
+					}
+
+					// always reset the selection if anything was replaced
+					// but not when we had a single line non-tab invocation
+					if (newOffset != -1 && (hasChanged || newOffset != offset || newLength != length))
+						selectAndReveal(newOffset, newLength);
+
+					document.removePosition(end);
+				} catch (BadLocationException e) {
+					// will only happen on concurrent modification
+					JavaPlugin.log(new Status(IStatus.ERROR, JavaPlugin.getPluginId(), IStatus.OK, "ConcurrentModification in IndentAction", e)); //$NON-NLS-1$
+
+				} finally {
+					if (target != null)
+						target.endCompoundChange();
 				}
 			};
 
@@ -299,9 +295,8 @@ public class IndentAction extends TextEditorAction {
 			return edits.get(0);
 
 		MultiTextEdit result= new MultiTextEdit();
-		for (Iterator<ReplaceEdit> iterator= edits.iterator(); iterator.hasNext();) {
-			TextEdit edit= iterator.next();
-			result.addChild(edit);
+		for (ReplaceEdit replaceEdit : edits) {
+			result.addChild(replaceEdit);
 		}
 
 		return result;
@@ -480,7 +475,7 @@ public class IndentAction extends TextEditorAction {
 		int max= lineInfo.getOffset() + lineInfo.getLength() - 1;
 
 		int pairCount= 0;
-		while (offset < max && document.get(offset, 2).equals("//")) { //$NON-NLS-1$
+		while (offset < max && "//".equals(document.get(offset, 2))) { //$NON-NLS-1$
 			pairCount++;
 			offset= offset + 2;
 		}
@@ -605,11 +600,11 @@ public class IndentAction extends TextEditorAction {
 			return 0;
 		else {
 			int size= 0;
-			int l= indent.length();
 			int tabSize= getTabSize(project);
 
-			for (int i= 0; i < l; i++)
-				size += indent.charAt(i) == '\t' ? tabSize : 1;
+			for (char c : indent.toCharArray()) {
+				size += c == '\t' ? tabSize : 1;
+			}
 			return size;
 		}
 	}
@@ -625,10 +620,12 @@ public class IndentAction extends TextEditorAction {
 		String tab;
 		if (JavaCore.SPACE.equals(getCoreFormatterOption(DefaultCodeFormatterConstants.FORMATTER_TAB_CHAR, project))) {
 			int size= getTabSize(project);
-			StringBuilder buf= new StringBuilder();
-			for (int i= 0; i< size; i++)
-				buf.append(' ');
-			tab= buf.toString();
+
+			if (size < 1) {
+				tab= ""; //$NON-NLS-1$
+			} else {
+				tab= String.format("%" + size + "s", ""); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+			}
 		} else
 			tab= "\t"; //$NON-NLS-1$
 
@@ -877,7 +874,7 @@ public class IndentAction extends TextEditorAction {
 			if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_ON_COLUMN) {
 				String newStr= indentation;
 				int length= IndentAction.measureLengthInSpaces(stringTocalculate, CodeFormatterUtil.getTabWidth(javaProject));
-				String str= IndentAction.EMPTY_STR;
+				StringBuilder str= new StringBuilder();
 				if (getUseTabsOnlyForLeadingIndentations(javaProject)) {
 					int existing= IndentAction.measureLengthInSpaces(indentation, CodeFormatterUtil.getTabWidth(javaProject));
 					if (length - existing > 0) {
@@ -887,37 +884,37 @@ public class IndentAction extends TextEditorAction {
 					}
 				} else {
 					for (int i= 0; i < length; i++) {
-						str+= IndentAction.SPACE_STR;
+						str.append(IndentAction.SPACE_STR);
 					}
-					int units= Strings.computeIndentUnits(str, javaProject);
+					int units= Strings.computeIndentUnits(str.toString(), javaProject);
 					newStr= CodeFormatterUtil.createIndentString(units, javaProject);
 					int newLength= IndentManipulation.measureIndentInSpaces(newStr, CodeFormatterUtil.getTabWidth(javaProject));
 					if (newLength < length) {
-						if (formatterTabValue.equals(DefaultCodeFormatterConstants.MIXED) || formatterTabValue.equals(JavaCore.SPACE)) {
+						if (DefaultCodeFormatterConstants.MIXED.equals(formatterTabValue) || JavaCore.SPACE.equals(formatterTabValue)) {
 							for (int i= newLength; i < length; i++) {
 								newStr+= IndentAction.SPACE_STR;
 							}
-						} else if (formatterTabValue.equals(JavaCore.TAB)) {
+						} else if (JavaCore.TAB.equals(formatterTabValue)) {
 							newStr+= tabString;
 						}
 					}
 				}
 				indentation= newStr;
 			} else if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_BY_ONE) {
-				if (formatterTabValue.equals(JavaCore.TAB)
-						|| formatterTabValue.equals(DefaultCodeFormatterConstants.MIXED)) {
+				if (JavaCore.TAB.equals(formatterTabValue)
+						|| DefaultCodeFormatterConstants.MIXED.equals(formatterTabValue)) {
 					indentation+= tabString;
-				} else if (formatterTabValue.equals(JavaCore.SPACE)) {
+				} else if (JavaCore.SPACE.equals(formatterTabValue)) {
 					indentation+= tabSpaceString;
 				}
 			} else if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_PRESERVE) {
 				indentation= IndentAction.EMPTY_STR;
 			} else if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_DEFAULT) {
 				String indentString= EMPTY_STR;
-				if (formatterTabValue.equals(JavaCore.TAB)
-						|| formatterTabValue.equals(DefaultCodeFormatterConstants.MIXED)) {
+				if (JavaCore.TAB.equals(formatterTabValue)
+						|| DefaultCodeFormatterConstants.MIXED.equals(formatterTabValue)) {
 					indentString= tabString;
-				} else if (formatterTabValue.equals(JavaCore.SPACE)) {
+				} else if (JavaCore.SPACE.equals(formatterTabValue)) {
 					indentString= tabSpaceString;
 				}
 				int count= getFormatterContinuationIndentation(javaProject);
@@ -942,7 +939,7 @@ public class IndentAction extends TextEditorAction {
 		if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_ON_COLUMN) {
 			String newStr= indentation;
 			int length= IndentAction.measureLengthInSpaces(stringTocalculate, CodeFormatterUtil.getTabWidth(javaProject));
-			String str= IndentAction.EMPTY_STR;
+			StringBuilder str= new StringBuilder();
 			if (getUseTabsOnlyForLeadingIndentations(javaProject)) {
 				int existing= IndentAction.measureLengthInSpaces(indentation, CodeFormatterUtil.getTabWidth(javaProject));
 				if (length - existing > 0) {
@@ -952,37 +949,37 @@ public class IndentAction extends TextEditorAction {
 				}
 			} else {
 				for (int i= 0; i < length; i++) {
-					str+= IndentAction.SPACE_STR;
+					str.append(IndentAction.SPACE_STR);
 				}
-				int units= Strings.computeIndentUnits(str, javaProject);
+				int units= Strings.computeIndentUnits(str.toString(), javaProject);
 				newStr= CodeFormatterUtil.createIndentString(units, javaProject);
 				int newLength= IndentManipulation.measureIndentInSpaces(newStr, CodeFormatterUtil.getTabWidth(javaProject));
 				if (newLength < length) {
-					if (formatterTabValue.equals(DefaultCodeFormatterConstants.MIXED) || formatterTabValue.equals(JavaCore.SPACE)) {
+					if (DefaultCodeFormatterConstants.MIXED.equals(formatterTabValue) || JavaCore.SPACE.equals(formatterTabValue)) {
 						for (int i= newLength; i < length; i++) {
 							newStr+= IndentAction.SPACE_STR;
 						}
-					} else if (formatterTabValue.equals(JavaCore.TAB)) {
+					} else if (JavaCore.TAB.equals(formatterTabValue)) {
 						newStr+= tabString;
 					}
 				}
 			}
 			indentation= newStr;
 		} else if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_BY_ONE) {
-			if (formatterTabValue.equals(JavaCore.TAB)
-					|| formatterTabValue.equals(DefaultCodeFormatterConstants.MIXED)) {
+			if (JavaCore.TAB.equals(formatterTabValue)
+					|| DefaultCodeFormatterConstants.MIXED.equals(formatterTabValue)) {
 				indentation+= tabString;
-			} else if (formatterTabValue.equals(JavaCore.SPACE)) {
+			} else if (JavaCore.SPACE.equals(formatterTabValue)) {
 				indentation+= tabSpaceString;
 			}
 		} else if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_PRESERVE) {
 			indentation= IndentAction.EMPTY_STR;
 		} else if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_DEFAULT) {
 			String indentString= EMPTY_STR;
-			if (formatterTabValue.equals(JavaCore.TAB)
-					|| formatterTabValue.equals(DefaultCodeFormatterConstants.MIXED)) {
+			if (JavaCore.TAB.equals(formatterTabValue)
+					|| DefaultCodeFormatterConstants.MIXED.equals(formatterTabValue)) {
 				indentString= tabString;
-			} else if (formatterTabValue.equals(JavaCore.SPACE)) {
+			} else if (JavaCore.SPACE.equals(formatterTabValue)) {
 				indentString= tabSpaceString;
 			}
 			int count= getFormatterContinuationIndentation(javaProject);
@@ -999,7 +996,7 @@ public class IndentAction extends TextEditorAction {
 		if (textBlockIndentationOption != null) {
 			Integer iVal= Integer.valueOf(textBlockIndentationOption);
 			if (iVal != null) {
-				val= iVal.intValue();
+				val= iVal;
 			}
 		}
 		return val;
@@ -1009,7 +1006,7 @@ public class IndentAction extends TextEditorAction {
 		boolean val= false;
 		String useTabsOnlyForLeadingIndentations= getCoreFormatterOption(DefaultCodeFormatterConstants.FORMATTER_USE_TABS_ONLY_FOR_LEADING_INDENTATIONS, javaProject);
 		if (useTabsOnlyForLeadingIndentations != null) {
-			val= (Boolean.valueOf(useTabsOnlyForLeadingIndentations)).booleanValue();
+			val= Boolean.parseBoolean(useTabsOnlyForLeadingIndentations);
 		}
 		return val;
 	}
@@ -1027,9 +1024,8 @@ public class IndentAction extends TextEditorAction {
 	}
 
 	private static String getTabSpaceString(IJavaProject javaProject) {
-		String tabString= "";
 		int tabWidth= CodeFormatterUtil.getTabWidth(javaProject);
-		tabString= EMPTY_STR;
+		String tabString= EMPTY_STR;
 		for (int i= 0; i < tabWidth; i++) {
 			tabString+= SPACE_STR;
 		}
