@@ -424,7 +424,7 @@ public class SourceActionDialog extends CheckedTreeSelectionDialog {
 		return composite;
 	}
 
-	protected Text createFilterComposite(@SuppressWarnings("unused") Composite inner) {
+	protected Text createFilterComposite(Composite inner) {
 		return null; // No filter as default
 	}
 
@@ -509,8 +509,8 @@ public class SourceActionDialog extends CheckedTreeSelectionDialog {
 
 	private List<Integer> convertToIntegerList(int[] array) {
 		List<Integer> result= new ArrayList<>(array.length);
-		for (int i= 0; i < array.length; i++) {
-			result.add(Integer.valueOf(array[i]));
+		for (int element : array) {
+			result.add(element);
 		}
 		return result;
 	}
@@ -557,11 +557,11 @@ public class SourceActionDialog extends CheckedTreeSelectionDialog {
 			ActionMessages.SourceActionDialog_modifier_private,
 		};
 		Integer[] data= new Integer[] {
-					Integer.valueOf(Modifier.PUBLIC),
-					Integer.valueOf(Modifier.PROTECTED),
-					Integer.valueOf(Modifier.NONE),
-					Integer.valueOf(Modifier.PRIVATE)};
-		Integer initialVisibility= Integer.valueOf(correctVisibility);
+					Modifier.PUBLIC,
+					Modifier.PROTECTED,
+					Modifier.NONE,
+					Modifier.PRIVATE};
+		Integer initialVisibility= correctVisibility;
 		for (int i= 0; i < labels.length; i++) {
 			Button radio= new Button(group, SWT.RADIO);
 			Integer visibilityCode= data[i];
@@ -573,7 +573,7 @@ public class SourceActionDialog extends CheckedTreeSelectionDialog {
 			radio.addSelectionListener(new SelectionAdapter() {
 				@Override
 				public void widgetSelected(SelectionEvent event) {
-					visibilityChangeListener.visibilityChanged(((Integer)event.widget.getData()).intValue());
+					visibilityChangeListener.visibilityChanged(((Integer)event.widget.getData()));
 				}
 			});
 		}
@@ -593,7 +593,7 @@ public class SourceActionDialog extends CheckedTreeSelectionDialog {
 		finalCheckboxButton.addSelectionListener(new SelectionListener() {
 			@Override
 			public void widgetSelected(SelectionEvent event) {
-				visibilityChangeListener.modifierChanged(((Integer)event.widget.getData()).intValue(), ((Button) event.widget).getSelection());
+				visibilityChangeListener.modifierChanged(((Integer)event.widget.getData()), ((Button) event.widget).getSelection());
 			}
 
 			@Override
@@ -612,7 +612,7 @@ public class SourceActionDialog extends CheckedTreeSelectionDialog {
 		syncCheckboxButton.addSelectionListener(new SelectionListener() {
 			@Override
 			public void widgetSelected(SelectionEvent event) {
-				visibilityChangeListener.modifierChanged(((Integer)event.widget.getData()).intValue(), ((Button) event.widget).getSelection());
+				visibilityChangeListener.modifierChanged(((Integer)event.widget.getData()), ((Button) event.widget).getSelection());
 			}
 
 			@Override
@@ -718,7 +718,6 @@ public class SourceActionDialog extends CheckedTreeSelectionDialog {
 		return JavaPlugin.getDefault().getDialogSettingsSection("DialogBounds_" + getClass().getSimpleName()); //$NON-NLS-1$
 	}
 
-	@SuppressWarnings("unused")
 	protected void addMethodSearchFilter(Text filterText, CheckboxTreeViewer treeViewer) {
 		//Default is do nothing
 	}
