@@ -16,18 +16,14 @@ package org.eclipse.jdt.internal.ui.javaeditor;
 
 import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.StackLayout;
 import org.eclipse.swt.custom.StyledText;
-import org.eclipse.swt.events.DisposeEvent;
-import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
 import org.eclipse.swt.graphics.Color;
-import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -92,6 +88,7 @@ import org.eclipse.jdt.core.util.ClassFileBytesDisassembler;
 import org.eclipse.jdt.core.util.ClassFormatException;
 
 import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
+import org.eclipse.jdt.internal.corext.fix.ExternalNullAnnotationChangeProposals;
 import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.internal.corext.util.Messages;
 
@@ -106,18 +103,14 @@ import org.eclipse.jdt.internal.ui.actions.CompositeActionGroup;
 import org.eclipse.jdt.internal.ui.util.ExceptionHandler;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.SourceAttachmentBlock;
 
-
 /**
  * Java specific text editor.
  */
 public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProvider.InputChangeListener {
-
-
 	/**
 	 * A form to attach source to a class file.
 	 */
 	private class SourceAttachmentForm implements IPropertyChangeListener {
-
 		private final IClassFile fFile;
 		private Composite fComposite;
 		private Color fBackgroundColor;
@@ -125,7 +118,6 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 		private Color fSeparatorColor;
 		private List<Label> fBannerLabels= new ArrayList<>();
 		private List<Label> fHeaderLabels= new ArrayList<>();
-		private Font fFont;
 
 		/**
 		 * Creates a source attachment form for a class file.
@@ -143,10 +135,10 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 		 * @return the package fragment root of the given class file
 		 */
 		private IPackageFragmentRoot getPackageFragmentRoot(IClassFile file) {
-
 			IJavaElement element= file.getParent();
-			while (element != null && element.getElementType() != IJavaElement.PACKAGE_FRAGMENT_ROOT)
+			while (element != null && element.getElementType() != IJavaElement.PACKAGE_FRAGMENT_ROOT) {
 				element= element.getParent();
+			}
 
 			return (IPackageFragmentRoot) element;
 		}
@@ -158,7 +150,6 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 		 * @return the creates source attachment form
 		 */
 		public Control createControl(Composite parent) {
-
 			Display display= parent.getDisplay();
 			fBackgroundColor= display.getSystemColor(SWT.COLOR_LIST_BACKGROUND);
 			fForegroundColor= display.getSystemColor(SWT.COLOR_LIST_FOREGROUND);
@@ -168,20 +159,12 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 
 			fComposite= createComposite(parent);
 			fComposite.setLayout(new GridLayout());
-			fComposite.addDisposeListener(new DisposeListener() {
-				@Override
-				public void widgetDisposed(DisposeEvent e) {
-					JFaceResources.getFontRegistry().removeListener(SourceAttachmentForm.this);
-					fComposite= null;
-					fSeparatorColor.dispose();
-					fSeparatorColor= null;
-					fBannerLabels.clear();
-					fHeaderLabels.clear();
-					if (fFont != null) {
-						fFont.dispose();
-						fFont= null;
-					}
-				}
+			fComposite.addDisposeListener(event -> {
+				JFaceResources.getFontRegistry().removeListener(SourceAttachmentForm.this);
+				fComposite= null;
+				fSeparatorColor= null;
+				fBannerLabels.clear();
+				fHeaderLabels.clear();
 			});
 
 			createTitleLabel(fComposite, JavaEditorMessages.SourceAttachmentForm_title);
@@ -225,10 +208,10 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 			try {
 				entry= JavaModelUtil.getClasspathEntry(root);
 			} catch (JavaModelException ex) {
-				if (ex.isDoesNotExist())
-					entry= null;
-				else
+				if (!ex.isDoesNotExist()) {
 					throw ex;
+				}
+				entry= null;
 			}
 			IPath containerPath= null;
 
@@ -258,12 +241,11 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 					return;
 				}
 				IStatus attributeStatus= initializer.getAttributeStatus(containerPath, jproject, IClasspathAttribute.SOURCE_ATTACHMENT_ENCODING);
-				canEditEncoding= !(attributeStatus.getCode() == ClasspathContainerInitializer.ATTRIBUTE_NOT_SUPPORTED || attributeStatus.getCode() == ClasspathContainerInitializer.ATTRIBUTE_READ_ONLY);
+				canEditEncoding= attributeStatus.getCode() != ClasspathContainerInitializer.ATTRIBUTE_NOT_SUPPORTED && attributeStatus.getCode() != ClasspathContainerInitializer.ATTRIBUTE_READ_ONLY;
 				entry= JavaModelUtil.findEntryInContainer(container, root.getPath());
 				Assert.isNotNull(entry);
 			}
 
-
 			Button button;
 
 			IPath path= entry.getSourceAttachmentPath();
@@ -274,7 +256,6 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 				createLabel(composite, null);
 
 				button= createButton(composite, JavaEditorMessages.SourceAttachmentForm_button_attachSource);
-
 			} else {
 				createLabel(composite, Messages.format(JavaEditorMessages.SourceAttachmentForm_message_noSourceInAttachment, BasicElementLabels.getFileName(fFile)));
 				createLabel(composite, JavaEditorMessages.SourceAttachmentForm_message_pressButtonToChange);
@@ -313,12 +294,10 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 			try {
 				IRunnableWithProgress runnable= SourceAttachmentBlock.getRunnable(shell, newEntry, project, containerPath, isReferencedEntry);
 				PlatformUI.getWorkbench().getProgressService().run(true, true, runnable);
-
 			} catch (InvocationTargetException e) {
 				String title= JavaEditorMessages.SourceAttachmentForm_attach_error_title;
 				String message= JavaEditorMessages.SourceAttachmentForm_attach_error_message;
 				ExceptionHandler.handle(e, shell, title, message);
-
 			} catch (InterruptedException e) {
 				// cancelled
 			}
@@ -329,14 +308,11 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 		 */
 		@Override
 		public void propertyChange(PropertyChangeEvent event) {
-
-			for (Iterator<Label> iterator = fBannerLabels.iterator(); iterator.hasNext();) {
-				Label label = iterator.next();
+			for (Label label : fBannerLabels) {
 				label.setFont(JFaceResources.getBannerFont());
 			}
 
-			for (Iterator<Label> iterator = fHeaderLabels.iterator(); iterator.hasNext();) {
-				Label label = iterator.next();
+			for (Label label : fHeaderLabels) {
 				label.setFont(JFaceResources.getHeaderFont());
 			}
 
@@ -374,8 +350,9 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 
 		private Label createLabel(Composite parent, String text) {
 			Label label= new Label(parent, SWT.WRAP);
-			if (text != null)
+			if (text != null) {
 				label.setText(text);
+			}
 			label.setBackground(fBackgroundColor);
 			label.setForeground(fForegroundColor);
 			GridData gd= new GridData(SWT.FILL, SWT.FILL, true, false);
@@ -385,8 +362,9 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 
 		private Label createTitleLabel(Composite parent, String text) {
 			Label label = new Label(parent, SWT.NONE);
-			if (text != null)
+			if (text != null) {
 				label.setText(text);
+			}
 			label.setBackground(fBackgroundColor);
 			label.setForeground(fForegroundColor);
 			label.setFont(JFaceResources.getHeaderFont());
@@ -396,8 +374,9 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 
 		private Label createHeadingLabel(Composite parent, String text) {
 			Label label = new Label(parent, SWT.NONE);
-			if (text != null)
+			if (text != null) {
 				label.setText(text);
+			}
 			label.setBackground(fBackgroundColor);
 			label.setForeground(fForegroundColor);
 			label.setFont(JFaceResources.getBannerFont());
@@ -409,8 +388,9 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 			Button button = new Button(parent, SWT.FLAT);
 			button.setBackground(fBackgroundColor);
 			button.setForeground(fForegroundColor);
-			if (text != null)
+			if (text != null) {
 				button.setText(text);
+			}
 			return button;
 		}
 
@@ -432,32 +412,26 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 	 *  Updater that takes care of minimizing changes of the editor input.
 	 */
 	private class InputUpdater implements Runnable {
-
 		/** Has the runnable already been posted? */
-		private boolean fPosted= false;
+		private boolean fPosted;
+
 		/** Editor input */
 		private IClassFileEditorInput fClassFileEditorInput;
 
-
-		public InputUpdater() {
-		}
-
 		/*
 		 * @see Runnable#run()
 		 */
 		@Override
 		public void run() {
-
 			IClassFileEditorInput input;
 			synchronized (this) {
 				input= fClassFileEditorInput;
 			}
 
 			try {
-
-				if (getSourceViewer() != null)
+				if (getSourceViewer() != null) {
 					setInput(input);
-
+				}
 			} finally {
 				synchronized (this) {
 					fPosted= false;
@@ -471,11 +445,11 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 		 * @param input the input to be set when executed
 		 */
 		public void post(IClassFileEditorInput input) {
-
 			synchronized(this) {
 				if (fPosted) {
-					if (isEqualInput(input, fClassFileEditorInput))
+					if (isEqualInput(input, fClassFileEditorInput)) {
 						fClassFileEditorInput= input;
+					}
 					return;
 				}
 			}
@@ -500,7 +474,6 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 		}
 	}
 
-
 	private StackLayout fStackLayout;
 	private Composite fParent;
 
@@ -530,7 +503,6 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 	 */
 	private StyledText fNoSourceTextWidget;
 
-
 	/**
 	 * Default constructor.
 	 */
@@ -624,8 +596,9 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 		if (getEditorInput() instanceof IClassFileEditorInput) {
 			IClassFileEditorInput input= (IClassFileEditorInput) getEditorInput();
 			IJavaElement parent= element.getAncestor(IJavaElement.CLASS_FILE);
-			if (input.getClassFile().equals(parent))
+			if (input.getClassFile().equals(parent)) {
 				return element;
+			}
 		}
 		return null;
 	}
@@ -660,12 +633,12 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 	 * @return the transformed editor input
 	 */
 	protected IEditorInput transformEditorInput(IEditorInput input) {
-
 		if (input instanceof IFileEditorInput) {
 			IFile file= ((IFileEditorInput) input).getFile();
 			IClassFileEditorInput classFileInput= new ExternalClassFileEditorInput(file);
-			if (classFileInput.getClassFile() != null)
+			if (classFileInput.getClassFile() != null) {
 				input= classFileInput;
+			}
 		}
 
 		return input;
@@ -698,28 +671,29 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 						IJavaModelStatusConstants.INVALID_RESOURCE,
 						JavaEditorMessages.ClassFileEditor_error_classfile_not_on_classpath,
 						null));
-			} else {
-				throw e;
 			}
+			throw e;
 		}
 
 		IDocumentProvider documentProvider= getDocumentProvider();
-		if (documentProvider instanceof ClassFileDocumentProvider)
+		if (documentProvider instanceof ClassFileDocumentProvider) {
 			((ClassFileDocumentProvider) documentProvider).removeInputChangeListener(this);
+		}
 
 		super.doSetInput(input);
 
 		documentProvider= getDocumentProvider();
-		if (documentProvider instanceof ClassFileDocumentProvider)
+		if (documentProvider instanceof ClassFileDocumentProvider) {
 			((ClassFileDocumentProvider) documentProvider).addInputChangeListener(this);
+		}
 
 		verifyInput(getEditorInput());
 
 		JavaPlugin.getDefault().getASTProvider().activeJavaEditorChanged(this);
 
-		if (fSemanticManager != null)
+		if (fSemanticManager != null) {
 			installSemanticHighlighting();
-
+		}
 	}
 
 	/*
@@ -737,15 +711,18 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 			@Override
 			protected IStatus run(IProgressMonitor monitor) {
 				CompilationUnit ast= SharedASTProviderCore.getAST(getInputJavaElement(), SharedASTProviderCore.WAIT_YES, null);
-				if (fOverrideIndicatorManager != null)
+				if (fOverrideIndicatorManager != null) {
 					fOverrideIndicatorManager.reconciled(ast, true, monitor);
+				}
 				if (fSemanticManager != null) {
 					SemanticHighlightingReconciler reconciler= fSemanticManager.getReconciler();
-					if (reconciler != null)
+					if (reconciler != null) {
 						reconciler.reconciled(ast, false, monitor);
+					}
 				}
-				if (isMarkingOccurrences())
+				if (isMarkingOccurrences()) {
 					installOccurrencesFinder(false);
+				}
 				return Status.OK_STATUS;
 			}
 		};
@@ -759,7 +736,6 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 	 */
 	@Override
 	public void createPartControl(Composite parent) {
-
 		fParent= new Composite(parent, SWT.NONE);
 		fStackLayout= new StackLayout();
 		fParent.setLayout(fStackLayout);
@@ -782,8 +758,9 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 	}
 
 	private JavaModelException probeInputForSource(IEditorInput input) {
-		if (input == null)
+		if (input == null) {
 			return null;
+		}
 
 		IClassFileEditorInput classFileEditorInput= (IClassFileEditorInput) input;
 		IClassFile file= classFileEditorInput.getClassFile();
@@ -804,9 +781,9 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 	 * @throws JavaModelException if an exception occurs while accessing its corresponding resource
 	 */
 	private void verifyInput(IEditorInput input) throws JavaModelException {
-
-		if (fParent == null || input == null)
+		if (fParent == null || input == null) {
 			return;
+		}
 
 		IClassFileEditorInput classFileEditorInput= (IClassFileEditorInput) input;
 		IClassFile file= classFileEditorInput.getClassFile();
@@ -818,10 +795,10 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 
 		// show source attachment form if no source found
 		if (file.getSourceRange() == null) {
-
 			// dispose old source attachment form
-			if (fSourceAttachmentForm != null)
+			if (fSourceAttachmentForm != null) {
 				fSourceAttachmentForm.dispose();
+			}
 
 			SourceAttachmentForm form= new SourceAttachmentForm(file);
 			fSourceAttachmentForm= form.createControl(fParent);
@@ -839,11 +816,11 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 				};
 				copyAction.setActionDefinitionId(IWorkbenchCommandConstants.EDIT_COPY);
 				setAction(ITextEditorActionConstants.COPY, copyAction);
-				copyAction.setEnabled(fNoSourceTextWidget.getSelectionText().length() > 0);
+				copyAction.setEnabled(!fNoSourceTextWidget.getSelectionText().isEmpty());
 				fNoSourceTextWidget.addSelectionListener(new SelectionListener() {
 					@Override
 					public void widgetSelected(SelectionEvent e) {
-						copyAction.setEnabled(fNoSourceTextWidget.getSelectionText().length() > 0);
+						copyAction.setEnabled(!fNoSourceTextWidget.getSelectionText().isEmpty());
 					}
 					@Override
 					public void widgetDefaultSelected(SelectionEvent e) {
@@ -860,14 +837,11 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 				};
 				selectAllAction.setActionDefinitionId(IWorkbenchCommandConstants.EDIT_SELECT_ALL);
 				setAction(ITextEditorActionConstants.SELECT_ALL, selectAllAction);
-				copyAction.setEnabled(fNoSourceTextWidget.getSelectionText().length() > 0);
+				copyAction.setEnabled(!fNoSourceTextWidget.getSelectionText().isEmpty());
 				copyQualifiedName.setEnabled(false);
-
-
 			}
 
 			annotateAction.setEnabled(false);
-
 		} else { // show source viewer
 
 			if (fSourceAttachmentForm != null) {
@@ -884,9 +858,9 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 
 			IJavaProject javaProject= file.getJavaProject();
 			boolean useExternalAnnotations= javaProject != null
-					&& javaProject.getOption(JavaCore.COMPILER_ANNOTATION_NULL_ANALYSIS, true).equals(JavaCore.ENABLED);
+					&& JavaCore.ENABLED.equals(javaProject.getOption(JavaCore.COMPILER_ANNOTATION_NULL_ANALYSIS, true))
+					&& ExternalNullAnnotationChangeProposals.hasAnnotationPathInWorkspace(javaProject, file);
 			annotateAction.setEnabled(useExternalAnnotations);
-
 		}
 
 		IAction currentCopyAction= getAction(ITextEditorActionConstants.COPY);
@@ -897,8 +871,7 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 			if (isUsingSourceCopyAction) {
 				createNavigationActions();
 			} else {
-				for (int i= 0; i < ACTION_MAP.length; i++) {
-					IdMapEntry entry= ACTION_MAP[i];
+				for (IdMapEntry entry : ACTION_MAP) {
 					actionBars.setGlobalActionHandler(entry.getActionId(), null);
 					setAction(entry.getActionId(), null);
 				}
@@ -908,7 +881,6 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 			actionBars.setGlobalActionHandler(ITextEditorActionConstants.SELECT_ALL, getAction(ITextEditorActionConstants.SELECT_ALL));
 			actionBars.updateActionBars();
 		}
-
 	}
 
 	/*
@@ -925,26 +897,19 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 	@Override
 	protected ISourceViewer createJavaSourceViewer(Composite parent, IVerticalRuler ruler, IOverviewRuler overviewRuler, boolean isOverviewRulerVisible, int styles, IPreferenceStore store) {
 		return new JavaSourceViewer(parent, ruler, overviewRuler, isOverviewRulerVisible, styles, store) {
-
 			@Override
 			public boolean requestWidgetToken(IWidgetTokenKeeper requester) {
-				if (PlatformUI.getWorkbench().getHelpSystem().isContextHelpDisplayed())
-					return false;
-				return super.requestWidgetToken(requester);
+				return !PlatformUI.getWorkbench().getHelpSystem().isContextHelpDisplayed() && super.requestWidgetToken(requester);
 			}
 
 			@Override
 			public boolean requestWidgetToken(IWidgetTokenKeeper requester, int priority) {
-				if (PlatformUI.getWorkbench().getHelpSystem().isContextHelpDisplayed())
-					return false;
-				return super.requestWidgetToken(requester, priority);
+				return !PlatformUI.getWorkbench().getHelpSystem().isContextHelpDisplayed() && super.requestWidgetToken(requester, priority);
 			}
-			
+
 			@Override
 			public boolean canDoOperation(int operation) {
-				if (operation == JavaSourceViewer.ANNOTATE_CLASS_FILE)
-					return true;
-				return super.canDoOperation(operation);
+				return operation == JavaSourceViewer.ANNOTATE_CLASS_FILE || super.canDoOperation(operation);
 			}
 
 			@Override
@@ -968,8 +933,9 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 	public void dispose() {
 		// http://bugs.eclipse.org/bugs/show_bug.cgi?id=18510
 		IDocumentProvider documentProvider= getDocumentProvider();
-		if (documentProvider instanceof ClassFileDocumentProvider)
+		if (documentProvider instanceof ClassFileDocumentProvider) {
 			((ClassFileDocumentProvider) documentProvider).removeInputChangeListener(this);
+		}
 		super.dispose();
 	}
 
@@ -980,8 +946,8 @@ public class ClassFileEditor extends JavaEditor implements ClassFileDocumentProv
 	public void setFocus() {
 		super.setFocus();
 
-		if (fSourceAttachmentForm != null && !fSourceAttachmentForm.isDisposed())
+		if (fSourceAttachmentForm != null && !fSourceAttachmentForm.isDisposed()) {
 			fSourceAttachmentForm.setFocus();
+		}
 	}
-
 }
