@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -56,7 +56,6 @@ import org.eclipse.jface.text.DocumentCommand;
 import org.eclipse.jface.text.DocumentEvent;
 import org.eclipse.jface.text.IDocument;
 import org.eclipse.jface.text.IDocumentExtension;
-import org.eclipse.jface.text.IDocumentListener;
 import org.eclipse.jface.text.IPositionUpdater;
 import org.eclipse.jface.text.IRegion;
 import org.eclipse.jface.text.ITextOperationTarget;
@@ -289,7 +288,7 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 						if (document.getChar(offset - 1) == '{')
 							return new ExitFlags(ILinkedModeListener.EXIT_ALL, true);
 
-						// see bug 308217: while overriding a method and using '(' followed by parameter type to filter the content assist proposals, if ')' is added 
+						// see bug 308217: while overriding a method and using '(' followed by parameter type to filter the content assist proposals, if ')' is added
 						// automatically on typing '(', pressing return key should not result in jumping after ')' instead of applying the selected proposal.
 						if (document.getChar(offset) == ')' && sourceViewer instanceof AdaptedSourceViewer && ((AdaptedSourceViewer) sourceViewer).getContentAssistant() instanceof ContentAssistant) {
 							ContentAssistant contentAssistant= (ContentAssistant) ((AdaptedSourceViewer) sourceViewer).getContentAssistant();
@@ -357,9 +356,7 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 			try {
 				Position[] positions= event.getDocument().getPositions(fCategory);
 
-				for (int i= 0; i != positions.length; i++) {
-
-					Position position= positions[i];
+				for (Position position : positions) {
 
 					if (position.isDeleted())
 						continue;
@@ -426,17 +423,16 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 			return identifier.length() > 0
 					&& Character.isUpperCase(identifier.charAt(0));
 		}
-		
+
 		private boolean isAngularIntroducer(String identifier) {
 			return identifier.length() > 0
 					&& (Character.isUpperCase(identifier.charAt(0))
 							|| identifier.startsWith("final") //$NON-NLS-1$
 							|| identifier.startsWith("public") //$NON-NLS-1$
-							|| identifier.startsWith("public") //$NON-NLS-1$
 							|| identifier.startsWith("protected") //$NON-NLS-1$
 							|| identifier.startsWith("private")); //$NON-NLS-1$
 		}
-		
+
 		private boolean isMultilineSelection() {
 			ISelection selection= getSelectionProvider().getSelection();
 			if (selection instanceof ITextSelection) {
@@ -494,7 +490,7 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 						break;
 
 					case '<':
-						if (!(fCloseAngularBrackets && fCloseBrackets)
+						if (!fCloseAngularBrackets || !fCloseBrackets
 								|| nextToken == Symbols.TokenLESSTHAN
 								|| nextToken == Symbols.TokenQUESTIONMARK
 								|| nextToken == Symbols.TokenIDENT && isTypeArgumentStart(next)
@@ -579,9 +575,7 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 
 				event.doit= false;
 
-			} catch (BadLocationException e) {
-				JavaPlugin.log(e);
-			} catch (BadPositionCategoryException e) {
+			} catch (BadLocationException | BadPositionCategoryException e) {
 				JavaPlugin.log(e);
 			}
 		}
@@ -602,30 +596,26 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 			final IDocument document= sourceViewer.getDocument();
 			if (document instanceof IDocumentExtension) {
 				IDocumentExtension extension= (IDocumentExtension) document;
-				extension.registerPostNotificationReplace(null, new IDocumentExtension.IReplace() {
-
-					@Override
-					public void perform(IDocument d, IDocumentListener owner) {
-						if ((level.fFirstPosition.isDeleted || level.fFirstPosition.length == 0)
-								&& !level.fSecondPosition.isDeleted
-								&& level.fSecondPosition.offset == level.fFirstPosition.offset)
-						{
-							try {
-								document.replace(level.fSecondPosition.offset,
-												 level.fSecondPosition.length,
-												 ""); //$NON-NLS-1$
-							} catch (BadLocationException e) {
-								JavaPlugin.log(e);
-							}
+				extension.registerPostNotificationReplace(null, (d, owner) -> {
+					if ((level.fFirstPosition.isDeleted || level.fFirstPosition.length == 0)
+							&& !level.fSecondPosition.isDeleted
+							&& level.fSecondPosition.offset == level.fFirstPosition.offset)
+					{
+						try {
+							document.replace(level.fSecondPosition.offset,
+											 level.fSecondPosition.length,
+											 ""); //$NON-NLS-1$
+						} catch (BadLocationException e1) {
+							JavaPlugin.log(e1);
 						}
+					}
 
-						if (fBracketLevelStack.size() == 0) {
-							document.removePositionUpdater(fUpdater);
-							try {
-								document.removePositionCategory(CATEGORY);
-							} catch (BadPositionCategoryException e) {
-								JavaPlugin.log(e);
-							}
+					if (fBracketLevelStack.isEmpty()) {
+						document.removePositionUpdater(fUpdater);
+						try {
+							document.removePositionCategory(CATEGORY);
+						} catch (BadPositionCategoryException e2) {
+							JavaPlugin.log(e2);
 						}
 					}
 				});
@@ -1012,8 +1002,6 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 	private final static String CLOSE_BRACKETS= PreferenceConstants.EDITOR_CLOSE_BRACKETS;
 
 
-	/** The editor's save policy */
-	protected ISavePolicy fSavePolicy;
 	/** Listener to annotation model changes that updates the error tick in the tab image */
 	private JavaEditorErrorTickUpdater fJavaEditorErrorTickUpdater;
 	/**
@@ -1062,7 +1050,6 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 		setRulerContextMenuId("#CompilationUnitRulerContext"); //$NON-NLS-1$
 		setOutlinerContextMenuId("#CompilationUnitOutlinerContext"); //$NON-NLS-1$
 		// don't set help contextId, we install our own help context
-		fSavePolicy= null;
 
 		fJavaEditorErrorTickUpdater= new JavaEditorErrorTickUpdater(this);
 		fCorrectionCommands= null;
@@ -1179,7 +1166,7 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 
 	/**
 	 * Returns the refactor action group.
-	 * 
+	 *
 	 * @return the refactor action group, or <code>null</code> if there is none
 	 * @since 3.5
 	 */
@@ -1189,7 +1176,7 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 
 	/**
 	 * Returns the generate action group.
-	 * 
+	 *
 	 * @return the generate action group, or <code>null</code> if there is none
 	 * @since 3.5
 	 */
@@ -1269,7 +1256,7 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 		IDocumentProvider p= getDocumentProvider();
 		if (p instanceof ICompilationUnitDocumentProvider) {
 			ICompilationUnitDocumentProvider cp= (ICompilationUnitDocumentProvider) p;
-			cp.setSavePolicy(fSavePolicy);
+			cp.setSavePolicy(null);
 		}
 		try {
 			super.performSave(overwrite, progressMonitor);
@@ -1477,6 +1464,7 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 			int tabWidth= config.getTabWidth(sourceViewer);
 			TabsToSpacesConverter tabToSpacesConverter= new TabsToSpacesConverter();
 			tabToSpacesConverter.setNumberOfSpacesPerTab(tabWidth);
+			tabToSpacesConverter.setDeleteSpacesAsTab(isSpacesAsTabsDeletionEnabled());
 			IDocumentProvider provider= getDocumentProvider();
 			if (provider instanceof ICompilationUnitDocumentProvider) {
 				ICompilationUnitDocumentProvider cup= (ICompilationUnitDocumentProvider) provider;
@@ -1580,8 +1568,6 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 				return '[';
 
 			case '"':
-				return character;
-
 			case '\'':
 				return character;
 
@@ -1603,34 +1589,33 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 
 				String p= event.getProperty();
 
-				if (CLOSE_BRACKETS.equals(p)) {
-					fBracketInserter.setCloseBracketsEnabled(getPreferenceStore().getBoolean(p));
-					return;
-				}
-
-				if (CLOSE_STRINGS.equals(p)) {
-					fBracketInserter.setCloseStringsEnabled(getPreferenceStore().getBoolean(p));
-					return;
-				}
-
-				if (JavaCore.COMPILER_SOURCE.equals(p)) {
-					boolean closeAngularBrackets= JavaCore.compareJavaVersions(JavaCore.VERSION_1_5, getPreferenceStore().getString(p)) <= 0;
-					fBracketInserter.setCloseAngularBracketsEnabled(closeAngularBrackets);
-				}
-
-				if (SPACES_FOR_TABS.equals(p)) {
-					if (isTabsToSpacesConversionEnabled())
-						installTabsToSpacesConverter();
-					else
-						uninstallTabsToSpacesConverter();
-					return;
-				}
-
-				if (PreferenceConstants.EDITOR_SMART_TAB.equals(p)) {
-					if (getPreferenceStore().getBoolean(PreferenceConstants.EDITOR_SMART_TAB)) {
-						setActionActivationCode("IndentOnTab", '\t', -1, SWT.NONE); //$NON-NLS-1$
-					} else {
-						removeActionActivationCode("IndentOnTab"); //$NON-NLS-1$
+				if (p != null) {
+					switch (p) {
+						case CLOSE_BRACKETS:
+							fBracketInserter.setCloseBracketsEnabled(getPreferenceStore().getBoolean(p));
+							return;
+						case CLOSE_STRINGS:
+							fBracketInserter.setCloseStringsEnabled(getPreferenceStore().getBoolean(p));
+							return;
+						case SPACES_FOR_TABS:
+							if (isTabsToSpacesConversionEnabled())
+								installTabsToSpacesConverter();
+							else
+								uninstallTabsToSpacesConverter();
+							return;
+						case JavaCore.COMPILER_SOURCE:
+							boolean closeAngularBrackets= JavaCore.compareJavaVersions(JavaCore.VERSION_1_5, getPreferenceStore().getString(p)) <= 0;
+							fBracketInserter.setCloseAngularBracketsEnabled(closeAngularBrackets);
+							break;
+						case PreferenceConstants.EDITOR_SMART_TAB:
+							if (getPreferenceStore().getBoolean(PreferenceConstants.EDITOR_SMART_TAB)) {
+								setActionActivationCode("IndentOnTab", '\t', -1, SWT.NONE); //$NON-NLS-1$
+							} else {
+								removeActionActivationCode("IndentOnTab"); //$NON-NLS-1$
+							}
+							break;
+						default:
+							break;
 					}
 				}
 
@@ -1697,12 +1682,7 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 		if (!forced && !progressMonitor.isCanceled()) {
 			Shell shell= getSite().getShell();
 			if (shell != null && !shell.isDisposed()) {
-				shell.getDisplay().asyncExec(new Runnable() {
-					@Override
-					public void run() {
-						selectionChanged();
-					}
-				});
+				shell.getDisplay().asyncExec(this::selectionChanged);
 			}
 		}
 	}
@@ -1719,7 +1699,7 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 		if (page == null)
 			return false;
 		IEditorPart activeEditor= page.getActiveEditor();
-		return activeEditor != null && activeEditor.equals(this);
+		return activeEditor != null && this.equals(activeEditor);
 	}
 
 	/**
@@ -1855,7 +1835,7 @@ public class CompilationUnitEditor extends JavaEditor implements IJavaReconcilin
 
 	/**
 	 * Returns the correction command installer.
-	 * 
+	 *
 	 * @return the correction command installer, or <code>null</code> if there is none
 	 * @since 3.5
 	 */
