@@ -15,8 +15,10 @@ package org.eclipse.jdt.internal.ui.javaeditor;
 
 import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
 
 import org.osgi.framework.Bundle;
@@ -259,10 +261,10 @@ public class EditorUtility {
 		// Support for non-Java editor
 		try {
 			ISourceRange range= null;
-			if (element instanceof ICompilationUnit)
-				return;
-			else if (element instanceof IClassFile)
+			if (element instanceof ICompilationUnit
+					|| element instanceof IClassFile) {
 				return;
+			}
 
 			if (element instanceof ISourceReference)
 				range= ((ISourceReference)element).getNameRange();
@@ -311,9 +313,11 @@ public class EditorUtility {
 					protected void execute(IProgressMonitor monitor) throws CoreException {
 						IMarker marker= null;
 						try {
-							marker= ((IFileEditorInput)input).getFile().createMarker(IMarker.TEXT);
-							marker.setAttribute(IMarker.CHAR_START, offset);
-							marker.setAttribute(IMarker.CHAR_END, offset + length);
+							Map<String,Object> attributes = new HashMap<>();
+							attributes.put(IMarker.CHAR_START, Integer.valueOf(offset));
+							attributes.put(IMarker.CHAR_END, Integer.valueOf(offset + length));
+
+							marker= ((IFileEditorInput)input).getFile().createMarker(IMarker.TEXT, attributes);
 
 							gotoMarkerTarget.gotoMarker(marker);
 
@@ -414,7 +418,7 @@ public class EditorUtility {
 	public static String getEditorID(IEditorInput input) throws PartInitException {
 		Assert.isNotNull(input);
 		if (input instanceof IFileEditorInput)
-			return IDE.getEditorDescriptor(((IFileEditorInput)input).getFile()).getId();
+			return IDE.getEditorDescriptor(((IFileEditorInput)input).getFile(), true, false).getId();
 
 		String name= input.getName();
 
@@ -435,7 +439,7 @@ public class EditorUtility {
 			}
 		}
 
-		return IDE.getEditorDescriptor(name).getId();
+		return IDE.getEditorDescriptor(name, true, false).getId();
 	}
 
 	/**
@@ -885,4 +889,7 @@ public class EditorUtility {
 		return new NullProgressMonitor();
 	}
 
+	private EditorUtility() {
+	}
+
 }
