@@ -84,8 +84,8 @@ public class TypeFilterPreferencePage extends PreferencePage implements IWorkben
 
 	private static String packOrderList(List<String> orderList) {
 		StringBuilder buf= new StringBuilder();
-		for (int i= 0; i < orderList.size(); i++) {
-			buf.append(orderList.get(i));
+		for (String element : orderList) {
+			buf.append(element);
 			buf.append(';');
 		}
 		return buf.toString();
