@@ -31,9 +31,16 @@ final class FormatterMessages extends NLS {
 		// Do not instantiate
 	}
 
+	public static String FormatterModifyDialog_blankLines_pref_after_code_block;
 	public static String FormatterModifyDialog_blankLines_pref_after_import;
+	public static String FormatterModifyDialog_blankLines_pref_after_last_decl;
 	public static String FormatterModifyDialog_blankLines_pref_after_package;
+	public static String FormatterModifyDialog_blankLines_pref_at_beginning_of_code_block;
 	public static String FormatterModifyDialog_blankLines_pref_at_beginning_of_method_body;
+	public static String FormatterModifyDialog_blankLines_pref_at_end_of_code_block;
+	public static String FormatterModifyDialog_blankLines_pref_at_end_of_method_body;
+	public static String FormatterModifyDialog_blankLines_pref_before_abstract_method_decls;
+	public static String FormatterModifyDialog_blankLines_pref_before_code_block;
 	public static String FormatterModifyDialog_blankLines_pref_before_decls_of_same_kind;
 	public static String FormatterModifyDialog_blankLines_pref_before_field_decls;
 	public static String FormatterModifyDialog_blankLines_pref_before_first_decl;
@@ -42,11 +49,14 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_blankLines_pref_before_method_decls;
 	public static String FormatterModifyDialog_blankLines_pref_before_package;
 	public static String FormatterModifyDialog_blankLines_pref_between_import_groups;
+	public static String FormatterModifyDialog_blankLines_pref_between_statement_groups_in_switch;
 	public static String FormatterModifyDialog_blankLines_pref_between_type_declarations;
 	public static String FormatterModifyDialog_blankLines_pref_empty_lines_to_preserve;
 	public static String FormatterModifyDialog_blankLines_tree_blank_lines;
 	public static String FormatterModifyDialog_blankLines_tree_class_declarations;
 	public static String FormatterModifyDialog_blankLines_tree_compilation_unit;
+	public static String FormatterModifyDialog_blankLines_tree_method_declarations;
+	public static String FormatterModifyDialog_blankLines_val_remove_extra_lines;
 	public static String FormatterModifyDialog_braces_pref_annotation_type_declaration;
 	public static String FormatterModifyDialog_braces_pref_anonymous_class_declaration;
 	public static String FormatterModifyDialog_braces_pref_array_initializer;
@@ -59,6 +69,8 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_braces_pref_keep_empty_array_initializer_on_one_line;
 	public static String FormatterModifyDialog_braces_pref_lambda_body;
 	public static String FormatterModifyDialog_braces_pref_method_declaration;
+	public static String FormatterModifyDialog_braces_pref_record_constructor;
+	public static String FormatterModifyDialog_braces_pref_record_declaration;
 	public static String FormatterModifyDialog_braces_pref_switch_case;
 	public static String FormatterModifyDialog_braces_tree_brace_positions;
 	public static String FormatterModifyDialog_braces_val_next_line;
@@ -66,6 +78,7 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_braces_val_next_line_on_wrap;
 	public static String FormatterModifyDialog_braces_val_same_line;
 	public static String FormatterModifyDialog_comments_pref_blank_line_before_javadoc_tags;
+	public static String FormatterModifyDialog_comments_pref_blank_line_beftween_different_tags;
 	public static String FormatterModifyDialog_comments_pref_enable_block;
 	public static String FormatterModifyDialog_comments_pref_enable_javadoc;
 	public static String FormatterModifyDialog_comments_pref_enable_line;
@@ -93,6 +106,8 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_comments_tree_block_comments;
 	public static String FormatterModifyDialog_comments_tree_comments;
 	public static String FormatterModifyDialog_comments_tree_javadocs;
+	public static String FormatterModifyDialog_indentation_info_blank_lines_before_field;
+	public static String FormatterModifyDialog_indentation_info_blank_lines_before_field_delete;
 	public static String FormatterModifyDialog_indentation_info_blank_lines_to_preserve;
 	public static String FormatterModifyDialog_indentation_pref_align_assignment_statements_on_columns;
 	public static String FormatterModifyDialog_indentation_pref_align_fields_in_columns;
@@ -104,6 +119,7 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_indentation_pref_indent_declarations_within_class_body;
 	public static String FormatterModifyDialog_indentation_pref_indent_declarations_within_enum_const;
 	public static String FormatterModifyDialog_indentation_pref_indent_declarations_within_enum_decl;
+	public static String FormatterModifyDialog_indentation_pref_indent_declarations_within_record_decl;
 	public static String FormatterModifyDialog_indentation_pref_indent_empty_lines;
 	public static String FormatterModifyDialog_indentation_pref_indent_size;
 	public static String FormatterModifyDialog_indentation_pref_indent_statements_compare_to_block;
@@ -112,6 +128,7 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_indentation_pref_indent_statements_within_switch_body;
 	public static String FormatterModifyDialog_indentation_pref_tab_policy;
 	public static String FormatterModifyDialog_indentation_pref_tab_size;
+	public static String FormatterModifyDialog_indentation_pref_text_block_indentation;
 	public static String FormatterModifyDialog_indentation_pref_use_tabs_only_for_leading_indentations;
 	public static String FormatterModifyDialog_indentation_tab_policy_MIXED;
 	public static String FormatterModifyDialog_indentation_tab_policy_SPACE;
@@ -119,11 +136,22 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_indentation_tree_align_items_in_columns;
 	public static String FormatterModifyDialog_indentation_tree_indentation;
 	public static String FormatterModifyDialog_indentation_tree_indented_elements;
+	public static String FormatterModifyDialog_indentation_val_indentation_default;
+	public static String FormatterModifyDialog_indentation_val_indentation_preserve;
 	public static String FormatterModifyDialog_lineWrap_indentation_policy_label;
 	public static String FormatterModifyDialog_lineWrap_pref_additive_operators;
 	public static String FormatterModifyDialog_lineWrap_pref_annotations_arguments;
+	public static String FormatterModifyDialog_lineWrap_pref_annotations_enum_constants;
+	public static String FormatterModifyDialog_lineWrap_pref_annotations_fields;
+	public static String FormatterModifyDialog_lineWrap_pref_annotations_local_variables;
+	public static String FormatterModifyDialog_lineWrap_pref_annotations_methods;
+	public static String FormatterModifyDialog_lineWrap_pref_annotations_packages;
+	public static String FormatterModifyDialog_lineWrap_pref_annotations_parameters;
+	public static String FormatterModifyDialog_lineWrap_pref_annotations_types;
+	public static String FormatterModifyDialog_lineWrap_pref_type_annotations;
 	public static String FormatterModifyDialog_lineWrap_pref_arguments;
 	public static String FormatterModifyDialog_lineWrap_pref_array_init;
+	public static String FormatterModifyDialog_lineWrap_pref_assertion_message;
 	public static String FormatterModifyDialog_lineWrap_pref_assignments;
 	public static String FormatterModifyDialog_lineWrap_pref_bitwise_operators;
 	public static String FormatterModifyDialog_lineWrap_pref_catch;
@@ -152,6 +180,7 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_lineWrap_pref_parameters;
 	public static String FormatterModifyDialog_lineWrap_pref_qualified_invocations;
 	public static String FormatterModifyDialog_lineWrap_pref_qualified_object_allocation_arguments;
+	public static String FormatterModifyDialog_lineWrap_pref_record_components;
 	public static String FormatterModifyDialog_lineWrap_pref_relational_operators;
 	public static String FormatterModifyDialog_lineWrap_pref_shift_operators;
 	public static String FormatterModifyDialog_lineWrap_pref_string_concatenation;
@@ -170,6 +199,7 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_lineWrap_tree_method_decls;
 	public static String FormatterModifyDialog_lineWrap_tree_module_descriptions;
 	public static String FormatterModifyDialog_lineWrap_tree_parameterized_types;
+	public static String FormatterModifyDialog_lineWrap_tree_record_decls;
 	public static String FormatterModifyDialog_lineWrap_tree_statements;
 	public static String FormatterModifyDialog_lineWrap_tree_wrapping_settings;
 	public static String FormatterModifyDialog_lineWrap_val_always_wrap_first_others_when_necessary;
@@ -213,6 +243,8 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_newLines_pref_keep_lambda_body_block_on_one_line;
 	public static String FormatterModifyDialog_newLines_pref_keep_loop_body_block_on_one_line;
 	public static String FormatterModifyDialog_newLines_pref_keep_method_body_on_one_line;
+	public static String FormatterModifyDialog_newLines_pref_keep_record_constructor_declaration_on_one_line;
+	public static String FormatterModifyDialog_newLines_pref_keep_record_declaration_on_one_line;
 	public static String FormatterModifyDialog_newLines_pref_keep_simple_getter_setter_on_one_line;
 	public static String FormatterModifyDialog_newLines_pref_keep_type_declaration_on_one_line;
 	public static String FormatterModifyDialog_newLines_pref_local_variables;
@@ -247,6 +279,7 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_parentheses_pref_lambda_declaration;
 	public static String FormatterModifyDialog_parentheses_pref_method_declaration;
 	public static String FormatterModifyDialog_parentheses_pref_method_invocation;
+	public static String FormatterModifyDialog_parentheses_pref_record_declaration;
 	public static String FormatterModifyDialog_parentheses_pref_switch_statement;
 	public static String FormatterModifyDialog_parentheses_pref_try_clause;
 	public static String FormatterModifyDialog_parentheses_tree_parentheses_positions;
@@ -287,11 +320,13 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_whiteSpace_pref_after_comma_in_method_args;
 	public static String FormatterModifyDialog_whiteSpace_pref_after_comma_in_params;
 	public static String FormatterModifyDialog_whiteSpace_pref_after_comma_in_qalloc;
+	public static String FormatterModifyDialog_whiteSpace_pref_after_comma_in_record_components;
 	public static String FormatterModifyDialog_whiteSpace_pref_after_comma_in_throws;
 	public static String FormatterModifyDialog_whiteSpace_pref_after_comma_inc;
 	public static String FormatterModifyDialog_whiteSpace_pref_after_comma_init;
 	public static String FormatterModifyDialog_whiteSpace_pref_after_comma_localvars;
 	public static String FormatterModifyDialog_whiteSpace_pref_after_ellipsis;
+	public static String FormatterModifyDialog_whiteSpace_pref_after_not_operator;
 	public static String FormatterModifyDialog_whiteSpace_pref_after_opening_angle_bracket;
 	public static String FormatterModifyDialog_whiteSpace_pref_after_opening_brace;
 	public static String FormatterModifyDialog_whiteSpace_pref_after_opening_bracket;
@@ -333,6 +368,7 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_whiteSpace_pref_before_comma_in_method_args;
 	public static String FormatterModifyDialog_whiteSpace_pref_before_comma_in_params;
 	public static String FormatterModifyDialog_whiteSpace_pref_before_comma_in_qalloc;
+	public static String FormatterModifyDialog_whiteSpace_pref_before_comma_in_record_components;
 	public static String FormatterModifyDialog_whiteSpace_pref_before_comma_in_throws;
 	public static String FormatterModifyDialog_whiteSpace_pref_before_comma_inc;
 	public static String FormatterModifyDialog_whiteSpace_pref_before_comma_init;
@@ -342,6 +378,7 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_whiteSpace_pref_before_opening_brace;
 	public static String FormatterModifyDialog_whiteSpace_pref_before_opening_brace_decl;
 	public static String FormatterModifyDialog_whiteSpace_pref_before_opening_brace_enum_const;
+	public static String FormatterModifyDialog_whiteSpace_pref_before_opening_brace_in_record_constructor;
 	public static String FormatterModifyDialog_whiteSpace_pref_before_opening_brace_of_a_class;
 	public static String FormatterModifyDialog_whiteSpace_pref_before_opening_brace_of_anon_class;
 	public static String FormatterModifyDialog_whiteSpace_pref_before_opening_bracket;
@@ -390,6 +427,7 @@ final class FormatterMessages extends NLS {
 	public static String FormatterModifyDialog_whiteSpace_tree_param_type_ref;
 	public static String FormatterModifyDialog_whiteSpace_tree_parameterized_types;
 	public static String FormatterModifyDialog_whiteSpace_tree_parenexpr;
+	public static String FormatterModifyDialog_whiteSpace_tree_records;
 	public static String FormatterModifyDialog_whiteSpace_tree_return;
 	public static String FormatterModifyDialog_whiteSpace_tree_statements;
 	public static String FormatterModifyDialog_whiteSpace_tree_switch;
