@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -17,6 +17,7 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Observable;
 import java.util.Observer;
 
@@ -28,8 +29,6 @@ import org.eclipse.swt.events.ControlListener;
 import org.eclipse.swt.events.FocusAdapter;
 import org.eclipse.swt.events.FocusEvent;
 import org.eclipse.swt.events.FocusListener;
-import org.eclipse.swt.events.ModifyEvent;
-import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Point;
@@ -69,12 +68,9 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 	 * classes. It is added by the respective factory methods and
 	 * updates the page's preview on each change.
 	 */
-	protected final Observer fUpdater= new Observer() {
-		@Override
-		public void update(Observable o, Object arg) {
-			doUpdatePreview();
-			notifyValuesModified();
-		}
+	protected final Observer fUpdater= (o, arg) -> {
+		doUpdatePreview();
+		notifyValuesModified();
 	};
 
 
@@ -83,7 +79,7 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 	 * around one or more SWT widgets and handles the input of values for some key.
 	 * On each change, the new value is written to the map and the listeners are notified.
 	 */
-	protected abstract class Preference extends Observable {
+	protected abstract static class Preference extends Observable {
 	    private final Map<String, String> fPreferences;
 	    private boolean fEnabled;
 	    private String fKey;
@@ -271,8 +267,11 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 			fCombo.setItems(items);
 
 			int max= 0;
-			for (int i= 0; i < items.length; i++)
-			    if (items[i].length() > max) max= items[i].length();
+			for (String item : items) {
+				if (item.length() > max) {
+					max= item.length();
+				}
+			}
 
 			fCombo.setLayoutData(createGridData(1, GridData.HORIZONTAL_ALIGN_FILL, fCombo.computeSize(SWT.DEFAULT, SWT.DEFAULT).x));
 
@@ -374,12 +373,7 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 				}
 			});
 
-			fNumberText.addModifyListener(new ModifyListener() {
-				@Override
-				public void modifyText(ModifyEvent e) {
-					fieldModified();
-				}
-			});
+			fNumberText.addModifyListener(e -> fieldModified());
 		}
 
 		private IStatus createErrorStatus() {
@@ -474,7 +468,7 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 
 	/**
 	 * Wrapper around a text field which requests a string input.
-	 * 
+	 *
 	 * @since 3.6
 	 */
 	protected final class StringPreference extends Preference {
@@ -484,7 +478,7 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 		 * <p>
 		 * The default implementation declares all non-<code>null</code> values as valid.
 		 * </p>
-		 * 
+		 *
 		 * @since 3.6
 		 */
 		protected class Validator {
@@ -505,7 +499,7 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 
 		/**
 		 * Creates a new <code>StringPreference</code>.
-		 * 
+		 *
 		 * @param composite the composite on which the SWT widgets are added.
 		 * @param numColumns the number of columns in the composite's {@link GridLayout}
 		 * @param preferences the map to store the values.
@@ -544,12 +538,7 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 				}
 			});
 
-			fText.addModifyListener(new ModifyListener() {
-				@Override
-				public void modifyText(ModifyEvent e) {
-					fieldModified();
-				}
-			});
+			fText.addModifyListener(e -> fieldModified());
 		}
 
 		private IStatus createErrorStatus(String errorText) {
@@ -569,7 +558,7 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 				fSelected= fOldSelected;
 			else
 				fSelected= input;
-			if (fSelected != fOldSelected) {
+			if (!Objects.equals(fSelected, fOldSelected)) {
 				saveSelected();
 				fText.setText(fSelected);
 			}
@@ -581,7 +570,7 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 			final String errorText= fInputValidator != null ? fInputValidator.isValid(text) : null;
 			if (errorText == null) {
 				updateStatus(null);
-				if (fSelected != text) {
+				if (!Objects.equals(fSelected, text)) {
 					fSelected= text;
 					saveSelected();
 				}
@@ -647,13 +636,13 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 
 		@Override
 		public void focusGained(FocusEvent e) {
-			fDialogSettings.put(PREF_LAST_FOCUS_INDEX, fItemMap.get(e.widget).intValue());
+			fDialogSettings.put(PREF_LAST_FOCUS_INDEX, fItemMap.get(e.widget));
 		}
 
 		public void add(Control control) {
 			control.addFocusListener(this);
 			fItemList.add(fIndex, control);
-			fItemMap.put(control, Integer.valueOf(fIndex++));
+			fItemMap.put(control, fIndex++);
 		}
 
 		public void add(Preference preference) {
@@ -709,10 +698,10 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 			int x = fMinimalWidth;
 			int y = fMinimalHight;
 			Control[] children = composite.getChildren();
-			for (int i = 0; i < children.length; i++) {
-				Point size = children[i].computeSize(SWT.DEFAULT, SWT.DEFAULT, force);
-				x = Math.max(x, size.x);
-				y = Math.max(y, size.y);
+			for (Control c : children) {
+				Point size= c.computeSize(SWT.DEFAULT, SWT.DEFAULT, force);
+				x= Math.max(x, size.x);
+				y= Math.max(y, size.y);
 			}
 
 			Rectangle area= fContainer.getClientArea();
@@ -741,9 +730,8 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 		@Override
 		public void layout(Composite composite, boolean force) {
 			Rectangle rect = composite.getClientArea();
-			Control[] children = composite.getChildren();
-			for (int i = 0; i < children.length; i++) {
-				children[i].setSize(rect.width, rect.height);
+			for (Control c : composite.getChildren()) {
+				c.setSize(rect.width, rect.height);
 			}
 		}
 	}
@@ -806,7 +794,7 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 	 * Subclasses should implement <code>doCreatePreferences</code> and <code>doCreatePreview</code>
 	 * may also be overridden as necessary.
 	 * </p>
-	 * 
+	 *
 	 * @param parent The parent composite
 	 * @return Created content control
 	 */
@@ -837,6 +825,7 @@ public abstract class ModifyDialogTabPage implements IModifyDialogTabPage {
 		scroll.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
 		scroll.setExpandHorizontal(true);
 		scroll.setExpandVertical(true);
+		scroll.setShowFocusedControl(true);
 
 		final Composite settingsContainer= new Composite(scroll, SWT.NONE);
 		settingsContainer.setFont(sashForm.getFont());
