@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -11,6 +11,7 @@
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Red Hat Inc. - add module-info support
+ *     Microsoft Corporation - read formatting options from the compilation unit
  *******************************************************************************/
 package org.eclipse.jdt.internal.ui.text.correction;
 
@@ -62,6 +63,7 @@ import org.eclipse.jdt.core.dom.ModuleDirective;
 import org.eclipse.jdt.core.dom.Name;
 import org.eclipse.jdt.core.dom.PrimitiveType;
 import org.eclipse.jdt.core.dom.ProvidesDirective;
+import org.eclipse.jdt.core.dom.RecordDeclaration;
 import org.eclipse.jdt.core.dom.SimpleName;
 import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
 import org.eclipse.jdt.core.dom.StructuralPropertyDescriptor;
@@ -115,12 +117,12 @@ public class JavadocTagsSubProcessor {
 		protected void addEdits(IDocument document, TextEdit rootEdit) throws CoreException {
 			try {
 				String lineDelimiter= TextUtilities.getDefaultLineDelimiter(document);
-				final IJavaProject project= getCompilationUnit().getJavaProject();
+				final ICompilationUnit unit= getCompilationUnit();
 				IRegion region= document.getLineInformationOfOffset(fInsertPosition);
 
 				String lineContent= document.get(region.getOffset(), region.getLength());
-				String indentString= Strings.getIndentString(lineContent, project);
-				String str= Strings.changeIndent(fComment, 0, project, indentString, lineDelimiter);
+				String indentString= Strings.getIndentString(lineContent, unit);
+				String str= Strings.changeIndent(fComment, 0, unit, indentString, lineDelimiter);
 				InsertEdit edit= new InsertEdit(fInsertPosition, str);
 				rootEdit.addChild(edit);
 				if (fComment.charAt(fComment.length() - 1) != '\n') {
@@ -148,14 +150,12 @@ public class JavadocTagsSubProcessor {
 		protected void addEdits(IDocument document, TextEdit rootEdit) throws CoreException {
 			try {
 				Javadoc javadoc= null;
-				int insertPosition= -1;
 				String lineDelimiter= TextUtilities.getDefaultLineDelimiter(document);
-				final IJavaProject project= getCompilationUnit().getJavaProject();
+				final ICompilationUnit unit= getCompilationUnit();
 				CompilationUnit cu= (CompilationUnit)fDecl.getParent();
 				Name name= fDecl.getName();
 				List<Comment> comments= cu.getCommentList();
-				for (int i= 0; i < comments.size(); ++i) {
-					Comment comment= comments.get(i);
+				for (Comment comment : comments) {
 					if (comment instanceof Javadoc
 							&& comment.getStartPosition() + comment.getLength() < name.getStartPosition()) {
 						javadoc= (Javadoc)comment;
@@ -164,23 +164,21 @@ public class JavadocTagsSubProcessor {
 				if (javadoc == null) {
 					return;
 				}
-				String comment= ""; //$NON-NLS-1$
-				insertPosition= findInsertPosition(javadoc, fMissingNode, document, lineDelimiter);
+				StringBuilder comment= new StringBuilder();
+				int insertPosition= findInsertPosition(javadoc, fMissingNode, document, lineDelimiter);
 
 			 	if (fMissingNode instanceof UsesDirective) {
 			 		UsesDirective directive= (UsesDirective)fMissingNode;
-			 		comment+= " * " + TagElement.TAG_USES + //$NON-NLS-1$
-			 				" " + directive.getName().getFullyQualifiedName().toString() + lineDelimiter; //$NON-NLS-1$
+			 		comment.append(" * ").append(TagElement.TAG_USES).append(" ").append(directive.getName().getFullyQualifiedName().toString()).append(lineDelimiter); //$NON-NLS-1$ //$NON-NLS-2$
 			 	} else if (fMissingNode instanceof ProvidesDirective) {
 			 		ProvidesDirective directive= (ProvidesDirective)fMissingNode;
-			 		comment+= " * " + TagElement.TAG_PROVIDES + //$NON-NLS-1$
-			 				" " + directive.getName().getFullyQualifiedName().toString() + lineDelimiter; //$NON-NLS-1$
+			 		comment.append(" * ").append(TagElement.TAG_PROVIDES).append(" ").append(directive.getName().getFullyQualifiedName().toString()).append(lineDelimiter); //$NON-NLS-1$ //$NON-NLS-2$
 			 	}
 				IRegion region= document.getLineInformationOfOffset(insertPosition);
 
 				String lineContent= document.get(region.getOffset(), region.getLength());
-				String indentString= Strings.getIndentString(lineContent, project);
-				String str= Strings.changeIndent(comment, 0, project, indentString, lineDelimiter);
+				String indentString= Strings.getIndentString(lineContent, unit);
+				String str= Strings.changeIndent(comment.toString(), 0, unit, indentString, lineDelimiter);
 				InsertEdit edit= new InsertEdit(insertPosition, str);
 				rootEdit.addChild(edit);
 			} catch (BadLocationException e) {
@@ -188,7 +186,7 @@ public class JavadocTagsSubProcessor {
 			}
 		}
 
-		public static int findInsertPosition(Javadoc javadoc, @SuppressWarnings("unused") ASTNode node, IDocument document, String lineDelimiter) throws BadLocationException {
+		public static int findInsertPosition(Javadoc javadoc, ASTNode node, IDocument document, String lineDelimiter) throws BadLocationException {
 			int position= -1;
 			List<TagElement> tags= javadoc.tags();
 			TagElement lastTag= null;
@@ -241,14 +239,13 @@ public class JavadocTagsSubProcessor {
 		protected void addEdits(IDocument document, TextEdit rootEdit) throws CoreException {
 			try {
 				Javadoc javadoc= null;
-				int insertPosition= -1;
+				int insertPosition;
 				String lineDelimiter= TextUtilities.getDefaultLineDelimiter(document);
-				final IJavaProject project= getCompilationUnit().getJavaProject();
+				final ICompilationUnit unit= getCompilationUnit();
 				CompilationUnit cu= (CompilationUnit)fDecl.getParent();
 				Name moduleName= fDecl.getName();
 				List<Comment> comments= cu.getCommentList();
-				for (int i= 0; i < comments.size(); ++i) {
-					Comment comment= comments.get(i);
+				for (Comment comment : comments) {
 					if (comment instanceof Javadoc
 							&& comment.getStartPosition() + comment.getLength() < moduleName.getStartPosition()) {
 							javadoc= (Javadoc)comment;
@@ -257,7 +254,7 @@ public class JavadocTagsSubProcessor {
 				if (javadoc == null) {
 					return;
 				}
-				String comment= ""; //$NON-NLS-1$
+				StringBuilder comment= new StringBuilder();
 				insertPosition= AddMissingModuleJavadocTagProposal.findInsertPosition(javadoc, fMissingNode, document, lineDelimiter);
 
 			 	List<ModuleDirective> moduleStatements= fDecl.moduleStatements();
@@ -267,8 +264,7 @@ public class JavadocTagsSubProcessor {
 			 		if (directive instanceof ProvidesDirective) {
 			 			name= ((ProvidesDirective)directive).getName().getFullyQualifiedName().toString();
 			 			if (findTag(javadoc, TagElement.TAG_PROVIDES, name) == null) {
-					 		comment+= " * " + TagElement.TAG_PROVIDES + //$NON-NLS-1$
-					 				" " + name + lineDelimiter; //$NON-NLS-1$
+					 		comment.append(" * ").append(TagElement.TAG_PROVIDES).append(" ").append(name).append(lineDelimiter); //$NON-NLS-1$ //$NON-NLS-2$
 			 			}
 			 		}
 			 	}
@@ -279,8 +275,7 @@ public class JavadocTagsSubProcessor {
 			 		if (directive instanceof UsesDirective) {
 			 			name= ((UsesDirective)directive).getName().getFullyQualifiedName().toString();
 			 			if (findTag(javadoc, TagElement.TAG_USES, name) == null) {
-					 		comment+= " * " + TagElement.TAG_USES + //$NON-NLS-1$
-					 				" " + name + lineDelimiter; //$NON-NLS-1$
+					 		comment.append(" * ").append(TagElement.TAG_USES).append(" ").append(name).append(lineDelimiter); //$NON-NLS-1$ //$NON-NLS-2$
 			 			}
 			 		}
 			 	}
@@ -288,8 +283,8 @@ public class JavadocTagsSubProcessor {
 				IRegion region= document.getLineInformationOfOffset(insertPosition);
 
 				String lineContent= document.get(region.getOffset(), region.getLength());
-				String indentString= Strings.getIndentString(lineContent, project);
-				String str= Strings.changeIndent(comment, 0, project, indentString, lineDelimiter);
+				String indentString= Strings.getIndentString(lineContent, unit);
+				String str= Strings.changeIndent(comment.toString(), 0, unit, indentString, lineDelimiter);
 				InsertEdit edit= new InsertEdit(insertPosition, str);
 				rootEdit.addChild(edit);
 			} catch (BadLocationException e) {
@@ -338,17 +333,31 @@ public class JavadocTagsSubProcessor {
 				newTag.setTagName(TagElement.TAG_PARAM);
 				newTag.fragments().add(ast.newSimpleName(name));
 
-				MethodDeclaration methodDeclaration= (MethodDeclaration) bodyDecl;
-				List<SingleVariableDeclaration> params= methodDeclaration.parameters();
+				if (bodyDecl instanceof MethodDeclaration) {
+					MethodDeclaration methodDeclaration= (MethodDeclaration) bodyDecl;
+					List<SingleVariableDeclaration> params= methodDeclaration.parameters();
 
-				Set<String> sameKindLeadingNames= getPreviousParamNames(params, decl);
+					Set<String> sameKindLeadingNames= getPreviousParamNames(params, decl);
 
-				List<TypeParameter> typeParams= methodDeclaration.typeParameters();
-				for (int i= 0; i < typeParams.size(); i++) {
-					String curr= '<' + typeParams.get(i).getName().getIdentifier() + '>';
-					sameKindLeadingNames.add(curr);
+					List<TypeParameter> typeParams= methodDeclaration.typeParameters();
+					for (TypeParameter typeParam : typeParams) {
+						String curr= '<' + typeParam.getName().getIdentifier() + '>';
+						sameKindLeadingNames.add(curr);
+					}
+					insertTag(tagsRewriter, newTag, sameKindLeadingNames);
+				} else if (bodyDecl instanceof RecordDeclaration) {
+					RecordDeclaration recordDeclaration= (RecordDeclaration) bodyDecl;
+					List<SingleVariableDeclaration> params= recordDeclaration.recordComponents();
+
+					Set<String> sameKindLeadingNames= getPreviousParamNames(params, decl);
+
+					List<TypeParameter> typeParams= recordDeclaration.typeParameters();
+					for (TypeParameter typeParam : typeParams) {
+						String curr= '<' + typeParam.getName().getIdentifier() + '>';
+						sameKindLeadingNames.add(curr);
+					}
+					insertTag(tagsRewriter, newTag, sameKindLeadingNames);
 				}
-				insertTag(tagsRewriter, newTag, sameKindLeadingNames);
 		 	} else if (location == TypeParameter.NAME_PROPERTY) {
 		 		// type parameter
 		 		TypeParameter typeParam= (TypeParameter) missingNode.getParent();
@@ -362,6 +371,8 @@ public class JavadocTagsSubProcessor {
 				List<TypeParameter> params;
 				if (bodyDecl instanceof TypeDeclaration) {
 					params= ((TypeDeclaration) bodyDecl).typeParameters();
+				} else if (bodyDecl instanceof RecordDeclaration) {
+					params= ((RecordDeclaration) bodyDecl).typeParameters();
 				} else {
 					params= ((MethodDeclaration) bodyDecl).typeParameters();
 				}
@@ -410,6 +421,8 @@ public class JavadocTagsSubProcessor {
 			ASTRewrite rewrite= ASTRewrite.create(fDecl.getAST());
 			if (fDecl instanceof MethodDeclaration) {
 				insertAllMissingMethodTags(rewrite, (MethodDeclaration) fDecl);
+			} else if (fDecl instanceof RecordDeclaration) {
+				insertAllMissingRecordTypeTags(rewrite, (RecordDeclaration) fDecl);
 			} else {
 				insertAllMissingTypeTags(rewrite, (TypeDeclaration) fDecl);
 			}
@@ -502,6 +515,42 @@ public class JavadocTagsSubProcessor {
 			}
 		}
 
+		private void insertAllMissingRecordTypeTags(ASTRewrite rewriter, RecordDeclaration recDecl) {
+			AST ast= recDecl.getAST();
+			Javadoc javadoc= recDecl.getJavadoc();
+			ListRewrite tagsRewriter= rewriter.getListRewrite(javadoc, Javadoc.TAGS_PROPERTY);
+
+			List<SingleVariableDeclaration> recComps= recDecl.recordComponents();
+			for (int i= recComps.size() - 1; i >= 0; i--) {
+				SingleVariableDeclaration decl= recComps.get(i);
+				String name= decl.getName().getIdentifier();
+				if (findTag(javadoc, TagElement.TAG_PARAM, name) == null) {
+					TagElement newTag= ast.newTagElement();
+					newTag.setTagName(TagElement.TAG_PARAM);
+					TextElement text= ast.newTextElement();
+					text.setText(name);
+					newTag.fragments().add(text);
+					insertTabStop(rewriter, newTag.fragments(), "recComps" + i); //$NON-NLS-1$
+					insertTag(tagsRewriter, newTag, getPreviousParamNames(recComps, decl));
+				}
+			}
+
+			List<TypeParameter> typeParams= recDecl.typeParameters();
+			for (int i= typeParams.size() - 1; i >= 0; i--) {
+				TypeParameter decl= typeParams.get(i);
+				String name= '<' + decl.getName().getIdentifier() + '>';
+				if (findTag(javadoc, TagElement.TAG_PARAM, name) == null) {
+					TagElement newTag= ast.newTagElement();
+					newTag.setTagName(TagElement.TAG_PARAM);
+					TextElement text= ast.newTextElement();
+					text.setText(name);
+					newTag.fragments().add(text);
+					insertTabStop(rewriter, newTag.fragments(), "typeParam" + i); //$NON-NLS-1$
+					insertTag(tagsRewriter, newTag, getPreviousTypeParamNames(typeParams, decl));
+				}
+			}
+		}
+
 		private void insertTabStop(ASTRewrite rewriter, List<ASTNode> fragments, String linkedName) {
 			TextElement textElement= rewriter.getAST().newTextElement();
 			textElement.setText(""); //$NON-NLS-1$
@@ -548,13 +597,17 @@ public class JavadocTagsSubProcessor {
 
 	 		if (location == SingleVariableDeclaration.NAME_PROPERTY) {
 	 			label= CorrectionMessages.JavadocTagsSubProcessor_addjavadoc_paramtag_description;
-	 			if (node.getParent().getLocationInParent() != MethodDeclaration.PARAMETERS_PROPERTY) {
+	 			StructuralPropertyDescriptor propDesc= node.getParent().getLocationInParent();
+	 			if (propDesc != MethodDeclaration.PARAMETERS_PROPERTY
+	 					&& propDesc != RecordDeclaration.RECORD_COMPONENTS_PROPERTY) {
 	 				return; // paranoia checks
 	 			}
 	 		} else if (location == TypeParameter.NAME_PROPERTY) {
 	 			label= CorrectionMessages.JavadocTagsSubProcessor_addjavadoc_paramtag_description;
 	 			StructuralPropertyDescriptor parentLocation= node.getParent().getLocationInParent();
-	 			if (parentLocation != MethodDeclaration.TYPE_PARAMETERS_PROPERTY && parentLocation != TypeDeclaration.TYPE_PARAMETERS_PROPERTY) {
+	 			if (parentLocation != MethodDeclaration.TYPE_PARAMETERS_PROPERTY
+	 					&& parentLocation != TypeDeclaration.TYPE_PARAMETERS_PROPERTY
+	 					&& parentLocation != RecordDeclaration.TYPE_PARAMETERS_PROPERTY) {
 	 				return; // paranoia checks
 	 			}
 	 		} else if (location == MethodDeclaration.RETURN_TYPE2_PROPERTY) {
@@ -663,17 +716,30 @@ public class JavadocTagsSubProcessor {
 	 			}
 	 		} else if (declaration instanceof AbstractTypeDeclaration) {
 	 			String typeQualifiedName= Bindings.getTypeQualifiedName(binding);
-	 			String[] typeParamNames;
+	 			String[] typeParamNames, params;
 	 			if (declaration instanceof TypeDeclaration) {
 	 				List<TypeParameter> typeParams= ((TypeDeclaration) declaration).typeParameters();
 	 				typeParamNames= new String[typeParams.size()];
 	 				for (int i= 0; i < typeParamNames.length; i++) {
 	 					typeParamNames[i]= (typeParams.get(i)).getName().getIdentifier();
 	 				}
+	 				params= new String[0];
+	 			} else if (declaration instanceof RecordDeclaration) {
+	 				List<SingleVariableDeclaration> recComps= ((RecordDeclaration)declaration).recordComponents();
+	 				params= new String[recComps.size()];
+	 				for (int i= 0; i < params.length; i++) {
+	 					params[i]= (recComps.get(i)).getName().getIdentifier();
+	 				}
+	 				List<TypeParameter> typeParams= ((RecordDeclaration) declaration).typeParameters();
+	 				typeParamNames= new String[typeParams.size()];
+	 				for (int i= 0; i < typeParamNames.length; i++) {
+	 					typeParamNames[i]= (typeParams.get(i)).getName().getIdentifier();
+	 				}
 	 			} else {
 	 				typeParamNames= new String[0];
+	 				params= new String[0];
 	 			}
-	 			String string= CodeGeneration.getTypeComment(cu, typeQualifiedName, typeParamNames, String.valueOf('\n'));
+	 			String string= CodeGeneration.getTypeComment(cu, typeQualifiedName, typeParamNames, params, String.valueOf('\n'));
 	 			if (string != null) {
 	 				String label= CorrectionMessages.JavadocTagsSubProcessor_addjavadoc_type_description;
 	 				proposals.add(new AddJavadocCommentProposal(label, cu, IProposalRelevance.ADD_JAVADOC_TYPE, declaration.getStartPosition(), string));
@@ -703,8 +769,7 @@ public class JavadocTagsSubProcessor {
 
 	public static Set<String> getPreviousTypeParamNames(List<TypeParameter> typeParams, ASTNode missingNode) {
 		Set<String> previousNames=  new HashSet<>();
-		for (int i = 0; i < typeParams.size(); i++) {
-			TypeParameter curr= typeParams.get(i);
+		for (TypeParameter curr : typeParams) {
 			if (curr == missingNode) {
 				return previousNames;
 			}
@@ -739,8 +804,7 @@ public class JavadocTagsSubProcessor {
 
 	private static Set<String> getPreviousParamNames(List<SingleVariableDeclaration> params, ASTNode missingNode) {
 		Set<String> previousNames=  new HashSet<>();
-		for (int i = 0; i < params.size(); i++) {
-			SingleVariableDeclaration curr= params.get(i);
+		for (SingleVariableDeclaration curr : params) {
 			if (curr == missingNode) {
 				return previousNames;
 			}
@@ -866,7 +930,7 @@ public class JavadocTagsSubProcessor {
 	};
 
 	private static int getTagRanking(String tagName) {
-		if (tagName.equals(TagElement.TAG_EXCEPTION)) {
+		if (TagElement.TAG_EXCEPTION.equals(tagName)) {
 			tagName= TagElement.TAG_THROWS;
 		}
 		for (int i= 0; i < TAG_ORDER.length; i++) {
@@ -947,21 +1011,20 @@ public class JavadocTagsSubProcessor {
 		}
 	}
 
-	@SuppressWarnings("rawtypes")
 	private static ASTNode findModuleJavadocTag(ModuleDeclaration decl, IProblemLocation problem) {
 		ASTNode result= null;
 		CompilationUnit cu= (CompilationUnit)decl.getParent();
 		int problemLocationStart= problem.getOffset();
 		Name moduleName= decl.getName();
-		List comments= cu.getCommentList();
-		for (int i= 0; i < comments.size(); ++i) {
-			Comment comment= (Comment)comments.get(i);
+		List<Comment> comments= cu.getCommentList();
+
+		for (Comment comment : comments) {
 			if (comment instanceof Javadoc
 					&& comment.getStartPosition() + comment.getLength() < moduleName.getStartPosition()) {
 				Javadoc javadoc= (Javadoc)comment;
-				List tags= javadoc.tags();
-				for (Object element : tags) {
-					TagElement tag= (TagElement)element;
+				List<TagElement> tags= javadoc.tags();
+
+				for (TagElement tag : tags) {
 					if (problemLocationStart  > tag.getStartPosition()
 							&& problemLocationStart < tag.getStartPosition() + tag.getLength()) {
 						result= tag;
@@ -995,4 +1058,7 @@ public class JavadocTagsSubProcessor {
 
 		proposals.add(proposal);
 	}
+
+	private JavadocTagsSubProcessor() {
+	}
 }
