@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2019 IBM Corporation and others.
+ * Copyright (c) 2019, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -160,14 +160,17 @@ public class PreviewFeaturesSubProcessor {
 							CONFIGURE_COMPILER_PROBLEM_SEVERITY_DIALOG_ID, shell, JavaHoverMessages.ProblemHover_chooseCompilerSettingsTypeDialog_title, null, message, MessageDialog.QUESTION, buttons,
 							0, JavaHoverMessages.ProblemHover_chooseSettingsTypeDialog_checkBox_dontShowAgain);
 
-					if (result == OptionalMessageDialog.NOT_SHOWN) {
-						usePropertyPage= false;
-					} else if (result == 2 || result == SWT.DEFAULT) {
-						return;
-					} else if (result == 0) {
-						usePropertyPage= true;
-					} else {
-						usePropertyPage= false;
+					switch (result) {
+						case 2:
+						case SWT.DEFAULT:
+							return;
+						case 0:
+							usePropertyPage= true;
+							break;
+						case OptionalMessageDialog.NOT_SHOWN:
+						default:
+							usePropertyPage= false;
+							break;
 					}
 				} else {
 					usePropertyPage= true;
@@ -219,7 +222,7 @@ public class PreviewFeaturesSubProcessor {
 	public static void getNeedHigherComplianceProposals(IInvocationContext context, IProblemLocation problem, Collection<ICommandAccess> proposals) {
 		String[] args= problem.getProblemArguments();
 		if (args != null && args.length > 0) {
-			String supportedVersion= JavaCore.VERSION_13;
+			String supportedVersion= JavaCore.latestSupportedJavaVersion();
 			String arg= args[1];
 			if (arg.equals(supportedVersion)) {
 				ReorgCorrectionsSubProcessor.getNeedHigherComplianceProposals(context, problem, proposals, true, supportedVersion);
@@ -239,22 +242,25 @@ public class PreviewFeaturesSubProcessor {
 
 	public static boolean isPreviewFeatureEnabled(IJavaProject javaProject) {
 		boolean isPreviewFeatureEnabled= false;
-		if (javaProject != null && JavaModelUtil.is13OrHigher(javaProject)) {
+		if (javaProject != null && JavaModelUtil.isLatestOrHigherJavaVersion(javaProject)) {
 			IProject project= javaProject.getProject();
 			Key[] keys= ComplianceConfigurationBlock.getKeys(true);
 			boolean hasProjectSpecificOptions= OptionsConfigurationBlock.hasProjectSpecificOptions(project, keys, null);
 			if (hasProjectSpecificOptions) {
 				String option= javaProject.getOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, true);
-				if (option != null && option.equals(ENABLED)) {
+				if (option != null && ENABLED.equals(option)) {
 					isPreviewFeatureEnabled= true;
 				}
 			} else {
 				String option= JavaCore.getOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES);
-				if (option != null && option.equals(ENABLED)) {
+				if (option != null && ENABLED.equals(option)) {
 					isPreviewFeatureEnabled= true;
 				}
 			}
 		}
 		return isPreviewFeatureEnabled;
 	}
+
+	private PreviewFeaturesSubProcessor() {
+	}
 }
