@@ -16,7 +16,6 @@ package org.eclipse.jdt.internal.ui.text.correction;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
-import java.util.Comparator;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
@@ -121,7 +120,7 @@ public class QuickTemplateProcessor implements IQuickAssistProcessor {
 			String contentType= TextUtilities.getContentType(document, IJavaPartitions.JAVA_PARTITIONING, offset, true);
 
 			String contextId;
-			if (contentType.equals(IJavaPartitions.JAVA_DOC)) {
+			if (IJavaPartitions.JAVA_DOC.equals(contentType)) {
 				contextId= JavaDocContextType.ID;
 			} else {
 				// TODO: Should compute location: member/statement
@@ -132,7 +131,7 @@ public class QuickTemplateProcessor implements IQuickAssistProcessor {
 			int startLine= document.getLineOfOffset(offset);
 			int endLine= document.getLineOfOffset(offset + length);
 
-			if (contextId.equals(JavaContextType.ID_ALL)) {
+			if (JavaContextType.ID_ALL.equals(contextId)) {
 				IRegion endLineRegion= document.getLineInformation(endLine);
 				//if end position is at start of line, set it back to the previous line's end
 				if (endLine > startLine && endLineRegion.getOffset() == offset + length) {
@@ -163,12 +162,7 @@ public class QuickTemplateProcessor implements IQuickAssistProcessor {
 	}
 
 	private void sort(ArrayList<IJavaCompletionProposal> proposals) {
-		Collections.sort(proposals, new Comparator<IJavaCompletionProposal>() {
-			@Override
-			public int compare(IJavaCompletionProposal p1, IJavaCompletionProposal p2) {
-				return Collator.getInstance().compare(p1.getDisplayString(), p2.getDisplayString());
-			}
-		});
+		Collections.sort(proposals, (p1, p2) -> Collator.getInstance().compare(p1.getDisplayString(), p2.getDisplayString()));
 	}
 
 	private IDocument getDocument(ICompilationUnit cu) throws JavaModelException {
@@ -194,8 +188,7 @@ public class QuickTemplateProcessor implements IQuickAssistProcessor {
 		ASTNode[] selectedNodes= SurroundWith.getValidSelectedNodes(invocationContext);
 
 		Template[] templates= JavaPlugin.getDefault().getTemplateStore().getTemplates();
-		for (int i= 0; i != templates.length; i++) {
-			Template currentTemplate= templates[i];
+		for (Template currentTemplate : templates) {
 			if (canEvaluate(context, currentTemplate)) {
 
 				if (selectedNodes != null) {
