@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -27,6 +27,8 @@ import org.eclipse.core.runtime.preferences.InstanceScope;
 
 import org.eclipse.core.resources.ProjectScope;
 
+import org.eclipse.jface.resource.ImageDescriptor;
+
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.NamingConventions;
@@ -37,12 +39,15 @@ import org.eclipse.jdt.core.dom.AbstractTypeDeclaration;
 import org.eclipse.jdt.core.dom.Assignment;
 import org.eclipse.jdt.core.dom.Block;
 import org.eclipse.jdt.core.dom.BodyDeclaration;
+import org.eclipse.jdt.core.dom.CatchClause;
 import org.eclipse.jdt.core.dom.ChildListPropertyDescriptor;
 import org.eclipse.jdt.core.dom.CompilationUnit;
+import org.eclipse.jdt.core.dom.EmptyStatement;
 import org.eclipse.jdt.core.dom.Expression;
 import org.eclipse.jdt.core.dom.ExpressionStatement;
 import org.eclipse.jdt.core.dom.FieldAccess;
 import org.eclipse.jdt.core.dom.FieldDeclaration;
+import org.eclipse.jdt.core.dom.IMethodBinding;
 import org.eclipse.jdt.core.dom.ITypeBinding;
 import org.eclipse.jdt.core.dom.IVariableBinding;
 import org.eclipse.jdt.core.dom.Initializer;
@@ -51,7 +56,10 @@ import org.eclipse.jdt.core.dom.Modifier;
 import org.eclipse.jdt.core.dom.SimpleName;
 import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
 import org.eclipse.jdt.core.dom.Statement;
+import org.eclipse.jdt.core.dom.ThrowStatement;
+import org.eclipse.jdt.core.dom.TryStatement;
 import org.eclipse.jdt.core.dom.Type;
+import org.eclipse.jdt.core.dom.UnionType;
 import org.eclipse.jdt.core.dom.VariableDeclarationExpression;
 import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
 import org.eclipse.jdt.core.dom.VariableDeclarationStatement;
@@ -59,16 +67,27 @@ import org.eclipse.jdt.core.dom.rewrite.ASTRewrite;
 import org.eclipse.jdt.core.dom.rewrite.ImportRewrite;
 import org.eclipse.jdt.core.dom.rewrite.ImportRewrite.ImportRewriteContext;
 import org.eclipse.jdt.core.dom.rewrite.ImportRewrite.TypeLocation;
+import org.eclipse.jdt.core.dom.rewrite.ListRewrite;
 
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
+import org.eclipse.jdt.internal.core.manipulation.dom.ASTResolving;
+import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.corext.codemanipulation.ContextSensitiveImportRewriteContext;
 import org.eclipse.jdt.internal.corext.dom.ASTNodeFactory;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
 import org.eclipse.jdt.internal.corext.dom.Bindings;
+import org.eclipse.jdt.internal.corext.dom.CodeScopeBuilder;
 import org.eclipse.jdt.internal.corext.dom.LinkedNodeFinder;
+import org.eclipse.jdt.internal.corext.dom.Selection;
 import org.eclipse.jdt.internal.corext.dom.TokenScanner;
 import org.eclipse.jdt.internal.corext.fix.CleanUpConstants;
 import org.eclipse.jdt.internal.corext.fix.CleanUpPostSaveListener;
 import org.eclipse.jdt.internal.corext.fix.CleanUpPreferenceUtil;
+import org.eclipse.jdt.internal.corext.fix.LinkedProposalModel;
+import org.eclipse.jdt.internal.corext.refactoring.surround.ExceptionAnalyzer;
+import org.eclipse.jdt.internal.corext.refactoring.surround.SurroundWithTryWithResourcesAnalyzer;
+import org.eclipse.jdt.internal.corext.refactoring.surround.SurroundWithTryWithResourcesRefactoring;
+import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.internal.corext.util.Messages;
 
 import org.eclipse.jdt.ui.PreferenceConstants;
@@ -78,11 +97,8 @@ import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.JavaPluginImages;
 import org.eclipse.jdt.internal.ui.javaeditor.saveparticipant.AbstractSaveParticipantPreferenceConfiguration;
 import org.eclipse.jdt.internal.ui.text.correction.CorrectionMessages;
-import org.eclipse.jdt.internal.ui.text.correction.ModifierCorrectionSubProcessor;
-
-import org.eclipse.jdt.internal.core.manipulation.StubUtility;
-import org.eclipse.jdt.internal.core.manipulation.dom.ASTResolving;
-import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
+import org.eclipse.jdt.internal.ui.text.correction.ModifierCorrectionSubProcessorCore;
+import org.eclipse.jdt.internal.ui.viewsupport.BindingLabelProvider;
 
 /**
  * Proposals for 'Assign to variable' quick assist
@@ -93,20 +109,28 @@ public class AssignToVariableAssistProposal extends LinkedCorrectionProposal {
 
 	public static final int LOCAL= 1;
 	public static final int FIELD= 2;
+	public static final int TRY_WITH_RESOURCES= 3;
 
 	private final String KEY_NAME= "name";  //$NON-NLS-1$
 	private final String KEY_TYPE= "type";  //$NON-NLS-1$
+	private final String GROUP_EXC_TYPE= "exc_type"; //$NON-NLS-1$
+	private final String GROUP_EXC_NAME= "exc_name"; //$NON-NLS-1$
+	private final String VAR_TYPE= "var";  //$NON-NLS-1$
 
 	private final int  fVariableKind;
 	private final List<ASTNode> fNodesToAssign; // ExpressionStatement or SingleVariableDeclaration(s)
 	private final ITypeBinding fTypeBinding;
+	private final ICompilationUnit fCUnit;
+	private final List<String> fParamNames;
 
 	private VariableDeclarationFragment fExistingFragment;
 
 	public AssignToVariableAssistProposal(ICompilationUnit cu, int variableKind, ExpressionStatement node, ITypeBinding typeBinding, int relevance) {
 		super("", cu, null, relevance, null); //$NON-NLS-1$
 
+		fCUnit= cu;
 		fVariableKind= variableKind;
+		fParamNames = null;
 		fNodesToAssign= new ArrayList<>();
 		fNodesToAssign.add(node);
 
@@ -114,9 +138,12 @@ public class AssignToVariableAssistProposal extends LinkedCorrectionProposal {
 		if (variableKind == LOCAL) {
 			setDisplayName(CorrectionMessages.AssignToVariableAssistProposal_assigntolocal_description);
 			setImage(JavaPluginImages.get(JavaPluginImages.IMG_CORRECTION_LOCAL));
-		} else {
+		} else if (variableKind == FIELD) {
 			setDisplayName(CorrectionMessages.AssignToVariableAssistProposal_assigntofield_description);
 			setImage(JavaPluginImages.get(JavaPluginImages.IMG_FIELD_PRIVATE));
+		} else {
+			setDisplayName(CorrectionMessages.AssignToVariableAssistProposal_assignintrywithresources_description);
+			setImage(JavaPluginImages.get(JavaPluginImages.IMG_CORRECTION_CHANGE));
 		}
 		createImportRewrite((CompilationUnit) node.getRoot());
 	}
@@ -124,9 +151,11 @@ public class AssignToVariableAssistProposal extends LinkedCorrectionProposal {
 	public AssignToVariableAssistProposal(ICompilationUnit cu, SingleVariableDeclaration parameter, VariableDeclarationFragment existingFragment, ITypeBinding typeBinding, int relevance) {
 		super("", cu, null, relevance, null); //$NON-NLS-1$
 
+		fCUnit= cu;
 		fVariableKind= FIELD;
 		fNodesToAssign= new ArrayList<>();
 		fNodesToAssign.add(parameter);
+		fParamNames= null;
 		fTypeBinding= typeBinding;
 		fExistingFragment= existingFragment;
 
@@ -141,11 +170,13 @@ public class AssignToVariableAssistProposal extends LinkedCorrectionProposal {
 	public AssignToVariableAssistProposal(ICompilationUnit cu, List<SingleVariableDeclaration> parameters, int relevance) {
 		super("", cu, null, relevance, null); //$NON-NLS-1$
 
+		fCUnit= cu;
 		fVariableKind= FIELD;
 		fNodesToAssign= new ArrayList<>();
 		fNodesToAssign.addAll(parameters);
 		fTypeBinding= null;
-
+		fParamNames= new ArrayList<>();
+		populateNames(parameters);
 		setDisplayName(CorrectionMessages.AssignToVariableAssistProposal_assignallparamstofields_description);
 		setImage(JavaPluginImages.get(JavaPluginImages.IMG_FIELD_PRIVATE));
 	}
@@ -159,23 +190,33 @@ public class AssignToVariableAssistProposal extends LinkedCorrectionProposal {
 			} else {
 				return doAddAllFields(rewrite);
 			}
-		} else { // LOCAL
+		} else { // LOCAL or TRY_WITH_RESOURCES
 			return doAddLocal();
 		}
 	}
 
-	private ASTRewrite doAddLocal() {
+	private void populateNames(List<SingleVariableDeclaration> parameters) {
+		if (parameters != null && parameters.size() > 0) {
+			for (SingleVariableDeclaration param : parameters) {
+				if (param.getName() != null) {
+					fParamNames.add(param.getName().getIdentifier());
+				}
+			}
+		}
+	}
+
+	private ASTRewrite doAddLocal() throws CoreException {
 		ASTNode nodeToAssign= fNodesToAssign.get(0);
 		Expression expression= ((ExpressionStatement) nodeToAssign).getExpression();
 		AST ast= nodeToAssign.getAST();
 
 		ASTRewrite rewrite= ASTRewrite.create(ast);
 
-		createImportRewrite((CompilationUnit) nodeToAssign.getRoot());
+		ImportRewrite importRewrite= createImportRewrite((CompilationUnit) nodeToAssign.getRoot());
 
 		String[] varNames= suggestLocalVariableNames(fTypeBinding, expression);
-		for (int i= 0; i < varNames.length; i++) {
-			addLinkedPositionProposal(KEY_NAME, varNames[i], null);
+		for (String varName : varNames) {
+			addLinkedPositionProposal(KEY_NAME, varName, null);
 		}
 
 		VariableDeclarationFragment newDeclFrag= ast.newVariableDeclarationFragment();
@@ -184,30 +225,148 @@ public class AssignToVariableAssistProposal extends LinkedCorrectionProposal {
 
 		Type type= evaluateType(ast, nodeToAssign, fTypeBinding, KEY_TYPE, TypeLocation.LOCAL_VARIABLE);
 
-		if (ASTNodes.isControlStatementBody(nodeToAssign.getLocationInParent())) {
-			Block block= ast.newBlock();
-			block.statements().add(rewrite.createMoveTarget(nodeToAssign));
-			rewrite.replace(nodeToAssign, block, null);
+		ICompilationUnit cu= getCompilationUnit();
+		if (type != null && cu != null && JavaModelUtil.is10OrHigher(cu.getJavaProject())) {
+			ImageDescriptor desc= BindingLabelProvider.getBindingImageDescriptor(fTypeBinding, BindingLabelProvider.DEFAULT_IMAGEFLAGS);
+			addLinkedPositionProposal(KEY_TYPE, VAR_TYPE, (desc != null) ? JavaPlugin.getImageDescriptorRegistry().get(desc) : null);
 		}
 
-		if (needsSemicolon(expression)) {
-			VariableDeclarationStatement varStatement= ast.newVariableDeclarationStatement(newDeclFrag);
-			varStatement.setType(type);
-			rewrite.replace(expression, varStatement, null);
+		if (fVariableKind == LOCAL) {
+			if (ASTNodes.isControlStatementBody(nodeToAssign.getLocationInParent())) {
+				Block block= ast.newBlock();
+				block.statements().add(rewrite.createMoveTarget(nodeToAssign));
+				rewrite.replace(nodeToAssign, block, null);
+			}
+
+			if (needsSemicolon(expression)) {
+				VariableDeclarationStatement varStatement= ast.newVariableDeclarationStatement(newDeclFrag);
+				varStatement.setType(type);
+				rewrite.replace(expression, varStatement, null);
+			} else {
+				// trick for bug 43248: use an VariableDeclarationExpression and keep the ExpressionStatement
+				VariableDeclarationExpression varExpression= ast.newVariableDeclarationExpression(newDeclFrag);
+				varExpression.setType(type);
+				rewrite.replace(expression, varExpression, null);
+			}
+			setEndPosition(rewrite.track(nodeToAssign)); // set cursor after expression statement
 		} else {
-			// trick for bug 43248: use an VariableDeclarationExpression and keep the ExpressionStatement
+			TryStatement tryStatement= null;
+			boolean modifyExistingTry= false;
+			TryStatement enclosingTry= (TryStatement)ASTResolving.findAncestor(nodeToAssign, ASTNode.TRY_STATEMENT);
+			ListRewrite resourcesRewriter= null;
+			ListRewrite clausesRewriter= null;
+			if (enclosingTry == null || enclosingTry.getBody() == null || enclosingTry.getBody().statements().get(0) != nodeToAssign) {
+				tryStatement= ast.newTryStatement();
+			} else {
+				modifyExistingTry= true;
+				resourcesRewriter= rewrite.getListRewrite(enclosingTry, TryStatement.RESOURCES2_PROPERTY);
+				clausesRewriter= rewrite.getListRewrite(enclosingTry, TryStatement.CATCH_CLAUSES_PROPERTY);
+			}
+
 			VariableDeclarationExpression varExpression= ast.newVariableDeclarationExpression(newDeclFrag);
 			varExpression.setType(type);
-			rewrite.replace(expression, varExpression, null);
+			EmptyStatement blankLine= null;
+			if (modifyExistingTry) {
+				resourcesRewriter.insertLast(varExpression, null);
+			} else {
+				tryStatement.resources().add(varExpression);
+				blankLine = (EmptyStatement) rewrite.createStringPlaceholder("", ASTNode.EMPTY_STATEMENT); //$NON-NLS-1$
+				tryStatement.getBody().statements().add(blankLine);
+			}
+
+
+			CatchClause catchClause= ast.newCatchClause();
+			SingleVariableDeclaration decl= ast.newSingleVariableDeclaration();
+			Selection selection= Selection.createFromStartLength(expression.getStartPosition(), expression.getLength());
+			String varName= StubUtility.getExceptionVariableName(fCUnit.getJavaProject());
+			SurroundWithTryWithResourcesAnalyzer analyzer= new SurroundWithTryWithResourcesAnalyzer(fCUnit, selection);
+			expression.getRoot().accept(analyzer);
+			CodeScopeBuilder.Scope scope= CodeScopeBuilder.perform(analyzer.getEnclosingBodyDeclaration(), selection).
+					findScope(selection.getOffset(), selection.getLength());
+			scope.setCursor(selection.getOffset());
+			String name= scope.createName(varName, false);
+			decl.setName(ast.newSimpleName(name));
+			ITypeBinding[] exceptions= 	ExceptionAnalyzer.perform(expression.getParent(), selection, false);
+			List<ITypeBinding> allExceptions= new ArrayList<>(Arrays.asList(exceptions));
+			List<ITypeBinding> mustRethrowList= new ArrayList<>();
+
+			if (fTypeBinding != null) {
+				IMethodBinding close= SurroundWithTryWithResourcesRefactoring.findAutocloseMethod(fTypeBinding);
+				if (close != null) {
+					for (ITypeBinding exceptionType : close.getExceptionTypes()) {
+						if (!allExceptions.contains(exceptionType)) {
+							allExceptions.add(exceptionType);
+						}
+					}
+				}
+			}
+			List<ITypeBinding> catchExceptions= analyzer.calculateCatchesAndRethrows(ASTNodes.filterSubtypes(allExceptions), mustRethrowList);
+			if (catchExceptions.size() > 0) {
+				ImportRewriteContext context= new ContextSensitiveImportRewriteContext(analyzer.getEnclosingBodyDeclaration(), importRewrite);
+				LinkedProposalModel linkedProposalModel= new LinkedProposalModel();
+				int i= 0;
+				if (!modifyExistingTry) {
+					for (ITypeBinding mustThrow : mustRethrowList) {
+						CatchClause newClause= ast.newCatchClause();
+						SingleVariableDeclaration newDecl= ast.newSingleVariableDeclaration();
+						newDecl.setName(ast.newSimpleName(name));
+						Type importType= importRewrite.addImport(mustThrow, ast, context, TypeLocation.EXCEPTION);
+						newDecl.setType(importType);
+						newClause.setException(newDecl);
+						ThrowStatement newThrowStatement= ast.newThrowStatement();
+						newThrowStatement.setExpression(ast.newSimpleName(name));
+						linkedProposalModel.getPositionGroup(GROUP_EXC_NAME + i, true).addPosition(rewrite.track(decl.getName()), false);
+						newClause.getBody().statements().add(newThrowStatement);
+						tryStatement.catchClauses().add(newClause);
+						++i;
+					}
+				}
+				List<ITypeBinding> filteredExceptions= ASTNodes.filterSubtypes(catchExceptions);
+				UnionType unionType= ast.newUnionType();
+				List<Type> types= unionType.types();
+				for (ITypeBinding exception : filteredExceptions) {
+					Type importType= importRewrite.addImport(exception, ast, context, TypeLocation.EXCEPTION);
+					types.add(importType);
+					linkedProposalModel.getPositionGroup(GROUP_EXC_TYPE + i, true).addPosition(rewrite.track(type), i == 0);
+					i++;
+				}
+				decl.setType(unionType);
+				catchClause.setException(decl);
+				linkedProposalModel.getPositionGroup(GROUP_EXC_NAME + 0, true).addPosition(rewrite.track(decl.getName()), false);
+				Statement st= getCatchBody(rewrite, expression, "Exception", name, fCUnit.findRecommendedLineSeparator()); //$NON-NLS-1$
+				if (st != null) {
+					catchClause.getBody().statements().add(st);
+				}
+				if (modifyExistingTry) {
+					clausesRewriter.insertLast(catchClause, null);
+				} else {
+					tryStatement.catchClauses().add(catchClause);
+				}
+			}
+			if (modifyExistingTry) {
+				rewrite.remove(nodeToAssign, null);
+			} else {
+				rewrite.replace(expression, tryStatement, null);
+				setEndPosition(rewrite.track(blankLine));
+			}
+
 		}
 
 		addLinkedPosition(rewrite.track(newDeclFrag.getName()), true, KEY_NAME);
 		addLinkedPosition(rewrite.track(type), false, KEY_TYPE);
-		setEndPosition(rewrite.track(nodeToAssign)); // set cursor after expression statement
 
 		return rewrite;
 	}
 
+	private Statement getCatchBody(ASTRewrite rewrite, Expression expression, String type, String name, String lineSeparator) throws CoreException {
+		String s= StubUtility.getCatchBodyContent(fCUnit, type, name, expression, lineSeparator);
+		if (s == null) {
+			return null;
+		} else {
+			return (Statement)rewrite.createStringPlaceholder(s, ASTNode.RETURN_STATEMENT);
+		}
+	}
+
 	private boolean needsSemicolon(Expression expression) {
 		if ((expression.getParent().getFlags() & ASTNode.RECOVERED) != 0) {
 			try {
@@ -325,9 +484,8 @@ public class AssignToVariableAssistProposal extends LinkedCorrectionProposal {
 		addLinkedPosition(rewrite.track(accessName), true, KEY_NAME + index);
 		IVariableBinding variableBinding= newDeclFrag.resolveBinding();
 		if (variableBinding != null) {
-			SimpleName[] linkedNodes= LinkedNodeFinder.findByBinding(nodeToAssign.getRoot(), variableBinding);
-			for (int i= 0; i < linkedNodes.length; i++) {
-				addLinkedPosition(rewrite.track(linkedNodes[i]), false, KEY_NAME + index);
+			for (SimpleName linkedNode : LinkedNodeFinder.findByBinding(nodeToAssign.getRoot(), variableBinding)) {
+				addLinkedPosition(rewrite.track(linkedNode), false, KEY_NAME + index);
 			}
 		}
 		setEndPosition(rewrite.track(selectionNode));
@@ -354,8 +512,8 @@ public class AssignToVariableAssistProposal extends LinkedCorrectionProposal {
 		List<BodyDeclaration> decls= ASTNodes.getBodyDeclarations(newTypeDecl);
 		AST ast= newTypeDecl.getAST();
 		String[] varNames= suggestFieldNames(typeBinding, expression, modifiers, nodeToAssign);
-		for (int i= 0; i < varNames.length; i++) {
-			addLinkedPositionProposal(KEY_NAME + index, varNames[i], null);
+		for (String varName : varNames) {
+			addLinkedPositionProposal(KEY_NAME + index, varName, null);
 		}
 		String varName= varNames[0];
 
@@ -368,7 +526,7 @@ public class AssignToVariableAssistProposal extends LinkedCorrectionProposal {
 		newDecl.setType(type);
 		newDecl.modifiers().addAll(ASTNodeFactory.newModifiers(ast, modifiers));
 
-		ModifierCorrectionSubProcessor.installLinkedVisibilityProposals(getLinkedProposalModel(), rewrite, newDecl.modifiers(), false, ModifierCorrectionSubProcessor.KEY_MODIFIER + index);
+		ModifierCorrectionSubProcessorCore.installLinkedVisibilityProposals(getLinkedProposalModel(), rewrite, newDecl.modifiers(), false, ModifierCorrectionSubProcessorCore.KEY_MODIFIER + index);
 
 		int insertIndex= findFieldInsertIndex(decls, nodeToAssign.getStartPosition()) + index;
 		rewrite.getListRewrite(newTypeDecl, property).insertAt(newDecl, insertIndex, null);
@@ -377,9 +535,10 @@ public class AssignToVariableAssistProposal extends LinkedCorrectionProposal {
 	}
 
 	private Type evaluateType(AST ast, ASTNode nodeToAssign, ITypeBinding typeBinding, String groupID, TypeLocation location) {
-		ITypeBinding[] proposals= ASTResolving.getRelaxingTypes(ast, typeBinding);
-		for (int i= 0; i < proposals.length; i++) {
-			addLinkedPositionProposal(groupID, proposals[i]);
+		for (ITypeBinding proposal : ASTResolving.getRelaxingTypes(ast, typeBinding)) {
+			if (fVariableKind != TRY_WITH_RESOURCES || Bindings.findTypeInHierarchy(proposal, "java.lang.AutoCloseable") != null) { //$NON-NLS-1$
+				addLinkedPositionProposal(groupID, proposal);
+			}
 		}
 		ImportRewrite importRewrite= getImportRewrite();
 		CompilationUnit cuNode= (CompilationUnit) nodeToAssign.getRoot();
@@ -399,7 +558,29 @@ public class AssignToVariableAssistProposal extends LinkedCorrectionProposal {
 	}
 
 	private Collection<String> getUsedVariableNames(ASTNode nodeToAssign) {
-		return Arrays.asList(ASTResolving.getUsedVariableNames(nodeToAssign));
+		Collection<String> usedVarNames = Arrays.asList(ASTResolving.getUsedVariableNames(nodeToAssign));
+		Collection<String> additionalVarNames= getRemainingParamNamed(nodeToAssign);
+		if (additionalVarNames != null) {
+			usedVarNames = new ArrayList<>(Arrays.asList(ASTResolving.getUsedVariableNames(nodeToAssign)));
+			usedVarNames.addAll(additionalVarNames);
+		}
+		return usedVarNames;
+	}
+
+	private ArrayList<String> getRemainingParamNamed(ASTNode nodeToAssign) {
+		ArrayList<String> paramNames = null;
+		if (fParamNames != null) {
+			paramNames = new ArrayList<>();
+			paramNames.addAll(fParamNames);
+			if (nodeToAssign instanceof SingleVariableDeclaration
+					&& ((SingleVariableDeclaration)nodeToAssign).getName() != null) {
+				int index= fNodesToAssign.indexOf(nodeToAssign);
+				if (index >= 0 && index < paramNames.size()) {
+					paramNames.remove(index);
+				}
+			}
+		}
+		return paramNames;
 	}
 
 	private int findAssignmentInsertIndex(List<Statement> statements, ASTNode nodeToAssign) {
