@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -48,6 +48,7 @@ import org.eclipse.jdt.core.dom.MethodDeclaration;
 import org.eclipse.jdt.core.dom.Name;
 import org.eclipse.jdt.core.dom.ParameterizedType;
 import org.eclipse.jdt.core.dom.ProvidesDirective;
+import org.eclipse.jdt.core.dom.TypeDeclaration;
 import org.eclipse.jdt.core.dom.rewrite.ImportRewrite;
 
 import org.eclipse.jdt.internal.core.manipulation.StubUtility;
@@ -72,6 +73,7 @@ import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.JavaPluginImages;
 import org.eclipse.jdt.internal.ui.text.correction.CorrectionMessages;
 import org.eclipse.jdt.internal.ui.text.correction.UnresolvedElementsSubProcessor;
+import org.eclipse.jdt.internal.ui.util.ASTHelper;
 import org.eclipse.jdt.internal.ui.viewsupport.BindingLabelProvider;
 import org.eclipse.jdt.internal.ui.wizards.NewAnnotationCreationWizard;
 import org.eclipse.jdt.internal.ui.wizards.NewClassCreationWizard;
@@ -409,9 +411,8 @@ public class NewCUUsingWizardProposal extends ChangeCorrectionProposal {
 				break;
 			case ASTNode.VARIABLE_DECLARATION_STATEMENT:
 			case ASTNode.FIELD_DECLARATION:
+			case ASTNode.PARAMETERIZED_TYPE: // Inheritance doesn't help: A<X> z= new A<String>(); ->
 				return null; // no guessing for LHS types, cannot be a supertype of a known type
-			case ASTNode.PARAMETERIZED_TYPE:
-				return null; // Inheritance doesn't help: A<X> z= new A<String>(); ->
 			case ASTNode.PROVIDES_DIRECTIVE:
 				if (node.getLocationInParent() == ProvidesDirective.IMPLEMENTATIONS_PROPERTY) {
 					Name serviceName= ((ProvidesDirective) parent).getName();
@@ -421,6 +422,11 @@ public class NewCUUsingWizardProposal extends ChangeCorrectionProposal {
 					}
 				}
 				break;
+			case ASTNode.TYPE_DECLARATION:
+				if (ASTHelper.isSealedTypeSupportedInAST(ast) && node.getLocationInParent() == TypeDeclaration.PERMITS_TYPES_PROPERTY) {
+					return ((TypeDeclaration) parent).resolveBinding();
+				}
+				break;
 		}
 		ITypeBinding binding= ASTResolving.guessBindingForTypeReference(node);
 		if (binding != null && !binding.isRecovered()) {
