@@ -292,9 +292,7 @@ public class JavadocHover extends AbstractJavaEditorTextHover {
 			try {
 				//FIXME: add hover location to editor navigation history?
 				openDeclaration(infoInput.getElement());
-			} catch (PartInitException e) {
-				JavaPlugin.log(e);
-			} catch (JavaModelException e) {
+			} catch (PartInitException | JavaModelException e) {
 				JavaPlugin.log(e);
 			}
 		}
@@ -353,21 +351,18 @@ public class JavadocHover extends AbstractJavaEditorTextHover {
 					tbm.add(openAttachedJavadocAction);
 				}
 
-				IInputChangedListener inputChangeListener= new IInputChangedListener() {
-					@Override
-					public void inputChanged(Object newInput) {
-						backAction.update();
-						forwardAction.update();
-						if (newInput == null) {
-							selectionProvider.setSelection(new StructuredSelection());
-						} else if (newInput instanceof BrowserInformationControlInput) {
-							BrowserInformationControlInput input= (BrowserInformationControlInput) newInput;
-							Object inputElement= input.getInputElement();
-							selectionProvider.setSelection(new StructuredSelection(inputElement));
-							boolean isJavaElementInput= inputElement instanceof IJavaElement;
-							showInJavadocViewAction.setEnabled(isJavaElementInput);
-							openDeclarationAction.setEnabled(isJavaElementInput);
-						}
+				IInputChangedListener inputChangeListener= newInput -> {
+					backAction.update();
+					forwardAction.update();
+					if (newInput == null) {
+						selectionProvider.setSelection(new StructuredSelection());
+					} else if (newInput instanceof BrowserInformationControlInput) {
+						BrowserInformationControlInput input= (BrowserInformationControlInput) newInput;
+						Object inputElement= input.getInputElement();
+						selectionProvider.setSelection(new StructuredSelection(inputElement));
+						boolean isJavaElementInput= inputElement instanceof IJavaElement;
+						showInJavadocViewAction.setEnabled(isJavaElementInput);
+						openDeclarationAction.setEnabled(isJavaElementInput);
 					}
 				};
 				iControl.addInputChangeListener(inputChangeListener);
@@ -446,12 +441,7 @@ public class JavadocHover extends AbstractJavaEditorTextHover {
 				return new DefaultInformationControl(parent, tooltipAffordanceString) {
 					@Override
 					public IInformationControlCreator getInformationPresenterControlCreator() {
-						return new IInformationControlCreator() {
-							@Override
-							public IInformationControl createInformationControl(Shell parentShell) {
-								return new DefaultInformationControl(parentShell, (ToolBarManager) null, new FallbackInformationPresenter());
-							}
-						};
+						return parentShell -> new DefaultInformationControl(parentShell, (ToolBarManager) null, new FallbackInformationPresenter());
 					}
 				};
 			}
@@ -461,8 +451,8 @@ public class JavadocHover extends AbstractJavaEditorTextHover {
 		public void propertyChange(PropertyChangeEvent event) {
 			String property= event.getProperty();
 			if (iControl != null &&
-					(property.equals("org.eclipse.jdt.ui.Javadoc.foregroundColor") //$NON-NLS-1$
-							|| property.equals("org.eclipse.jdt.ui.Javadoc.backgroundColor"))) { //$NON-NLS-1$
+					("org.eclipse.jdt.ui.Javadoc.foregroundColor".equals(property) //$NON-NLS-1$
+							|| "org.eclipse.jdt.ui.Javadoc.backgroundColor".equals(property))) { //$NON-NLS-1$
 				setHoverColors();
 			}
 		}
@@ -628,9 +618,7 @@ public class JavadocHover extends AbstractJavaEditorTextHover {
 				try {
 					//FIXME: add hover location to editor navigation history?
 					openDeclaration(linkTarget);
-				} catch (PartInitException e) {
-					JavaPlugin.log(e);
-				} catch (JavaModelException e) {
+				} catch (PartInitException | JavaModelException e) {
 					JavaPlugin.log(e);
 				}
 			}
@@ -811,11 +799,11 @@ public class JavadocHover extends AbstractJavaEditorTextHover {
 		ASTNode node= haveSource ? getHoveredASTNode(editorInputElement, hoverRegion) : null;
 		IBinding binding= getHoverBinding(element, node);
 
-		StringBuffer label;
+		StringBuilder label;
 		if (binding != null) {
-			label= new StringBuffer(JavaElementLinks.getBindingLabel(binding, element, flags, haveSource));
+			label= new StringBuilder(JavaElementLinks.getBindingLabel(binding, element, flags, haveSource));
 		} else {
-			label= new StringBuffer(JavaElementLinks.getElementLabel(element, flags));
+			label= new StringBuilder(JavaElementLinks.getElementLabel(element, flags));
 		}
 
 		if (element.getElementType() == IJavaElement.FIELD) {
@@ -919,7 +907,7 @@ public class JavadocHover extends AbstractJavaEditorTextHover {
 	 */
 	public static IBinding getHoverBinding(IJavaElement element, ASTNode node) {
 
-		if (element.getJavaProject().getOption(JavaCore.COMPILER_ANNOTATION_NULL_ANALYSIS, true).equals(JavaCore.ENABLED)) {
+		if (JavaCore.ENABLED.equals(element.getJavaProject().getOption(JavaCore.COMPILER_ANNOTATION_NULL_ANALYSIS, true))) {
 			if (node == null) {
 				if (element instanceof ISourceReference) {
 					ASTParser p= ASTParser.newParser(IASTSharedValues.SHARED_AST_LEVEL);
@@ -1114,7 +1102,7 @@ public class JavadocHover extends AbstractJavaEditorTextHover {
 					element= null; // no link
 				}
 			}
-			StringBuffer imageStyle= new StringBuffer("border:none; position: absolute; "); //$NON-NLS-1$
+			StringBuilder imageStyle= new StringBuilder("border:none; position: absolute; "); //$NON-NLS-1$
 			imageStyle.append("width: ").append(imageWidth).append("px; "); //$NON-NLS-1$ //$NON-NLS-2$
 			imageStyle.append("height: ").append(imageHeight).append("px; "); //$NON-NLS-1$ //$NON-NLS-2$
 			imageStyle.append("left: ").append(- labelLeft - 1).append("px; "); //$NON-NLS-1$ //$NON-NLS-2$
@@ -1167,10 +1155,7 @@ public class JavadocHover extends AbstractJavaEditorTextHover {
 					}
 				}
 			}
-		} catch (JavaModelException e) {
-			// no annotations this time...
-			buf.append("<br>"); //$NON-NLS-1$
-		} catch (URISyntaxException e) {
+		} catch (JavaModelException | URISyntaxException e) {
 			// no annotations this time...
 			buf.append("<br>"); //$NON-NLS-1$
 		}
@@ -1304,7 +1289,7 @@ public class JavadocHover extends AbstractJavaEditorTextHover {
 			buf.append(ASTNodes.getEscapedStringLiteral((String)value));
 
 		} else if (value instanceof Character) {
-			buf.append(ASTNodes.getEscapedCharacterLiteral(((Character)value).charValue()));
+			buf.append(ASTNodes.getEscapedCharacterLiteral(((Character)value)));
 
 		} else if (value instanceof Object[]) {
 			Object[] values= (Object[])value;
@@ -1330,7 +1315,7 @@ public class JavadocHover extends AbstractJavaEditorTextHover {
 		if (constantValue instanceof Character) {
 			String constantResult= '\'' + constantValue.toString() + '\'';
 
-			char charValue= ((Character) constantValue).charValue();
+			char charValue= ((Character) constantValue);
 			String hexString= Integer.toHexString(charValue);
 			StringBuilder hexResult= new StringBuilder("\\u"); //$NON-NLS-1$
 			for (int i= hexString.length(); i < 4; i++) {
@@ -1348,11 +1333,11 @@ public class JavadocHover extends AbstractJavaEditorTextHover {
 			return formatWithHexValue(constantValue, "0x" + Integer.toHexString(shortValue)); //$NON-NLS-1$
 
 		} else if (constantValue instanceof Integer) {
-			int intValue= ((Integer) constantValue).intValue();
+			int intValue= ((Integer) constantValue);
 			return formatWithHexValue(constantValue, "0x" + Integer.toHexString(intValue)); //$NON-NLS-1$
 
 		} else if (constantValue instanceof Long) {
-			long longValue= ((Long) constantValue).longValue();
+			long longValue= ((Long) constantValue);
 			return formatWithHexValue(constantValue, "0x" + Long.toHexString(longValue)); //$NON-NLS-1$
 
 		} else {
