@@ -26,12 +26,11 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.TabFolder;
 import org.eclipse.swt.widgets.TabItem;
 
-import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
-import org.eclipse.core.runtime.IProgressMonitor;
 
 import org.eclipse.core.resources.IWorkspaceRunnable;
 
+import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.jface.window.Window;
@@ -42,6 +41,7 @@ import org.eclipse.jdt.core.IClasspathAttribute;
 import org.eclipse.jdt.core.IClasspathEntry;
 import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.IJavaProject;
+import org.eclipse.jdt.core.JavaCore;
 
 import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.internal.corext.util.Messages;
@@ -126,15 +126,12 @@ public abstract class BuildPathBasePage {
 		IJavaElement[] selectedJavaElements;
 		IJavaProject javaProject= element.getJavaProject();
 		IClasspathEntry newEntry= element.getClasspathEntry();
-		IWorkspaceRunnable runnable= new IWorkspaceRunnable() {
-			@Override
-			public void run(IProgressMonitor monitor) throws CoreException {
-				IClasspathEntry[] oldClasspath= javaProject.getRawClasspath();
-				int nEntries= oldClasspath.length;
-				IClasspathEntry[] newEntries= Arrays.copyOf(oldClasspath, nEntries+1);
-				newEntries[nEntries]= newEntry;
-				javaProject.setRawClasspath(newEntries, monitor);
-			}
+		IWorkspaceRunnable runnable= monitor -> {
+			IClasspathEntry[] oldClasspath= javaProject.getRawClasspath();
+			int nEntries= oldClasspath.length;
+			IClasspathEntry[] newEntries= Arrays.copyOf(oldClasspath, nEntries+1);
+			newEntries[nEntries]= newEntry;
+			javaProject.setRawClasspath(newEntries, monitor);
 		};
 		PlatformUI.getWorkbench().getProgressService().run(true, true, new WorkbenchRunnableAdapter(runnable));
 		selectedJavaElements= ModuleEncapsulationDetail.getTargetJavaElements(element.getJavaProject(), element.getPath());
@@ -263,8 +260,7 @@ public abstract class BuildPathBasePage {
 		if (selElements.isEmpty()) {
 			return true;
 		}
-		for (int i= 0; i < selElements.size(); i++) {
-			Object elem= selElements.get(i);
+		for (Object elem : selElements) {
 			if (elem instanceof CPListElement) {
 				if (((CPListElement) elem).getParentContainer() != null) {
 					return false;
@@ -357,7 +353,7 @@ public abstract class BuildPathBasePage {
 		}
 	}
 
-	protected abstract class CPListAdapter implements IDialogFieldListener, ITreeListAdapter<CPListElement> {
+	protected abstract static class CPListAdapter implements IDialogFieldListener, ITreeListAdapter<CPListElement> {
 		private final Object[] EMPTY_ARR= new Object[0];
 
 		@Override
@@ -402,4 +398,25 @@ public abstract class BuildPathBasePage {
 		}
 		return null;
 	}
+
+	protected Shell getShell() {
+		if (fSWTControl != null) {
+			return fSWTControl.getShell();
+		}
+		return JavaPlugin.getActiveWorkbenchShell();
+	}
+
+	protected void checkAttributeEffect(String key, IJavaProject javaProject) {
+		if (IClasspathAttribute.EXTERNAL_ANNOTATION_PATH.equals(key)) {
+			if (JavaCore.DISABLED.equals(javaProject.getOption(JavaCore.COMPILER_ANNOTATION_NULL_ANALYSIS, true))) {
+				MessageDialog messageDialog= new MessageDialog(getShell(),
+						NewWizardMessages.LibrariesWorkbookPage_externalAnnotationNeedsNullAnnotationEnabled_title,
+						null,
+						NewWizardMessages.LibrariesWorkbookPage_externalAnnotationNeedsNullAnnotationEnabled_message,
+						MessageDialog.INFORMATION, new String[] { IDialogConstants.OK_LABEL },
+						0);
+				messageDialog.open();
+			}
+		}
+	}
 }
