@@ -105,7 +105,7 @@ import org.eclipse.jdt.internal.ui.wizards.dialogfields.StringButtonDialogField;
 
 public class BuildPathsBlock {
 
-	public static interface IRemoveOldBinariesQuery {
+	public interface IRemoveOldBinariesQuery {
 
 		/**
 		 * Do the callback. Returns <code>true</code> if .class files should be removed from the
@@ -319,10 +319,9 @@ public class BuildPathsBlock {
 	 */
 	public void init(IJavaProject jproject, IPath outputLocation, IClasspathEntry[] classpathEntries) {
 		fCurrJProject= jproject;
-		boolean projectExists= false;
 		List<CPListElement> newClassPath= null;
 		IProject project= fCurrJProject.getProject();
-		projectExists= (project.exists() && project.getFile(".classpath").exists()); //$NON-NLS-1$
+		boolean projectExists= (project.exists() && project.getFile(".classpath").exists()); //$NON-NLS-1$
 		IClasspathEntry[] existingEntries= null;
 		if  (projectExists) {
 			if (outputLocation == null) {
@@ -380,14 +379,11 @@ public class BuildPathsBlock {
 		if (Display.getCurrent() != null) {
 			doUpdateUI();
 		} else {
-			Display.getDefault().asyncExec(new Runnable() {
-				@Override
-				public void run() {
-					if (fSWTWidget == null || fSWTWidget.isDisposed()) {
-						return;
-					}
-					doUpdateUI();
+			Display.getDefault().asyncExec(() -> {
+				if (fSWTWidget == null || fSWTWidget.isDisposed()) {
+					return;
 				}
+				doUpdateUI();
 			});
 		}
 	}
@@ -682,7 +678,7 @@ public class BuildPathsBlock {
 		String pathStr= fBuildPathDialogField.getText();
 		Path outputPath= (new Path(pathStr));
 		pathStr= outputPath.lastSegment();
-		if (pathStr.equals(".settings") && outputPath.segmentCount() == 2) { //$NON-NLS-1$
+		if (".settings".equals(pathStr) && outputPath.segmentCount() == 2) { //$NON-NLS-1$
 			fOutputFolderStatus.setWarning(NewWizardMessages.OutputLocation_SettingsAsLocation);
 		}
 
@@ -812,12 +808,9 @@ public class BuildPathsBlock {
 			} else if (!outputLocation.equals(oldOutputLocation)) {
 				IFolder folder= ResourcesPlugin.getWorkspace().getRoot().getFolder(oldOutputLocation);
 				if (folder.exists()) {
-					if (folder.members().length == 0) {
+					if (folder.members().length == 0
+							|| BuildPathsBlock.getRemoveOldBinariesQuery(JavaPlugin.getActiveWorkbenchShell()).doQuery(folder.isDerived(), oldOutputLocation)) {
 						BuildPathsBlock.removeOldClassfiles(folder);
-					} else {
-						if (BuildPathsBlock.getRemoveOldBinariesQuery(JavaPlugin.getActiveWorkbenchShell()).doQuery(folder.isDerived(), oldOutputLocation)) {
-							BuildPathsBlock.removeOldClassfiles(folder);
-						}
 					}
 				}
 			}
@@ -973,33 +966,27 @@ public class BuildPathsBlock {
 	}
 
 	public static IRemoveOldBinariesQuery getRemoveOldBinariesQuery(final Shell shell) {
-		return new IRemoveOldBinariesQuery() {
-			@Override
-			public boolean doQuery(final boolean removeFolder, final IPath oldOutputLocation) throws OperationCanceledException {
-				final int[] res= new int[] { 1 };
-				Display.getDefault().syncExec(new Runnable() {
-					@Override
-					public void run() {
-						Shell sh= shell != null ? shell : JavaPlugin.getActiveWorkbenchShell();
-						String title= NewWizardMessages.BuildPathsBlock_RemoveBinariesDialog_title;
-						String message;
-						String pathLabel= BasicElementLabels.getPathLabel(oldOutputLocation, false);
-						if (removeFolder) {
-							message= Messages.format(NewWizardMessages.BuildPathsBlock_RemoveOldOutputFolder_description, pathLabel);
-						} else {
-							message= Messages.format(NewWizardMessages.BuildPathsBlock_RemoveBinariesDialog_description, pathLabel);
-						}
-						MessageDialog dialog= new MessageDialog(sh, title, null, message, MessageDialog.QUESTION, new String[] { IDialogConstants.YES_LABEL, IDialogConstants.NO_LABEL, IDialogConstants.CANCEL_LABEL }, 0);
-						res[0]= dialog.open();
-					}
-				});
-				if (res[0] == 0) {
-					return true;
-				} else if (res[0] == 1) {
-					return false;
+		return (removeFolder, oldOutputLocation) -> {
+			final int[] res= new int[] { 1 };
+			Display.getDefault().syncExec(() -> {
+				Shell sh= shell != null ? shell : JavaPlugin.getActiveWorkbenchShell();
+				String title= NewWizardMessages.BuildPathsBlock_RemoveBinariesDialog_title;
+				String message;
+				String pathLabel= BasicElementLabels.getPathLabel(oldOutputLocation, false);
+				if (removeFolder) {
+					message= Messages.format(NewWizardMessages.BuildPathsBlock_RemoveOldOutputFolder_description, pathLabel);
+				} else {
+					message= Messages.format(NewWizardMessages.BuildPathsBlock_RemoveBinariesDialog_description, pathLabel);
 				}
-				throw new OperationCanceledException();
+				MessageDialog dialog= new MessageDialog(sh, title, null, message, MessageDialog.QUESTION, new String[] { IDialogConstants.YES_LABEL, IDialogConstants.NO_LABEL, IDialogConstants.CANCEL_LABEL }, 0);
+				res[0]= dialog.open();
+			});
+			if (res[0] == 0) {
+				return true;
+			} else if (res[0] == 1) {
+				return false;
 			}
+			throw new OperationCanceledException();
 		};
 	}
 
@@ -1152,8 +1139,4 @@ public class BuildPathsBlock {
 	public void setFocus() {
 		fSourceContainerPage.setFocus();
     }
-
-	public BuildPathBasePage getSourceContainerPage() {
-		return fSourceContainerPage;
-	}
 }
