@@ -137,6 +137,7 @@ public class CPListElement {
 				createAttributeElement(INCLUSION, new Path[0], true);
 				createAttributeElement(EXCLUSION, new Path[0], true);
 				createAttributeElement(NATIVE_LIB_PATH, null, false);
+				createAttributeElement(IClasspathAttribute.EXTERNAL_ANNOTATION_PATH, null, false);
 				createAttributeElement(IGNORE_OPTIONAL_PROBLEMS, null, false);
 				createAttributeElement(TEST, null, false);
 				break;
@@ -239,8 +240,7 @@ public class CPListElement {
 
 	private IClasspathAttribute[] getClasspathAttributes() {
 		ArrayList<IClasspathAttribute> res= new ArrayList<>();
-		for (int i= 0; i < fChildren.size(); i++) {
-			Object curr= fChildren.get(i);
+		for (Object curr : fChildren) {
 			if (curr instanceof CPListElementAttribute) {
 				CPListElementAttribute elem= (CPListElementAttribute) curr;
 				if (!elem.isBuiltIn()) {
@@ -293,7 +293,7 @@ public class CPListElement {
 			}
 			case IClasspathEntry.CPE_PROJECT: {
 				IAccessRule[] accesRules= (IAccessRule[]) getAttribute(ACCESSRULES);
-				boolean combineAccessRules= ((Boolean) getAttribute(COMBINE_ACCESSRULES)).booleanValue();
+				boolean combineAccessRules= ((Boolean) getAttribute(COMBINE_ACCESSRULES));
 				return JavaCore.newProjectEntry(fPath, accesRules, combineAccessRules, extraAttributes, isExported());
 			}
 			case IClasspathEntry.CPE_CONTAINER: {
@@ -350,14 +350,14 @@ public class CPListElement {
 		if (attribute == null) {
 			return null;
 		}
-		if (key.equals(EXCLUSION) || key.equals(INCLUSION)) {
+		if (EXCLUSION.equals(key) || INCLUSION.equals(key)) {
 			Assert.isTrue(value != null || fEntryKind != IClasspathEntry.CPE_SOURCE);
 		}
 
-		if (key.equals(ACCESSRULES)) {
+		if (ACCESSRULES.equals(key)) {
 			Assert.isTrue(value != null || fEntryKind == IClasspathEntry.CPE_SOURCE);
 		}
-		if (key.equals(COMBINE_ACCESSRULES)) {
+		if (COMBINE_ACCESSRULES.equals(key)) {
 			Assert.isTrue(value instanceof Boolean);
 		}
 
@@ -418,8 +418,7 @@ public class CPListElement {
 	}
 
 	public CPListElementAttribute findAttributeElement(String key) {
-		for (int i= 0; i < fChildren.size(); i++) {
-			Object curr= fChildren.get(i);
+		for (Object curr : fChildren) {
 			if (curr instanceof CPListElementAttribute) {
 				CPListElementAttribute elem= (CPListElementAttribute) curr;
 				if (key.equals(elem.getKey())) {
@@ -441,8 +440,7 @@ public class CPListElement {
 
 	public CPListElementAttribute[] getAllAttributes() {
 		ArrayList<Object> res= new ArrayList<>();
-		for (int i= 0; i < fChildren.size(); i++) {
-			Object curr= fChildren.get(i);
+		for (Object curr : fChildren) {
 			if (curr instanceof CPListElementAttribute) {
 				res.add(curr);
 			}
@@ -484,7 +482,7 @@ public class CPListElement {
 			if (curr.isNotSupported()) {
 				return true;
 			}
-			if (!curr.isBuiltIn() && !key.equals(CPListElement.JAVADOC) && !key.equals(CPListElement.NATIVE_LIB_PATH) && !key.equals(CPListElement.IGNORE_OPTIONAL_PROBLEMS)) {
+			if (!curr.isBuiltIn() && !CPListElement.JAVADOC.equals(key) && !key.equals(CPListElement.NATIVE_LIB_PATH) && !CPListElement.IGNORE_OPTIONAL_PROBLEMS.equals(key)) {
 				return !JavaPlugin.getDefault().getClasspathAttributeConfigurationDescriptors().containsKey(key);
 			}
 		}
@@ -495,8 +493,7 @@ public class CPListElement {
 		int nChildren= fChildren.size();
 		ArrayList<Object> res= new ArrayList<>(nChildren);
 
-		for (int i= 0; i < nChildren; i++) {
-			Object curr= fChildren.get(i);
+		for (Object curr : fChildren) {
 			if (!isFiltered(curr, filteredKeys)) {
 				res.add(curr);
 			}
@@ -651,8 +648,7 @@ public class CPListElement {
 	 * @return Returns a boolean
 	 */
 	public boolean hasMissingChildren() {
-		for (int i= 0; i < fChildren.size(); i++) {
-			Object curr= fChildren.get(i);
+		for (Object curr : fChildren) {
 			if (curr instanceof CPListElement && ((CPListElement) curr).isMissing()) {
 				return true;
 			}
@@ -784,14 +780,14 @@ public class CPListElement {
 			if (attribElem == null) {
 				if (!isModuleAttribute(attrib.getName())) {
 					elem.createAttributeElement(attrib.getName(), attrib.getValue(), false);
-				} else if (attrib.getName().equals(MODULE)) {
+				} else if (MODULE.equals(attrib.getName())) {
 					attribElem= new CPListElementAttribute(elem, MODULE, null, true);
 					attribElem.setValue(getModuleAttributeValue(attribElem, attrib, extraAttributes));
 					elem.fChildren.add(attribElem);
 				}
 			} else {
 				Object value= attrib.getValue();
-				if (attrib.getName().equals(MODULE)) {
+				if (MODULE.equals(attrib.getName())) {
 					value= getModuleAttributeValue(attribElem, attrib, extraAttributes);
 				}
 				attribElem.setValue(value);
@@ -884,38 +880,49 @@ public class CPListElement {
 			appendEncodePath(getLinkTarget(), buf).append(';');
 		}
 		buf.append(Boolean.valueOf(fIsExported)).append(';');
-		for (int i= 0; i < fChildren.size(); i++) {
-			Object curr= fChildren.get(i);
+		for (Object curr : fChildren) {
 			if (curr instanceof CPListElementAttribute) {
 				CPListElementAttribute elem= (CPListElementAttribute) curr;
 				if (elem.isBuiltIn()) {
 					String key= elem.getKey();
-					if (OUTPUT.equals(key) || SOURCEATTACHMENT.equals(key)) {
-						appendEncodePath((IPath) elem.getValue(), buf).append(';');
-					} else if (EXCLUSION.equals(key) || INCLUSION.equals(key)) {
-						appendEncodedFilter((IPath[]) elem.getValue(), buf).append(';');
-					} else if (ACCESSRULES.equals(key)) {
-						appendEncodedAccessRules((IAccessRule[]) elem.getValue(), buf).append(';');
-					} else if (COMBINE_ACCESSRULES.equals(key)) {
-						buf.append(((Boolean) elem.getValue()).booleanValue()).append(';');
-					} else if (MODULE.equals(key)) {
-						Object value= elem.getValue();
-						if (value instanceof ModuleEncapsulationDetail[]) {
-							buf.append(MODULE+"=true;"); //$NON-NLS-1$
-							for (ModuleEncapsulationDetail detail : ((ModuleEncapsulationDetail[]) value)) {
-								if (detail instanceof ModulePatch)
-									buf.append(IClasspathAttribute.PATCH_MODULE+':'+detail.toString()).append(';');
-								if (detail instanceof ModuleAddExport)
-									buf.append(IClasspathAttribute.ADD_EXPORTS+':'+detail.toString()).append(';');
-								if (detail instanceof ModuleAddOpens)
-									buf.append(IClasspathAttribute.ADD_OPENS+':'+detail.toString()).append(';');
-								if (detail instanceof ModuleAddReads)
-									buf.append(IClasspathAttribute.ADD_READS+':'+detail.toString()).append(';');
-								if (detail instanceof LimitModules)
-									buf.append(IClasspathAttribute.LIMIT_MODULES+':'+detail.toString()).append(';');
-							}
-						} else {
-							buf.append(MODULE+"=false;"); //$NON-NLS-1$
+					if (key != null) {
+						switch (key) {
+							case OUTPUT:
+							case SOURCEATTACHMENT:
+								appendEncodePath((IPath) elem.getValue(), buf).append(';');
+								break;
+							case EXCLUSION:
+							case INCLUSION:
+								appendEncodedFilter((IPath[]) elem.getValue(), buf).append(';');
+								break;
+							case ACCESSRULES:
+								appendEncodedAccessRules((IAccessRule[]) elem.getValue(), buf).append(';');
+								break;
+							case COMBINE_ACCESSRULES:
+								buf.append(elem.getValue()).append(';');
+								break;
+							case MODULE:
+								Object value= elem.getValue();
+								if (value instanceof ModuleEncapsulationDetail[]) {
+									buf.append(MODULE+"=true;"); //$NON-NLS-1$
+									for (ModuleEncapsulationDetail detail : ((ModuleEncapsulationDetail[]) value)) {
+										if (detail instanceof ModulePatch)
+											buf.append(IClasspathAttribute.PATCH_MODULE+':'+detail.toString()).append(';');
+										if (detail instanceof ModuleAddExport)
+											buf.append(IClasspathAttribute.ADD_EXPORTS+':'+detail.toString()).append(';');
+										if (detail instanceof ModuleAddOpens)
+											buf.append(IClasspathAttribute.ADD_OPENS+':'+detail.toString()).append(';');
+										if (detail instanceof ModuleAddReads)
+											buf.append(IClasspathAttribute.ADD_READS+':'+detail.toString()).append(';');
+										if (detail instanceof LimitModules)
+											buf.append(IClasspathAttribute.LIMIT_MODULES+':'+detail.toString()).append(';');
+									}
+								} else {
+									buf.append(MODULE+"=false;"); //$NON-NLS-1$
+								}
+								break;
+							default:
+								break;
 						}
 					}
 				} else {
@@ -1061,8 +1068,7 @@ public class CPListElement {
 
 	public void updateExtraAttributeOfClasspathEntry() {
 		if (fChildren != null) {
-			for (int i= 0; i < fChildren.size(); i++) {
-				Object curr= fChildren.get(i);
+			for (Object curr : fChildren) {
 				if (curr instanceof CPListElementAttribute) {
 					CPListElementAttribute elem= (CPListElementAttribute) curr;
 					String key= elem.getKey();
