@@ -14,7 +14,6 @@
 package org.eclipse.jdt.internal.ui.wizards.buildpaths;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.equinox.bidi.StructuredTextTypeHandlerFactory;
@@ -51,7 +50,6 @@ import org.eclipse.jdt.internal.corext.buildpath.ClasspathModifier;
 
 import org.eclipse.jdt.ui.actions.AbstractOpenWizardAction;
 
-import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.wizards.NewWizardMessages;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.DialogField;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.IDialogFieldListener;
@@ -92,7 +90,7 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 
 		@Override
 		public void propertyChange(PropertyChangeEvent event) {
-			if (event.getProperty().equals(IAction.RESULT)) {
+			if (IAction.RESULT.equals(event.getProperty())) {
 				if (event.getNewValue().equals(Boolean.TRUE)) {
 					finishWizard();
 				} else {
@@ -185,12 +183,7 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 		if (Display.getCurrent() != null) {
 			updateFoldersList();
 		} else {
-			Display.getDefault().asyncExec(new Runnable() {
-				@Override
-				public void run() {
-					updateFoldersList();
-				}
-			});
+			Display.getDefault().asyncExec(this::updateFoldersList);
 		}
 	}
 
@@ -203,8 +196,7 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 
 		boolean useFolderOutputs= false;
 		List<CPListElement> cpelements= fClassPathList.getElements();
-		for (int i= 0; i < cpelements.size(); i++) {
-			CPListElement cpe= cpelements.get(i);
+		for (CPListElement cpe : cpelements) {
 			if (cpe.getEntryKind() == IClasspathEntry.CPE_SOURCE) {
 				folders.add(cpe);
 				boolean hasOutputFolder= (cpe.getAttribute(CPListElement.OUTPUT) != null);
@@ -217,8 +209,7 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 		fFoldersList.setElements(folders);
 		fUseFolderOutputs.setSelection(useFolderOutputs);
 
-		for (int i= 0; i < folders.size(); i++) {
-			CPListElement cpe= folders.get(i);
+		for (CPListElement cpe : folders) {
 			IPath[] ePatterns= (IPath[]) cpe.getAttribute(CPListElement.EXCLUSION);
 			IPath[] iPatterns= (IPath[])cpe.getAttribute(CPListElement.INCLUSION);
 			boolean hasOutputFolder= (cpe.getAttribute(CPListElement.OUTPUT) != null);
@@ -244,8 +235,7 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 
 		// expand
 		List<CPListElement> elements= fFoldersList.getElements();
-		for (int i= 0; i < elements.size(); i++) {
-			CPListElement elem= elements.get(i);
+		for (CPListElement elem : elements) {
 			IPath[] exclusionPatterns= (IPath[]) elem.getAttribute(CPListElement.EXCLUSION);
 			IPath[] inclusionPatterns= (IPath[]) elem.getAttribute(CPListElement.INCLUSION);
 			IPath output= (IPath) elem.getAttribute(CPListElement.OUTPUT);
@@ -256,14 +246,6 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 		return composite;
 	}
 
-	private Shell getShell() {
-		if (fSWTControl != null) {
-			return fSWTControl.getShell();
-		}
-		return JavaPlugin.getActiveWorkbenchShell();
-	}
-
-
 	private class SourceContainerAdapter implements ITreeListAdapter<CPListElement>, IDialogFieldListener {
 
 		private final Object[] EMPTY_ARR= new Object[0];
@@ -428,7 +410,7 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 
 	private void editAttributeEntry(CPListElementAttribute elem) {
 		String key= elem.getKey();
-		if (key.equals(CPListElement.OUTPUT)) {
+		if (CPListElement.OUTPUT.equals(key)) {
 			CPListElement selElement=  elem.getParent();
 			OutputLocationDialog dialog= new OutputLocationDialog(getShell(), selElement, fClassPathList.getElements(), new Path(fOutputLocationField.getText()).makeAbsolute(), true);
 			if (dialog.open() == Window.OK) {
@@ -436,20 +418,20 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 				fFoldersList.refresh();
 				fClassPathList.dialogFieldChanged(); // validate
 			}
-		} else if (key.equals(CPListElement.EXCLUSION) || key.equals(CPListElement.INCLUSION)) {
+		} else if (CPListElement.EXCLUSION.equals(key) || CPListElement.INCLUSION.equals(key)) {
 			EditFilterWizard wizard= newEditFilterWizard(elem.getParent(), fFoldersList.getElements(), fOutputLocationField.getText());
 			OpenBuildPathWizardAction action= new OpenBuildPathWizardAction(wizard);
 			action.run();
-		} else if (key.equals(CPListElement.IGNORE_OPTIONAL_PROBLEMS)) {
+		} else if (CPListElement.IGNORE_OPTIONAL_PROBLEMS.equals(key)) {
 			String newValue= "true".equals(elem.getValue()) ? null : "true"; //$NON-NLS-1$ //$NON-NLS-2$
 			elem.setValue(newValue);
 			fFoldersList.refresh(elem);
-		} else if (key.equals(CPListElement.TEST)) {
+		} else if (CPListElement.TEST.equals(key)) {
 			String newValue= "true".equals(elem.getValue()) ? null : "true"; //$NON-NLS-1$ //$NON-NLS-2$
 			elem.setValue(newValue);
 			fFoldersList.refresh(elem.getParent());
 			fClassPathList.dialogFieldChanged(); // validate
-		} else if (key.equals(CPListElement.WITHOUT_TEST_CODE)) {
+		} else if (CPListElement.WITHOUT_TEST_CODE.equals(key)) {
 			String newValue= "true".equals(elem.getValue()) ? null : "true"; //$NON-NLS-1$ //$NON-NLS-2$
 			elem.setValue(newValue);
 			fFoldersList.refresh(elem.getParent());
@@ -457,6 +439,7 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 			if (editCustomAttribute(getShell(), elem)) {
 				fFoldersList.refresh();
 				fClassPathList.dialogFieldChanged(); // validate
+				checkAttributeEffect(key, fCurrJProject);
 			}
 		}
 	}
@@ -493,7 +476,7 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 				String key= attrib.getKey();
 				if (attrib.isBuiltIn()) {
 					Object value= null;
-					if (key.equals(CPListElement.EXCLUSION) || key.equals(CPListElement.INCLUSION)) {
+					if (CPListElement.EXCLUSION.equals(key) || CPListElement.INCLUSION.equals(key)) {
 						value= new Path[0];
 					}
 					attrib.getParent().setAttribute(key, value);
@@ -507,8 +490,8 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 			fFoldersList.refresh();
 			fClassPathList.dialogFieldChanged(); // validate
 		} else {
-			for (Iterator<Object> iter= selElements.iterator(); iter.hasNext();) {
-				CPListElement element= (CPListElement)iter.next();
+			for (Object object : selElements) {
+				CPListElement element= (CPListElement)object;
 				if (element.getEntryKind() == IClasspathEntry.CPE_SOURCE) {
 					for (CPListElement modified : ClasspathModifier.removeFilters(element.getPath(), fCurrJProject, fFoldersList.getElements())) {
 						fFoldersList.refresh(modified);
@@ -524,17 +507,13 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 		if (selElements.isEmpty()) {
 			return false;
 		}
-		for (int i= 0; i < selElements.size(); i++) {
-			Object elem= selElements.get(i);
+		for (Object elem : selElements) {
 			if (elem instanceof CPListElementAttribute) {
 				CPListElementAttribute attrib= (CPListElementAttribute) elem;
 				String key= attrib.getKey();
 				if (attrib.isBuiltIn()) {
-					if (CPListElement.INCLUSION.equals(key)) {
-						if (((IPath[]) attrib.getValue()).length == 0) {
-							return false;
-						}
-					} else if (CPListElement.EXCLUSION.equals(key)) {
+					if (CPListElement.INCLUSION.equals(key)
+							|| CPListElement.EXCLUSION.equals(key)) {
 						if (((IPath[]) attrib.getValue()).length == 0) {
 							return false;
 						}
@@ -570,9 +549,7 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 		}
 		if (elem instanceof CPListElementAttribute) {
 			CPListElementAttribute attrib= (CPListElementAttribute) elem;
-			if (attrib.isBuiltIn()) {
-				return true;
-			} else if (CPListElement.IGNORE_OPTIONAL_PROBLEMS.equals(attrib.getKey())) {
+			if (attrib.isBuiltIn() || CPListElement.IGNORE_OPTIONAL_PROBLEMS.equals(attrib.getKey())) {
 				return true;
 			} else {
 				return canEditCustomAttribute(attrib);
@@ -650,8 +627,8 @@ public class SourceContainerWorkbookPage extends BuildPathBasePage {
 	public void setSelection(List<?> selElements, boolean expand) {
 		fFoldersList.selectElements(new StructuredSelection(selElements));
 		if (expand) {
-			for (int i= 0; i < selElements.size(); i++) {
-				fFoldersList.expandElement(selElements.get(i), 1);
+			for (Object selElement : selElements) {
+				fFoldersList.expandElement(selElement, 1);
 			}
 		}
 	}
