@@ -15,14 +15,12 @@ package org.eclipse.jdt.internal.ui.wizards.buildpaths.newsourcepage;
 
 import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.swt.widgets.Shell;
 
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.CoreException;
-import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.SubProgressMonitor;
 
 import org.eclipse.core.resources.IFolder;
@@ -150,24 +148,21 @@ public class EditOutputFolderAction extends BuildpathModifierAction {
         	}
 
 			try {
-				final IRunnableWithProgress runnable= new IRunnableWithProgress() {
-					@Override
-					public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
-						try {
-                        	monitor.beginTask(NewWizardMessages.EditOutputFolderAction_ProgressMonitorDescription, 50 + (folderToDelete == null?0:10));
+				final IRunnableWithProgress runnable= monitor -> {
+					try {
+				    	monitor.beginTask(NewWizardMessages.EditOutputFolderAction_ProgressMonitorDescription, 50 + (folderToDelete == null?0:10));
 
-                        	ClasspathModifier.commitClassPath(cpProject, new SubProgressMonitor(monitor, 50));
-                        	if (folderToDelete != null)
-                                folderToDelete.delete(true, new SubProgressMonitor(monitor, 10));
+				    	ClasspathModifier.commitClassPath(cpProject, new SubProgressMonitor(monitor, 50));
+				    	if (folderToDelete != null)
+				            folderToDelete.delete(true, new SubProgressMonitor(monitor, 10));
 
-                        	informListeners(delta);
-                        	selectAndReveal(new StructuredSelection(JavaCore.create(element.getResource())));
-						} catch (CoreException e) {
-							throw new InvocationTargetException(e);
-						} finally {
-                        	monitor.done();
-                        }
-					}
+				    	informListeners(delta);
+				    	selectAndReveal(new StructuredSelection(JavaCore.create(element.getResource())));
+					} catch (CoreException e) {
+						throw new InvocationTargetException(e);
+					} finally {
+				    	monitor.done();
+				    }
 				};
 				fContext.run(false, false, runnable);
 			} catch (final InvocationTargetException e) {
@@ -189,12 +184,12 @@ public class EditOutputFolderAction extends BuildpathModifierAction {
 		}
 	    if (existingFolders.size() > 0) {
 	    	if (existingFolders.size() > 1) {
-	    		String message= "Found more then one existing folders:"; //$NON-NLS-1$
-	    		for (Iterator<IResource> iterator= existingFolders.iterator(); iterator.hasNext();) {
-	                IFolder folder= (IFolder)iterator.next();
-	                message+= "\n" + folder.toString(); //$NON-NLS-1$
+	    		StringBuilder message= new StringBuilder("Found more then one existing folders:"); //$NON-NLS-1$
+	    		for (IResource iResource : existingFolders) {
+	                IFolder folder= (IFolder)iResource;
+	                message.append("\n").append(folder.toString()); //$NON-NLS-1$
 	            }
-	    		Assert.isTrue(false, message);
+	    		Assert.isTrue(false, message.toString());
 	    	}
 	    	return (IFolder)existingFolders.get(0);
 	    }
@@ -233,7 +228,7 @@ public class EditOutputFolderAction extends BuildpathModifierAction {
 				return true;
 			} else if (element instanceof CPListElementAttribute) {
 				CPListElementAttribute attribute= (CPListElementAttribute)element;
-				if (attribute.getKey() != CPListElement.OUTPUT)
+				if (!CPListElement.OUTPUT.equals(attribute.getKey()))
 					return false;
 
 				return true;
