@@ -45,9 +45,7 @@ import org.eclipse.jface.dialogs.Dialog;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.IDialogSettings;
 import org.eclipse.jface.resource.ImageDescriptor;
-import org.eclipse.jface.viewers.CheckStateChangedEvent;
 import org.eclipse.jface.viewers.CheckboxTableViewer;
-import org.eclipse.jface.viewers.ICheckStateListener;
 import org.eclipse.jface.viewers.IStructuredContentProvider;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.LabelProvider;
@@ -102,31 +100,31 @@ public final class ConfigureWorkingSetAssignementAction extends SelectionDispatc
 
 		public GrayedCheckedModelElement[] getChecked() {
 			ArrayList<GrayedCheckedModelElement> result= new ArrayList<>();
-			for (int i= 0; i < fElements.size(); i++) {
-				if (fElements.get(i).isChecked())
-					result.add(fElements.get(i));
+			for (GrayedCheckedModelElement element : fElements) {
+				if (element.isChecked())
+					result.add(element);
 			}
 			return result.toArray(new GrayedCheckedModelElement[result.size()]);
 		}
 
 		public GrayedCheckedModelElement[] getGrayed() {
 			ArrayList<GrayedCheckedModelElement> result= new ArrayList<>();
-			for (int i= 0; i < fElements.size(); i++) {
-				if (fElements.get(i).isGrayed())
-					result.add(fElements.get(i));
+			for (GrayedCheckedModelElement element : fElements) {
+				if (element.isGrayed())
+					result.add(element);
 			}
 			return result.toArray(new GrayedCheckedModelElement[result.size()]);
 		}
 
 		public void selectAll() {
-			for (int i= 0; i < fElements.size(); i++) {
-				fElements.get(i).select();
+			for (GrayedCheckedModelElement fElement : fElements) {
+				fElement.select();
 			}
 		}
 
 		public void deselectAll() {
-			for (int i= 0; i < fElements.size(); i++) {
-				fElements.get(i).deselect();
+			for (GrayedCheckedModelElement fElement : fElements) {
+				fElement.deselect();
 			}
 		}
 
@@ -206,7 +204,7 @@ public final class ConfigureWorkingSetAssignementAction extends SelectionDispatc
 	/**
 	 * Label provider for GrayedCheckedModelElements
 	 */
-	private class GrayedCheckedModelLabelProvider extends LabelProvider {
+	private static class GrayedCheckedModelLabelProvider extends LabelProvider {
 
 		private Map<ImageDescriptor, Image> fIcons;
 
@@ -359,7 +357,7 @@ public final class ConfigureWorkingSetAssignementAction extends SelectionDispatc
 		}
 
 		@Override
-		protected final Control createDialogArea(Composite parent) {
+		protected Control createDialogArea(Composite parent) {
 			Composite composite= (Composite)super.createDialogArea(parent);
 
 			createMessageArea(composite);
@@ -456,18 +454,15 @@ public final class ConfigureWorkingSetAssignementAction extends SelectionDispatc
 		protected CheckboxTableViewer createTableViewer(Composite parent) {
 
 			final CheckboxTableViewer result= CheckboxTableViewer.newCheckList(parent, SWT.BORDER | SWT.MULTI);
-			result.addCheckStateListener(new ICheckStateListener() {
-				@Override
-				public void checkStateChanged(CheckStateChangedEvent event) {
-					GrayedCheckedModelElement element= (GrayedCheckedModelElement)event.getElement();
-					result.setGrayed(element, false);
-					if (event.getChecked()) {
-						element.select();
-					} else {
-						element.deselect();
-					}
-					result.update(element, null);
+			result.addCheckStateListener(event -> {
+				GrayedCheckedModelElement element= (GrayedCheckedModelElement)event.getElement();
+				result.setGrayed(element, false);
+				if (event.getChecked()) {
+					element.select();
+				} else {
+					element.deselect();
 				}
+				result.update(element, null);
 			});
 			GridData data= new GridData(GridData.FILL_BOTH);
 			data.heightHint= convertHeightInCharsToPixels(20);
@@ -581,8 +576,8 @@ public final class ConfigureWorkingSetAssignementAction extends SelectionDispatc
 		@Override
 		protected void cancelPressed() {
 			IWorkingSetManager manager= PlatformUI.getWorkbench().getWorkingSetManager();
-			for (int i= 0; i < fCreatedWorkingSets.size(); i++) {
-				manager.removeWorkingSet(fCreatedWorkingSets.get(i));
+			for (IWorkingSet fCreatedWorkingSet : fCreatedWorkingSets) {
+				manager.removeWorkingSet(fCreatedWorkingSet);
 			}
 
 			super.cancelPressed();
@@ -776,13 +771,7 @@ public final class ConfigureWorkingSetAssignementAction extends SelectionDispatc
 		if (!set.isEditable())
 			return false;
 
-		for (String v : VALID_WORKING_SET_IDS) {
-			if (v.equals(set.getId())) {
-				return true;
-			}
-		}
-
-		return false;
+		return Arrays.asList(VALID_WORKING_SET_IDS).contains(set.getId());
 	}
 
 	private static IAdaptable adapt(IWorkingSet set, IAdaptable element) {
@@ -796,13 +785,7 @@ public final class ConfigureWorkingSetAssignementAction extends SelectionDispatc
 	}
 
 	private static boolean contains(IWorkingSet set, IAdaptable adaptedElement) {
-		for (IAdaptable element : set.getElements()) {
-			if (element.equals(adaptedElement)) {
-				return true;
-			}
-		}
-
-		return false;
+		return Arrays.asList(set.getElements()).contains(adaptedElement);
 	}
 
 	private static void remove(IWorkingSet workingSet, IAdaptable adaptedElement) {
