@@ -15,7 +15,6 @@ package org.eclipse.jdt.internal.ui.workingsets;
 
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.swt.widgets.Shell;
@@ -83,12 +82,7 @@ public class WorkingSetFilterActionGroup extends ActionGroup implements IWorking
 		fSelectWorkingSetAction= new SelectWorkingSetAction(this, site);
 		fEditWorkingSetAction= new EditWorkingSetAction(this, site);
 
-		fWorkingSetListener= new IPropertyChangeListener() {
-			@Override
-			public void propertyChange(PropertyChangeEvent event) {
-				doPropertyChange(event);
-			}
-		};
+		fWorkingSetListener= this::doPropertyChange;
 		fWorkingSetFilter= new WorkingSetFilter();
 
 		IWorkingSetManager manager= PlatformUI.getWorkbench().getWorkingSetManager();
@@ -110,12 +104,7 @@ public class WorkingSetFilterActionGroup extends ActionGroup implements IWorking
 		fSelectWorkingSetAction= new SelectWorkingSetAction(this, shell);
 		fEditWorkingSetAction= new EditWorkingSetAction(this, shell);
 
-		fWorkingSetListener= new IPropertyChangeListener() {
-			@Override
-			public void propertyChange(PropertyChangeEvent event) {
-				doPropertyChange(event);
-			}
-		};
+		fWorkingSetListener= this::doPropertyChange;
 
 		fWorkingSetFilter= new WorkingSetFilter();
 
@@ -233,12 +222,9 @@ public class WorkingSetFilterActionGroup extends ActionGroup implements IWorking
 		add(mm, new Separator(LRU_GROUP));
 
 		fMenuManager= mm;
-		fMenuListener= new IMenuListener() {
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				removePreviousLRUWorkingSetActions(manager);
-				addLRUWorkingSetActions(manager);
-			}
+		fMenuListener= manager -> {
+			removePreviousLRUWorkingSetActions(manager);
+			addLRUWorkingSetActions(manager);
 		};
 		fMenuManager.addMenuListener(fMenuListener);
 	}
@@ -291,8 +277,8 @@ public class WorkingSetFilterActionGroup extends ActionGroup implements IWorking
 
 	@Override
 	public void cleanViewMenu(IMenuManager menuManager) {
-		for (Iterator<IContributionItem> iter= fContributions.iterator(); iter.hasNext();) {
-			IContributionItem removed= menuManager.remove(iter.next());
+		for (IContributionItem iContributionItem : fContributions) {
+			IContributionItem removed= menuManager.remove(iContributionItem);
 			if (removed != null) {
 				removed.dispose();
 			}
