@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 20201 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -11,6 +11,7 @@
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Philippe Ombredanne - bug 149382
+ *     Microsoft Corporation - read formatting options from the compilation unit
  *******************************************************************************/
 package org.eclipse.jdt.ui.actions;
 
@@ -18,7 +19,6 @@ import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
 import java.util.List;
@@ -510,8 +510,7 @@ public class AddGetterSetterAction extends SelectionDispatchAction {
 
 	private static List<IField> reorderFields(List<IField> collection, Set<IField> set) {
 		final List<IField> list= new ArrayList<>(collection.size());
-		for (final Iterator<IField> iterator= set.iterator(); iterator.hasNext();) {
-			final IField field= iterator.next();
+		for (IField field : set) {
 			if (collection.contains(field))
 				list.add(field);
 		}
@@ -558,7 +557,12 @@ public class AddGetterSetterAction extends SelectionDispatchAction {
 			if (element != null) {
 				IType type= (IType) element.getAncestor(IJavaElement.TYPE);
 				if (type != null) {
-					if (type.getFields().length > 0) {
+					if (type.isRecord()) {
+						if (type.getRecordComponents().length > 0) {
+							run(type, new IField[0], true);
+							return;
+						}
+					} else if (type.getFields().length > 0) {
 						run(type, new IField[0], true);
 						return;
 					}
@@ -582,7 +586,7 @@ public class AddGetterSetterAction extends SelectionDispatchAction {
 			target.beginCompoundChange();
 		}
 		try {
-			CodeGenerationSettings settings= JavaPreferencesSettings.getCodeGenerationSettings(cu.getJavaProject());
+			CodeGenerationSettings settings= JavaPreferencesSettings.getCodeGenerationSettings(cu);
 			settings.createComments= fGenerateComment;
 
 			AddGetterSetterOperation op= new AddGetterSetterOperation(type, getterFields, setterFields, getterSetterFields, unit, skipReplaceQuery(), elementPosition, settings, true, false);
@@ -621,19 +625,15 @@ public class AddGetterSetterAction extends SelectionDispatchAction {
 	}
 
 	private IRequestQuery skipReplaceQuery() {
-		return new IRequestQuery() {
-
-			@Override
-			public int doQuery(IMember method) {
-				int[] returnCodes= { IRequestQuery.YES, IRequestQuery.NO, IRequestQuery.YES_ALL, IRequestQuery.CANCEL};
-				String skipLabel= ActionMessages.AddGetterSetterAction_SkipExistingDialog_skip_label;
-				String replaceLabel= ActionMessages.AddGetterSetterAction_SkipExistingDialog_replace_label;
-				String skipAllLabel= ActionMessages.AddGetterSetterAction_SkipExistingDialog_skipAll_label;
-				String[] options= { skipLabel, replaceLabel, skipAllLabel, IDialogConstants.CANCEL_LABEL};
-				String methodName= JavaElementLabels.getElementLabel(method, JavaElementLabels.M_PARAMETER_TYPES);
-				String formattedMessage= Messages.format(ActionMessages.AddGetterSetterAction_SkipExistingDialog_message, BasicElementLabels.getJavaElementName(methodName));
-				return showQueryDialog(formattedMessage, options, returnCodes);
-			}
+		return method -> {
+			int[] returnCodes= { IRequestQuery.YES, IRequestQuery.NO, IRequestQuery.YES_ALL, IRequestQuery.CANCEL};
+			String skipLabel= ActionMessages.AddGetterSetterAction_SkipExistingDialog_skip_label;
+			String replaceLabel= ActionMessages.AddGetterSetterAction_SkipExistingDialog_replace_label;
+			String skipAllLabel= ActionMessages.AddGetterSetterAction_SkipExistingDialog_skipAll_label;
+			String[] options= { skipLabel, replaceLabel, skipAllLabel, IDialogConstants.CANCEL_LABEL};
+			String methodName= JavaElementLabels.getElementLabel(method, JavaElementLabels.M_PARAMETER_TYPES);
+			String formattedMessage= Messages.format(ActionMessages.AddGetterSetterAction_SkipExistingDialog_message, BasicElementLabels.getJavaElementName(methodName));
+			return showQueryDialog(formattedMessage, options, returnCodes);
 		};
 	}
 
@@ -644,14 +644,10 @@ public class AddGetterSetterAction extends SelectionDispatchAction {
 			return IRequestQuery.CANCEL;
 		}
 		final int[] result= { Window.CANCEL};
-		shell.getDisplay().syncExec(new Runnable() {
-
-			@Override
-			public void run() {
-				String title= ActionMessages.AddGetterSetterAction_QueryDialog_title;
-				MessageDialog dialog= new MessageDialog(shell, title, null, message, MessageDialog.QUESTION, buttonLabels, 0);
-				result[0]= dialog.open();
-			}
+		shell.getDisplay().syncExec(() -> {
+			String title= ActionMessages.AddGetterSetterAction_QueryDialog_title;
+			MessageDialog dialog= new MessageDialog(shell, title, null, message, MessageDialog.QUESTION, buttonLabels, 0);
+			result[0]= dialog.open();
 		});
 		int returnVal= result[0];
 		return returnVal < 0 ? IRequestQuery.CANCEL : returnCodes[returnVal];
@@ -773,6 +769,21 @@ public class AddGetterSetterAction extends SelectionDispatchAction {
 					result.put(field, l.toArray(new GetterSetterEntry[l.size()]));
 			}
 		}
+		if (type.isRecord()) {
+			for (IField field : type.getRecordComponents()) {
+				int flags= field.getFlags();
+				if (!Flags.isEnum(flags)) {
+					List<GetterSetterEntry> l= new ArrayList<>(1);
+					if (GetterSetterUtil.getGetter(field) == null) {
+						l.add(new GetterSetterEntry(field, true, Flags.isFinal(flags)));
+						incNumEntries();
+					}
+
+					if (!l.isEmpty())
+						result.put(field, l.toArray(new GetterSetterEntry[l.size()]));
+				}
+			}
+		}
 		return result;
 	}
 
@@ -1041,8 +1052,7 @@ public class AddGetterSetterAction extends SelectionDispatchAction {
 			label.setLayoutData(gd);
 
 			final Combo combo= new Combo(composite, SWT.READ_ONLY);
-			combo.setItems(new String[] { ActionMessages.GetterSetterTreeSelectionDialog_alpha_pair_sort,
-					ActionMessages.GetterSetterTreeSelectionDialog_alpha_method_sort});
+			combo.setItems(ActionMessages.GetterSetterTreeSelectionDialog_alpha_pair_sort, ActionMessages.GetterSetterTreeSelectionDialog_alpha_method_sort);
 			final int methodIndex= 1; // Hard-coded. Change this if the
 			// list gets more complicated.
 			// http://bugs.eclipse.org/bugs/show_bug.cgi?id=38400
