@@ -43,10 +43,8 @@ import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.jface.viewers.ArrayContentProvider;
 import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.LabelProvider;
-import org.eclipse.jface.viewers.SelectionChangedEvent;
 
 import org.eclipse.jface.text.BadLocationException;
 import org.eclipse.jface.text.ITextSelection;
@@ -206,14 +204,11 @@ public class ExternalizeStringsAction extends SelectionDispatchAction {
 	}
 
 	private IRunnableWithProgress createRunnable(final IStructuredSelection selection) {
-		return new IRunnableWithProgress() {
-			@Override
-			public void run(IProgressMonitor pm) throws InvocationTargetException {
-				try {
-					fElements= doRun(selection, pm);
-				} catch (CoreException e) {
-					throw new InvocationTargetException(e);
-				}
+		return pm -> {
+			try {
+				fElements= doRun(selection, pm);
+			} catch (CoreException e) {
+				throw new InvocationTargetException(e);
 			}
 		};
 	}
@@ -414,10 +409,7 @@ public class ExternalizeStringsAction extends SelectionDispatchAction {
 				result+= countNonExternalizedStrings(line);
 			}
 			return result;
-		} catch (InvalidInputException e) {
-			throw new CoreException(new Status(IStatus.ERROR, JavaPlugin.getPluginId(), IStatus.ERROR,
-					Messages.format(ActionMessages.FindStringsToExternalizeAction_error_cannotBeParsed, BasicElementLabels.getFileName(cu)), e));
-		} catch (BadLocationException e) {
+		} catch (InvalidInputException | BadLocationException e) {
 			throw new CoreException(new Status(IStatus.ERROR, JavaPlugin.getPluginId(), IStatus.ERROR, Messages.format(ActionMessages.FindStringsToExternalizeAction_error_cannotBeParsed,
 					BasicElementLabels.getFileName(cu)), e));
 		}
@@ -474,12 +466,9 @@ public class ExternalizeStringsAction extends SelectionDispatchAction {
 		@Override
 		protected Control createDialogArea(Composite parent) {
 			Composite result= (Composite)super.createDialogArea(parent);
-			getTableViewer().addSelectionChangedListener(new ISelectionChangedListener(){
-				@Override
-				public void selectionChanged(SelectionChangedEvent event){
-					if (fOpenButton != null){
-						fOpenButton.setEnabled(! getTableViewer().getSelection().isEmpty());
-					}
+			getTableViewer().addSelectionChangedListener(event -> {
+				if (fOpenButton != null){
+					fOpenButton.setEnabled(! getTableViewer().getSelection().isEmpty());
 				}
 			});
 			getTableViewer().getTable().addSelectionListener(new SelectionAdapter(){
