@@ -35,6 +35,6 @@ public interface ICleanUpFix {
 	 * @return a compilation unit change change which should not be empty
 	 * @throws CoreException if something went wrong while calculating the change
 	 */
-	public CompilationUnitChange createChange(IProgressMonitor progressMonitor) throws CoreException;
+	CompilationUnitChange createChange(IProgressMonitor progressMonitor) throws CoreException;
 
 }
