@@ -19,7 +19,6 @@ import java.util.Arrays;
 import java.util.Map;
 
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.widgets.Shell;
 
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.IAdaptable;
@@ -32,7 +31,6 @@ import org.eclipse.jface.text.AbstractInformationControlManager;
 import org.eclipse.jface.text.DefaultInformationControl;
 import org.eclipse.jface.text.IAutoEditStrategy;
 import org.eclipse.jface.text.IDocument;
-import org.eclipse.jface.text.IInformationControl;
 import org.eclipse.jface.text.IInformationControlCreator;
 import org.eclipse.jface.text.ITextDoubleClickStrategy;
 import org.eclipse.jface.text.ITextHover;
@@ -74,6 +72,7 @@ import org.eclipse.jdt.ui.actions.IJavaEditorActionDefinitionIds;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.javaeditor.EditorUtility;
+import org.eclipse.jdt.internal.ui.javaeditor.JavaSourceViewer;
 import org.eclipse.jdt.internal.ui.text.AbstractJavaScanner;
 import org.eclipse.jdt.internal.ui.text.ContentAssistPreference;
 import org.eclipse.jdt.internal.ui.text.HTMLAnnotationHover;
@@ -86,7 +85,6 @@ import org.eclipse.jdt.internal.ui.text.JavaReconciler;
 import org.eclipse.jdt.internal.ui.text.PreferencesAdapter;
 import org.eclipse.jdt.internal.ui.text.SingleTokenJavaScanner;
 import org.eclipse.jdt.internal.ui.text.correction.JavaCorrectionAssistant;
-import org.eclipse.jdt.internal.ui.text.java.CompletionProposalComputerRegistry;
 import org.eclipse.jdt.internal.ui.text.java.ContentAssistProcessor;
 import org.eclipse.jdt.internal.ui.text.java.JavaAutoIndentStrategy;
 import org.eclipse.jdt.internal.ui.text.java.JavaCodeScanner;
@@ -435,7 +433,7 @@ public class JavaSourceViewerConfiguration extends TextSourceViewerConfiguration
 	public IContentAssistant getContentAssistant(ISourceViewer sourceViewer) {
 
 		if (getEditor() != null) {
-			ContentAssistant assistant= new ContentAssistant(fPreferenceStore.getBoolean(PreferenceConstants.CODEASSIST_NONUITHREAD_COMPUTATION) && !CompletionProposalComputerRegistry.getDefault().computingCompletionRequiresUIThread());
+			ContentAssistant assistant= new ContentAssistant((sourceViewer instanceof JavaSourceViewer) && ((JavaSourceViewer) sourceViewer).isAsyncCompletionActive());
 			assistant.setDocumentPartitioning(getConfiguredDocumentPartitioning(sourceViewer));
 
 			assistant.setRestoreCompletionProposalSize(getSettings("completion_proposal_size")); //$NON-NLS-1$
@@ -461,12 +459,7 @@ public class JavaSourceViewerConfiguration extends TextSourceViewerConfiguration
 			ContentAssistPreference.configure(assistant, fPreferenceStore);
 
 			assistant.setContextInformationPopupOrientation(IContentAssistant.CONTEXT_INFO_ABOVE);
-			assistant.setInformationControlCreator(new IInformationControlCreator() {
-				@Override
-				public IInformationControl createInformationControl(Shell parent) {
-					return new DefaultInformationControl(parent, JavaPlugin.getAdditionalInfoAffordanceString());
-				}
-			});
+			assistant.setInformationControlCreator(parent -> new DefaultInformationControl(parent, JavaPlugin.getAdditionalInfoAffordanceString()));
 
 			return assistant;
 		}
@@ -513,16 +506,25 @@ public class JavaSourceViewerConfiguration extends TextSourceViewerConfiguration
 	@Override
 	public IAutoEditStrategy[] getAutoEditStrategies(ISourceViewer sourceViewer, String contentType) {
 		String partitioning= getConfiguredDocumentPartitioning(sourceViewer);
-		if (IJavaPartitions.JAVA_DOC.equals(contentType) || IJavaPartitions.JAVA_MULTI_LINE_COMMENT.equals(contentType))
-			return new IAutoEditStrategy[] { new JavaDocAutoIndentStrategy(partitioning) };
-		else if (IJavaPartitions.JAVA_STRING.equals(contentType))
-			return new IAutoEditStrategy[] { new SmartSemicolonAutoEditStrategy(partitioning), new JavaStringAutoIndentStrategy(partitioning, EditorUtility.getJavaProject(fTextEditor)) };
-		else if (IJavaPartitions.JAVA_CHARACTER.equals(contentType) || IDocument.DEFAULT_CONTENT_TYPE.equals(contentType))
-			return new IAutoEditStrategy[] { new SmartSemicolonAutoEditStrategy(partitioning), new JavaAutoIndentStrategy(partitioning, EditorUtility.getJavaProject(fTextEditor), sourceViewer) };
-		else if (IJavaPartitions.JAVA_MULTI_LINE_STRING.equals(contentType))
-			return new IAutoEditStrategy[] { new JavaMultiLineStringAutoIndentStrategy(partitioning, EditorUtility.getJavaProject(fTextEditor)) };
-		else
-			return new IAutoEditStrategy[] { new JavaAutoIndentStrategy(partitioning, EditorUtility.getJavaProject(fTextEditor), sourceViewer) };
+
+		if (contentType != null) {
+			switch (contentType) {
+				case IJavaPartitions.JAVA_DOC:
+				case IJavaPartitions.JAVA_MULTI_LINE_COMMENT:
+					return new IAutoEditStrategy[] { new JavaDocAutoIndentStrategy(partitioning) };
+				case IJavaPartitions.JAVA_STRING:
+					return new IAutoEditStrategy[] { new SmartSemicolonAutoEditStrategy(partitioning), new JavaStringAutoIndentStrategy(partitioning, EditorUtility.getJavaProject(fTextEditor)) };
+				case IJavaPartitions.JAVA_CHARACTER:
+				case IDocument.DEFAULT_CONTENT_TYPE:
+					return new IAutoEditStrategy[] { new SmartSemicolonAutoEditStrategy(partitioning), new JavaAutoIndentStrategy(partitioning, EditorUtility.getJavaProject(fTextEditor), sourceViewer) };
+				case IJavaPartitions.JAVA_MULTI_LINE_STRING:
+					return new IAutoEditStrategy[] { new JavaMultiLineStringAutoIndentStrategy(partitioning, EditorUtility.getJavaProject(fTextEditor)) };
+				default:
+					break;
+			}
+		}
+
+		return new IAutoEditStrategy[] { new JavaAutoIndentStrategy(partitioning, EditorUtility.getJavaProject(fTextEditor), sourceViewer) };
 	}
 
 	/*
@@ -530,16 +532,22 @@ public class JavaSourceViewerConfiguration extends TextSourceViewerConfiguration
 	 */
 	@Override
 	public ITextDoubleClickStrategy getDoubleClickStrategy(ISourceViewer sourceViewer, String contentType) {
-		if (IJavaPartitions.JAVA_DOC.equals(contentType))
-			return new JavadocDoubleClickStrategy(getConfiguredDocumentPartitioning(sourceViewer));
-		if (IJavaPartitions.JAVA_SINGLE_LINE_COMMENT.equals(contentType))
-			return new PartitionDoubleClickSelector(getConfiguredDocumentPartitioning(sourceViewer), 0, 0);
-		if (IJavaPartitions.JAVA_MULTI_LINE_COMMENT.equals(contentType))
-			return new PartitionDoubleClickSelector(getConfiguredDocumentPartitioning(sourceViewer), 0, 0);
-		else if (IJavaPartitions.JAVA_STRING.equals(contentType) || IJavaPartitions.JAVA_CHARACTER.equals(contentType))
-			return new PartitionDoubleClickSelector(getConfiguredDocumentPartitioning(sourceViewer), 1, 1);
-		else if (IJavaPartitions.JAVA_MULTI_LINE_STRING.equals(contentType))
-			return new PartitionDoubleClickSelector(getConfiguredDocumentPartitioning(sourceViewer), 3, 3, 3);
+		if (contentType != null) {
+			switch (contentType) {
+				case IJavaPartitions.JAVA_DOC:
+					return new JavadocDoubleClickStrategy(getConfiguredDocumentPartitioning(sourceViewer));
+				case IJavaPartitions.JAVA_SINGLE_LINE_COMMENT:
+				case IJavaPartitions.JAVA_MULTI_LINE_COMMENT:
+					return new PartitionDoubleClickSelector(getConfiguredDocumentPartitioning(sourceViewer), 0, 0);
+				case IJavaPartitions.JAVA_STRING:
+				case IJavaPartitions.JAVA_CHARACTER:
+					return new PartitionDoubleClickSelector(getConfiguredDocumentPartitioning(sourceViewer), 1, 1);
+				case IJavaPartitions.JAVA_MULTI_LINE_STRING:
+					return new PartitionDoubleClickSelector(getConfiguredDocumentPartitioning(sourceViewer), 3, 3, 3);
+				default:
+					break;
+			}
+		}
 		if (fJavaDoubleClickSelector == null) {
 			fJavaDoubleClickSelector= new JavaDoubleClickSelector();
 			fJavaDoubleClickSelector.setSourceVersion(fPreferenceStore.getString(JavaCore.COMPILER_SOURCE));
@@ -758,12 +766,7 @@ public class JavaSourceViewerConfiguration extends TextSourceViewerConfiguration
 	 */
 	@Override
 	public IInformationControlCreator getInformationControlCreator(ISourceViewer sourceViewer) {
-		return new IInformationControlCreator() {
-			@Override
-			public IInformationControl createInformationControl(Shell parent) {
-				return new DefaultInformationControl(parent, false);
-			}
-		};
+		return parent -> new DefaultInformationControl(parent, false);
 	}
 
 	/**
@@ -776,12 +779,7 @@ public class JavaSourceViewerConfiguration extends TextSourceViewerConfiguration
 	 * @since 2.1
 	 */
 	private IInformationControlCreator getInformationPresenterControlCreator(ISourceViewer sourceViewer) {
-		return new IInformationControlCreator() {
-			@Override
-			public IInformationControl createInformationControl(Shell parent) {
-				return new DefaultInformationControl(parent, true);
-			}
-		};
+		return parent -> new DefaultInformationControl(parent, true);
 	}
 
 	/**
@@ -795,24 +793,18 @@ public class JavaSourceViewerConfiguration extends TextSourceViewerConfiguration
 	 * @since 2.1
 	 */
 	private IInformationControlCreator getOutlinePresenterControlCreator(ISourceViewer sourceViewer, final String commandId) {
-		return new IInformationControlCreator() {
-			@Override
-			public IInformationControl createInformationControl(Shell parent) {
-				int shellStyle= SWT.RESIZE;
-				int treeStyle= SWT.V_SCROLL | SWT.H_SCROLL;
-				return new JavaOutlineInformationControl(parent, shellStyle, treeStyle, commandId);
-			}
+		return parent -> {
+			int shellStyle= SWT.RESIZE;
+			int treeStyle= SWT.V_SCROLL | SWT.H_SCROLL;
+			return new JavaOutlineInformationControl(parent, shellStyle, treeStyle, commandId);
 		};
 	}
 
 	private IInformationControlCreator getHierarchyPresenterControlCreator() {
-		return new IInformationControlCreator() {
-			@Override
-			public IInformationControl createInformationControl(Shell parent) {
-				int shellStyle= SWT.RESIZE;
-				int treeStyle= SWT.V_SCROLL | SWT.H_SCROLL;
-				return new HierarchyInformationControl(parent, shellStyle, treeStyle);
-			}
+		return parent -> {
+			int shellStyle= SWT.RESIZE;
+			int treeStyle= SWT.V_SCROLL | SWT.H_SCROLL;
+			return new HierarchyInformationControl(parent, shellStyle, treeStyle);
 		};
 	}
 
