@@ -97,25 +97,25 @@ public class DeleteResourceChange extends ResourceChange {
 	@Override
 	public String getName() {
 		IPath path= fResourcePath.makeRelative();
-		String label= Messages.format(
+		StringBuilder label= new StringBuilder(Messages.format(
 				RefactoringCoreMessages.DeleteResourceChange_name,
-				BasicElementLabels.getPathLabel(path, false));
+				BasicElementLabels.getPathLabel(path, false)));
 
 		if (path.segmentCount() == 1) {
 			IResource resource= getResource();
 			if (resource != null) {
 				IPath location= resource.getLocation();
 				if (location != null) {
-					label= label + BasicElementLabels.CONCAT_STRING + BasicElementLabels.getPathLabel(location, true);
+					label.append(BasicElementLabels.CONCAT_STRING).append(BasicElementLabels.getPathLabel(location, true));
 				} else {
 					URI uri= resource.getLocationURI();
 					if (uri != null) {
-						label= label + BasicElementLabels.CONCAT_STRING + BasicElementLabels.getURLPart(uri.toString());
+						label.append(BasicElementLabels.CONCAT_STRING).append(BasicElementLabels.getURLPart(uri.toString()));
 					}
 				}
 			}
 		}
-		return label;
+		return label.toString();
 	}
 
 	@Override
@@ -137,19 +137,16 @@ public class DeleteResourceChange extends ResourceChange {
 
 			// make sure all files inside the resource are saved so restoring works
 			if (resource.isAccessible()) {
-				resource.accept(new IResourceVisitor() {
-					@Override
-					public boolean visit(IResource curr) throws CoreException {
-						try {
-							if (curr instanceof IFile) {
-								// progress is covered outside.
-								saveFileIfNeeded((IFile) curr, new NullProgressMonitor());
-							}
-						} catch (CoreException e) {
-							// ignore
+				resource.accept((IResourceVisitor) curr -> {
+					try {
+						if (curr instanceof IFile) {
+							// progress is covered outside.
+							saveFileIfNeeded((IFile) curr, new NullProgressMonitor());
 						}
-						return true;
+					} catch (CoreException e) {
+						// ignore
 					}
+					return true;
 				}, IResource.DEPTH_INFINITE, false);
 			}
 
